BskyAppStatePref class abstract

A grab bag of state that's specific to the bsky.app program. Third-party apps shouldn't use this.

Available extensions
Annotations
  • @freezed

Constructors

BskyAppStatePref({@Default.new('app.bsky.actor.defs#bskyAppStatePref') String $type, @BskyAppProgressGuideConverter() BskyAppProgressGuide? activeProgressGuide, bool? isBetaUser, List<String>? queuedNudges, @NuxConverter() List<Nux>? nuxs, Map<String, dynamic>? $unknown})
const
factory
BskyAppStatePref.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
activeProgressGuide → BskyAppProgressGuide?
no setterinherited
copyWith → $BskyAppStatePrefCopyWith<BskyAppStatePref>
Create a copy of BskyAppStatePref with the given fields replaced by the non-null parameter values.
no setterinherited
hasActiveProgressGuide → bool

Available on BskyAppStatePref, provided by the BskyAppStatePrefExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotActiveProgressGuide → bool

Available on BskyAppStatePref, provided by the BskyAppStatePrefExtension extension

no setter
isBetaUser → bool?
Indicates if the user is participating in the beta features program.
no setterinherited
isIsBetaUser → bool

Available on BskyAppStatePref, provided by the BskyAppStatePrefExtension extension

no setter
isNotIsBetaUser → bool

Available on BskyAppStatePref, provided by the BskyAppStatePrefExtension extension

no setter
nuxs → List<Nux>?
no setterinherited
queuedNudges → List<String>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_BskyAppStatePref value)) → TResult

Available on BskyAppStatePref, provided by the BskyAppStatePrefPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_BskyAppStatePref value)?) → TResult?

Available on BskyAppStatePref, provided by the BskyAppStatePrefPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_BskyAppStatePref value)?, {required TResult orElse()}) → TResult

Available on BskyAppStatePref, provided by the BskyAppStatePrefPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, BskyAppProgressGuide? activeProgressGuide, bool? isBetaUser, List<String>? queuedNudges, List<Nux>? nuxs, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on BskyAppStatePref, provided by the BskyAppStatePrefPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this BskyAppStatePref to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, BskyAppProgressGuide? activeProgressGuide, bool? isBetaUser, List<String>? queuedNudges, List<Nux>? nuxs, Map<String, dynamic>? $unknown)) → TResult

Available on BskyAppStatePref, provided by the BskyAppStatePrefPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, BskyAppProgressGuide? activeProgressGuide, bool? isBetaUser, List<String>? queuedNudges, List<Nux>? nuxs, Map<String, dynamic>? $unknown)?) → TResult?

Available on BskyAppStatePref, provided by the BskyAppStatePrefPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>