DeclaredAgePref constructor
const
DeclaredAgePref({})
Implementation
@JsonSerializable(includeIfNull: false)
const factory DeclaredAgePref({
@Default('app.bsky.actor.defs#declaredAgePref') String $type,
/// Indicates if the user has declared that they are over 13 years of age.
bool? isOverAge13,
/// Indicates if the user has declared that they are over 16 years of age.
bool? isOverAge16,
/// Indicates if the user has declared that they are over 18 years of age.
bool? isOverAge18,
Map<String, dynamic>? $unknown,
}) = _DeclaredAgePref;