FeedViewPref class abstract

Available extensions
Annotations
  • @freezed

Constructors

FeedViewPref({@Default.new('app.bsky.actor.defs#feedViewPref') String $type, required String feed, bool? hideReplies, @Default.new(true) bool hideRepliesByUnfollowed, int? hideRepliesByLikeCount, bool? hideReposts, bool? hideQuotePosts, Map<String, dynamic>? $unknown})
const
factory
FeedViewPref.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $FeedViewPrefCopyWith<FeedViewPref>
Create a copy of FeedViewPref with the given fields replaced by the non-null parameter values.
no setterinherited
feed → String
The URI of the feed, or an identifier which describes the feed.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasHideRepliesByLikeCount → bool

Available on FeedViewPref, provided by the FeedViewPrefExtension extension

no setter
hasNotHideRepliesByLikeCount → bool

Available on FeedViewPref, provided by the FeedViewPrefExtension extension

no setter
hideQuotePosts → bool?
Hide quote posts in the feed.
no setterinherited
hideReplies → bool?
Hide replies in the feed.
no setterinherited
hideRepliesByLikeCount → int?
Hide replies in the feed if they do not have this number of likes.
no setterinherited
hideRepliesByUnfollowed → bool
Hide replies in the feed if they are not by followed users.
no setterinherited
hideReposts → bool?
Hide reposts in the feed.
no setterinherited
isHideQuotePosts → bool

Available on FeedViewPref, provided by the FeedViewPrefExtension extension

no setter
isHideReplies → bool

Available on FeedViewPref, provided by the FeedViewPrefExtension extension

no setter
isHideRepliesByUnfollowed → bool

Available on FeedViewPref, provided by the FeedViewPrefExtension extension

no setter
isHideReposts → bool

Available on FeedViewPref, provided by the FeedViewPrefExtension extension

no setter
isNotHideQuotePosts → bool

Available on FeedViewPref, provided by the FeedViewPrefExtension extension

no setter
isNotHideReplies → bool

Available on FeedViewPref, provided by the FeedViewPrefExtension extension

no setter
isNotHideRepliesByUnfollowed → bool

Available on FeedViewPref, provided by the FeedViewPrefExtension extension

no setter
isNotHideReposts → bool

Available on FeedViewPref, provided by the FeedViewPrefExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FeedViewPref value)) → TResult

Available on FeedViewPref, provided by the FeedViewPrefPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedViewPref value)?) → TResult?

Available on FeedViewPref, provided by the FeedViewPrefPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedViewPref value)?, {required TResult orElse()}) → TResult

Available on FeedViewPref, provided by the FeedViewPrefPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String feed, bool? hideReplies, bool hideRepliesByUnfollowed, int? hideRepliesByLikeCount, bool? hideReposts, bool? hideQuotePosts, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedViewPref, provided by the FeedViewPrefPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this FeedViewPref to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String feed, bool? hideReplies, bool hideRepliesByUnfollowed, int? hideRepliesByLikeCount, bool? hideReposts, bool? hideQuotePosts, Map<String, dynamic>? $unknown)) → TResult

Available on FeedViewPref, provided by the FeedViewPrefPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String feed, bool? hideReplies, bool hideRepliesByUnfollowed, int? hideRepliesByLikeCount, bool? hideReposts, bool? hideQuotePosts, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedViewPref, provided by the FeedViewPrefPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>