LiveEventPreferences class abstract

Preferences for live events.

Available extensions
Annotations
  • @freezed

Constructors

LiveEventPreferences({@Default.new('app.bsky.actor.defs#liveEventPreferences') String $type, List<String>? hiddenFeedIds, @Default.new(false) bool hideAllFeeds, Map<String, dynamic>? $unknown})
const
factory
LiveEventPreferences.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $LiveEventPreferencesCopyWith<LiveEventPreferences>
Create a copy of LiveEventPreferences with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hiddenFeedIds → List<String>?
no setterinherited
hideAllFeeds → bool
Whether to hide all feeds from live events.
no setterinherited
isHideAllFeeds → bool

Available on LiveEventPreferences, provided by the LiveEventPreferencesExtension extension

no setter
isNotHideAllFeeds → bool

Available on LiveEventPreferences, provided by the LiveEventPreferencesExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_LiveEventPreferences value)) → TResult

Available on LiveEventPreferences, provided by the LiveEventPreferencesPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_LiveEventPreferences value)?) → TResult?

Available on LiveEventPreferences, provided by the LiveEventPreferencesPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_LiveEventPreferences value)?, {required TResult orElse()}) → TResult

Available on LiveEventPreferences, provided by the LiveEventPreferencesPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, List<String>? hiddenFeedIds, bool hideAllFeeds, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on LiveEventPreferences, provided by the LiveEventPreferencesPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this LiveEventPreferences to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, List<String>? hiddenFeedIds, bool hideAllFeeds, Map<String, dynamic>? $unknown)) → TResult

Available on LiveEventPreferences, provided by the LiveEventPreferencesPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, List<String>? hiddenFeedIds, bool hideAllFeeds, Map<String, dynamic>? $unknown)?) → TResult?

Available on LiveEventPreferences, provided by the LiveEventPreferencesPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>