actorTarget property
Groups of users to apply the muted word to. If undefined, applies to all users.
Implementation
String get value;@MutedWordTargetConverter() List<MutedWordTarget> get targets;/// Groups of users to apply the muted word to. If undefined, applies to all users.
@MutedWordActorTargetConverter() MutedWordActorTarget get actorTarget;