ProfileAssociatedChat class abstract

Available extensions
Annotations
  • @freezed

Constructors

ProfileAssociatedChat({@Default.new('app.bsky.actor.defs#profileAssociatedChat') String $type, @ProfileAssociatedChatAllowIncomingConverter() required ProfileAssociatedChatAllowIncoming allowIncoming, @ProfileAssociatedChatAllowGroupInvitesConverter() ProfileAssociatedChatAllowGroupInvites? allowGroupInvites, Map<String, dynamic>? $unknown})
const
factory
ProfileAssociatedChat.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
allowGroupInvites ProfileAssociatedChatAllowGroupInvites?
no setterinherited
allowIncoming ProfileAssociatedChatAllowIncoming
no setterinherited
copyWith → $ProfileAssociatedChatCopyWith<ProfileAssociatedChat>
Create a copy of ProfileAssociatedChat with the given fields replaced by the non-null parameter values.
no setterinherited
hasAllowGroupInvites bool

Available on ProfileAssociatedChat, provided by the ProfileAssociatedChatExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotAllowGroupInvites bool

Available on ProfileAssociatedChat, provided by the ProfileAssociatedChatExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ProfileAssociatedChat value)) → TResult

Available on ProfileAssociatedChat, provided by the ProfileAssociatedChatPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ProfileAssociatedChat value)?) → TResult?

Available on ProfileAssociatedChat, provided by the ProfileAssociatedChatPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ProfileAssociatedChat value)?, {required TResult orElse()}) → TResult

Available on ProfileAssociatedChat, provided by the ProfileAssociatedChatPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, ProfileAssociatedChatAllowIncoming allowIncoming, ProfileAssociatedChatAllowGroupInvites? allowGroupInvites, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ProfileAssociatedChat, provided by the ProfileAssociatedChatPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ProfileAssociatedChat to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, ProfileAssociatedChatAllowIncoming allowIncoming, ProfileAssociatedChatAllowGroupInvites? allowGroupInvites, Map<String, dynamic>? $unknown)) → TResult

Available on ProfileAssociatedChat, provided by the ProfileAssociatedChatPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, ProfileAssociatedChatAllowIncoming allowIncoming, ProfileAssociatedChatAllowGroupInvites? allowGroupInvites, Map<String, dynamic>? $unknown)?) → TResult?

Available on ProfileAssociatedChat, provided by the ProfileAssociatedChatPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>