ProfileAssociatedChatAllowGroupInvites class abstract

Available extensions
Annotations
  • @freezed

Properties

data Object
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isKnownValue bool

Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesExtension extension

no setter
isNotKnownValue bool

Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesExtension extension

no setter
isNotUnknown bool

Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesExtension extension

no setter
isUnknown bool

Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesExtension extension

no setter
knownValue KnownProfileAssociatedChatAllowGroupInvites?

Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknown String?

Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult knownValue(ProfileAssociatedChatAllowGroupInvitesKnownValue value), required TResult unknown(ProfileAssociatedChatAllowGroupInvitesUnknown value)}) → TResult

Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(ProfileAssociatedChatAllowGroupInvitesKnownValue value)?, TResult? unknown(ProfileAssociatedChatAllowGroupInvitesUnknown value)?}) → TResult?

Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(ProfileAssociatedChatAllowGroupInvitesKnownValue value)?, TResult unknown(ProfileAssociatedChatAllowGroupInvitesUnknown value)?, required TResult orElse()}) → TResult

Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownProfileAssociatedChatAllowGroupInvites data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult knownValue(KnownProfileAssociatedChatAllowGroupInvites data), required TResult unknown(String data)}) → TResult

Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownProfileAssociatedChatAllowGroupInvites data)?, TResult? unknown(String data)?}) → TResult?

Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited