ProfileAssociatedGermShowButtonToPatterns extension

Adds pattern-matching-related methods to ProfileAssociatedGermShowButtonTo.

on

Methods

map<TResult extends Object?>({required TResult knownValue(ProfileAssociatedGermShowButtonToKnownValue value), required TResult unknown(ProfileAssociatedGermShowButtonToUnknown value)}) → TResult

Available on ProfileAssociatedGermShowButtonTo, provided by the ProfileAssociatedGermShowButtonToPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(ProfileAssociatedGermShowButtonToKnownValue value)?, TResult? unknown(ProfileAssociatedGermShowButtonToUnknown value)?}) → TResult?

Available on ProfileAssociatedGermShowButtonTo, provided by the ProfileAssociatedGermShowButtonToPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(ProfileAssociatedGermShowButtonToKnownValue value)?, TResult unknown(ProfileAssociatedGermShowButtonToUnknown value)?, required TResult orElse()}) → TResult

Available on ProfileAssociatedGermShowButtonTo, provided by the ProfileAssociatedGermShowButtonToPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownProfileAssociatedGermShowButtonTo data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on ProfileAssociatedGermShowButtonTo, provided by the ProfileAssociatedGermShowButtonToPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult knownValue(KnownProfileAssociatedGermShowButtonTo data), required TResult unknown(String data)}) → TResult

Available on ProfileAssociatedGermShowButtonTo, provided by the ProfileAssociatedGermShowButtonToPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownProfileAssociatedGermShowButtonTo data)?, TResult? unknown(String data)?}) → TResult?

Available on ProfileAssociatedGermShowButtonTo, provided by the ProfileAssociatedGermShowButtonToPatterns extension

A variant of when that fallback to returning null