StatusView class abstract

Available extensions
Annotations
  • @freezed

Constructors

StatusView({@Default.new('app.bsky.actor.defs#statusView') String $type, @AtUriConverter.new() AtUri? uri, String? cid, @StatusViewStatusConverter() required StatusViewStatus status, required Map<String, dynamic> record, @UStatusViewEmbedConverter() UStatusViewEmbed? embed, @LabelConverter() List<Label>? labels, @JsonKey.new(toJson: iso8601) DateTime? expiresAt, bool? isActive, bool? isDisabled, Map<String, dynamic>? $unknown})
const
factory
StatusView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
cid → String?
no setterinherited
copyWith → $StatusViewCopyWith<StatusView>
Create a copy of StatusView with the given fields replaced by the non-null parameter values.
no setterinherited
embed → UStatusViewEmbed?
no setterinherited
expiresAt → DateTime?
The date when this status will expire. The application might choose to no longer return the status after expiration.
no setterinherited
hasCid → bool

Available on StatusView, provided by the StatusViewExtension extension

no setter
hasEmbed → bool

Available on StatusView, provided by the StatusViewExtension extension

no setter
hasExpiresAt → bool

Available on StatusView, provided by the StatusViewExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotCid → bool

Available on StatusView, provided by the StatusViewExtension extension

no setter
hasNotEmbed → bool

Available on StatusView, provided by the StatusViewExtension extension

no setter
hasNotExpiresAt → bool

Available on StatusView, provided by the StatusViewExtension extension

no setter
hasNotUri → bool

Available on StatusView, provided by the StatusViewExtension extension

no setter
hasUri → bool

Available on StatusView, provided by the StatusViewExtension extension

no setter
isActive → bool?
True if the status is not expired, false if it is expired. Only present if expiration was set.
no setterinherited
isDisabled → bool?
True if the user's go-live access has been disabled by a moderator, false otherwise.
no setterinherited
isIsActive → bool

Available on StatusView, provided by the StatusViewExtension extension

no setter
isIsDisabled → bool

Available on StatusView, provided by the StatusViewExtension extension

no setter
isNotIsActive → bool

Available on StatusView, provided by the StatusViewExtension extension

no setter
isNotIsDisabled → bool

Available on StatusView, provided by the StatusViewExtension extension

no setter
labels → List<Label>?
no setterinherited
record → Map<String, dynamic>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → StatusViewStatus
The status for the account.
no setterinherited
uri → AtUri?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_StatusView value)) → TResult

Available on StatusView, provided by the StatusViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_StatusView value)?) → TResult?

Available on StatusView, provided by the StatusViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_StatusView value)?, {required TResult orElse()}) → TResult

Available on StatusView, provided by the StatusViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, AtUri? uri, String? cid, StatusViewStatus status, Map<String, dynamic> record, UStatusViewEmbed? embed, List<Label>? labels, DateTime? expiresAt, bool? isActive, bool? isDisabled, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on StatusView, provided by the StatusViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this StatusView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, AtUri? uri, String? cid, StatusViewStatus status, Map<String, dynamic> record, UStatusViewEmbed? embed, List<Label>? labels, DateTime? expiresAt, bool? isActive, bool? isDisabled, Map<String, dynamic>? $unknown)) → TResult

Available on StatusView, provided by the StatusViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, AtUri? uri, String? cid, StatusViewStatus status, Map<String, dynamic> record, UStatusViewEmbed? embed, List<Label>? labels, DateTime? expiresAt, bool? isActive, bool? isDisabled, Map<String, dynamic>? $unknown)?) → TResult?

Available on StatusView, provided by the StatusViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>