expiresAt property

  1. @JsonKey.new(toJson: iso8601)
DateTime? get expiresAt
inherited

The date when this status will expire. The application might choose to no longer return the status after expiration.

Implementation

@StatusViewStatusConverter() StatusViewStatus get status; Map<String, dynamic> get record;@UStatusViewEmbedConverter() UStatusViewEmbed? get embed;@LabelConverter() List<Label>? get labels;/// The date when this status will expire. The application might choose to no longer return the status after expiration.
@JsonKey(toJson: iso8601) DateTime? get expiresAt;