isDisabled property

bool? get isDisabled
inherited

True if the user's go-live access has been disabled by a moderator, false otherwise.

Implementation

bool? get isActive;/// True if the user's go-live access has been disabled by a moderator, false otherwise.
bool? get isDisabled;