VerificationPrefs class abstract

Preferences for how verified accounts appear in the app.

Available extensions
Annotations
  • @freezed

Constructors

VerificationPrefs({@Default.new('app.bsky.actor.defs#verificationPrefs') String $type, @Default.new(false) bool hideBadges, Map<String, dynamic>? $unknown})
const
factory
VerificationPrefs.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $VerificationPrefsCopyWith<VerificationPrefs>
Create a copy of VerificationPrefs with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hideBadges → bool
Hide the blue check badges for verified accounts and trusted verifiers.
no setterinherited
isHideBadges → bool

Available on VerificationPrefs, provided by the VerificationPrefsExtension extension

no setter
isNotHideBadges → bool

Available on VerificationPrefs, provided by the VerificationPrefsExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_VerificationPrefs value)) → TResult

Available on VerificationPrefs, provided by the VerificationPrefsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VerificationPrefs value)?) → TResult?

Available on VerificationPrefs, provided by the VerificationPrefsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VerificationPrefs value)?, {required TResult orElse()}) → TResult

Available on VerificationPrefs, provided by the VerificationPrefsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, bool hideBadges, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on VerificationPrefs, provided by the VerificationPrefsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this VerificationPrefs to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, bool hideBadges, Map<String, dynamic>? $unknown)) → TResult

Available on VerificationPrefs, provided by the VerificationPrefsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, bool hideBadges, Map<String, dynamic>? $unknown)?) → TResult?

Available on VerificationPrefs, provided by the VerificationPrefsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>