VerificationView class abstract

An individual verification for an associated subject.

Available extensions
Annotations
  • @freezed

Constructors

VerificationView({@Default.new('app.bsky.actor.defs#verificationView') String $type, required String issuer, String? issuerDisplayName, String? issuerHandle, @AtUriConverter.new() required AtUri uri, required bool isValid, @JsonKey.new(toJson: iso8601) required DateTime createdAt, Map<String, dynamic>? $unknown})
const
factory
VerificationView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $VerificationViewCopyWith<VerificationView>
Create a copy of VerificationView with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
Timestamp when the verification was created.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasIssuerDisplayName → bool

Available on VerificationView, provided by the VerificationViewExtension extension

no setter
hasIssuerHandle → bool

Available on VerificationView, provided by the VerificationViewExtension extension

no setter
hasNotIssuerDisplayName → bool

Available on VerificationView, provided by the VerificationViewExtension extension

no setter
hasNotIssuerHandle → bool

Available on VerificationView, provided by the VerificationViewExtension extension

no setter
isIsValid → bool

Available on VerificationView, provided by the VerificationViewExtension extension

no setter
isNotIsValid → bool

Available on VerificationView, provided by the VerificationViewExtension extension

no setter
issuer → String
The user who issued this verification.
no setterinherited
issuerDisplayName → String?
The display name of the issuer.
no setterinherited
issuerHandle → String?
The handle of the issuer.
no setterinherited
isValid → bool
True if the verification passes validation, otherwise false.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → AtUri
The AT-URI of the verification record.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_VerificationView value)) → TResult

Available on VerificationView, provided by the VerificationViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VerificationView value)?) → TResult?

Available on VerificationView, provided by the VerificationViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VerificationView value)?, {required TResult orElse()}) → TResult

Available on VerificationView, provided by the VerificationViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String issuer, String? issuerDisplayName, String? issuerHandle, AtUri uri, bool isValid, DateTime createdAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on VerificationView, provided by the VerificationViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this VerificationView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String issuer, String? issuerDisplayName, String? issuerHandle, AtUri uri, bool isValid, DateTime createdAt, Map<String, dynamic>? $unknown)) → TResult

Available on VerificationView, provided by the VerificationViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String issuer, String? issuerDisplayName, String? issuerHandle, AtUri uri, bool isValid, DateTime createdAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on VerificationView, provided by the VerificationViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>