ViewerState constructor

const ViewerState({
  1. @Default.new('app.bsky.actor.defs#viewerState') String $type,
  2. bool? muted,
  3. bool? mutedOnlyReposts,
  4. bool? mutedOnlyQuoteposts,
  5. @ListViewBasicConverter() ListViewBasic? mutedByList,
  6. bool? blockedBy,
  7. @AtUriConverter.new() AtUri? blocking,
  8. @ListViewBasicConverter() ListViewBasic? blockingByList,
  9. @AtUriConverter.new() AtUri? following,
  10. @AtUriConverter.new() AtUri? followedBy,
  11. @KnownFollowersConverter() KnownFollowers? knownFollowers,
  12. @ActivitySubscriptionConverter() ActivitySubscription? activitySubscription,
  13. Map<String, dynamic>? $unknown,
})

Implementation

@JsonSerializable(includeIfNull: false)
const factory ViewerState({
  @Default('app.bsky.actor.defs#viewerState') String $type,

  /// Whether the account is fully muted, directly or via a mutelist. False when the mute is scoped to specific kinds; see mutedOnlyReposts and mutedOnlyQuoteposts.
  bool? muted,

  /// Whether the account's reposts are muted. Scoped mutes are exclusive with muted: this can be true while muted is false. If muted is true, this will be false.
  bool? mutedOnlyReposts,

  /// Whether the account's quote posts are muted. Scoped mutes are exclusive with muted: this can be true while muted is false. If muted is true, this will be false.
  bool? mutedOnlyQuoteposts,
  @ListViewBasicConverter() ListViewBasic? mutedByList,
  bool? blockedBy,
  @AtUriConverter() AtUri? blocking,
  @ListViewBasicConverter() ListViewBasic? blockingByList,
  @AtUriConverter() AtUri? following,
  @AtUriConverter() AtUri? followedBy,

  /// This property is present only in selected cases, as an optimization.
  @KnownFollowersConverter() KnownFollowers? knownFollowers,

  /// This property is present only in selected cases, as an optimization.
  @ActivitySubscriptionConverter() ActivitySubscription? activitySubscription,

  Map<String, dynamic>? $unknown,
}) = _ViewerState;