ActorLinkRecordPatterns extension

Adds pattern-matching-related methods to ActorLinkRecord.

on

Methods

map<TResult extends Object?>(TResult $default(_ActorLinkRecord value)) → TResult

Available on ActorLinkRecord, provided by the ActorLinkRecordPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ActorLinkRecord value)?) → TResult?

Available on ActorLinkRecord, provided by the ActorLinkRecordPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ActorLinkRecord value)?, {required TResult orElse()}) → TResult

Available on ActorLinkRecord, provided by the ActorLinkRecordPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String url, String? title, Blob? icon, DateTime createdAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ActorLinkRecord, provided by the ActorLinkRecordPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String $type, String url, String? title, Blob? icon, DateTime createdAt, Map<String, dynamic>? $unknown)) → TResult

Available on ActorLinkRecord, provided by the ActorLinkRecordPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String url, String? title, Blob? icon, DateTime createdAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on ActorLinkRecord, provided by the ActorLinkRecordPatterns extension

A variant of when that fallback to returning null