ActorProfileRecord class abstract

A declaration of a Bluesky account profile.

Available extensions
Annotations
  • @freezed

Constructors

ActorProfileRecord({@Default.new('app.bsky.actor.profile') String $type, String? displayName, String? description, String? pronouns, String? website, @BlobConverter() Blob? avatar, @BlobConverter() Blob? banner, @UActorProfileLabelsConverter() UActorProfileLabels? labels, @RepoStrongRefConverter() RepoStrongRef? joinedViaStarterPack, @RepoStrongRefConverter() RepoStrongRef? pinnedPost, @JsonKey.new(toJson: iso8601) DateTime? createdAt, Map<String, dynamic>? $unknown})
const
factory
ActorProfileRecord.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
avatar → Blob?
Small image to be displayed next to posts from account. AKA, 'profile picture'
no setterinherited
Larger horizontal image to display behind profile view.
no setterinherited
copyWith → $ActorProfileRecordCopyWith<ActorProfileRecord>
Create a copy of ActorProfileRecord with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime?
no setterinherited
description → String?
Free-form profile description text.
no setterinherited
displayName → String?
no setterinherited
hasAvatar → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasBanner → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasCreatedAt → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasDescription → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasDisplayName → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasJoinedViaStarterPack → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasLabels → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasNotAvatar → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasNotBanner → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasNotCreatedAt → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasNotDescription → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasNotDisplayName → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasNotJoinedViaStarterPack → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasNotLabels → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasNotPinnedPost → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasNotPronouns → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasNotWebsite → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasPinnedPost → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasPronouns → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
hasWebsite → bool

Available on ActorProfileRecord, provided by the ActorProfileRecordExtension extension

no setter
joinedViaStarterPack → RepoStrongRef?
no setterinherited
labels → UActorProfileLabels?
no setterinherited
pinnedPost → RepoStrongRef?
no setterinherited
pronouns → String?
Free-form pronouns text.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
website → String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ActorProfileRecord value)) → TResult

Available on ActorProfileRecord, provided by the ActorProfileRecordPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ActorProfileRecord value)?) → TResult?

Available on ActorProfileRecord, provided by the ActorProfileRecordPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ActorProfileRecord value)?, {required TResult orElse()}) → TResult

Available on ActorProfileRecord, provided by the ActorProfileRecordPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String? displayName, String? description, String? pronouns, String? website, Blob? avatar, Blob? banner, UActorProfileLabels? labels, RepoStrongRef? joinedViaStarterPack, RepoStrongRef? pinnedPost, DateTime? createdAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ActorProfileRecord, provided by the ActorProfileRecordPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ActorProfileRecord to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String? displayName, String? description, String? pronouns, String? website, Blob? avatar, Blob? banner, UActorProfileLabels? labels, RepoStrongRef? joinedViaStarterPack, RepoStrongRef? pinnedPost, DateTime? createdAt, Map<String, dynamic>? $unknown)) → TResult

Available on ActorProfileRecord, provided by the ActorProfileRecordPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String? displayName, String? description, String? pronouns, String? website, Blob? avatar, Blob? banner, UActorProfileLabels? labels, RepoStrongRef? joinedViaStarterPack, RepoStrongRef? pinnedPost, DateTime? createdAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on ActorProfileRecord, provided by the ActorProfileRecordPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>