ActorStatusRecord class abstract

A declaration of a Bluesky account status.

Available extensions
Annotations
  • @freezed

Constructors

ActorStatusRecord({@Default.new('app.bsky.actor.status') String $type, @ActorStatusStatusConverter() required ActorStatusStatus status, @UActorStatusEmbedConverter() UActorStatusEmbed? embed, int? durationMinutes, @JsonKey.new(toJson: iso8601) required DateTime createdAt, Map<String, dynamic>? $unknown})
const
factory
ActorStatusRecord.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $ActorStatusRecordCopyWith<ActorStatusRecord>
Create a copy of ActorStatusRecord with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
durationMinutes → int?
The duration of the status in minutes. Applications can choose to impose minimum and maximum limits.
no setterinherited
embed → UActorStatusEmbed?
no setterinherited
hasDurationMinutes → bool

Available on ActorStatusRecord, provided by the ActorStatusRecordExtension extension

no setter
hasEmbed → bool

Available on ActorStatusRecord, provided by the ActorStatusRecordExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotDurationMinutes → bool

Available on ActorStatusRecord, provided by the ActorStatusRecordExtension extension

no setter
hasNotEmbed → bool

Available on ActorStatusRecord, provided by the ActorStatusRecordExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ActorStatusStatus
The status for the account.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ActorStatusRecord value)) → TResult

Available on ActorStatusRecord, provided by the ActorStatusRecordPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ActorStatusRecord value)?) → TResult?

Available on ActorStatusRecord, provided by the ActorStatusRecordPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ActorStatusRecord value)?, {required TResult orElse()}) → TResult

Available on ActorStatusRecord, provided by the ActorStatusRecordPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, ActorStatusStatus status, UActorStatusEmbed? embed, int? durationMinutes, DateTime createdAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ActorStatusRecord, provided by the ActorStatusRecordPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ActorStatusRecord to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, ActorStatusStatus status, UActorStatusEmbed? embed, int? durationMinutes, DateTime createdAt, Map<String, dynamic>? $unknown)) → TResult

Available on ActorStatusRecord, provided by the ActorStatusRecordPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, ActorStatusStatus status, UActorStatusEmbed? embed, int? durationMinutes, DateTime createdAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on ActorStatusRecord, provided by the ActorStatusRecordPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>