KnownActorStatusStatus enum

Inheritance
Implemented types
Available extensions

Values

appBskyActorStatusLive → const KnownActorStatusStatus
const KnownActorStatusStatus('app.bsky.actor.status#live')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
Returns the value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isKnownValue(String value) → bool
valueOf(String? value) → KnownActorStatusStatus?

Constants

values → const List<KnownActorStatusStatus>
A constant List of the values in this enum, in order of their declaration.