State class abstract

The user's computed Age Assurance state.

Available extensions
Annotations
  • @freezed

Constructors

State({@Default.new('app.bsky.ageassurance.defs#state') String $type, DateTime? lastInitiatedAt, @StatusConverter() required Status status, @AccessConverter() required Access access, Map<String, dynamic>? $unknown})
const
factory
State.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
access Access
no setterinherited
copyWith → $StateCopyWith<State>
Create a copy of State with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasLastInitiatedAt bool

Available on State, provided by the StateExtension extension

no setter
hasNotLastInitiatedAt bool

Available on State, provided by the StateExtension extension

no setter
lastInitiatedAt DateTime?
The timestamp when this state was last updated.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status Status
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_State value)) → TResult

Available on State, provided by the StatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_State value)?) → TResult?

Available on State, provided by the StatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_State value)?, {required TResult orElse()}) → TResult

Available on State, provided by the StatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, DateTime? lastInitiatedAt, Status status, Access access, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on State, provided by the StatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this State to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, DateTime? lastInitiatedAt, Status status, Access access, Map<String, dynamic>? $unknown)) → TResult

Available on State, provided by the StatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, DateTime? lastInitiatedAt, Status status, Access access, Map<String, dynamic>? $unknown)?) → TResult?

Available on State, provided by the StatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>