DraftEmbedImage class abstract

Available extensions
Annotations
  • @freezed

Constructors

DraftEmbedImage({@Default.new('app.bsky.draft.defs#draftEmbedImage') String $type, @DraftEmbedLocalRefConverter() required DraftEmbedLocalRef localRef, String? alt, Map<String, dynamic>? $unknown})
const
factory
DraftEmbedImage.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
alt String?
no setterinherited
copyWith → $DraftEmbedImageCopyWith<DraftEmbedImage>
Create a copy of DraftEmbedImage with the given fields replaced by the non-null parameter values.
no setterinherited
hasAlt bool

Available on DraftEmbedImage, provided by the DraftEmbedImageExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotAlt bool

Available on DraftEmbedImage, provided by the DraftEmbedImageExtension extension

no setter
localRef DraftEmbedLocalRef
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_DraftEmbedImage value)) → TResult

Available on DraftEmbedImage, provided by the DraftEmbedImagePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_DraftEmbedImage value)?) → TResult?

Available on DraftEmbedImage, provided by the DraftEmbedImagePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_DraftEmbedImage value)?, {required TResult orElse()}) → TResult

Available on DraftEmbedImage, provided by the DraftEmbedImagePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, DraftEmbedLocalRef localRef, String? alt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on DraftEmbedImage, provided by the DraftEmbedImagePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this DraftEmbedImage to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, DraftEmbedLocalRef localRef, String? alt, Map<String, dynamic>? $unknown)) → TResult

Available on DraftEmbedImage, provided by the DraftEmbedImagePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, DraftEmbedLocalRef localRef, String? alt, Map<String, dynamic>? $unknown)?) → TResult?

Available on DraftEmbedImage, provided by the DraftEmbedImagePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>