DraftView class abstract

View to present drafts data to users.

Available extensions
Annotations
  • @freezed

Constructors

DraftView({@Default.new('app.bsky.draft.defs#draftView') String $type, required String id, @DraftConverter() required Draft draft, required DateTime createdAt, required DateTime updatedAt, Map<String, dynamic>? $unknown})
const
factory
DraftView.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
copyWith → $DraftViewCopyWith<DraftView>
Create a copy of DraftView with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime
The time the draft was created.
no setterinherited
draft Draft
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
A TID to be used as a draft identifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime
The time the draft was last updated.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_DraftView value)) → TResult

Available on DraftView, provided by the DraftViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_DraftView value)?) → TResult?

Available on DraftView, provided by the DraftViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_DraftView value)?, {required TResult orElse()}) → TResult

Available on DraftView, provided by the DraftViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String id, Draft draft, DateTime createdAt, DateTime updatedAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on DraftView, provided by the DraftViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this DraftView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String id, Draft draft, DateTime createdAt, DateTime updatedAt, Map<String, dynamic>? $unknown)) → TResult

Available on DraftView, provided by the DraftViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String id, Draft draft, DateTime createdAt, DateTime updatedAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on DraftView, provided by the DraftViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>