UDraftPostLabels class sealed

Available extensions
Annotations
  • @freezed

Constructors

UDraftPostLabels.selfLabels({required SelfLabels data})
const
factory
UDraftPostLabels.unknown({required Map<String, dynamic> data})
const
factory

Properties

data → Object
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isNotSelfLabels → bool

Available on UDraftPostLabels, provided by the UDraftPostLabelsExtension extension

no setter
isNotUnknown → bool

Available on UDraftPostLabels, provided by the UDraftPostLabelsExtension extension

no setter
isSelfLabels → bool

Available on UDraftPostLabels, provided by the UDraftPostLabelsExtension extension

no setter
isUnknown → bool

Available on UDraftPostLabels, provided by the UDraftPostLabelsExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selfLabels → SelfLabels?

Available on UDraftPostLabels, provided by the UDraftPostLabelsExtension extension

no setter
unknown → Map<String, dynamic>?

Available on UDraftPostLabels, provided by the UDraftPostLabelsExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult selfLabels(UDraftPostLabelsSelfLabels value), required TResult unknown(UDraftPostLabelsUnknown value)}) → TResult

Available on UDraftPostLabels, provided by the UDraftPostLabelsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? selfLabels(UDraftPostLabelsSelfLabels value)?, TResult? unknown(UDraftPostLabelsUnknown value)?}) → TResult?

Available on UDraftPostLabels, provided by the UDraftPostLabelsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult selfLabels(UDraftPostLabelsSelfLabels value)?, TResult unknown(UDraftPostLabelsUnknown value)?, required TResult orElse()}) → TResult

Available on UDraftPostLabels, provided by the UDraftPostLabelsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult selfLabels(SelfLabels data)?, TResult unknown(Map<String, dynamic> data)?, required TResult orElse()}) → TResult

Available on UDraftPostLabels, provided by the UDraftPostLabelsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult selfLabels(SelfLabels data), required TResult unknown(Map<String, dynamic> data)}) → TResult

Available on UDraftPostLabels, provided by the UDraftPostLabelsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? selfLabels(SelfLabels data)?, TResult? unknown(Map<String, dynamic> data)?}) → TResult?

Available on UDraftPostLabels, provided by the UDraftPostLabelsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited