app_bsky_embed_external library

Classes

EmbedExternal
A representation of some externally linked content (eg, a URL and 'card'), embedded in a Bluesky record (eg, a post).
EmbedExternalColorRGB
RGB color definition, inspired by site.standard.theme.color#rgb
EmbedExternalColorRGBConverter
EmbedExternalConverter
EmbedExternalExternal
EmbedExternalExternalConverter
EmbedExternalView
EmbedExternalViewConverter
EmbedExternalViewExternal
EmbedExternalViewExternalConverter
EmbedExternalViewExternalSource
The source of an external embed, such as a standard.site publication.
EmbedExternalViewExternalSourceConverter
EmbedExternalViewExternalSourceTheme
The theme colors of an external source, such as a site.standard.publication. These colors may be used when rendering an embed from that source.
EmbedExternalViewExternalSourceThemeConverter