EmbedExternalViewArticle class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
EmbedExternalViewArticle({@Default.new('app.bsky.embed.external#viewArticle') String $type, required String uri, required String title, required String description, @JsonKey.new(toJson: iso8601) DateTime? createdAt, @JsonKey.new(toJson: iso8601) DateTime? updatedAt, @LabelConverter() List<
Label> ? labels, @RepoStrongRefConverter() List<RepoStrongRef> ? associatedRefs, @ProfileViewBasicConverter() List<ProfileViewBasic> ? associatedProfiles, String? image, @EmbedExternalViewArticlePublicationConverter() EmbedExternalViewArticlePublication? publisher, int? readingTime, int? likeCount, @ProfileViewBasicConverter() List<ProfileViewBasic> ? likers, Map<String, dynamic> ? $unknown}) -
constfactory
-
EmbedExternalViewArticle.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
associatedProfiles
→ List<
ProfileViewBasic> ? -
no setterinherited
-
associatedRefs
→ List<
RepoStrongRef> ? -
no setterinherited
-
copyWith
→ $EmbedExternalViewArticleCopyWith<
EmbedExternalViewArticle> -
Create a copy of EmbedExternalViewArticle
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime?
-
no setterinherited
- description → String
-
no setterinherited
- hasCreatedAt → bool
-
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticleExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasImage → bool
-
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticleExtension extension
no setter - hasLikeCount → bool
-
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticleExtension extension
no setter - hasNotCreatedAt → bool
-
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticleExtension extension
no setter - hasNotImage → bool
-
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticleExtension extension
no setter - hasNotLikeCount → bool
-
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticleExtension extension
no setter - hasNotPublisher → bool
-
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticleExtension extension
no setter - hasNotReadingTime → bool
-
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticleExtension extension
no setter - hasNotUpdatedAt → bool
-
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticleExtension extension
no setter - hasPublisher → bool
-
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticleExtension extension
no setter - hasReadingTime → bool
-
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticleExtension extension
no setter - hasUpdatedAt → bool
-
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticleExtension extension
no setter - image → String?
-
no setterinherited
-
labels
→ List<
Label> ? -
no setterinherited
- likeCount → int?
-
no setterinherited
-
likers
→ List<
ProfileViewBasic> ? -
no setterinherited
- publisher → EmbedExternalViewArticlePublication?
-
no setterinherited
- readingTime → int?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
no setterinherited
- updatedAt → DateTime?
-
no setterinherited
- uri → String
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_EmbedExternalViewArticle value)) → TResult -
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticlePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_EmbedExternalViewArticle value)?) → TResult? -
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticlePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_EmbedExternalViewArticle value)?, {required TResult orElse()}) → TResult -
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticlePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, String uri, String title, String description, DateTime? createdAt, DateTime? updatedAt, List< Label> ? labels, List<RepoStrongRef> ? associatedRefs, List<ProfileViewBasic> ? associatedProfiles, String? image, EmbedExternalViewArticlePublication? publisher, int? readingTime, int? likeCount, List<ProfileViewBasic> ? likers, Map<String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticlePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this EmbedExternalViewArticle to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, String uri, String title, String description, DateTime? createdAt, DateTime? updatedAt, List< Label> ? labels, List<RepoStrongRef> ? associatedRefs, List<ProfileViewBasic> ? associatedProfiles, String? image, EmbedExternalViewArticlePublication? publisher, int? readingTime, int? likeCount, List<ProfileViewBasic> ? likers, Map<String, dynamic> ? $unknown)) → TResult -
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticlePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, String uri, String title, String description, DateTime? createdAt, DateTime? updatedAt, List< Label> ? labels, List<RepoStrongRef> ? associatedRefs, List<ProfileViewBasic> ? associatedProfiles, String? image, EmbedExternalViewArticlePublication? publisher, int? readingTime, int? likeCount, List<ProfileViewBasic> ? likers, Map<String, dynamic> ? $unknown)?) → TResult? -
Available on EmbedExternalViewArticle, provided by the EmbedExternalViewArticlePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>