EmbedExternalViewArticlePublication class abstract

Available extensions
Annotations
  • @freezed

Constructors

EmbedExternalViewArticlePublication({@Default.new('app.bsky.embed.external#viewArticlePublication') String $type, required String uri, required String title, required String description, @JsonKey.new(toJson: iso8601) DateTime? createdAt, @JsonKey.new(toJson: iso8601) DateTime? updatedAt, @LabelConverter() List<Label>? labels, @RepoStrongRefConverter() List<RepoStrongRef>? associatedRefs, @ProfileViewBasicConverter() List<ProfileViewBasic>? associatedProfiles, String? image, @EmbedExternalViewArticlePublicationThemeConverter() EmbedExternalViewArticlePublicationTheme? theme, int? subscriptionCount, @ProfileViewBasicConverter() List<ProfileViewBasic>? subscribers, Map<String, dynamic>? $unknown})
const
factory
EmbedExternalViewArticlePublication.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
associatedProfiles → List<ProfileViewBasic>?
no setterinherited
associatedRefs → List<RepoStrongRef>?
no setterinherited
copyWith → $EmbedExternalViewArticlePublicationCopyWith<EmbedExternalViewArticlePublication>
Create a copy of EmbedExternalViewArticlePublication with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime?
no setterinherited
description → String
no setterinherited
hasCreatedAt → bool

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasImage → bool

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationExtension extension

no setter

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationExtension extension

no setter
hasNotCreatedAt → bool

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationExtension extension

no setter
hasNotImage → bool

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationExtension extension

no setter

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationExtension extension

no setter
hasNotSubscriptionCount → bool

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationExtension extension

no setter
hasNotTheme → bool

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationExtension extension

no setter
hasNotUpdatedAt → bool

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationExtension extension

no setter
hasSubscriptionCount → bool

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationExtension extension

no setter
hasTheme → bool

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationExtension extension

no setter
hasUpdatedAt → bool

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationExtension extension

no setter
image → String?
no setterinherited
labels → List<Label>?
no setterinherited
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscribers → List<ProfileViewBasic>?
no setterinherited
subscriptionCount → int?
no setterinherited
theme → EmbedExternalViewArticlePublicationTheme?
no setterinherited
title → String
no setterinherited
updatedAt → DateTime?
no setterinherited
uri → String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EmbedExternalViewArticlePublication value)) → TResult

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EmbedExternalViewArticlePublication value)?) → TResult?

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EmbedExternalViewArticlePublication value)?, {required TResult orElse()}) → TResult

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String uri, String title, String description, DateTime? createdAt, DateTime? updatedAt, List<Label>? labels, List<RepoStrongRef>? associatedRefs, List<ProfileViewBasic>? associatedProfiles, String? image, EmbedExternalViewArticlePublicationTheme? theme, int? subscriptionCount, List<ProfileViewBasic>? subscribers, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this EmbedExternalViewArticlePublication to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String uri, String title, String description, DateTime? createdAt, DateTime? updatedAt, List<Label>? labels, List<RepoStrongRef>? associatedRefs, List<ProfileViewBasic>? associatedProfiles, String? image, EmbedExternalViewArticlePublicationTheme? theme, int? subscriptionCount, List<ProfileViewBasic>? subscribers, Map<String, dynamic>? $unknown)) → TResult

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String uri, String title, String description, DateTime? createdAt, DateTime? updatedAt, List<Label>? labels, List<RepoStrongRef>? associatedRefs, List<ProfileViewBasic>? associatedProfiles, String? image, EmbedExternalViewArticlePublicationTheme? theme, int? subscriptionCount, List<ProfileViewBasic>? subscribers, Map<String, dynamic>? $unknown)?) → TResult?

Available on EmbedExternalViewArticlePublication, provided by the EmbedExternalViewArticlePublicationPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>