readingTime property

int? get readingTime
inherited

Estimated reading time in minutes, if applicable and available.

Implementation

DateTime? get updatedAt;/// Estimated reading time in minutes, if applicable and available.
int? get readingTime;