EmbedExternalViewExternalSource class abstract

The source of an external embed, such as a standard.site publication.

Available extensions
Annotations
  • @freezed

Constructors

EmbedExternalViewExternalSource({@Default.new('app.bsky.embed.external#viewExternalSource') String $type, required String uri, String? icon, required String title, String? description, @EmbedExternalViewExternalSourceThemeConverter() EmbedExternalViewExternalSourceTheme? theme, Map<String, dynamic>? $unknown})
const
factory
EmbedExternalViewExternalSource.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $EmbedExternalViewExternalSourceCopyWith<EmbedExternalViewExternalSource>
Create a copy of EmbedExternalViewExternalSource with the given fields replaced by the non-null parameter values.
no setterinherited
description → String?
no setterinherited
hasDescription → bool

Available on EmbedExternalViewExternalSource, provided by the EmbedExternalViewExternalSourceExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasIcon → bool

Available on EmbedExternalViewExternalSource, provided by the EmbedExternalViewExternalSourceExtension extension

no setter
hasNotDescription → bool

Available on EmbedExternalViewExternalSource, provided by the EmbedExternalViewExternalSourceExtension extension

no setter
hasNotIcon → bool

Available on EmbedExternalViewExternalSource, provided by the EmbedExternalViewExternalSourceExtension extension

no setter
hasNotTheme → bool

Available on EmbedExternalViewExternalSource, provided by the EmbedExternalViewExternalSourceExtension extension

no setter
hasTheme → bool

Available on EmbedExternalViewExternalSource, provided by the EmbedExternalViewExternalSourceExtension extension

no setter
icon → String?
Fully-qualified URL where an icon representing the source can be fetched. For example, CDN location provided by the App View.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → EmbedExternalViewExternalSourceTheme?
no setterinherited
title → String
no setterinherited
uri → String
URI of the source, if available. Example: the https:// URL of a site.standard.publication record.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EmbedExternalViewExternalSource value)) → TResult

Available on EmbedExternalViewExternalSource, provided by the EmbedExternalViewExternalSourcePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EmbedExternalViewExternalSource value)?) → TResult?

Available on EmbedExternalViewExternalSource, provided by the EmbedExternalViewExternalSourcePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EmbedExternalViewExternalSource value)?, {required TResult orElse()}) → TResult

Available on EmbedExternalViewExternalSource, provided by the EmbedExternalViewExternalSourcePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String uri, String? icon, String title, String? description, EmbedExternalViewExternalSourceTheme? theme, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EmbedExternalViewExternalSource, provided by the EmbedExternalViewExternalSourcePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this EmbedExternalViewExternalSource to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String uri, String? icon, String title, String? description, EmbedExternalViewExternalSourceTheme? theme, Map<String, dynamic>? $unknown)) → TResult

Available on EmbedExternalViewExternalSource, provided by the EmbedExternalViewExternalSourcePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String uri, String? icon, String title, String? description, EmbedExternalViewExternalSourceTheme? theme, Map<String, dynamic>? $unknown)?) → TResult?

Available on EmbedExternalViewExternalSource, provided by the EmbedExternalViewExternalSourcePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>