icon property

String? get icon
inherited

Fully-qualified URL where an icon representing the source can be fetched. For example, CDN location provided by the App View.

Implementation

String get uri;/// Fully-qualified URL where an icon representing the source can be fetched. For example, CDN location provided by the App View.
String? get icon;