EmbedExternalViewExternalSourceTheme class abstract

The theme colors of an external source, such as a site.standard.publication. These colors may be used when rendering an embed from that source.

Available extensions
Annotations
  • @freezed

Constructors

EmbedExternalViewExternalSourceTheme({@Default.new('app.bsky.embed.external#viewExternalSourceTheme') String $type, @EmbedExternalColorRGBConverter() EmbedExternalColorRGB? backgroundRGB, @EmbedExternalColorRGBConverter() EmbedExternalColorRGB? foregroundRGB, @EmbedExternalColorRGBConverter() EmbedExternalColorRGB? accentRGB, @EmbedExternalColorRGBConverter() EmbedExternalColorRGB? accentForegroundRGB, Map<String, dynamic>? $unknown})
const
factory
EmbedExternalViewExternalSourceTheme.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
accentForegroundRGB → EmbedExternalColorRGB?
no setterinherited
accentRGB → EmbedExternalColorRGB?
no setterinherited
backgroundRGB → EmbedExternalColorRGB?
no setterinherited
copyWith → $EmbedExternalViewExternalSourceThemeCopyWith<EmbedExternalViewExternalSourceTheme>
Create a copy of EmbedExternalViewExternalSourceTheme with the given fields replaced by the non-null parameter values.
no setterinherited
foregroundRGB → EmbedExternalColorRGB?
no setterinherited
hasAccentForegroundRGB → bool

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemeExtension extension

no setter
hasAccentRGB → bool

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemeExtension extension

no setter
hasBackgroundRGB → bool

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemeExtension extension

no setter
hasForegroundRGB → bool

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemeExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotAccentForegroundRGB → bool

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemeExtension extension

no setter
hasNotAccentRGB → bool

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemeExtension extension

no setter
hasNotBackgroundRGB → bool

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemeExtension extension

no setter
hasNotForegroundRGB → bool

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemeExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EmbedExternalViewExternalSourceTheme value)) → TResult

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EmbedExternalViewExternalSourceTheme value)?) → TResult?

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EmbedExternalViewExternalSourceTheme value)?, {required TResult orElse()}) → TResult

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, EmbedExternalColorRGB? backgroundRGB, EmbedExternalColorRGB? foregroundRGB, EmbedExternalColorRGB? accentRGB, EmbedExternalColorRGB? accentForegroundRGB, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this EmbedExternalViewExternalSourceTheme to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, EmbedExternalColorRGB? backgroundRGB, EmbedExternalColorRGB? foregroundRGB, EmbedExternalColorRGB? accentRGB, EmbedExternalColorRGB? accentForegroundRGB, Map<String, dynamic>? $unknown)) → TResult

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, EmbedExternalColorRGB? backgroundRGB, EmbedExternalColorRGB? foregroundRGB, EmbedExternalColorRGB? accentRGB, EmbedExternalColorRGB? accentForegroundRGB, Map<String, dynamic>? $unknown)?) → TResult?

Available on EmbedExternalViewExternalSourceTheme, provided by the EmbedExternalViewExternalSourceThemePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>