EmbedExternalViewGalleryImage class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
EmbedExternalViewGalleryImage({@Default.new('app.bsky.embed.external#viewGalleryImage') String $type, required String thumbnail, required String fullsize, String? alt, @AspectRatioConverter() AspectRatio? aspectRatio, Map<
String, dynamic> ? $unknown}) -
constfactory
-
EmbedExternalViewGalleryImage.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
- alt → String?
-
Alt text description of the image, for accessibility.
no setterinherited
- aspectRatio → AspectRatio?
-
no setterinherited
-
copyWith
→ $EmbedExternalViewGalleryImageCopyWith<
EmbedExternalViewGalleryImage> -
Create a copy of EmbedExternalViewGalleryImage
with the given fields replaced by the non-null parameter values.
no setterinherited
- fullsize → String
-
Fully-qualified URL where a large version of the image can be fetched. May or may not be the exact original blob. For example, CDN location provided by the App View.
no setterinherited
- hasAlt → bool
-
Available on EmbedExternalViewGalleryImage, provided by the EmbedExternalViewGalleryImageExtension extension
no setter - hasAspectRatio → bool
-
Available on EmbedExternalViewGalleryImage, provided by the EmbedExternalViewGalleryImageExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotAlt → bool
-
Available on EmbedExternalViewGalleryImage, provided by the EmbedExternalViewGalleryImageExtension extension
no setter - hasNotAspectRatio → bool
-
Available on EmbedExternalViewGalleryImage, provided by the EmbedExternalViewGalleryImageExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbnail → String
-
Fully-qualified URL where a thumbnail of the image can be fetched. For example, CDN location provided by the App View.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_EmbedExternalViewGalleryImage value)) → TResult -
Available on EmbedExternalViewGalleryImage, provided by the EmbedExternalViewGalleryImagePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_EmbedExternalViewGalleryImage value)?) → TResult? -
Available on EmbedExternalViewGalleryImage, provided by the EmbedExternalViewGalleryImagePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_EmbedExternalViewGalleryImage value)?, {required TResult orElse()}) → TResult -
Available on EmbedExternalViewGalleryImage, provided by the EmbedExternalViewGalleryImagePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, String thumbnail, String fullsize, String? alt, AspectRatio? aspectRatio, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on EmbedExternalViewGalleryImage, provided by the EmbedExternalViewGalleryImagePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this EmbedExternalViewGalleryImage to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, String thumbnail, String fullsize, String? alt, AspectRatio? aspectRatio, Map< String, dynamic> ? $unknown)) → TResult -
Available on EmbedExternalViewGalleryImage, provided by the EmbedExternalViewGalleryImagePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, String thumbnail, String fullsize, String? alt, AspectRatio? aspectRatio, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on EmbedExternalViewGalleryImage, provided by the EmbedExternalViewGalleryImagePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>