EmbedExternalViewGalleryImage constructor

const EmbedExternalViewGalleryImage({
  1. @Default.new('app.bsky.embed.external#viewGalleryImage') String $type,
  2. required String thumbnail,
  3. required String fullsize,
  4. String? alt,
  5. @AspectRatioConverter() AspectRatio? aspectRatio,
  6. Map<String, dynamic>? $unknown,
})

Implementation

@JsonSerializable(includeIfNull: false)
const factory EmbedExternalViewGalleryImage({
  @Default('app.bsky.embed.external#viewGalleryImage') String $type,

  /// Fully-qualified URL where a thumbnail of the image can be fetched. For example, CDN location provided by the App View.
  required String thumbnail,

  /// Fully-qualified URL where a large version of the image can be fetched. May or may not be the exact original blob. For example, CDN location provided by the App View.
  required String fullsize,

  /// Alt text description of the image, for accessibility.
  String? alt,
  @AspectRatioConverter() AspectRatio? aspectRatio,

  Map<String, dynamic>? $unknown,
}) = _EmbedExternalViewGalleryImage;