EmbedExternalViewLivestream class abstract

Available extensions
Annotations
  • @freezed

Constructors

EmbedExternalViewLivestream({@Default.new('app.bsky.embed.external#viewLivestream') String $type, required String uri, required String title, required String description, @JsonKey.new(toJson: iso8601) DateTime? createdAt, @JsonKey.new(toJson: iso8601) DateTime? updatedAt, @LabelConverter() List<Label>? labels, @RepoStrongRefConverter() List<RepoStrongRef>? associatedRefs, @ProfileViewBasicConverter() List<ProfileViewBasic>? associatedProfiles, String? image, required bool active, @JsonKey.new(toJson: iso8601) DateTime? startedAt, @JsonKey.new(toJson: iso8601) DateTime? endedAt, Map<String, dynamic>? $unknown})
const
factory
EmbedExternalViewLivestream.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
active → bool
True if the livestream is currently active at the time this view is served, false if it has ended.
no setterinherited
associatedProfiles → List<ProfileViewBasic>?
no setterinherited
associatedRefs → List<RepoStrongRef>?
no setterinherited
copyWith → $EmbedExternalViewLivestreamCopyWith<EmbedExternalViewLivestream>
Create a copy of EmbedExternalViewLivestream with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime?
no setterinherited
description → String
no setterinherited
endedAt → DateTime?
no setterinherited
hasCreatedAt → bool

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamExtension extension

no setter
hasEndedAt → bool

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasImage → bool

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamExtension extension

no setter
hasNotCreatedAt → bool

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamExtension extension

no setter
hasNotEndedAt → bool

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamExtension extension

no setter
hasNotImage → bool

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamExtension extension

no setter
hasNotStartedAt → bool

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamExtension extension

no setter
hasNotUpdatedAt → bool

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamExtension extension

no setter
hasStartedAt → bool

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamExtension extension

no setter
hasUpdatedAt → bool

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamExtension extension

no setter
image → String?
no setterinherited
isActive → bool

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamExtension extension

no setter
isNotActive → bool

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamExtension extension

no setter
labels → List<Label>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startedAt → DateTime?
no setterinherited
title → String
no setterinherited
updatedAt → DateTime?
no setterinherited
uri → String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EmbedExternalViewLivestream value)) → TResult

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EmbedExternalViewLivestream value)?) → TResult?

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EmbedExternalViewLivestream value)?, {required TResult orElse()}) → TResult

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String uri, String title, String description, DateTime? createdAt, DateTime? updatedAt, List<Label>? labels, List<RepoStrongRef>? associatedRefs, List<ProfileViewBasic>? associatedProfiles, String? image, bool active, DateTime? startedAt, DateTime? endedAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this EmbedExternalViewLivestream to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String uri, String title, String description, DateTime? createdAt, DateTime? updatedAt, List<Label>? labels, List<RepoStrongRef>? associatedRefs, List<ProfileViewBasic>? associatedProfiles, String? image, bool active, DateTime? startedAt, DateTime? endedAt, Map<String, dynamic>? $unknown)) → TResult

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String uri, String title, String description, DateTime? createdAt, DateTime? updatedAt, List<Label>? labels, List<RepoStrongRef>? associatedRefs, List<ProfileViewBasic>? associatedProfiles, String? image, bool active, DateTime? startedAt, DateTime? endedAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on EmbedExternalViewLivestream, provided by the EmbedExternalViewLivestreamPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>