active property
True if the livestream is currently active at the time this view is served, false if it has ended.
Implementation
String get $type; String get uri; String get title; String get description;@JsonKey(toJson: iso8601) DateTime? get createdAt;@JsonKey(toJson: iso8601) DateTime? get updatedAt;@LabelConverter() List<Label>? get labels;@RepoStrongRefConverter() List<RepoStrongRef>? get associatedRefs;@ProfileViewBasicConverter() List<ProfileViewBasic>? get associatedProfiles; String? get image;/// True if the livestream is currently active at the time this view is served, false if it has ended.
bool get active;