EmbedGalleryImage class abstract

Available extensions
Annotations
  • @freezed

Constructors

EmbedGalleryImage({@Default.new('app.bsky.embed.gallery#image') String $type, @BlobConverter() required Blob image, required String alt, @AspectRatioConverter() required AspectRatio aspectRatio, Map<String, dynamic>? $unknown})
const
factory
EmbedGalleryImage.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
alt String
Alt text description of the image, for accessibility.
no setterinherited
aspectRatio AspectRatio
no setterinherited
copyWith → $EmbedGalleryImageCopyWith<EmbedGalleryImage>
Create a copy of EmbedGalleryImage with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
image Blob
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EmbedGalleryImage value)) → TResult

Available on EmbedGalleryImage, provided by the EmbedGalleryImagePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EmbedGalleryImage value)?) → TResult?

Available on EmbedGalleryImage, provided by the EmbedGalleryImagePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EmbedGalleryImage value)?, {required TResult orElse()}) → TResult

Available on EmbedGalleryImage, provided by the EmbedGalleryImagePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, Blob image, String alt, AspectRatio aspectRatio, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EmbedGalleryImage, provided by the EmbedGalleryImagePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this EmbedGalleryImage to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, Blob image, String alt, AspectRatio aspectRatio, Map<String, dynamic>? $unknown)) → TResult

Available on EmbedGalleryImage, provided by the EmbedGalleryImagePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, Blob image, String alt, AspectRatio aspectRatio, Map<String, dynamic>? $unknown)?) → TResult?

Available on EmbedGalleryImage, provided by the EmbedGalleryImagePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>