EmbedGetEmbedExternalViewOutput class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
EmbedGetEmbedExternalViewOutput({@EmbedExternalViewConverter() EmbedExternalView? view, @RepoStrongRefConverter() List<
RepoStrongRef> ? associatedRefs, List<Map< ? associatedRecords, Map<String, dynamic> >String, dynamic> ? $unknown}) -
constfactory
-
EmbedGetEmbedExternalViewOutput.fromJson(Map<
String, Object?> json) -
factory
Properties
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
associatedRecords
→ List<
Map< ?String, dynamic> > -
no setterinherited
-
associatedRefs
→ List<
RepoStrongRef> ? -
no setterinherited
-
copyWith
→ $EmbedGetEmbedExternalViewOutputCopyWith<
EmbedGetEmbedExternalViewOutput> -
Create a copy of EmbedGetEmbedExternalViewOutput
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotView → bool
-
Available on EmbedGetEmbedExternalViewOutput, provided by the EmbedGetEmbedExternalViewOutputExtension extension
no setter - hasView → bool
-
Available on EmbedGetEmbedExternalViewOutput, provided by the EmbedGetEmbedExternalViewOutputExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- view → EmbedExternalView?
-
Hydrated view of the embed. Present only when the resolved records back the requested URL and supply enough information to populate the required
viewExternalfields. Omitted alongside the rest of the response when no records resolved or validation failed.no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_EmbedGetEmbedExternalViewOutput value)) → TResult -
Available on EmbedGetEmbedExternalViewOutput, provided by the EmbedGetEmbedExternalViewOutputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_EmbedGetEmbedExternalViewOutput value)?) → TResult? -
Available on EmbedGetEmbedExternalViewOutput, provided by the EmbedGetEmbedExternalViewOutputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_EmbedGetEmbedExternalViewOutput value)?, {required TResult orElse()}) → TResult -
Available on EmbedGetEmbedExternalViewOutput, provided by the EmbedGetEmbedExternalViewOutputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(EmbedExternalView? view, List< RepoStrongRef> ? associatedRefs, List<Map< ? associatedRecords, Map<String, dynamic> >String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on EmbedGetEmbedExternalViewOutput, provided by the EmbedGetEmbedExternalViewOutputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this EmbedGetEmbedExternalViewOutput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(EmbedExternalView? view, List< RepoStrongRef> ? associatedRefs, List<Map< ? associatedRecords, Map<String, dynamic> >String, dynamic> ? $unknown)) → TResult -
Available on EmbedGetEmbedExternalViewOutput, provided by the EmbedGetEmbedExternalViewOutputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(EmbedExternalView? view, List< RepoStrongRef> ? associatedRefs, List<Map< ? associatedRecords, Map<String, dynamic> >String, dynamic> ? $unknown)?) → TResult? -
Available on EmbedGetEmbedExternalViewOutput, provided by the EmbedGetEmbedExternalViewOutputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>