EmbedImagesViewImage class abstract

Available extensions
Annotations
  • @freezed

Constructors

EmbedImagesViewImage({@Default.new('app.bsky.embed.images#viewImage') String $type, required String thumb, required String fullsize, required String alt, @AspectRatioConverter() AspectRatio? aspectRatio, Map<String, dynamic>? $unknown})
const
factory
EmbedImagesViewImage.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
alt → String
Alt text description of the image, for accessibility.
no setterinherited
aspectRatio → AspectRatio?
no setterinherited
copyWith → $EmbedImagesViewImageCopyWith<EmbedImagesViewImage>
Create a copy of EmbedImagesViewImage with the given fields replaced by the non-null parameter values.
no setterinherited
fullsize → String
Fully-qualified URL where a large version of the image can be fetched. May or may not be the exact original blob. For example, CDN location provided by the App View.
no setterinherited
hasAspectRatio → bool

Available on EmbedImagesViewImage, provided by the EmbedImagesViewImageExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotAspectRatio → bool

Available on EmbedImagesViewImage, provided by the EmbedImagesViewImageExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumb → String
Fully-qualified URL where a thumbnail of the image can be fetched. For example, CDN location provided by the App View.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EmbedImagesViewImage value)) → TResult

Available on EmbedImagesViewImage, provided by the EmbedImagesViewImagePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EmbedImagesViewImage value)?) → TResult?

Available on EmbedImagesViewImage, provided by the EmbedImagesViewImagePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EmbedImagesViewImage value)?, {required TResult orElse()}) → TResult

Available on EmbedImagesViewImage, provided by the EmbedImagesViewImagePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String thumb, String fullsize, String alt, AspectRatio? aspectRatio, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EmbedImagesViewImage, provided by the EmbedImagesViewImagePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this EmbedImagesViewImage to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String thumb, String fullsize, String alt, AspectRatio? aspectRatio, Map<String, dynamic>? $unknown)) → TResult

Available on EmbedImagesViewImage, provided by the EmbedImagesViewImagePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String thumb, String fullsize, String alt, AspectRatio? aspectRatio, Map<String, dynamic>? $unknown)?) → TResult?

Available on EmbedImagesViewImage, provided by the EmbedImagesViewImagePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>