EmbedRecordViewBlocked class abstract

Available extensions
Annotations
  • @freezed

Constructors

EmbedRecordViewBlocked({@Default.new('app.bsky.embed.record#viewBlocked') String $type, @AtUriConverter.new() required AtUri uri, required bool blocked, @BlockedAuthorConverter() required BlockedAuthor author, Map<String, dynamic>? $unknown})
const
factory
EmbedRecordViewBlocked.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
author → BlockedAuthor
no setterinherited
blocked → bool
no setterinherited
copyWith → $EmbedRecordViewBlockedCopyWith<EmbedRecordViewBlocked>
Create a copy of EmbedRecordViewBlocked with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isBlocked → bool

Available on EmbedRecordViewBlocked, provided by the EmbedRecordViewBlockedExtension extension

no setter
isNotBlocked → bool

Available on EmbedRecordViewBlocked, provided by the EmbedRecordViewBlockedExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → AtUri
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EmbedRecordViewBlocked value)) → TResult

Available on EmbedRecordViewBlocked, provided by the EmbedRecordViewBlockedPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EmbedRecordViewBlocked value)?) → TResult?

Available on EmbedRecordViewBlocked, provided by the EmbedRecordViewBlockedPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EmbedRecordViewBlocked value)?, {required TResult orElse()}) → TResult

Available on EmbedRecordViewBlocked, provided by the EmbedRecordViewBlockedPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, AtUri uri, bool blocked, BlockedAuthor author, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EmbedRecordViewBlocked, provided by the EmbedRecordViewBlockedPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this EmbedRecordViewBlocked to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, AtUri uri, bool blocked, BlockedAuthor author, Map<String, dynamic>? $unknown)) → TResult

Available on EmbedRecordViewBlocked, provided by the EmbedRecordViewBlockedPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, AtUri uri, bool blocked, BlockedAuthor author, Map<String, dynamic>? $unknown)?) → TResult?

Available on EmbedRecordViewBlocked, provided by the EmbedRecordViewBlockedPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>