EmbedRecordViewRecord class abstract

Available extensions
Annotations
  • @freezed

Constructors

EmbedRecordViewRecord({@Default.new('app.bsky.embed.record#viewRecord') String $type, @AtUriConverter.new() required AtUri uri, required String cid, @ProfileViewBasicConverter() required ProfileViewBasic author, required Map<String, dynamic> value, @LabelConverter() List<Label>? labels, int? replyCount, int? repostCount, int? likeCount, int? quoteCount, @UEmbedRecordViewRecordEmbedsConverter() List<UEmbedRecordViewRecordEmbeds>? embeds, @JsonKey.new(toJson: iso8601) required DateTime indexedAt, Map<String, dynamic>? $unknown})
const
factory
EmbedRecordViewRecord.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
author → ProfileViewBasic
no setterinherited
cid → String
no setterinherited
copyWith → $EmbedRecordViewRecordCopyWith<EmbedRecordViewRecord>
Create a copy of EmbedRecordViewRecord with the given fields replaced by the non-null parameter values.
no setterinherited
embeds → List<UEmbedRecordViewRecordEmbeds>?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasLikeCount → bool

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordExtension extension

no setter
hasNotLikeCount → bool

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordExtension extension

no setter
hasNotQuoteCount → bool

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordExtension extension

no setter
hasNotReplyCount → bool

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordExtension extension

no setter
hasNotRepostCount → bool

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordExtension extension

no setter
hasQuoteCount → bool

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordExtension extension

no setter
hasReplyCount → bool

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordExtension extension

no setter
hasRepostCount → bool

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordExtension extension

no setter
indexedAt → DateTime
no setterinherited
labels → List<Label>?
no setterinherited
likeCount → int?
no setterinherited
quoteCount → int?
no setterinherited
replyCount → int?
no setterinherited
repostCount → int?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → AtUri
no setterinherited
value → Map<String, dynamic>
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EmbedRecordViewRecord value)) → TResult

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EmbedRecordViewRecord value)?) → TResult?

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EmbedRecordViewRecord value)?, {required TResult orElse()}) → TResult

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, AtUri uri, String cid, ProfileViewBasic author, Map<String, dynamic> value, List<Label>? labels, int? replyCount, int? repostCount, int? likeCount, int? quoteCount, List<UEmbedRecordViewRecordEmbeds>? embeds, DateTime indexedAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this EmbedRecordViewRecord to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, AtUri uri, String cid, ProfileViewBasic author, Map<String, dynamic> value, List<Label>? labels, int? replyCount, int? repostCount, int? likeCount, int? quoteCount, List<UEmbedRecordViewRecordEmbeds>? embeds, DateTime indexedAt, Map<String, dynamic>? $unknown)) → TResult

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, AtUri uri, String cid, ProfileViewBasic author, Map<String, dynamic> value, List<Label>? labels, int? replyCount, int? repostCount, int? likeCount, int? quoteCount, List<UEmbedRecordViewRecordEmbeds>? embeds, DateTime indexedAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on EmbedRecordViewRecord, provided by the EmbedRecordViewRecordPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>