opThreadPostIndex property

int? get opThreadPostIndex
inherited

The 1-indexed position of this post within the contiguous OP thread. Only present when this post is part of the OP thread.

Implementation

String get $type;@AtUriConverter() AtUri get uri; String get cid;@ProfileViewBasicConverter() ProfileViewBasic get author; Map<String, dynamic> get value;@LabelConverter() List<Label>? get labels; int? get replyCount; int? get repostCount; int? get likeCount; int? get quoteCount;/// The 1-indexed position of this post within the contiguous OP thread. Only present when this post is part of the OP thread.
int? get opThreadPostIndex;