EmbedVideo class abstract

Available extensions
Annotations
  • @freezed

Constructors

EmbedVideo({@Default.new('app.bsky.embed.video') String $type, @BlobConverter() required Blob video, @EmbedVideoCaptionConverter() List<EmbedVideoCaption>? captions, String? alt, @AspectRatioConverter() AspectRatio? aspectRatio, @EmbedVideoPresentationConverter() EmbedVideoPresentation? presentation, Map<String, dynamic>? $unknown})
const
factory
EmbedVideo.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
alt → String?
Alt text description of the video, for accessibility.
no setterinherited
aspectRatio → AspectRatio?
no setterinherited
captions → List<EmbedVideoCaption>?
no setterinherited
copyWith → $EmbedVideoCopyWith<EmbedVideo>
Create a copy of EmbedVideo with the given fields replaced by the non-null parameter values.
no setterinherited
hasAlt → bool

Available on EmbedVideo, provided by the EmbedVideoExtension extension

no setter
hasAspectRatio → bool

Available on EmbedVideo, provided by the EmbedVideoExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotAlt → bool

Available on EmbedVideo, provided by the EmbedVideoExtension extension

no setter
hasNotAspectRatio → bool

Available on EmbedVideo, provided by the EmbedVideoExtension extension

no setter
hasNotPresentation → bool

Available on EmbedVideo, provided by the EmbedVideoExtension extension

no setter
hasPresentation → bool

Available on EmbedVideo, provided by the EmbedVideoExtension extension

no setter
presentation → EmbedVideoPresentation?
A hint to the client about how to present the video.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
video → Blob
The mp4 video file. May be up to 300mb, formerly limited to 100mb.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EmbedVideo value)) → TResult

Available on EmbedVideo, provided by the EmbedVideoPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EmbedVideo value)?) → TResult?

Available on EmbedVideo, provided by the EmbedVideoPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EmbedVideo value)?, {required TResult orElse()}) → TResult

Available on EmbedVideo, provided by the EmbedVideoPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, Blob video, List<EmbedVideoCaption>? captions, String? alt, AspectRatio? aspectRatio, EmbedVideoPresentation? presentation, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EmbedVideo, provided by the EmbedVideoPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this EmbedVideo to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, Blob video, List<EmbedVideoCaption>? captions, String? alt, AspectRatio? aspectRatio, EmbedVideoPresentation? presentation, Map<String, dynamic>? $unknown)) → TResult

Available on EmbedVideo, provided by the EmbedVideoPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, Blob video, List<EmbedVideoCaption>? captions, String? alt, AspectRatio? aspectRatio, EmbedVideoPresentation? presentation, Map<String, dynamic>? $unknown)?) → TResult?

Available on EmbedVideo, provided by the EmbedVideoPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>