EmbedVideoPresentation class abstract

Available extensions
Annotations
  • @freezed

Constructors

EmbedVideoPresentation.knownValue({required KnownEmbedVideoPresentation data})
const
factory
EmbedVideoPresentation.unknown({required String data})
const
factory

Properties

data Object
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isKnownValue bool

Available on EmbedVideoPresentation, provided by the EmbedVideoPresentationExtension extension

no setter
isNotKnownValue bool

Available on EmbedVideoPresentation, provided by the EmbedVideoPresentationExtension extension

no setter
isNotUnknown bool

Available on EmbedVideoPresentation, provided by the EmbedVideoPresentationExtension extension

no setter
isUnknown bool

Available on EmbedVideoPresentation, provided by the EmbedVideoPresentationExtension extension

no setter
knownValue KnownEmbedVideoPresentation?

Available on EmbedVideoPresentation, provided by the EmbedVideoPresentationExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknown String?

Available on EmbedVideoPresentation, provided by the EmbedVideoPresentationExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult knownValue(EmbedVideoPresentationKnownValue value), required TResult unknown(EmbedVideoPresentationUnknown value)}) → TResult

Available on EmbedVideoPresentation, provided by the EmbedVideoPresentationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(EmbedVideoPresentationKnownValue value)?, TResult? unknown(EmbedVideoPresentationUnknown value)?}) → TResult?

Available on EmbedVideoPresentation, provided by the EmbedVideoPresentationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(EmbedVideoPresentationKnownValue value)?, TResult unknown(EmbedVideoPresentationUnknown value)?, required TResult orElse()}) → TResult

Available on EmbedVideoPresentation, provided by the EmbedVideoPresentationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownEmbedVideoPresentation data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on EmbedVideoPresentation, provided by the EmbedVideoPresentationPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult knownValue(KnownEmbedVideoPresentation data), required TResult unknown(String data)}) → TResult

Available on EmbedVideoPresentation, provided by the EmbedVideoPresentationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownEmbedVideoPresentation data)?, TResult? unknown(String data)?}) → TResult?

Available on EmbedVideoPresentation, provided by the EmbedVideoPresentationPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(String? value) EmbedVideoPresentation?