EmbedVideoView class abstract

Available extensions
Annotations
  • @freezed

Constructors

EmbedVideoView({@Default.new('app.bsky.embed.video#view') String $type, required String cid, required String playlist, String? thumbnail, String? alt, @AspectRatioConverter() AspectRatio? aspectRatio, @EmbedVideoViewPresentationConverter() EmbedVideoViewPresentation? presentation, Map<String, dynamic>? $unknown})
const
factory
EmbedVideoView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
alt → String?
no setterinherited
aspectRatio → AspectRatio?
no setterinherited
cid → String
no setterinherited
copyWith → $EmbedVideoViewCopyWith<EmbedVideoView>
Create a copy of EmbedVideoView with the given fields replaced by the non-null parameter values.
no setterinherited
hasAlt → bool

Available on EmbedVideoView, provided by the EmbedVideoViewExtension extension

no setter
hasAspectRatio → bool

Available on EmbedVideoView, provided by the EmbedVideoViewExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotAlt → bool

Available on EmbedVideoView, provided by the EmbedVideoViewExtension extension

no setter
hasNotAspectRatio → bool

Available on EmbedVideoView, provided by the EmbedVideoViewExtension extension

no setter
hasNotPresentation → bool

Available on EmbedVideoView, provided by the EmbedVideoViewExtension extension

no setter
hasNotThumbnail → bool

Available on EmbedVideoView, provided by the EmbedVideoViewExtension extension

no setter
hasPresentation → bool

Available on EmbedVideoView, provided by the EmbedVideoViewExtension extension

no setter
hasThumbnail → bool

Available on EmbedVideoView, provided by the EmbedVideoViewExtension extension

no setter
playlist → String
no setterinherited
presentation → EmbedVideoViewPresentation?
A hint to the client about how to present the video.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EmbedVideoView value)) → TResult

Available on EmbedVideoView, provided by the EmbedVideoViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EmbedVideoView value)?) → TResult?

Available on EmbedVideoView, provided by the EmbedVideoViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EmbedVideoView value)?, {required TResult orElse()}) → TResult

Available on EmbedVideoView, provided by the EmbedVideoViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String cid, String playlist, String? thumbnail, String? alt, AspectRatio? aspectRatio, EmbedVideoViewPresentation? presentation, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EmbedVideoView, provided by the EmbedVideoViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this EmbedVideoView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String cid, String playlist, String? thumbnail, String? alt, AspectRatio? aspectRatio, EmbedVideoViewPresentation? presentation, Map<String, dynamic>? $unknown)) → TResult

Available on EmbedVideoView, provided by the EmbedVideoViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String cid, String playlist, String? thumbnail, String? alt, AspectRatio? aspectRatio, EmbedVideoViewPresentation? presentation, Map<String, dynamic>? $unknown)?) → TResult?

Available on EmbedVideoView, provided by the EmbedVideoViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>