EmbedVideoViewPresentation class abstract

Available extensions
Annotations
  • @freezed

Constructors

EmbedVideoViewPresentation.knownValue({required KnownEmbedVideoViewPresentation data})
const
factory
EmbedVideoViewPresentation.unknown({required String data})
const
factory

Properties

data Object
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isKnownValue bool

Available on EmbedVideoViewPresentation, provided by the EmbedVideoViewPresentationExtension extension

no setter
isNotKnownValue bool

Available on EmbedVideoViewPresentation, provided by the EmbedVideoViewPresentationExtension extension

no setter
isNotUnknown bool

Available on EmbedVideoViewPresentation, provided by the EmbedVideoViewPresentationExtension extension

no setter
isUnknown bool

Available on EmbedVideoViewPresentation, provided by the EmbedVideoViewPresentationExtension extension

no setter
knownValue KnownEmbedVideoViewPresentation?

Available on EmbedVideoViewPresentation, provided by the EmbedVideoViewPresentationExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknown String?

Available on EmbedVideoViewPresentation, provided by the EmbedVideoViewPresentationExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult knownValue(EmbedVideoViewPresentationKnownValue value), required TResult unknown(EmbedVideoViewPresentationUnknown value)}) → TResult

Available on EmbedVideoViewPresentation, provided by the EmbedVideoViewPresentationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(EmbedVideoViewPresentationKnownValue value)?, TResult? unknown(EmbedVideoViewPresentationUnknown value)?}) → TResult?

Available on EmbedVideoViewPresentation, provided by the EmbedVideoViewPresentationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(EmbedVideoViewPresentationKnownValue value)?, TResult unknown(EmbedVideoViewPresentationUnknown value)?, required TResult orElse()}) → TResult

Available on EmbedVideoViewPresentation, provided by the EmbedVideoViewPresentationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownEmbedVideoViewPresentation data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on EmbedVideoViewPresentation, provided by the EmbedVideoViewPresentationPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult knownValue(KnownEmbedVideoViewPresentation data), required TResult unknown(String data)}) → TResult

Available on EmbedVideoViewPresentation, provided by the EmbedVideoViewPresentationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownEmbedVideoViewPresentation data)?, TResult? unknown(String data)?}) → TResult?

Available on EmbedVideoViewPresentation, provided by the EmbedVideoViewPresentationPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(String? value) EmbedVideoViewPresentation?