FeedViewPost class abstract

Available extensions
Annotations
  • @freezed

Constructors

FeedViewPost({@Default.new('app.bsky.feed.defs#feedViewPost') String $type, @PostViewConverter() required PostView post, @ReplyRefConverter() ReplyRef? reply, int? opThreadPostIndex, int? opThreadPostCount, @UFeedViewPostReasonConverter() UFeedViewPostReason? reason, String? feedContext, String? reqId, Map<String, dynamic>? $unknown})
const
factory
FeedViewPost.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $FeedViewPostCopyWith<FeedViewPost>
Create a copy of FeedViewPost with the given fields replaced by the non-null parameter values.
no setterinherited
feedContext → String?
Context provided by feed generator that may be passed back alongside interactions.
no setterinherited
hasFeedContext → bool

Available on FeedViewPost, provided by the FeedViewPostExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotFeedContext → bool

Available on FeedViewPost, provided by the FeedViewPostExtension extension

no setter
hasNotOpThreadPostCount → bool

Available on FeedViewPost, provided by the FeedViewPostExtension extension

no setter
hasNotOpThreadPostIndex → bool

Available on FeedViewPost, provided by the FeedViewPostExtension extension

no setter
hasNotReason → bool

Available on FeedViewPost, provided by the FeedViewPostExtension extension

no setter
hasNotReply → bool

Available on FeedViewPost, provided by the FeedViewPostExtension extension

no setter
hasNotReqId → bool

Available on FeedViewPost, provided by the FeedViewPostExtension extension

no setter
hasOpThreadPostCount → bool

Available on FeedViewPost, provided by the FeedViewPostExtension extension

no setter
hasOpThreadPostIndex → bool

Available on FeedViewPost, provided by the FeedViewPostExtension extension

no setter
hasReason → bool

Available on FeedViewPost, provided by the FeedViewPostExtension extension

no setter
hasReply → bool

Available on FeedViewPost, provided by the FeedViewPostExtension extension

no setter
hasReqId → bool

Available on FeedViewPost, provided by the FeedViewPostExtension extension

no setter
opThreadPostCount → int?
The total number of posts in the contiguous OP thread that this post belongs to. Only present when this post is part of the OP thread.
no setterinherited
opThreadPostIndex → int?
The 1-indexed position of this post within the contiguous OP thread. Only present when this post is part of the OP thread.
no setterinherited
post → PostView
no setterinherited
reason → UFeedViewPostReason?
no setterinherited
reply → ReplyRef?
no setterinherited
reqId → String?
Unique identifier per request that may be passed back alongside interactions.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FeedViewPost value)) → TResult

Available on FeedViewPost, provided by the FeedViewPostPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedViewPost value)?) → TResult?

Available on FeedViewPost, provided by the FeedViewPostPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedViewPost value)?, {required TResult orElse()}) → TResult

Available on FeedViewPost, provided by the FeedViewPostPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, PostView post, ReplyRef? reply, int? opThreadPostIndex, int? opThreadPostCount, UFeedViewPostReason? reason, String? feedContext, String? reqId, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedViewPost, provided by the FeedViewPostPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this FeedViewPost to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, PostView post, ReplyRef? reply, int? opThreadPostIndex, int? opThreadPostCount, UFeedViewPostReason? reason, String? feedContext, String? reqId, Map<String, dynamic>? $unknown)) → TResult

Available on FeedViewPost, provided by the FeedViewPostPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, PostView post, ReplyRef? reply, int? opThreadPostIndex, int? opThreadPostCount, UFeedViewPostReason? reason, String? feedContext, String? reqId, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedViewPost, provided by the FeedViewPostPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>