FeedViewPost constructor

const FeedViewPost({
  1. @Default.new('app.bsky.feed.defs#feedViewPost') String $type,
  2. @PostViewConverter() required PostView post,
  3. @ReplyRefConverter() ReplyRef? reply,
  4. int? opThreadPostIndex,
  5. int? opThreadPostCount,
  6. @UFeedViewPostReasonConverter() UFeedViewPostReason? reason,
  7. String? feedContext,
  8. String? reqId,
  9. Map<String, dynamic>? $unknown,
})

Implementation

@JsonSerializable(includeIfNull: false)
const factory FeedViewPost({
  @Default('app.bsky.feed.defs#feedViewPost') String $type,
  @PostViewConverter() required PostView post,
  @ReplyRefConverter() ReplyRef? reply,

  /// The 1-indexed position of this post within the contiguous OP thread. Only present when this post is part of the OP thread.
  int? opThreadPostIndex,

  /// The total number of posts in the contiguous OP thread that this post belongs to. Only present when this post is part of the OP thread.
  int? opThreadPostCount,
  @UFeedViewPostReasonConverter() UFeedViewPostReason? reason,

  /// Context provided by feed generator that may be passed back alongside interactions.
  String? feedContext,

  /// Unique identifier per request that may be passed back alongside interactions.
  String? reqId,

  Map<String, dynamic>? $unknown,
}) = _FeedViewPost;