GeneratorViewerState class abstract

Available extensions
Annotations
  • @freezed

Constructors

GeneratorViewerState({@Default.new('app.bsky.feed.defs#generatorViewerState') String $type, @AtUriConverter.new() AtUri? like, Map<String, dynamic>? $unknown})
const
factory
GeneratorViewerState.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $GeneratorViewerStateCopyWith<GeneratorViewerState>
Create a copy of GeneratorViewerState with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasLike → bool

Available on GeneratorViewerState, provided by the GeneratorViewerStateExtension extension

no setter
hasNotLike → bool

Available on GeneratorViewerState, provided by the GeneratorViewerStateExtension extension

no setter
like → AtUri?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GeneratorViewerState value)) → TResult

Available on GeneratorViewerState, provided by the GeneratorViewerStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GeneratorViewerState value)?) → TResult?

Available on GeneratorViewerState, provided by the GeneratorViewerStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GeneratorViewerState value)?, {required TResult orElse()}) → TResult

Available on GeneratorViewerState, provided by the GeneratorViewerStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, AtUri? like, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on GeneratorViewerState, provided by the GeneratorViewerStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this GeneratorViewerState to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, AtUri? like, Map<String, dynamic>? $unknown)) → TResult

Available on GeneratorViewerState, provided by the GeneratorViewerStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, AtUri? like, Map<String, dynamic>? $unknown)?) → TResult?

Available on GeneratorViewerState, provided by the GeneratorViewerStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>