Interaction class abstract

Available extensions
Annotations
  • @freezed

Constructors

Interaction({@Default.new('app.bsky.feed.defs#interaction') String $type, @AtUriConverter.new() AtUri? item, @InteractionEventConverter() InteractionEvent? event, String? feedContext, String? reqId, Map<String, dynamic>? $unknown})
const
factory
Interaction.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $InteractionCopyWith<Interaction>
Create a copy of Interaction with the given fields replaced by the non-null parameter values.
no setterinherited
event → InteractionEvent?
no setterinherited
feedContext → String?
Context on a feed item that was originally supplied by the feed generator on getFeedSkeleton.
no setterinherited
hasEvent → bool

Available on Interaction, provided by the InteractionExtension extension

no setter
hasFeedContext → bool

Available on Interaction, provided by the InteractionExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasItem → bool

Available on Interaction, provided by the InteractionExtension extension

no setter
hasNotEvent → bool

Available on Interaction, provided by the InteractionExtension extension

no setter
hasNotFeedContext → bool

Available on Interaction, provided by the InteractionExtension extension

no setter
hasNotItem → bool

Available on Interaction, provided by the InteractionExtension extension

no setter
hasNotReqId → bool

Available on Interaction, provided by the InteractionExtension extension

no setter
hasReqId → bool

Available on Interaction, provided by the InteractionExtension extension

no setter
item → AtUri?
no setterinherited
reqId → String?
Unique identifier per request that may be passed back alongside interactions.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Interaction value)) → TResult

Available on Interaction, provided by the InteractionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Interaction value)?) → TResult?

Available on Interaction, provided by the InteractionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Interaction value)?, {required TResult orElse()}) → TResult

Available on Interaction, provided by the InteractionPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, AtUri? item, InteractionEvent? event, String? feedContext, String? reqId, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on Interaction, provided by the InteractionPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Interaction to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, AtUri? item, InteractionEvent? event, String? feedContext, String? reqId, Map<String, dynamic>? $unknown)) → TResult

Available on Interaction, provided by the InteractionPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, AtUri? item, InteractionEvent? event, String? feedContext, String? reqId, Map<String, dynamic>? $unknown)?) → TResult?

Available on Interaction, provided by the InteractionPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>