Interaction constructor
const
Interaction({
- @Default.new('app.bsky.feed.defs#interaction') String $type,
- @AtUriConverter.new() AtUri? item,
- @InteractionEventConverter() InteractionEvent? event,
- String? feedContext,
- String? reqId,
- Map<
String, dynamic> ? $unknown,
Implementation
@JsonSerializable(includeIfNull: false)
const factory Interaction({
@Default('app.bsky.feed.defs#interaction') String $type,
@AtUriConverter() AtUri? item,
@InteractionEventConverter() InteractionEvent? event,
/// Context on a feed item that was originally supplied by the feed generator on getFeedSkeleton.
String? feedContext,
/// Unique identifier per request that may be passed back alongside interactions.
String? reqId,
Map<String, dynamic>? $unknown,
}) = _Interaction;