PostView class abstract

Available extensions
Annotations
  • @freezed

Constructors

PostView({@Default.new('app.bsky.feed.defs#postView') String $type, @AtUriConverter.new() required AtUri uri, required String cid, @ProfileViewBasicConverter() required ProfileViewBasic author, required Map<String, dynamic> record, @UPostViewEmbedConverter() UPostViewEmbed? embed, int? bookmarkCount, int? replyCount, int? repostCount, int? likeCount, int? quoteCount, @JsonKey.new(toJson: iso8601) required DateTime indexedAt, @ViewerStateConverter() ViewerState? viewer, @LabelConverter() List<Label>? labels, @ThreadgateViewConverter() ThreadgateView? threadgate, Map<String, dynamic>? debug, Map<String, dynamic>? $unknown})
const
factory
PostView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
author → ProfileViewBasic
no setterinherited
bookmarkCount → int?
no setterinherited
cid → String
no setterinherited
copyWith → $PostViewCopyWith<PostView>
Create a copy of PostView with the given fields replaced by the non-null parameter values.
no setterinherited
debug → Map<String, dynamic>?
no setterinherited
embed → UPostViewEmbed?
no setterinherited
hasBookmarkCount → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasDebug → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasEmbed → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasLikeCount → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasNotBookmarkCount → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasNotDebug → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasNotEmbed → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasNotLikeCount → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasNotQuoteCount → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasNotReplyCount → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasNotRepostCount → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasNotThreadgate → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasNotViewer → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasQuoteCount → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasReplyCount → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasRepostCount → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasThreadgate → bool

Available on PostView, provided by the PostViewExtension extension

no setter
hasViewer → bool

Available on PostView, provided by the PostViewExtension extension

no setter
indexedAt → DateTime
no setterinherited
labels → List<Label>?
no setterinherited
likeCount → int?
no setterinherited
quoteCount → int?
no setterinherited
record → Map<String, dynamic>
no setterinherited
replyCount → int?
no setterinherited
repostCount → int?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadgate → ThreadgateView?
no setterinherited
uri → AtUri
no setterinherited
viewer → ViewerState?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PostView value)) → TResult

Available on PostView, provided by the PostViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PostView value)?) → TResult?

Available on PostView, provided by the PostViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PostView value)?, {required TResult orElse()}) → TResult

Available on PostView, provided by the PostViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, AtUri uri, String cid, ProfileViewBasic author, Map<String, dynamic> record, UPostViewEmbed? embed, int? bookmarkCount, int? replyCount, int? repostCount, int? likeCount, int? quoteCount, DateTime indexedAt, ViewerState? viewer, List<Label>? labels, ThreadgateView? threadgate, Map<String, dynamic>? debug, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on PostView, provided by the PostViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this PostView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, AtUri uri, String cid, ProfileViewBasic author, Map<String, dynamic> record, UPostViewEmbed? embed, int? bookmarkCount, int? replyCount, int? repostCount, int? likeCount, int? quoteCount, DateTime indexedAt, ViewerState? viewer, List<Label>? labels, ThreadgateView? threadgate, Map<String, dynamic>? debug, Map<String, dynamic>? $unknown)) → TResult

Available on PostView, provided by the PostViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, AtUri uri, String cid, ProfileViewBasic author, Map<String, dynamic> record, UPostViewEmbed? embed, int? bookmarkCount, int? replyCount, int? repostCount, int? likeCount, int? quoteCount, DateTime indexedAt, ViewerState? viewer, List<Label>? labels, ThreadgateView? threadgate, Map<String, dynamic>? debug, Map<String, dynamic>? $unknown)?) → TResult?

Available on PostView, provided by the PostViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>