ReasonRepost class abstract

Available extensions
Annotations
  • @freezed

Constructors

ReasonRepost({@Default.new('app.bsky.feed.defs#reasonRepost') String $type, @ProfileViewBasicConverter() required ProfileViewBasic by, @AtUriConverter.new() AtUri? uri, String? cid, @JsonKey.new(toJson: iso8601) required DateTime indexedAt, Map<String, dynamic>? $unknown})
const
factory
ReasonRepost.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
by → ProfileViewBasic
no setterinherited
cid → String?
no setterinherited
copyWith → $ReasonRepostCopyWith<ReasonRepost>
Create a copy of ReasonRepost with the given fields replaced by the non-null parameter values.
no setterinherited
hasCid → bool

Available on ReasonRepost, provided by the ReasonRepostExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotCid → bool

Available on ReasonRepost, provided by the ReasonRepostExtension extension

no setter
hasNotUri → bool

Available on ReasonRepost, provided by the ReasonRepostExtension extension

no setter
hasUri → bool

Available on ReasonRepost, provided by the ReasonRepostExtension extension

no setter
indexedAt → DateTime
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → AtUri?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReasonRepost value)) → TResult

Available on ReasonRepost, provided by the ReasonRepostPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReasonRepost value)?) → TResult?

Available on ReasonRepost, provided by the ReasonRepostPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReasonRepost value)?, {required TResult orElse()}) → TResult

Available on ReasonRepost, provided by the ReasonRepostPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, ProfileViewBasic by, AtUri? uri, String? cid, DateTime indexedAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ReasonRepost, provided by the ReasonRepostPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ReasonRepost to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, ProfileViewBasic by, AtUri? uri, String? cid, DateTime indexedAt, Map<String, dynamic>? $unknown)) → TResult

Available on ReasonRepost, provided by the ReasonRepostPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, ProfileViewBasic by, AtUri? uri, String? cid, DateTime indexedAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on ReasonRepost, provided by the ReasonRepostPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>