UThreadViewPostParent class sealed

Available extensions
Annotations
  • @freezed

Constructors

UThreadViewPostParent.blockedPost({required BlockedPost data})
const
factory
UThreadViewPostParent.notFoundPost({required NotFoundPost data})
const
factory
UThreadViewPostParent.threadViewPost({required ThreadViewPost data})
const
factory
UThreadViewPostParent.unknown({required Map<String, dynamic> data})
const
factory

Properties

blockedPost → BlockedPost?

Available on UThreadViewPostParent, provided by the UThreadViewPostParentExtension extension

no setter
data → Object
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isBlockedPost → bool

Available on UThreadViewPostParent, provided by the UThreadViewPostParentExtension extension

no setter
isNotBlockedPost → bool

Available on UThreadViewPostParent, provided by the UThreadViewPostParentExtension extension

no setter
isNotFoundPost → bool

Available on UThreadViewPostParent, provided by the UThreadViewPostParentExtension extension

no setter
isNotNotFoundPost → bool

Available on UThreadViewPostParent, provided by the UThreadViewPostParentExtension extension

no setter
isNotThreadViewPost → bool

Available on UThreadViewPostParent, provided by the UThreadViewPostParentExtension extension

no setter
isNotUnknown → bool

Available on UThreadViewPostParent, provided by the UThreadViewPostParentExtension extension

no setter
isThreadViewPost → bool

Available on UThreadViewPostParent, provided by the UThreadViewPostParentExtension extension

no setter
isUnknown → bool

Available on UThreadViewPostParent, provided by the UThreadViewPostParentExtension extension

no setter
notFoundPost → NotFoundPost?

Available on UThreadViewPostParent, provided by the UThreadViewPostParentExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadViewPost → ThreadViewPost?

Available on UThreadViewPostParent, provided by the UThreadViewPostParentExtension extension

no setter
unknown → Map<String, dynamic>?

Available on UThreadViewPostParent, provided by the UThreadViewPostParentExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult threadViewPost(UThreadViewPostParentThreadViewPost value), required TResult notFoundPost(UThreadViewPostParentNotFoundPost value), required TResult blockedPost(UThreadViewPostParentBlockedPost value), required TResult unknown(UThreadViewPostParentUnknown value)}) → TResult

Available on UThreadViewPostParent, provided by the UThreadViewPostParentPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? threadViewPost(UThreadViewPostParentThreadViewPost value)?, TResult? notFoundPost(UThreadViewPostParentNotFoundPost value)?, TResult? blockedPost(UThreadViewPostParentBlockedPost value)?, TResult? unknown(UThreadViewPostParentUnknown value)?}) → TResult?

Available on UThreadViewPostParent, provided by the UThreadViewPostParentPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult threadViewPost(UThreadViewPostParentThreadViewPost value)?, TResult notFoundPost(UThreadViewPostParentNotFoundPost value)?, TResult blockedPost(UThreadViewPostParentBlockedPost value)?, TResult unknown(UThreadViewPostParentUnknown value)?, required TResult orElse()}) → TResult

Available on UThreadViewPostParent, provided by the UThreadViewPostParentPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult threadViewPost(ThreadViewPost data)?, TResult notFoundPost(NotFoundPost data)?, TResult blockedPost(BlockedPost data)?, TResult unknown(Map<String, dynamic> data)?, required TResult orElse()}) → TResult

Available on UThreadViewPostParent, provided by the UThreadViewPostParentPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult threadViewPost(ThreadViewPost data), required TResult notFoundPost(NotFoundPost data), required TResult blockedPost(BlockedPost data), required TResult unknown(Map<String, dynamic> data)}) → TResult

Available on UThreadViewPostParent, provided by the UThreadViewPostParentPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? threadViewPost(ThreadViewPost data)?, TResult? notFoundPost(NotFoundPost data)?, TResult? blockedPost(BlockedPost data)?, TResult? unknown(Map<String, dynamic> data)?}) → TResult?

Available on UThreadViewPostParent, provided by the UThreadViewPostParentPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited