ViewerState class abstract

Metadata about the requesting account's relationship with the subject content. Only has meaningful content for authed requests.

Available extensions
Annotations
  • @freezed

Constructors

ViewerState({@Default.new('app.bsky.feed.defs#viewerState') String $type, @AtUriConverter.new() AtUri? repost, @AtUriConverter.new() AtUri? like, bool? bookmarked, bool? threadMuted, bool? replyDisabled, bool? embeddingDisabled, bool? pinned, @KnownLikersConverter() KnownLikers? knownLikers, Map<String, dynamic>? $unknown})
const
factory
ViewerState.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
bookmarked → bool?
no setterinherited
copyWith → $ViewerStateCopyWith<ViewerState>
Create a copy of ViewerState with the given fields replaced by the non-null parameter values.
no setterinherited
embeddingDisabled → bool?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasKnownLikers → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
hasLike → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
hasNotKnownLikers → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
hasNotLike → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
hasNotRepost → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
hasRepost → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
isBookmarked → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
isEmbeddingDisabled → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
isNotBookmarked → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
isNotEmbeddingDisabled → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
isNotPinned → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
isNotReplyDisabled → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
isNotThreadMuted → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
isPinned → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
isReplyDisabled → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
isThreadMuted → bool

Available on ViewerState, provided by the ViewerStateExtension extension

no setter
knownLikers → KnownLikers?
This property is present only in selected cases, as an optimization.
no setterinherited
like → AtUri?
no setterinherited
pinned → bool?
no setterinherited
replyDisabled → bool?
no setterinherited
repost → AtUri?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadMuted → bool?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ViewerState value)) → TResult

Available on ViewerState, provided by the ViewerStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ViewerState value)?) → TResult?

Available on ViewerState, provided by the ViewerStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ViewerState value)?, {required TResult orElse()}) → TResult

Available on ViewerState, provided by the ViewerStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, AtUri? repost, AtUri? like, bool? bookmarked, bool? threadMuted, bool? replyDisabled, bool? embeddingDisabled, bool? pinned, KnownLikers? knownLikers, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ViewerState, provided by the ViewerStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ViewerState to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, AtUri? repost, AtUri? like, bool? bookmarked, bool? threadMuted, bool? replyDisabled, bool? embeddingDisabled, bool? pinned, KnownLikers? knownLikers, Map<String, dynamic>? $unknown)) → TResult

Available on ViewerState, provided by the ViewerStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, AtUri? repost, AtUri? like, bool? bookmarked, bool? threadMuted, bool? replyDisabled, bool? embeddingDisabled, bool? pinned, KnownLikers? knownLikers, Map<String, dynamic>? $unknown)?) → TResult?

Available on ViewerState, provided by the ViewerStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>