FeedDescribeFeedGeneratorOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

FeedDescribeFeedGeneratorOutput({required String did, @FeedConverter() required List<Feed> feeds, @LinksConverter() Links? links, Map<String, dynamic>? $unknown})
const
factory
FeedDescribeFeedGeneratorOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
copyWith → $FeedDescribeFeedGeneratorOutputCopyWith<FeedDescribeFeedGeneratorOutput>
Create a copy of FeedDescribeFeedGeneratorOutput with the given fields replaced by the non-null parameter values.
no setterinherited
did String
no setterinherited
feeds List<Feed>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited

Available on FeedDescribeFeedGeneratorOutput, provided by the FeedDescribeFeedGeneratorOutputExtension extension

no setter

Available on FeedDescribeFeedGeneratorOutput, provided by the FeedDescribeFeedGeneratorOutputExtension extension

no setter
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FeedDescribeFeedGeneratorOutput value)) → TResult

Available on FeedDescribeFeedGeneratorOutput, provided by the FeedDescribeFeedGeneratorOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedDescribeFeedGeneratorOutput value)?) → TResult?

Available on FeedDescribeFeedGeneratorOutput, provided by the FeedDescribeFeedGeneratorOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedDescribeFeedGeneratorOutput value)?, {required TResult orElse()}) → TResult

Available on FeedDescribeFeedGeneratorOutput, provided by the FeedDescribeFeedGeneratorOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String did, List<Feed> feeds, Links? links, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedDescribeFeedGeneratorOutput, provided by the FeedDescribeFeedGeneratorOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this FeedDescribeFeedGeneratorOutput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String did, List<Feed> feeds, Links? links, Map<String, dynamic>? $unknown)) → TResult

Available on FeedDescribeFeedGeneratorOutput, provided by the FeedDescribeFeedGeneratorOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String did, List<Feed> feeds, Links? links, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedDescribeFeedGeneratorOutput, provided by the FeedDescribeFeedGeneratorOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>