FeedGeneratorRecord class abstract

Record declaring of the existence of a feed generator, and containing metadata about it. The record can exist in any repository.

Available extensions
Annotations
  • @freezed

Constructors

FeedGeneratorRecord({@Default.new('app.bsky.feed.generator') String $type, required String did, required String displayName, String? description, @RichtextFacetConverter() List<RichtextFacet>? descriptionFacets, @BlobConverter() Blob? avatar, bool? acceptsInteractions, @UFeedGeneratorLabelsConverter() UFeedGeneratorLabels? labels, @FeedGeneratorContentModeConverter() FeedGeneratorContentMode? contentMode, @JsonKey.new(toJson: iso8601) required DateTime createdAt, Map<String, dynamic>? $unknown})
const
factory
FeedGeneratorRecord.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
acceptsInteractions → bool?
Declaration that a feed accepts feedback interactions from a client through app.bsky.feed.sendInteractions
no setterinherited
avatar → Blob?
no setterinherited
contentMode → FeedGeneratorContentMode?
no setterinherited
copyWith → $FeedGeneratorRecordCopyWith<FeedGeneratorRecord>
Create a copy of FeedGeneratorRecord with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
description → String?
no setterinherited
descriptionFacets → List<RichtextFacet>?
no setterinherited
did → String
no setterinherited
displayName → String
no setterinherited
hasAvatar → bool

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordExtension extension

no setter
hasContentMode → bool

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordExtension extension

no setter
hasDescription → bool

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasLabels → bool

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordExtension extension

no setter
hasNotAvatar → bool

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordExtension extension

no setter
hasNotContentMode → bool

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordExtension extension

no setter
hasNotDescription → bool

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordExtension extension

no setter
hasNotLabels → bool

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordExtension extension

no setter
isAcceptsInteractions → bool

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordExtension extension

no setter
isNotAcceptsInteractions → bool

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordExtension extension

no setter
labels → UFeedGeneratorLabels?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FeedGeneratorRecord value)) → TResult

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedGeneratorRecord value)?) → TResult?

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedGeneratorRecord value)?, {required TResult orElse()}) → TResult

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String did, String displayName, String? description, List<RichtextFacet>? descriptionFacets, Blob? avatar, bool? acceptsInteractions, UFeedGeneratorLabels? labels, FeedGeneratorContentMode? contentMode, DateTime createdAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this FeedGeneratorRecord to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String did, String displayName, String? description, List<RichtextFacet>? descriptionFacets, Blob? avatar, bool? acceptsInteractions, UFeedGeneratorLabels? labels, FeedGeneratorContentMode? contentMode, DateTime createdAt, Map<String, dynamic>? $unknown)) → TResult

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String did, String displayName, String? description, List<RichtextFacet>? descriptionFacets, Blob? avatar, bool? acceptsInteractions, UFeedGeneratorLabels? labels, FeedGeneratorContentMode? contentMode, DateTime createdAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedGeneratorRecord, provided by the FeedGeneratorRecordPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>