FeedGetFeedGeneratorOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

FeedGetFeedGeneratorOutput({@GeneratorViewConverter() required GeneratorView view, required bool isOnline, required bool isValid, Map<String, dynamic>? $unknown})
const
factory
FeedGetFeedGeneratorOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $FeedGetFeedGeneratorOutputCopyWith<FeedGetFeedGeneratorOutput>
Create a copy of FeedGetFeedGeneratorOutput with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isIsOnline → bool

Available on FeedGetFeedGeneratorOutput, provided by the FeedGetFeedGeneratorOutputExtension extension

no setter
isIsValid → bool

Available on FeedGetFeedGeneratorOutput, provided by the FeedGetFeedGeneratorOutputExtension extension

no setter
isNotIsOnline → bool

Available on FeedGetFeedGeneratorOutput, provided by the FeedGetFeedGeneratorOutputExtension extension

no setter
isNotIsValid → bool

Available on FeedGetFeedGeneratorOutput, provided by the FeedGetFeedGeneratorOutputExtension extension

no setter
isOnline → bool
Indicates whether the feed generator service has been online recently, or else seems to be inactive.
no setterinherited
isValid → bool
Indicates whether the feed generator service is compatible with the record declaration.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
view → GeneratorView
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FeedGetFeedGeneratorOutput value)) → TResult

Available on FeedGetFeedGeneratorOutput, provided by the FeedGetFeedGeneratorOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedGetFeedGeneratorOutput value)?) → TResult?

Available on FeedGetFeedGeneratorOutput, provided by the FeedGetFeedGeneratorOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedGetFeedGeneratorOutput value)?, {required TResult orElse()}) → TResult

Available on FeedGetFeedGeneratorOutput, provided by the FeedGetFeedGeneratorOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(GeneratorView view, bool isOnline, bool isValid, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedGetFeedGeneratorOutput, provided by the FeedGetFeedGeneratorOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this FeedGetFeedGeneratorOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(GeneratorView view, bool isOnline, bool isValid, Map<String, dynamic>? $unknown)) → TResult

Available on FeedGetFeedGeneratorOutput, provided by the FeedGetFeedGeneratorOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(GeneratorView view, bool isOnline, bool isValid, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedGetFeedGeneratorOutput, provided by the FeedGetFeedGeneratorOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>