FeedGetPostThreadInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

FeedGetPostThreadInput({@AtUriConverter.new() required AtUri uri, @Default.new(6) int depth, @Default.new(80) int parentHeight, Map<String, dynamic>? $unknown})
const
factory
FeedGetPostThreadInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $FeedGetPostThreadInputCopyWith<FeedGetPostThreadInput>
Create a copy of FeedGetPostThreadInput with the given fields replaced by the non-null parameter values.
no setterinherited
depth → int
How many levels of reply depth should be included in response.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
parentHeight → int
How many levels of parent (and grandparent, etc) post to include.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → AtUri
Reference (AT-URI) to post record.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FeedGetPostThreadInput value)) → TResult

Available on FeedGetPostThreadInput, provided by the FeedGetPostThreadInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedGetPostThreadInput value)?) → TResult?

Available on FeedGetPostThreadInput, provided by the FeedGetPostThreadInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedGetPostThreadInput value)?, {required TResult orElse()}) → TResult

Available on FeedGetPostThreadInput, provided by the FeedGetPostThreadInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(AtUri uri, int depth, int parentHeight, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedGetPostThreadInput, provided by the FeedGetPostThreadInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this FeedGetPostThreadInput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(AtUri uri, int depth, int parentHeight, Map<String, dynamic>? $unknown)) → TResult

Available on FeedGetPostThreadInput, provided by the FeedGetPostThreadInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(AtUri uri, int depth, int parentHeight, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedGetPostThreadInput, provided by the FeedGetPostThreadInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>