FeedGetPostThreadOutput class abstract

Available extensions
Annotations
  • @freezed

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $FeedGetPostThreadOutputCopyWith<FeedGetPostThreadOutput>
Create a copy of FeedGetPostThreadOutput with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNotThreadgate → bool

Available on FeedGetPostThreadOutput, provided by the FeedGetPostThreadOutputExtension extension

no setter
hasThreadgate → bool

Available on FeedGetPostThreadOutput, provided by the FeedGetPostThreadOutputExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thread → UFeedGetPostThreadThread
no setterinherited
threadgate → ThreadgateView?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FeedGetPostThreadOutput value)) → TResult

Available on FeedGetPostThreadOutput, provided by the FeedGetPostThreadOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedGetPostThreadOutput value)?) → TResult?

Available on FeedGetPostThreadOutput, provided by the FeedGetPostThreadOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedGetPostThreadOutput value)?, {required TResult orElse()}) → TResult

Available on FeedGetPostThreadOutput, provided by the FeedGetPostThreadOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(UFeedGetPostThreadThread thread, ThreadgateView? threadgate, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedGetPostThreadOutput, provided by the FeedGetPostThreadOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this FeedGetPostThreadOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(UFeedGetPostThreadThread thread, ThreadgateView? threadgate, Map<String, dynamic>? $unknown)) → TResult

Available on FeedGetPostThreadOutput, provided by the FeedGetPostThreadOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(UFeedGetPostThreadThread thread, ThreadgateView? threadgate, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedGetPostThreadOutput, provided by the FeedGetPostThreadOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>