FeedGetQuotesSort class sealed

Available extensions
Annotations
  • @freezed

Constructors

FeedGetQuotesSort.knownValue({required KnownFeedGetQuotesSort data})
const
factory
FeedGetQuotesSort.unknown({required String data})
const
factory

Properties

data → Object
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isKnownValue → bool

Available on FeedGetQuotesSort, provided by the FeedGetQuotesSortExtension extension

no setter
isNotKnownValue → bool

Available on FeedGetQuotesSort, provided by the FeedGetQuotesSortExtension extension

no setter
isNotUnknown → bool

Available on FeedGetQuotesSort, provided by the FeedGetQuotesSortExtension extension

no setter
isUnknown → bool

Available on FeedGetQuotesSort, provided by the FeedGetQuotesSortExtension extension

no setter
knownValue → KnownFeedGetQuotesSort?

Available on FeedGetQuotesSort, provided by the FeedGetQuotesSortExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknown → String?

Available on FeedGetQuotesSort, provided by the FeedGetQuotesSortExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult knownValue(FeedGetQuotesSortKnownValue value), required TResult unknown(FeedGetQuotesSortUnknown value)}) → TResult

Available on FeedGetQuotesSort, provided by the FeedGetQuotesSortPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(FeedGetQuotesSortKnownValue value)?, TResult? unknown(FeedGetQuotesSortUnknown value)?}) → TResult?

Available on FeedGetQuotesSort, provided by the FeedGetQuotesSortPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(FeedGetQuotesSortKnownValue value)?, TResult unknown(FeedGetQuotesSortUnknown value)?, required TResult orElse()}) → TResult

Available on FeedGetQuotesSort, provided by the FeedGetQuotesSortPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownFeedGetQuotesSort data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on FeedGetQuotesSort, provided by the FeedGetQuotesSortPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult knownValue(KnownFeedGetQuotesSort data), required TResult unknown(String data)}) → TResult

Available on FeedGetQuotesSort, provided by the FeedGetQuotesSortPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownFeedGetQuotesSort data)?, TResult? unknown(String data)?}) → TResult?

Available on FeedGetQuotesSort, provided by the FeedGetQuotesSortPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(String? value) → FeedGetQuotesSort?