FeedPostRecord class abstract

Record containing a Bluesky post.

Available extensions
Annotations
  • @freezed

Constructors

FeedPostRecord({@Default.new('app.bsky.feed.post') String $type, required String text, @RichtextFacetConverter() List<RichtextFacet>? facets, @ReplyRefConverter() ReplyRef? reply, @UFeedPostEmbedConverter() UFeedPostEmbed? embed, List<String>? langs, @UFeedPostLabelsConverter() UFeedPostLabels? labels, List<String>? tags, @JsonKey.new(toJson: iso8601) required DateTime createdAt, Map<String, dynamic>? $unknown})
const
factory
FeedPostRecord.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $FeedPostRecordCopyWith<FeedPostRecord>
Create a copy of FeedPostRecord with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
Client-declared timestamp when this post was originally created.
no setterinherited
embed → UFeedPostEmbed?
no setterinherited
facets → List<RichtextFacet>?
no setterinherited
hasEmbed → bool

Available on FeedPostRecord, provided by the FeedPostRecordExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasLabels → bool

Available on FeedPostRecord, provided by the FeedPostRecordExtension extension

no setter
hasNotEmbed → bool

Available on FeedPostRecord, provided by the FeedPostRecordExtension extension

no setter
hasNotLabels → bool

Available on FeedPostRecord, provided by the FeedPostRecordExtension extension

no setter
hasNotReply → bool

Available on FeedPostRecord, provided by the FeedPostRecordExtension extension

no setter
hasReply → bool

Available on FeedPostRecord, provided by the FeedPostRecordExtension extension

no setter
labels → UFeedPostLabels?
no setterinherited
langs → List<String>?
no setterinherited
reply → ReplyRef?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>?
no setterinherited
text → String
The primary post content. May be an empty string, if there are embeds.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FeedPostRecord value)) → TResult

Available on FeedPostRecord, provided by the FeedPostRecordPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedPostRecord value)?) → TResult?

Available on FeedPostRecord, provided by the FeedPostRecordPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedPostRecord value)?, {required TResult orElse()}) → TResult

Available on FeedPostRecord, provided by the FeedPostRecordPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String text, List<RichtextFacet>? facets, ReplyRef? reply, UFeedPostEmbed? embed, List<String>? langs, UFeedPostLabels? labels, List<String>? tags, DateTime createdAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedPostRecord, provided by the FeedPostRecordPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this FeedPostRecord to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String text, List<RichtextFacet>? facets, ReplyRef? reply, UFeedPostEmbed? embed, List<String>? langs, UFeedPostLabels? labels, List<String>? tags, DateTime createdAt, Map<String, dynamic>? $unknown)) → TResult

Available on FeedPostRecord, provided by the FeedPostRecordPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String text, List<RichtextFacet>? facets, ReplyRef? reply, UFeedPostEmbed? embed, List<String>? langs, UFeedPostLabels? labels, List<String>? tags, DateTime createdAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedPostRecord, provided by the FeedPostRecordPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>