TextSlice class abstract

Deprecated. Use app.bsky.richtext instead -- A text segment. Start is inclusive, end is exclusive. Indices are for utf16-encoded strings.

Available extensions
Annotations
  • @freezed

Constructors

TextSlice({@Default.new('app.bsky.feed.post#textSlice') String $type, required int start, required int end, Map<String, dynamic>? $unknown})
const
factory
TextSlice.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
copyWith → $TextSliceCopyWith<TextSlice>
Create a copy of TextSlice with the given fields replaced by the non-null parameter values.
no setterinherited
end int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_TextSlice value)) → TResult

Available on TextSlice, provided by the TextSlicePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TextSlice value)?) → TResult?

Available on TextSlice, provided by the TextSlicePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TextSlice value)?, {required TResult orElse()}) → TResult

Available on TextSlice, provided by the TextSlicePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, int start, int end, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on TextSlice, provided by the TextSlicePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TextSlice to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, int start, int end, Map<String, dynamic>? $unknown)) → TResult

Available on TextSlice, provided by the TextSlicePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, int start, int end, Map<String, dynamic>? $unknown)?) → TResult?

Available on TextSlice, provided by the TextSlicePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>