UFeedPostEmbed class sealed

Available extensions
Annotations
  • @freezed

Constructors

UFeedPostEmbed.embedExternal({required EmbedExternal data})
const
factory
UFeedPostEmbed.embedGallery({required EmbedGallery data})
const
factory
UFeedPostEmbed.embedImages({required EmbedImages data})
const
factory
UFeedPostEmbed.embedRecord({required EmbedRecord data})
const
factory
UFeedPostEmbed.embedRecordWithMedia({required EmbedRecordWithMedia data})
const
factory
UFeedPostEmbed.embedVideo({required EmbedVideo data})
const
factory
UFeedPostEmbed.unknown({required Map<String, dynamic> data})
const
factory

Properties

data → Object
no setterinherited
embedExternal → EmbedExternal?

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
embedGallery → EmbedGallery?

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
embedImages → EmbedImages?

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
embedRecord → EmbedRecord?

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
embedRecordWithMedia → EmbedRecordWithMedia?

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
embedVideo → EmbedVideo?

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
isEmbedExternal → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
isEmbedGallery → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
isEmbedImages → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
isEmbedRecord → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
isEmbedRecordWithMedia → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
isEmbedVideo → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
isNotEmbedExternal → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
isNotEmbedGallery → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
isNotEmbedImages → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
isNotEmbedRecord → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
isNotEmbedRecordWithMedia → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
isNotEmbedVideo → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
isNotUnknown → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
isUnknown → bool

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknown → Map<String, dynamic>?

Available on UFeedPostEmbed, provided by the UFeedPostEmbedExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult embedImages(UFeedPostEmbedEmbedImages value), required TResult embedVideo(UFeedPostEmbedEmbedVideo value), required TResult embedGallery(UFeedPostEmbedEmbedGallery value), required TResult embedExternal(UFeedPostEmbedEmbedExternal value), required TResult embedRecord(UFeedPostEmbedEmbedRecord value), required TResult embedRecordWithMedia(UFeedPostEmbedEmbedRecordWithMedia value), required TResult unknown(UFeedPostEmbedUnknown value)}) → TResult

Available on UFeedPostEmbed, provided by the UFeedPostEmbedPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? embedImages(UFeedPostEmbedEmbedImages value)?, TResult? embedVideo(UFeedPostEmbedEmbedVideo value)?, TResult? embedGallery(UFeedPostEmbedEmbedGallery value)?, TResult? embedExternal(UFeedPostEmbedEmbedExternal value)?, TResult? embedRecord(UFeedPostEmbedEmbedRecord value)?, TResult? embedRecordWithMedia(UFeedPostEmbedEmbedRecordWithMedia value)?, TResult? unknown(UFeedPostEmbedUnknown value)?}) → TResult?

Available on UFeedPostEmbed, provided by the UFeedPostEmbedPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult embedImages(UFeedPostEmbedEmbedImages value)?, TResult embedVideo(UFeedPostEmbedEmbedVideo value)?, TResult embedGallery(UFeedPostEmbedEmbedGallery value)?, TResult embedExternal(UFeedPostEmbedEmbedExternal value)?, TResult embedRecord(UFeedPostEmbedEmbedRecord value)?, TResult embedRecordWithMedia(UFeedPostEmbedEmbedRecordWithMedia value)?, TResult unknown(UFeedPostEmbedUnknown value)?, required TResult orElse()}) → TResult

Available on UFeedPostEmbed, provided by the UFeedPostEmbedPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult embedImages(EmbedImages data)?, TResult embedVideo(EmbedVideo data)?, TResult embedGallery(EmbedGallery data)?, TResult embedExternal(EmbedExternal data)?, TResult embedRecord(EmbedRecord data)?, TResult embedRecordWithMedia(EmbedRecordWithMedia data)?, TResult unknown(Map<String, dynamic> data)?, required TResult orElse()}) → TResult

Available on UFeedPostEmbed, provided by the UFeedPostEmbedPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult embedImages(EmbedImages data), required TResult embedVideo(EmbedVideo data), required TResult embedGallery(EmbedGallery data), required TResult embedExternal(EmbedExternal data), required TResult embedRecord(EmbedRecord data), required TResult embedRecordWithMedia(EmbedRecordWithMedia data), required TResult unknown(Map<String, dynamic> data)}) → TResult

Available on UFeedPostEmbed, provided by the UFeedPostEmbedPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? embedImages(EmbedImages data)?, TResult? embedVideo(EmbedVideo data)?, TResult? embedGallery(EmbedGallery data)?, TResult? embedExternal(EmbedExternal data)?, TResult? embedRecord(EmbedRecord data)?, TResult? embedRecordWithMedia(EmbedRecordWithMedia data)?, TResult? unknown(Map<String, dynamic> data)?}) → TResult?

Available on UFeedPostEmbed, provided by the UFeedPostEmbedPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited