FeedSearchPostsInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

FeedSearchPostsInput({required String q, @FeedSearchPostsSortConverter() @Default.new(FeedSearchPostsSort.knownValue(data: KnownFeedSearchPostsSort.latest)) FeedSearchPostsSort sort, String? since, String? until, String? mentions, String? author, String? lang, String? domain, String? url, List<String>? tag, @Default.new(25) int limit, String? cursor, Map<String, dynamic>? $unknown})
const
factory
FeedSearchPostsInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
author → String?
Filter to posts by the given account. Handles are resolved to DID before query-time.
no setterinherited
copyWith → $FeedSearchPostsInputCopyWith<FeedSearchPostsInput>
Create a copy of FeedSearchPostsInput with the given fields replaced by the non-null parameter values.
no setterinherited
cursor → String?
Optional pagination mechanism; may not necessarily allow scrolling through entire result set.
no setterinherited
domain → String?
Filter to posts with URLs (facet links or embeds) linking to the given domain (hostname). Server may apply hostname normalization.
no setterinherited
hasAuthor → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasCursor → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasDomain → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasLang → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasMentions → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasNotAuthor → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasNotCursor → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasNotDomain → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasNotLang → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasNotMentions → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasNotSince → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasNotUntil → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasNotUrl → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasSince → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasUntil → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasUrl → bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
lang → String?
Filter to posts in the given language. Expected to be based on post language field, though server may override language detection.
no setterinherited
limit → int
no setterinherited
mentions → String?
Filter to posts which mention the given account. Handles are resolved to DID before query-time. Only matches rich-text facet mentions.
no setterinherited
q → String
Search query string; syntax, phrase, boolean, and faceting is unspecified, but Lucene query syntax is recommended.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
since → String?
Filter results for posts after the indicated datetime (inclusive). Expected to use 'sortAt' timestamp, which may not match 'createdAt'. Can be a datetime, or just an ISO date (YYYY-MM-DD).
no setterinherited
sort → FeedSearchPostsSort
Specifies the ranking order of results.
no setterinherited
tag → List<String>?
no setterinherited
until → String?
Filter results for posts before the indicated datetime (not inclusive). Expected to use 'sortAt' timestamp, which may not match 'createdAt'. Can be a datetime, or just an ISO date (YYY-MM-DD).
no setterinherited
url → String?
Filter to posts with links (facet links or embeds) pointing to this URL. Server may apply URL normalization or fuzzy matching.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FeedSearchPostsInput value)) → TResult

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedSearchPostsInput value)?) → TResult?

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedSearchPostsInput value)?, {required TResult orElse()}) → TResult

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String q, FeedSearchPostsSort sort, String? since, String? until, String? mentions, String? author, String? lang, String? domain, String? url, List<String>? tag, int limit, String? cursor, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this FeedSearchPostsInput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String q, FeedSearchPostsSort sort, String? since, String? until, String? mentions, String? author, String? lang, String? domain, String? url, List<String>? tag, int limit, String? cursor, Map<String, dynamic>? $unknown)) → TResult

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String q, FeedSearchPostsSort sort, String? since, String? until, String? mentions, String? author, String? lang, String? domain, String? url, List<String>? tag, int limit, String? cursor, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>