FeedSearchPostsV2DetectedQueryLanguages class abstract

Available extensions
Annotations
  • @freezed

Properties

data Object
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isKnownValue bool

Available on FeedSearchPostsV2DetectedQueryLanguages, provided by the FeedSearchPostsV2DetectedQueryLanguagesExtension extension

no setter
isNotKnownValue bool

Available on FeedSearchPostsV2DetectedQueryLanguages, provided by the FeedSearchPostsV2DetectedQueryLanguagesExtension extension

no setter
isNotUnknown bool

Available on FeedSearchPostsV2DetectedQueryLanguages, provided by the FeedSearchPostsV2DetectedQueryLanguagesExtension extension

no setter
isUnknown bool

Available on FeedSearchPostsV2DetectedQueryLanguages, provided by the FeedSearchPostsV2DetectedQueryLanguagesExtension extension

no setter
knownValue KnownFeedSearchPostsV2DetectedQueryLanguages?

Available on FeedSearchPostsV2DetectedQueryLanguages, provided by the FeedSearchPostsV2DetectedQueryLanguagesExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknown String?

Available on FeedSearchPostsV2DetectedQueryLanguages, provided by the FeedSearchPostsV2DetectedQueryLanguagesExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult knownValue(FeedSearchPostsV2DetectedQueryLanguagesKnownValue value), required TResult unknown(FeedSearchPostsV2DetectedQueryLanguagesUnknown value)}) → TResult

Available on FeedSearchPostsV2DetectedQueryLanguages, provided by the FeedSearchPostsV2DetectedQueryLanguagesPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(FeedSearchPostsV2DetectedQueryLanguagesKnownValue value)?, TResult? unknown(FeedSearchPostsV2DetectedQueryLanguagesUnknown value)?}) → TResult?

Available on FeedSearchPostsV2DetectedQueryLanguages, provided by the FeedSearchPostsV2DetectedQueryLanguagesPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(FeedSearchPostsV2DetectedQueryLanguagesKnownValue value)?, TResult unknown(FeedSearchPostsV2DetectedQueryLanguagesUnknown value)?, required TResult orElse()}) → TResult

Available on FeedSearchPostsV2DetectedQueryLanguages, provided by the FeedSearchPostsV2DetectedQueryLanguagesPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownFeedSearchPostsV2DetectedQueryLanguages data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on FeedSearchPostsV2DetectedQueryLanguages, provided by the FeedSearchPostsV2DetectedQueryLanguagesPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult knownValue(KnownFeedSearchPostsV2DetectedQueryLanguages data), required TResult unknown(String data)}) → TResult

Available on FeedSearchPostsV2DetectedQueryLanguages, provided by the FeedSearchPostsV2DetectedQueryLanguagesPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownFeedSearchPostsV2DetectedQueryLanguages data)?, TResult? unknown(String data)?}) → TResult?

Available on FeedSearchPostsV2DetectedQueryLanguages, provided by the FeedSearchPostsV2DetectedQueryLanguagesPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited