FeedSearchPostsV2Output class abstract

Available extensions
Annotations
  • @freezed

Constructors

FeedSearchPostsV2Output({String? cursor, int? hitsTotal, @PostViewConverter() required List<PostView> posts, @FeedSearchPostsV2DetectedQueryLanguagesConverter() List<FeedSearchPostsV2DetectedQueryLanguages>? detectedQueryLanguages, Map<String, dynamic>? $unknown})
const
factory
FeedSearchPostsV2Output.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
copyWith → $FeedSearchPostsV2OutputCopyWith<FeedSearchPostsV2Output>
Create a copy of FeedSearchPostsV2Output with the given fields replaced by the non-null parameter values.
no setterinherited
cursor String?
Cursor for the next page of results.
no setterinherited
detectedQueryLanguages List<FeedSearchPostsV2DetectedQueryLanguages>?
no setterinherited
hasCursor bool

Available on FeedSearchPostsV2Output, provided by the FeedSearchPostsV2OutputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasHitsTotal bool

Available on FeedSearchPostsV2Output, provided by the FeedSearchPostsV2OutputExtension extension

no setter
hasNotCursor bool

Available on FeedSearchPostsV2Output, provided by the FeedSearchPostsV2OutputExtension extension

no setter
hasNotHitsTotal bool

Available on FeedSearchPostsV2Output, provided by the FeedSearchPostsV2OutputExtension extension

no setter
hitsTotal int?
Estimated total number of matching hits. May be rounded or truncated.
no setterinherited
posts List<PostView>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FeedSearchPostsV2Output value)) → TResult

Available on FeedSearchPostsV2Output, provided by the FeedSearchPostsV2OutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedSearchPostsV2Output value)?) → TResult?

Available on FeedSearchPostsV2Output, provided by the FeedSearchPostsV2OutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedSearchPostsV2Output value)?, {required TResult orElse()}) → TResult

Available on FeedSearchPostsV2Output, provided by the FeedSearchPostsV2OutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? cursor, int? hitsTotal, List<PostView> posts, List<FeedSearchPostsV2DetectedQueryLanguages>? detectedQueryLanguages, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedSearchPostsV2Output, provided by the FeedSearchPostsV2OutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this FeedSearchPostsV2Output to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? cursor, int? hitsTotal, List<PostView> posts, List<FeedSearchPostsV2DetectedQueryLanguages>? detectedQueryLanguages, Map<String, dynamic>? $unknown)) → TResult

Available on FeedSearchPostsV2Output, provided by the FeedSearchPostsV2OutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? cursor, int? hitsTotal, List<PostView> posts, List<FeedSearchPostsV2DetectedQueryLanguages>? detectedQueryLanguages, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedSearchPostsV2Output, provided by the FeedSearchPostsV2OutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>