FeedSearchPostsV2Sort class abstract

Available extensions
Annotations
  • @freezed

Constructors

FeedSearchPostsV2Sort.knownValue({required KnownFeedSearchPostsV2Sort data})
const
factory
FeedSearchPostsV2Sort.unknown({required String data})
const
factory

Properties

data Object
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isKnownValue bool

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortExtension extension

no setter
isNotKnownValue bool

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortExtension extension

no setter
isNotUnknown bool

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortExtension extension

no setter
isUnknown bool

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortExtension extension

no setter
knownValue KnownFeedSearchPostsV2Sort?

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknown String?

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult knownValue(FeedSearchPostsV2SortKnownValue value), required TResult unknown(FeedSearchPostsV2SortUnknown value)}) → TResult

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(FeedSearchPostsV2SortKnownValue value)?, TResult? unknown(FeedSearchPostsV2SortUnknown value)?}) → TResult?

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(FeedSearchPostsV2SortKnownValue value)?, TResult unknown(FeedSearchPostsV2SortUnknown value)?, required TResult orElse()}) → TResult

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownFeedSearchPostsV2Sort data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult knownValue(KnownFeedSearchPostsV2Sort data), required TResult unknown(String data)}) → TResult

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownFeedSearchPostsV2Sort data)?, TResult? unknown(String data)?}) → TResult?

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(String? value) FeedSearchPostsV2Sort?