FeedSearchPostsV2SortPatterns extension

Adds pattern-matching-related methods to FeedSearchPostsV2Sort.

on

Methods

map<TResult extends Object?>({required TResult knownValue(FeedSearchPostsV2SortKnownValue value), required TResult unknown(FeedSearchPostsV2SortUnknown value)}) → TResult

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(FeedSearchPostsV2SortKnownValue value)?, TResult? unknown(FeedSearchPostsV2SortUnknown value)?}) → TResult?

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(FeedSearchPostsV2SortKnownValue value)?, TResult unknown(FeedSearchPostsV2SortUnknown value)?, required TResult orElse()}) → TResult

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownFeedSearchPostsV2Sort data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult knownValue(KnownFeedSearchPostsV2Sort data), required TResult unknown(String data)}) → TResult

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownFeedSearchPostsV2Sort data)?, TResult? unknown(String data)?}) → TResult?

Available on FeedSearchPostsV2Sort, provided by the FeedSearchPostsV2SortPatterns extension

A variant of when that fallback to returning null