KnownFeedSearchPostsV2DetectedQueryLanguages enum
- Inheritance
- Implemented types
- Available extensions
Values
- ja → const KnownFeedSearchPostsV2DetectedQueryLanguages
-
const KnownFeedSearchPostsV2DetectedQueryLanguages('ja') - zh → const KnownFeedSearchPostsV2DetectedQueryLanguages
-
const KnownFeedSearchPostsV2DetectedQueryLanguages('zh') - ko → const KnownFeedSearchPostsV2DetectedQueryLanguages
-
const KnownFeedSearchPostsV2DetectedQueryLanguages('ko') - th → const KnownFeedSearchPostsV2DetectedQueryLanguages
-
const KnownFeedSearchPostsV2DetectedQueryLanguages('th') - ar → const KnownFeedSearchPostsV2DetectedQueryLanguages
-
const KnownFeedSearchPostsV2DetectedQueryLanguages('ar')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Returns the value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isKnownValue(
String value) → bool -
valueOf(
String? value) → KnownFeedSearchPostsV2DetectedQueryLanguages?
Constants
-
values
→ const List<
KnownFeedSearchPostsV2DetectedQueryLanguages> - A constant List of the values in this enum, in order of their declaration.