KnownFeedSearchPostsV2QueryLanguage enum

Inheritance
Implemented types
Available extensions

Values

ja → const KnownFeedSearchPostsV2QueryLanguage
const KnownFeedSearchPostsV2QueryLanguage('ja')
zh → const KnownFeedSearchPostsV2QueryLanguage
const KnownFeedSearchPostsV2QueryLanguage('zh')
ko → const KnownFeedSearchPostsV2QueryLanguage
const KnownFeedSearchPostsV2QueryLanguage('ko')
th → const KnownFeedSearchPostsV2QueryLanguage
const KnownFeedSearchPostsV2QueryLanguage('th')
ar → const KnownFeedSearchPostsV2QueryLanguage
const KnownFeedSearchPostsV2QueryLanguage('ar')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Returns the value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KnownFeedSearchPostsV2QueryLanguage>
A constant List of the values in this enum, in order of their declaration.