ListItemView class abstract

Available extensions
Annotations
  • @freezed

Constructors

ListItemView({@Default.new('app.bsky.graph.defs#listItemView') String $type, @AtUriConverter.new() required AtUri uri, @ProfileViewConverter() required ProfileView subject, bool? subjectOptedOut, Map<String, dynamic>? $unknown})
const
factory
ListItemView.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
copyWith → $ListItemViewCopyWith<ListItemView>
Create a copy of ListItemView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isNotSubjectOptedOut bool

Available on ListItemView, provided by the ListItemViewExtension extension

no setter
isSubjectOptedOut bool

Available on ListItemView, provided by the ListItemViewExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject ProfileView
no setterinherited
subjectOptedOut bool?
Set to true when the subject has opted out of appearing in the reference list. Only set when the viewer owns the list.
no setterinherited
uri AtUri
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ListItemView value)) → TResult

Available on ListItemView, provided by the ListItemViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ListItemView value)?) → TResult?

Available on ListItemView, provided by the ListItemViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ListItemView value)?, {required TResult orElse()}) → TResult

Available on ListItemView, provided by the ListItemViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, AtUri uri, ProfileView subject, bool? subjectOptedOut, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ListItemView, provided by the ListItemViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ListItemView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, AtUri uri, ProfileView subject, bool? subjectOptedOut, Map<String, dynamic>? $unknown)) → TResult

Available on ListItemView, provided by the ListItemViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, AtUri uri, ProfileView subject, bool? subjectOptedOut, Map<String, dynamic>? $unknown)?) → TResult?

Available on ListItemView, provided by the ListItemViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>