ListView class abstract

Available extensions
Annotations
  • @freezed

Constructors

ListView({@Default.new('app.bsky.graph.defs#listView') String $type, @AtUriConverter.new() required AtUri uri, required String cid, @ProfileViewConverter() required ProfileView creator, required String name, @ListPurposeConverter() required ListPurpose purpose, String? description, @RichtextFacetConverter() List<RichtextFacet>? descriptionFacets, String? avatar, int? listItemCount, @LabelConverter() List<Label>? labels, @ListViewerStateConverter() ListViewerState? viewer, @JsonKey.new(toJson: iso8601) required DateTime indexedAt, Map<String, dynamic>? $unknown})
const
factory
ListView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
avatar → String?
no setterinherited
cid → String
no setterinherited
copyWith → $ListViewCopyWith<ListView>
Create a copy of ListView with the given fields replaced by the non-null parameter values.
no setterinherited
creator → ProfileView
no setterinherited
description → String?
no setterinherited
descriptionFacets → List<RichtextFacet>?
no setterinherited
hasAvatar → bool

Available on ListView, provided by the ListViewExtension extension

no setter
hasDescription → bool

Available on ListView, provided by the ListViewExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListItemCount → bool

Available on ListView, provided by the ListViewExtension extension

no setter
hasNotAvatar → bool

Available on ListView, provided by the ListViewExtension extension

no setter
hasNotDescription → bool

Available on ListView, provided by the ListViewExtension extension

no setter
hasNotListItemCount → bool

Available on ListView, provided by the ListViewExtension extension

no setter
hasNotViewer → bool

Available on ListView, provided by the ListViewExtension extension

no setter
hasViewer → bool

Available on ListView, provided by the ListViewExtension extension

no setter
indexedAt → DateTime
no setterinherited
labels → List<Label>?
no setterinherited
listItemCount → int?
no setterinherited
name → String
no setterinherited
purpose → ListPurpose
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → AtUri
no setterinherited
viewer → ListViewerState?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ListView value)) → TResult

Available on ListView, provided by the ListViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ListView value)?) → TResult?

Available on ListView, provided by the ListViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ListView value)?, {required TResult orElse()}) → TResult

Available on ListView, provided by the ListViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, AtUri uri, String cid, ProfileView creator, String name, ListPurpose purpose, String? description, List<RichtextFacet>? descriptionFacets, String? avatar, int? listItemCount, List<Label>? labels, ListViewerState? viewer, DateTime indexedAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ListView, provided by the ListViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ListView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, AtUri uri, String cid, ProfileView creator, String name, ListPurpose purpose, String? description, List<RichtextFacet>? descriptionFacets, String? avatar, int? listItemCount, List<Label>? labels, ListViewerState? viewer, DateTime indexedAt, Map<String, dynamic>? $unknown)) → TResult

Available on ListView, provided by the ListViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, AtUri uri, String cid, ProfileView creator, String name, ListPurpose purpose, String? description, List<RichtextFacet>? descriptionFacets, String? avatar, int? listItemCount, List<Label>? labels, ListViewerState? viewer, DateTime indexedAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on ListView, provided by the ListViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>