referenceListOptOut property

  1. @AtUriConverter.new()
AtUri? get referenceListOptOut
inherited

The authenticated viewer's app.bsky.graph.referencelistoptout record URI for this reference list. Only set for reference lists. A client can delete this record to undo the opt-out.

Implementation

String get $type; bool? get muted;@AtUriConverter() AtUri? get blocked;/// The authenticated viewer's app.bsky.graph.referencelistoptout record URI for this reference list. Only set for reference lists. A client can delete this record to undo the opt-out.
@AtUriConverter() AtUri? get referenceListOptOut;