Relationship class abstract

lists the bi-directional graph relationships between one actor (not indicated in the object), and the target actors (the DID included in the object)

Available extensions
Annotations
  • @freezed

Constructors

Relationship({@Default.new('app.bsky.graph.defs#relationship') String $type, required String did, @AtUriConverter.new() AtUri? following, @AtUriConverter.new() AtUri? followedBy, @AtUriConverter.new() AtUri? blocking, @AtUriConverter.new() AtUri? blockedBy, @AtUriConverter.new() AtUri? blockingByList, @AtUriConverter.new() AtUri? blockedByList, Map<String, dynamic>? $unknown})
const
factory
Relationship.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
blockedBy → AtUri?
if the actor is blocked by this DID, contains the AT-URI of the block record
no setterinherited
blockedByList → AtUri?
if the actor is blocked by this DID via a block list, contains the AT-URI of the listblock record
no setterinherited
blocking → AtUri?
if the actor blocks this DID, this is the AT-URI of the block record
no setterinherited
blockingByList → AtUri?
if the actor blocks this DID via a block list, this is the AT-URI of the listblock record
no setterinherited
copyWith → $RelationshipCopyWith<Relationship>
Create a copy of Relationship with the given fields replaced by the non-null parameter values.
no setterinherited
did → String
no setterinherited
followedBy → AtUri?
if the actor is followed by this DID, contains the AT-URI of the follow record
no setterinherited
following → AtUri?
if the actor follows this DID, this is the AT-URI of the follow record
no setterinherited
hasBlockedBy → bool

Available on Relationship, provided by the RelationshipExtension extension

no setter
hasBlockedByList → bool

Available on Relationship, provided by the RelationshipExtension extension

no setter
hasBlocking → bool

Available on Relationship, provided by the RelationshipExtension extension

no setter
hasBlockingByList → bool

Available on Relationship, provided by the RelationshipExtension extension

no setter
hasFollowedBy → bool

Available on Relationship, provided by the RelationshipExtension extension

no setter
hasFollowing → bool

Available on Relationship, provided by the RelationshipExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotBlockedBy → bool

Available on Relationship, provided by the RelationshipExtension extension

no setter
hasNotBlockedByList → bool

Available on Relationship, provided by the RelationshipExtension extension

no setter
hasNotBlocking → bool

Available on Relationship, provided by the RelationshipExtension extension

no setter
hasNotBlockingByList → bool

Available on Relationship, provided by the RelationshipExtension extension

no setter
hasNotFollowedBy → bool

Available on Relationship, provided by the RelationshipExtension extension

no setter
hasNotFollowing → bool

Available on Relationship, provided by the RelationshipExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Relationship value)) → TResult

Available on Relationship, provided by the RelationshipPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Relationship value)?) → TResult?

Available on Relationship, provided by the RelationshipPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Relationship value)?, {required TResult orElse()}) → TResult

Available on Relationship, provided by the RelationshipPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String did, AtUri? following, AtUri? followedBy, AtUri? blocking, AtUri? blockedBy, AtUri? blockingByList, AtUri? blockedByList, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on Relationship, provided by the RelationshipPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Relationship to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String did, AtUri? following, AtUri? followedBy, AtUri? blocking, AtUri? blockedBy, AtUri? blockingByList, AtUri? blockedByList, Map<String, dynamic>? $unknown)) → TResult

Available on Relationship, provided by the RelationshipPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String did, AtUri? following, AtUri? followedBy, AtUri? blocking, AtUri? blockedBy, AtUri? blockingByList, AtUri? blockedByList, Map<String, dynamic>? $unknown)?) → TResult?

Available on Relationship, provided by the RelationshipPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>