blockingByList property

  1. @AtUriConverter.new()
AtUri? get blockingByList
inherited

if the actor blocks this DID via a block list, this is the AT-URI of the listblock record

Implementation

@AtUriConverter() AtUri? get blockedBy;/// if the actor blocks this DID via a block list, this is the AT-URI of the listblock record
@AtUriConverter() AtUri? get blockingByList;