StarterPackView class abstract

Available extensions
Annotations
  • @freezed

Constructors

StarterPackView({@Default.new('app.bsky.graph.defs#starterPackView') String $type, @AtUriConverter.new() required AtUri uri, required String cid, required Map<String, dynamic> record, @ProfileViewBasicConverter() required ProfileViewBasic creator, @ListViewBasicConverter() ListViewBasic? list, @ListItemViewConverter() List<ListItemView>? listItemsSample, @GeneratorViewConverter() List<GeneratorView>? feeds, int? joinedWeekCount, int? joinedAllTimeCount, @LabelConverter() List<Label>? labels, @JsonKey.new(toJson: iso8601) required DateTime indexedAt, Map<String, dynamic>? $unknown})
const
factory
StarterPackView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
cid → String
no setterinherited
copyWith → $StarterPackViewCopyWith<StarterPackView>
Create a copy of StarterPackView with the given fields replaced by the non-null parameter values.
no setterinherited
creator → ProfileViewBasic
no setterinherited
feeds → List<GeneratorView>?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasJoinedAllTimeCount → bool

Available on StarterPackView, provided by the StarterPackViewExtension extension

no setter
hasJoinedWeekCount → bool

Available on StarterPackView, provided by the StarterPackViewExtension extension

no setter
hasList → bool

Available on StarterPackView, provided by the StarterPackViewExtension extension

no setter
hasNotJoinedAllTimeCount → bool

Available on StarterPackView, provided by the StarterPackViewExtension extension

no setter
hasNotJoinedWeekCount → bool

Available on StarterPackView, provided by the StarterPackViewExtension extension

no setter
hasNotList → bool

Available on StarterPackView, provided by the StarterPackViewExtension extension

no setter
indexedAt → DateTime
no setterinherited
joinedAllTimeCount → int?
no setterinherited
joinedWeekCount → int?
no setterinherited
labels → List<Label>?
no setterinherited
list → ListViewBasic?
no setterinherited
listItemsSample → List<ListItemView>?
no setterinherited
record → Map<String, dynamic>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → AtUri
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_StarterPackView value)) → TResult

Available on StarterPackView, provided by the StarterPackViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_StarterPackView value)?) → TResult?

Available on StarterPackView, provided by the StarterPackViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_StarterPackView value)?, {required TResult orElse()}) → TResult

Available on StarterPackView, provided by the StarterPackViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, AtUri uri, String cid, Map<String, dynamic> record, ProfileViewBasic creator, ListViewBasic? list, List<ListItemView>? listItemsSample, List<GeneratorView>? feeds, int? joinedWeekCount, int? joinedAllTimeCount, List<Label>? labels, DateTime indexedAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on StarterPackView, provided by the StarterPackViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this StarterPackView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, AtUri uri, String cid, Map<String, dynamic> record, ProfileViewBasic creator, ListViewBasic? list, List<ListItemView>? listItemsSample, List<GeneratorView>? feeds, int? joinedWeekCount, int? joinedAllTimeCount, List<Label>? labels, DateTime indexedAt, Map<String, dynamic>? $unknown)) → TResult

Available on StarterPackView, provided by the StarterPackViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, AtUri uri, String cid, Map<String, dynamic> record, ProfileViewBasic creator, ListViewBasic? list, List<ListItemView>? listItemsSample, List<GeneratorView>? feeds, int? joinedWeekCount, int? joinedAllTimeCount, List<Label>? labels, DateTime indexedAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on StarterPackView, provided by the StarterPackViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>