GraphGetFollowersOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

GraphGetFollowersOutput({@ProfileViewConverter() required ProfileView subject, String? cursor, @ProfileViewConverter() required List<ProfileView> followers, Map<String, dynamic>? $unknown})
const
factory
GraphGetFollowersOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $GraphGetFollowersOutputCopyWith<GraphGetFollowersOutput>
Create a copy of GraphGetFollowersOutput with the given fields replaced by the non-null parameter values.
no setterinherited
cursor → String?
no setterinherited
followers → List<ProfileView>
no setterinherited
hasCursor → bool

Available on GraphGetFollowersOutput, provided by the GraphGetFollowersOutputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotCursor → bool

Available on GraphGetFollowersOutput, provided by the GraphGetFollowersOutputExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → ProfileView
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GraphGetFollowersOutput value)) → TResult

Available on GraphGetFollowersOutput, provided by the GraphGetFollowersOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GraphGetFollowersOutput value)?) → TResult?

Available on GraphGetFollowersOutput, provided by the GraphGetFollowersOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GraphGetFollowersOutput value)?, {required TResult orElse()}) → TResult

Available on GraphGetFollowersOutput, provided by the GraphGetFollowersOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(ProfileView subject, String? cursor, List<ProfileView> followers, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on GraphGetFollowersOutput, provided by the GraphGetFollowersOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this GraphGetFollowersOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(ProfileView subject, String? cursor, List<ProfileView> followers, Map<String, dynamic>? $unknown)) → TResult

Available on GraphGetFollowersOutput, provided by the GraphGetFollowersOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(ProfileView subject, String? cursor, List<ProfileView> followers, Map<String, dynamic>? $unknown)?) → TResult?

Available on GraphGetFollowersOutput, provided by the GraphGetFollowersOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>