GraphGetListsPurposes class sealed

Available extensions
Annotations
  • @freezed

Constructors

GraphGetListsPurposes.knownValue({required KnownGraphGetListsPurposes data})
const
factory
GraphGetListsPurposes.unknown({required String data})
const
factory

Properties

data → Object
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isKnownValue → bool

Available on GraphGetListsPurposes, provided by the GraphGetListsPurposesExtension extension

no setter
isNotKnownValue → bool

Available on GraphGetListsPurposes, provided by the GraphGetListsPurposesExtension extension

no setter
isNotUnknown → bool

Available on GraphGetListsPurposes, provided by the GraphGetListsPurposesExtension extension

no setter
isUnknown → bool

Available on GraphGetListsPurposes, provided by the GraphGetListsPurposesExtension extension

no setter
knownValue → KnownGraphGetListsPurposes?

Available on GraphGetListsPurposes, provided by the GraphGetListsPurposesExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknown → String?

Available on GraphGetListsPurposes, provided by the GraphGetListsPurposesExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult knownValue(GraphGetListsPurposesKnownValue value), required TResult unknown(GraphGetListsPurposesUnknown value)}) → TResult

Available on GraphGetListsPurposes, provided by the GraphGetListsPurposesPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(GraphGetListsPurposesKnownValue value)?, TResult? unknown(GraphGetListsPurposesUnknown value)?}) → TResult?

Available on GraphGetListsPurposes, provided by the GraphGetListsPurposesPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(GraphGetListsPurposesKnownValue value)?, TResult unknown(GraphGetListsPurposesUnknown value)?, required TResult orElse()}) → TResult

Available on GraphGetListsPurposes, provided by the GraphGetListsPurposesPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownGraphGetListsPurposes data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on GraphGetListsPurposes, provided by the GraphGetListsPurposesPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult knownValue(KnownGraphGetListsPurposes data), required TResult unknown(String data)}) → TResult

Available on GraphGetListsPurposes, provided by the GraphGetListsPurposesPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownGraphGetListsPurposes data)?, TResult? unknown(String data)?}) → TResult?

Available on GraphGetListsPurposes, provided by the GraphGetListsPurposesPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(String? value) → GraphGetListsPurposes?