GraphGetRelationshipsOutput class abstract

Available extensions
Annotations
  • @freezed

Properties

$unknown → Map<String, dynamic>?
no setterinherited
actor → String?
no setterinherited
copyWith → $GraphGetRelationshipsOutputCopyWith<GraphGetRelationshipsOutput>
Create a copy of GraphGetRelationshipsOutput with the given fields replaced by the non-null parameter values.
no setterinherited
hasActor → bool

Available on GraphGetRelationshipsOutput, provided by the GraphGetRelationshipsOutputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotActor → bool

Available on GraphGetRelationshipsOutput, provided by the GraphGetRelationshipsOutputExtension extension

no setter
relationships → List<UGraphGetRelationshipsRelationships>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GraphGetRelationshipsOutput value)) → TResult

Available on GraphGetRelationshipsOutput, provided by the GraphGetRelationshipsOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GraphGetRelationshipsOutput value)?) → TResult?

Available on GraphGetRelationshipsOutput, provided by the GraphGetRelationshipsOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GraphGetRelationshipsOutput value)?, {required TResult orElse()}) → TResult

Available on GraphGetRelationshipsOutput, provided by the GraphGetRelationshipsOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? actor, List<UGraphGetRelationshipsRelationships> relationships, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on GraphGetRelationshipsOutput, provided by the GraphGetRelationshipsOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this GraphGetRelationshipsOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? actor, List<UGraphGetRelationshipsRelationships> relationships, Map<String, dynamic>? $unknown)) → TResult

Available on GraphGetRelationshipsOutput, provided by the GraphGetRelationshipsOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? actor, List<UGraphGetRelationshipsRelationships> relationships, Map<String, dynamic>? $unknown)?) → TResult?

Available on GraphGetRelationshipsOutput, provided by the GraphGetRelationshipsOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>