GraphListRecord class abstract

Record representing a list of accounts (actors). Scope includes both moderation-oriented lists and curration-oriented lists.

Available extensions
Annotations
  • @freezed

Constructors

GraphListRecord({@Default.new('app.bsky.graph.list') String $type, @ListPurposeConverter() required ListPurpose purpose, required String name, String? description, @RichtextFacetConverter() List<RichtextFacet>? descriptionFacets, @BlobConverter() Blob? avatar, @UGraphListLabelsConverter() UGraphListLabels? labels, @JsonKey.new(toJson: iso8601) required DateTime createdAt, Map<String, dynamic>? $unknown})
const
factory
GraphListRecord.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
avatar → Blob?
no setterinherited
copyWith → $GraphListRecordCopyWith<GraphListRecord>
Create a copy of GraphListRecord with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
description → String?
no setterinherited
descriptionFacets → List<RichtextFacet>?
no setterinherited
hasAvatar → bool

Available on GraphListRecord, provided by the GraphListRecordExtension extension

no setter
hasDescription → bool

Available on GraphListRecord, provided by the GraphListRecordExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasLabels → bool

Available on GraphListRecord, provided by the GraphListRecordExtension extension

no setter
hasNotAvatar → bool

Available on GraphListRecord, provided by the GraphListRecordExtension extension

no setter
hasNotDescription → bool

Available on GraphListRecord, provided by the GraphListRecordExtension extension

no setter
hasNotLabels → bool

Available on GraphListRecord, provided by the GraphListRecordExtension extension

no setter
labels → UGraphListLabels?
no setterinherited
name → String
Display name for list; can not be empty.
no setterinherited
purpose → ListPurpose
Defines the purpose of the list (aka, moderation-oriented or curration-oriented)
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GraphListRecord value)) → TResult

Available on GraphListRecord, provided by the GraphListRecordPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GraphListRecord value)?) → TResult?

Available on GraphListRecord, provided by the GraphListRecordPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GraphListRecord value)?, {required TResult orElse()}) → TResult

Available on GraphListRecord, provided by the GraphListRecordPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, ListPurpose purpose, String name, String? description, List<RichtextFacet>? descriptionFacets, Blob? avatar, UGraphListLabels? labels, DateTime createdAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on GraphListRecord, provided by the GraphListRecordPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this GraphListRecord to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, ListPurpose purpose, String name, String? description, List<RichtextFacet>? descriptionFacets, Blob? avatar, UGraphListLabels? labels, DateTime createdAt, Map<String, dynamic>? $unknown)) → TResult

Available on GraphListRecord, provided by the GraphListRecordPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, ListPurpose purpose, String name, String? description, List<RichtextFacet>? descriptionFacets, Blob? avatar, UGraphListLabels? labels, DateTime createdAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on GraphListRecord, provided by the GraphListRecordPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>