GraphMuteActorInput constructor
const
GraphMuteActorInput({})
Implementation
@JsonSerializable(includeIfNull: false)
const factory GraphMuteActorInput({
required String actor,
/// Restrict the mute to the account's reposts. When any 'only' scope is set, just the scoped content is muted; when none are set, the account is fully muted. Repeat calls replace the stored scope rather than adding to it.
bool? onlyReposts,
/// Restrict the mute to the account's quote posts. See onlyReposts.
bool? onlyQuoteposts,
Map<String, dynamic>? $unknown,
}) = _GraphMuteActorInput;