app_bsky_graph_referencelistoptout library
Classes
- GraphReferencelistoptoutRecord
- Record requesting that its author be omitted from the public presentation of a reference list. This record is only enforced when the subject list's current purpose is app.bsky.graph.defs#referencelist. AppView indexes at most one record per actor and list pair, and ignores duplicate records.
- GraphReferencelistoptoutRecordConverter
Extensions
- GraphReferencelistoptoutRecordPatterns on GraphReferencelistoptoutRecord
- Adds pattern-matching-related methods to GraphReferencelistoptoutRecord.