GraphStarterpackRecord class abstract

Record defining a starter pack of actors and feeds for new users.

Available extensions
Annotations
  • @freezed

Constructors

GraphStarterpackRecord({@Default.new('app.bsky.graph.starterpack') String $type, required String name, String? description, @RichtextFacetConverter() List<RichtextFacet>? descriptionFacets, @AtUriConverter.new() required AtUri list, @FeedItemConverter() List<FeedItem>? feeds, @JsonKey.new(toJson: iso8601) required DateTime createdAt, Map<String, dynamic>? $unknown})
const
factory
GraphStarterpackRecord.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $GraphStarterpackRecordCopyWith<GraphStarterpackRecord>
Create a copy of GraphStarterpackRecord with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
description → String?
no setterinherited
descriptionFacets → List<RichtextFacet>?
no setterinherited
feeds → List<FeedItem>?
no setterinherited
hasDescription → bool

Available on GraphStarterpackRecord, provided by the GraphStarterpackRecordExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotDescription → bool

Available on GraphStarterpackRecord, provided by the GraphStarterpackRecordExtension extension

no setter
list → AtUri
Reference (AT-URI) to the list record.
no setterinherited
name → String
Display name for starter pack; can not be empty.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GraphStarterpackRecord value)) → TResult

Available on GraphStarterpackRecord, provided by the GraphStarterpackRecordPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GraphStarterpackRecord value)?) → TResult?

Available on GraphStarterpackRecord, provided by the GraphStarterpackRecordPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GraphStarterpackRecord value)?, {required TResult orElse()}) → TResult

Available on GraphStarterpackRecord, provided by the GraphStarterpackRecordPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String name, String? description, List<RichtextFacet>? descriptionFacets, AtUri list, List<FeedItem>? feeds, DateTime createdAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on GraphStarterpackRecord, provided by the GraphStarterpackRecordPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this GraphStarterpackRecord to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String name, String? description, List<RichtextFacet>? descriptionFacets, AtUri list, List<FeedItem>? feeds, DateTime createdAt, Map<String, dynamic>? $unknown)) → TResult

Available on GraphStarterpackRecord, provided by the GraphStarterpackRecordPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String name, String? description, List<RichtextFacet>? descriptionFacets, AtUri list, List<FeedItem>? feeds, DateTime createdAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on GraphStarterpackRecord, provided by the GraphStarterpackRecordPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>