Preference class abstract

Available extensions
Annotations
  • @freezed

Constructors

Preference({@Default.new('app.bsky.notification.defs#preference') String $type, required bool list, required bool push, Map<String, dynamic>? $unknown})
const
factory
Preference.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $PreferenceCopyWith<Preference>
Create a copy of Preference with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isList → bool

Available on Preference, provided by the PreferenceExtension extension

no setter
isNotList → bool

Available on Preference, provided by the PreferenceExtension extension

no setter
isNotPush → bool

Available on Preference, provided by the PreferenceExtension extension

no setter
isPush → bool

Available on Preference, provided by the PreferenceExtension extension

no setter
list → bool
no setterinherited
push → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Preference value)) → TResult

Available on Preference, provided by the PreferencePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Preference value)?) → TResult?

Available on Preference, provided by the PreferencePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Preference value)?, {required TResult orElse()}) → TResult

Available on Preference, provided by the PreferencePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, bool list, bool push, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on Preference, provided by the PreferencePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Preference to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, bool list, bool push, Map<String, dynamic>? $unknown)) → TResult

Available on Preference, provided by the PreferencePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, bool list, bool push, Map<String, dynamic>? $unknown)?) → TResult?

Available on Preference, provided by the PreferencePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>