app_bsky_notification_getgroupednotifications library

Classes

ContactMatchNotification
A contact of the requesting account joined Bluesky.
ContactMatchNotificationConverter
FollowBackNotification
An actor followed the requesting account back, possibly via a starter pack.
FollowBackNotificationConverter
FollowGroup
Group of actors who followed the requesting account.
FollowGroupConverter
FollowItem
An actor who followed the requesting account, possibly via a starter pack.
FollowItemConverter
GeneratorLikeGroup
Group of likes by different actors on the same feed generator.
GeneratorLikeGroupConverter
GeneratorLikeItem
One actor who liked the feed generator in the group.
GeneratorLikeItemConverter
Group
Contains common metadata and kind-specific data for a notification group or individual notification.
GroupConverter
LikeGroup
Group of likes by different actors on the same post.
LikeGroupConverter
LikeItem
One actor who liked the group's post.
LikeItemConverter
LikeViaRepostGroup
Group of likes by different actors on the same post via the requesting account's repost.
LikeViaRepostGroupConverter
LikeViaRepostItem
One actor who liked the group's post via the requesting account's repost.
LikeViaRepostItemConverter
MentionNotification
A post mentioning the requesting account.
MentionNotificationConverter
MultiPostLikeGroup
Group of likes by the same actor on different posts.
MultiPostLikeGroupConverter
MultiPostLikeItem
One post which was liked by the group's actor.
MultiPostLikeItemConverter
NotificationGetGroupedNotificationsFeed
NotificationGetGroupedNotificationsFeedConverter
NotificationGetGroupedNotificationsInput
NotificationGetGroupedNotificationsInputConverter
NotificationGetGroupedNotificationsOutput
NotificationGetGroupedNotificationsOutputConverter
QuoteNotification
A post quoting a post by the requesting account.
QuoteNotificationConverter
ReplyNotification
A reply to a post by the requesting account or to a thread they are participating in.
ReplyNotificationConverter
RepostGroup
Group of reposts by different actors of the same post.
RepostGroupConverter
RepostItem
One actor who reposted the group's post.
RepostItemConverter
RepostViaRepostGroup
Group of reposts by different actors of the same post via the requesting account's repost.
RepostViaRepostGroupConverter
RepostViaRepostItem
One actor who reposted the group's post via the requesting account's repost.
RepostViaRepostItemConverter
StarterPackJoinedNotification
An actor joined Bluesky via a starter pack created by the requesting account.
StarterPackJoinedNotificationConverter
SubscribedPostGroup
Group of new posts by actors the requesting account subscribes to.
SubscribedPostGroupConverter
SubscribedPostItem
One new post by an actor the requesting account subscribes to.
SubscribedPostItemConverter
UGroupKind
UGroupKindConverter
UNotificationGetGroupedNotificationsRelatedViews
UNotificationGetGroupedNotificationsRelatedViewsConverter
UnverifiedNotification
A verification of the requesting account was removed.
UnverifiedNotificationConverter
VerifiedNotification
An actor verified the requesting account.
VerifiedNotificationConverter

Extensions

ContactMatchNotificationPatterns on ContactMatchNotification
Adds pattern-matching-related methods to ContactMatchNotification.
FollowBackNotificationExtension on FollowBackNotification
FollowBackNotificationPatterns on FollowBackNotification
Adds pattern-matching-related methods to FollowBackNotification.
FollowGroupPatterns on FollowGroup
Adds pattern-matching-related methods to FollowGroup.
FollowItemExtension on FollowItem
FollowItemPatterns on FollowItem
Adds pattern-matching-related methods to FollowItem.
GeneratorLikeGroupPatterns on GeneratorLikeGroup
Adds pattern-matching-related methods to GeneratorLikeGroup.
GeneratorLikeItemPatterns on GeneratorLikeItem
Adds pattern-matching-related methods to GeneratorLikeItem.
GroupExtension on Group
GroupPatterns on Group
Adds pattern-matching-related methods to Group.
LikeGroupPatterns on LikeGroup
Adds pattern-matching-related methods to LikeGroup.
LikeItemPatterns on LikeItem
Adds pattern-matching-related methods to LikeItem.
LikeViaRepostGroupPatterns on LikeViaRepostGroup
Adds pattern-matching-related methods to LikeViaRepostGroup.
LikeViaRepostItemPatterns on LikeViaRepostItem
Adds pattern-matching-related methods to LikeViaRepostItem.
MentionNotificationExtension on MentionNotification
MentionNotificationPatterns on MentionNotification
Adds pattern-matching-related methods to MentionNotification.
MultiPostLikeGroupPatterns on MultiPostLikeGroup
Adds pattern-matching-related methods to MultiPostLikeGroup.
MultiPostLikeItemPatterns on MultiPostLikeItem
Adds pattern-matching-related methods to MultiPostLikeItem.
NotificationGetGroupedNotificationsFeedExtension on NotificationGetGroupedNotificationsFeed
NotificationGetGroupedNotificationsFeedPatterns on NotificationGetGroupedNotificationsFeed
Adds pattern-matching-related methods to NotificationGetGroupedNotificationsFeed.
NotificationGetGroupedNotificationsInputExtension on NotificationGetGroupedNotificationsInput
NotificationGetGroupedNotificationsInputPatterns on NotificationGetGroupedNotificationsInput
Adds pattern-matching-related methods to NotificationGetGroupedNotificationsInput.
NotificationGetGroupedNotificationsOutputExtension on NotificationGetGroupedNotificationsOutput
NotificationGetGroupedNotificationsOutputPatterns on NotificationGetGroupedNotificationsOutput
Adds pattern-matching-related methods to NotificationGetGroupedNotificationsOutput.
QuoteNotificationExtension on QuoteNotification
QuoteNotificationPatterns on QuoteNotification
Adds pattern-matching-related methods to QuoteNotification.
ReplyNotificationPatterns on ReplyNotification
Adds pattern-matching-related methods to ReplyNotification.
RepostGroupPatterns on RepostGroup
Adds pattern-matching-related methods to RepostGroup.
RepostItemPatterns on RepostItem
Adds pattern-matching-related methods to RepostItem.
RepostViaRepostGroupPatterns on RepostViaRepostGroup
Adds pattern-matching-related methods to RepostViaRepostGroup.
RepostViaRepostItemPatterns on RepostViaRepostItem
Adds pattern-matching-related methods to RepostViaRepostItem.
StarterPackJoinedNotificationPatterns on StarterPackJoinedNotification
Adds pattern-matching-related methods to StarterPackJoinedNotification.
SubscribedPostGroupPatterns on SubscribedPostGroup
Adds pattern-matching-related methods to SubscribedPostGroup.
SubscribedPostItemPatterns on SubscribedPostItem
Adds pattern-matching-related methods to SubscribedPostItem.
UGroupKindExtension on UGroupKind
UGroupKindPatterns on UGroupKind
Adds pattern-matching-related methods to UGroupKind.
UNotificationGetGroupedNotificationsRelatedViewsExtension on UNotificationGetGroupedNotificationsRelatedViews
UNotificationGetGroupedNotificationsRelatedViewsPatterns on UNotificationGetGroupedNotificationsRelatedViews
Adds pattern-matching-related methods to UNotificationGetGroupedNotificationsRelatedViews.
UnverifiedNotificationPatterns on UnverifiedNotification
Adds pattern-matching-related methods to UnverifiedNotification.
VerifiedNotificationPatterns on VerifiedNotification
Adds pattern-matching-related methods to VerifiedNotification.