LikeViaRepostGroup class abstract

Group of likes by different actors on the same post via the requesting account's repost.

Available extensions
Annotations
  • @freezed

Constructors

LikeViaRepostGroup({@Default.new('app.bsky.notification.getGroupedNotifications#likeViaRepostGroup') String $type, @AtUriConverter.new() required AtUri post, @AtUriConverter.new() required AtUri viaRepost, @LikeViaRepostItemConverter() required List<LikeViaRepostItem> items, Map<String, dynamic>? $unknown})
const
factory
LikeViaRepostGroup.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $LikeViaRepostGroupCopyWith<LikeViaRepostGroup>
Create a copy of LikeViaRepostGroup with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
items → List<LikeViaRepostItem>
no setterinherited
post → AtUri
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viaRepost → AtUri
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_LikeViaRepostGroup value)) → TResult

Available on LikeViaRepostGroup, provided by the LikeViaRepostGroupPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_LikeViaRepostGroup value)?) → TResult?

Available on LikeViaRepostGroup, provided by the LikeViaRepostGroupPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_LikeViaRepostGroup value)?, {required TResult orElse()}) → TResult

Available on LikeViaRepostGroup, provided by the LikeViaRepostGroupPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, AtUri post, AtUri viaRepost, List<LikeViaRepostItem> items, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on LikeViaRepostGroup, provided by the LikeViaRepostGroupPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this LikeViaRepostGroup to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, AtUri post, AtUri viaRepost, List<LikeViaRepostItem> items, Map<String, dynamic>? $unknown)) → TResult

Available on LikeViaRepostGroup, provided by the LikeViaRepostGroupPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, AtUri post, AtUri viaRepost, List<LikeViaRepostItem> items, Map<String, dynamic>? $unknown)?) → TResult?

Available on LikeViaRepostGroup, provided by the LikeViaRepostGroupPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>