NotificationGetGroupedNotificationsFeedPatterns extension

Adds pattern-matching-related methods to NotificationGetGroupedNotificationsFeed.

on

Methods

map<TResult extends Object?>({required TResult knownValue(NotificationGetGroupedNotificationsFeedKnownValue value), required TResult unknown(NotificationGetGroupedNotificationsFeedUnknown value)}) → TResult

Available on NotificationGetGroupedNotificationsFeed, provided by the NotificationGetGroupedNotificationsFeedPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(NotificationGetGroupedNotificationsFeedKnownValue value)?, TResult? unknown(NotificationGetGroupedNotificationsFeedUnknown value)?}) → TResult?

Available on NotificationGetGroupedNotificationsFeed, provided by the NotificationGetGroupedNotificationsFeedPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(NotificationGetGroupedNotificationsFeedKnownValue value)?, TResult unknown(NotificationGetGroupedNotificationsFeedUnknown value)?, required TResult orElse()}) → TResult

Available on NotificationGetGroupedNotificationsFeed, provided by the NotificationGetGroupedNotificationsFeedPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownNotificationGetGroupedNotificationsFeed data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on NotificationGetGroupedNotificationsFeed, provided by the NotificationGetGroupedNotificationsFeedPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult knownValue(KnownNotificationGetGroupedNotificationsFeed data), required TResult unknown(String data)}) → TResult

Available on NotificationGetGroupedNotificationsFeed, provided by the NotificationGetGroupedNotificationsFeedPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownNotificationGetGroupedNotificationsFeed data)?, TResult? unknown(String data)?}) → TResult?

Available on NotificationGetGroupedNotificationsFeed, provided by the NotificationGetGroupedNotificationsFeedPatterns extension

A variant of when that fallback to returning null