NotificationGetGroupedNotificationsInput class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
NotificationGetGroupedNotificationsInput({@NotificationGetGroupedNotificationsFeedConverter() @Default.new(NotificationGetGroupedNotificationsFeed.knownValue(data: KnownNotificationGetGroupedNotificationsFeed.all)) NotificationGetGroupedNotificationsFeed feed, @Default.new(30) int limit, String? cursor, Map<
String, dynamic> ? $unknown}) -
constfactory
-
NotificationGetGroupedNotificationsInput.fromJson(Map<
String, Object?> json) -
factory
Properties
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
copyWith
→ $NotificationGetGroupedNotificationsInputCopyWith<
NotificationGetGroupedNotificationsInput> -
Create a copy of NotificationGetGroupedNotificationsInput
with the given fields replaced by the non-null parameter values.
no setterinherited
- cursor → String?
-
no setterinherited
- feed → NotificationGetGroupedNotificationsFeed
-
Which notification feed to return. Grouping behavior varies by feed: notifications about follows might be grouped in 'all' and ungrouped (or rather, in single-item groups) in 'followers'.
no setterinherited
- hasCursor → bool
-
Available on NotificationGetGroupedNotificationsInput, provided by the NotificationGetGroupedNotificationsInputExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotCursor → bool
-
Available on NotificationGetGroupedNotificationsInput, provided by the NotificationGetGroupedNotificationsInputExtension extension
no setter - limit → int
-
Maximum number of groups to return.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_NotificationGetGroupedNotificationsInput value)) → TResult -
Available on NotificationGetGroupedNotificationsInput, provided by the NotificationGetGroupedNotificationsInputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_NotificationGetGroupedNotificationsInput value)?) → TResult? -
Available on NotificationGetGroupedNotificationsInput, provided by the NotificationGetGroupedNotificationsInputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_NotificationGetGroupedNotificationsInput value)?, {required TResult orElse()}) → TResult -
Available on NotificationGetGroupedNotificationsInput, provided by the NotificationGetGroupedNotificationsInputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(NotificationGetGroupedNotificationsFeed feed, int limit, String? cursor, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on NotificationGetGroupedNotificationsInput, provided by the NotificationGetGroupedNotificationsInputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this NotificationGetGroupedNotificationsInput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(NotificationGetGroupedNotificationsFeed feed, int limit, String? cursor, Map< String, dynamic> ? $unknown)) → TResult -
Available on NotificationGetGroupedNotificationsInput, provided by the NotificationGetGroupedNotificationsInputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(NotificationGetGroupedNotificationsFeed feed, int limit, String? cursor, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on NotificationGetGroupedNotificationsInput, provided by the NotificationGetGroupedNotificationsInputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>