NotificationGetGroupedNotificationsOutput class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
NotificationGetGroupedNotificationsOutput({String? cursor, @GroupConverter() required List<
Group> groups, @JsonKey.new(toJson: iso8601) DateTime? seenAt, Map<String, dynamic> ? $unknown}) -
constfactory
-
NotificationGetGroupedNotificationsOutput.fromJson(Map<
String, Object?> json) -
factory
Properties
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
copyWith
→ $NotificationGetGroupedNotificationsOutputCopyWith<
NotificationGetGroupedNotificationsOutput> -
Create a copy of NotificationGetGroupedNotificationsOutput
with the given fields replaced by the non-null parameter values.
no setterinherited
- cursor → String?
-
no setterinherited
-
groups
→ List<
Group> -
no setterinherited
- hasCursor → bool
-
Available on NotificationGetGroupedNotificationsOutput, provided by the NotificationGetGroupedNotificationsOutputExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotCursor → bool
-
Available on NotificationGetGroupedNotificationsOutput, provided by the NotificationGetGroupedNotificationsOutputExtension extension
no setter - hasNotSeenAt → bool
-
Available on NotificationGetGroupedNotificationsOutput, provided by the NotificationGetGroupedNotificationsOutputExtension extension
no setter - hasSeenAt → bool
-
Available on NotificationGetGroupedNotificationsOutput, provided by the NotificationGetGroupedNotificationsOutputExtension extension
no setter -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seenAt → DateTime?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_NotificationGetGroupedNotificationsOutput value)) → TResult -
Available on NotificationGetGroupedNotificationsOutput, provided by the NotificationGetGroupedNotificationsOutputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_NotificationGetGroupedNotificationsOutput value)?) → TResult? -
Available on NotificationGetGroupedNotificationsOutput, provided by the NotificationGetGroupedNotificationsOutputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_NotificationGetGroupedNotificationsOutput value)?, {required TResult orElse()}) → TResult -
Available on NotificationGetGroupedNotificationsOutput, provided by the NotificationGetGroupedNotificationsOutputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? cursor, List< Group> groups, DateTime? seenAt, Map<String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on NotificationGetGroupedNotificationsOutput, provided by the NotificationGetGroupedNotificationsOutputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this NotificationGetGroupedNotificationsOutput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? cursor, List< Group> groups, DateTime? seenAt, Map<String, dynamic> ? $unknown)) → TResult -
Available on NotificationGetGroupedNotificationsOutput, provided by the NotificationGetGroupedNotificationsOutputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? cursor, List< Group> groups, DateTime? seenAt, Map<String, dynamic> ? $unknown)?) → TResult? -
Available on NotificationGetGroupedNotificationsOutput, provided by the NotificationGetGroupedNotificationsOutputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>