ReplyNotification class abstract

A reply to a post by the requesting account or to a thread they are participating in.

Available extensions
Annotations
  • @freezed

Constructors

ReplyNotification({@Default.new('app.bsky.notification.getGroupedNotifications#replyNotification') String $type, @AtUriConverter.new() required AtUri post, @AtUriConverter.new() required AtUri parent, Map<String, dynamic>? $unknown})
const
factory
ReplyNotification.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $ReplyNotificationCopyWith<ReplyNotification>
Create a copy of ReplyNotification with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
parent → AtUri
no setterinherited
post → AtUri
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReplyNotification value)) → TResult

Available on ReplyNotification, provided by the ReplyNotificationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReplyNotification value)?) → TResult?

Available on ReplyNotification, provided by the ReplyNotificationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReplyNotification value)?, {required TResult orElse()}) → TResult

Available on ReplyNotification, provided by the ReplyNotificationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, AtUri post, AtUri parent, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ReplyNotification, provided by the ReplyNotificationPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ReplyNotification to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, AtUri post, AtUri parent, Map<String, dynamic>? $unknown)) → TResult

Available on ReplyNotification, provided by the ReplyNotificationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, AtUri post, AtUri parent, Map<String, dynamic>? $unknown)?) → TResult?

Available on ReplyNotification, provided by the ReplyNotificationPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>