UNotificationGetGroupedNotificationsRelatedViews class sealed

Available extensions
Annotations
  • @freezed

Properties

blockedPost → BlockedPost?

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
data → Object
no setterinherited
generatorView → GeneratorView?

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
isBlockedPost → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
isGeneratorView → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
isNotBlockedPost → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
isNotFoundPost → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
isNotGeneratorView → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
isNotNotFoundPost → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
isNotPostView → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
isNotProfileViewDetailed → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
isNotStarterPackView → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
isNotUnknown → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
isPostView → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
isProfileViewDetailed → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
isStarterPackView → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
isUnknown → bool

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
notFoundPost → NotFoundPost?

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
postView → PostView?

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
profileViewDetailed → ProfileViewDetailed?

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
starterPackView → StarterPackView?

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter
unknown → Map<String, dynamic>?

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult profileViewDetailed(UNotificationGetGroupedNotificationsRelatedViewsProfileViewDetailed value), required TResult blockedPost(UNotificationGetGroupedNotificationsRelatedViewsBlockedPost value), required TResult generatorView(UNotificationGetGroupedNotificationsRelatedViewsGeneratorView value), required TResult notFoundPost(UNotificationGetGroupedNotificationsRelatedViewsNotFoundPost value), required TResult postView(UNotificationGetGroupedNotificationsRelatedViewsPostView value), required TResult starterPackView(UNotificationGetGroupedNotificationsRelatedViewsStarterPackView value), required TResult unknown(UNotificationGetGroupedNotificationsRelatedViewsUnknown value)}) → TResult

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? profileViewDetailed(UNotificationGetGroupedNotificationsRelatedViewsProfileViewDetailed value)?, TResult? blockedPost(UNotificationGetGroupedNotificationsRelatedViewsBlockedPost value)?, TResult? generatorView(UNotificationGetGroupedNotificationsRelatedViewsGeneratorView value)?, TResult? notFoundPost(UNotificationGetGroupedNotificationsRelatedViewsNotFoundPost value)?, TResult? postView(UNotificationGetGroupedNotificationsRelatedViewsPostView value)?, TResult? starterPackView(UNotificationGetGroupedNotificationsRelatedViewsStarterPackView value)?, TResult? unknown(UNotificationGetGroupedNotificationsRelatedViewsUnknown value)?}) → TResult?

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult profileViewDetailed(UNotificationGetGroupedNotificationsRelatedViewsProfileViewDetailed value)?, TResult blockedPost(UNotificationGetGroupedNotificationsRelatedViewsBlockedPost value)?, TResult generatorView(UNotificationGetGroupedNotificationsRelatedViewsGeneratorView value)?, TResult notFoundPost(UNotificationGetGroupedNotificationsRelatedViewsNotFoundPost value)?, TResult postView(UNotificationGetGroupedNotificationsRelatedViewsPostView value)?, TResult starterPackView(UNotificationGetGroupedNotificationsRelatedViewsStarterPackView value)?, TResult unknown(UNotificationGetGroupedNotificationsRelatedViewsUnknown value)?, required TResult orElse()}) → TResult

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult profileViewDetailed(ProfileViewDetailed data)?, TResult blockedPost(BlockedPost data)?, TResult generatorView(GeneratorView data)?, TResult notFoundPost(NotFoundPost data)?, TResult postView(PostView data)?, TResult starterPackView(StarterPackView data)?, TResult unknown(Map<String, dynamic> data)?, required TResult orElse()}) → TResult

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult profileViewDetailed(ProfileViewDetailed data), required TResult blockedPost(BlockedPost data), required TResult generatorView(GeneratorView data), required TResult notFoundPost(NotFoundPost data), required TResult postView(PostView data), required TResult starterPackView(StarterPackView data), required TResult unknown(Map<String, dynamic> data)}) → TResult

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? profileViewDetailed(ProfileViewDetailed data)?, TResult? blockedPost(BlockedPost data)?, TResult? generatorView(GeneratorView data)?, TResult? notFoundPost(NotFoundPost data)?, TResult? postView(PostView data)?, TResult? starterPackView(StarterPackView data)?, TResult? unknown(Map<String, dynamic> data)?}) → TResult?

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited