UNotificationGetGroupedNotificationsRelatedViewsPatterns extension

Adds pattern-matching-related methods to UNotificationGetGroupedNotificationsRelatedViews.

on

Methods

map<TResult extends Object?>({required TResult profileViewDetailed(UNotificationGetGroupedNotificationsRelatedViewsProfileViewDetailed value), required TResult blockedPost(UNotificationGetGroupedNotificationsRelatedViewsBlockedPost value), required TResult generatorView(UNotificationGetGroupedNotificationsRelatedViewsGeneratorView value), required TResult notFoundPost(UNotificationGetGroupedNotificationsRelatedViewsNotFoundPost value), required TResult postView(UNotificationGetGroupedNotificationsRelatedViewsPostView value), required TResult starterPackView(UNotificationGetGroupedNotificationsRelatedViewsStarterPackView value), required TResult unknown(UNotificationGetGroupedNotificationsRelatedViewsUnknown value)}) → TResult

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? profileViewDetailed(UNotificationGetGroupedNotificationsRelatedViewsProfileViewDetailed value)?, TResult? blockedPost(UNotificationGetGroupedNotificationsRelatedViewsBlockedPost value)?, TResult? generatorView(UNotificationGetGroupedNotificationsRelatedViewsGeneratorView value)?, TResult? notFoundPost(UNotificationGetGroupedNotificationsRelatedViewsNotFoundPost value)?, TResult? postView(UNotificationGetGroupedNotificationsRelatedViewsPostView value)?, TResult? starterPackView(UNotificationGetGroupedNotificationsRelatedViewsStarterPackView value)?, TResult? unknown(UNotificationGetGroupedNotificationsRelatedViewsUnknown value)?}) → TResult?

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult profileViewDetailed(UNotificationGetGroupedNotificationsRelatedViewsProfileViewDetailed value)?, TResult blockedPost(UNotificationGetGroupedNotificationsRelatedViewsBlockedPost value)?, TResult generatorView(UNotificationGetGroupedNotificationsRelatedViewsGeneratorView value)?, TResult notFoundPost(UNotificationGetGroupedNotificationsRelatedViewsNotFoundPost value)?, TResult postView(UNotificationGetGroupedNotificationsRelatedViewsPostView value)?, TResult starterPackView(UNotificationGetGroupedNotificationsRelatedViewsStarterPackView value)?, TResult unknown(UNotificationGetGroupedNotificationsRelatedViewsUnknown value)?, required TResult orElse()}) → TResult

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult profileViewDetailed(ProfileViewDetailed data)?, TResult blockedPost(BlockedPost data)?, TResult generatorView(GeneratorView data)?, TResult notFoundPost(NotFoundPost data)?, TResult postView(PostView data)?, TResult starterPackView(StarterPackView data)?, TResult unknown(Map<String, dynamic> data)?, required TResult orElse()}) → TResult

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult profileViewDetailed(ProfileViewDetailed data), required TResult blockedPost(BlockedPost data), required TResult generatorView(GeneratorView data), required TResult notFoundPost(NotFoundPost data), required TResult postView(PostView data), required TResult starterPackView(StarterPackView data), required TResult unknown(Map<String, dynamic> data)}) → TResult

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? profileViewDetailed(ProfileViewDetailed data)?, TResult? blockedPost(BlockedPost data)?, TResult? generatorView(GeneratorView data)?, TResult? notFoundPost(NotFoundPost data)?, TResult? postView(PostView data)?, TResult? starterPackView(StarterPackView data)?, TResult? unknown(Map<String, dynamic> data)?}) → TResult?

Available on UNotificationGetGroupedNotificationsRelatedViews, provided by the UNotificationGetGroupedNotificationsRelatedViewsPatterns extension

A variant of when that fallback to returning null