Notification class abstract

Available extensions
Annotations
  • @freezed

Constructors

Notification({@Default.new('app.bsky.notification.listNotifications#notification') String $type, @AtUriConverter.new() required AtUri uri, required String cid, @ProfileViewConverter() required ProfileView author, @NotificationReasonConverter() required NotificationReason reason, @AtUriConverter.new() AtUri? reasonSubject, required Map<String, dynamic> record, @StarterPackViewBasicConverter() StarterPackViewBasic? starterPack, required bool isRead, @JsonKey.new(toJson: iso8601) required DateTime indexedAt, @LabelConverter() List<Label>? labels, Map<String, dynamic>? $unknown})
const
factory
Notification.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
author → ProfileView
no setterinherited
cid → String
no setterinherited
copyWith → $NotificationCopyWith<Notification>
Create a copy of Notification with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNotReasonSubject → bool

Available on Notification, provided by the NotificationExtension extension

no setter
hasNotStarterPack → bool

Available on Notification, provided by the NotificationExtension extension

no setter
hasReasonSubject → bool

Available on Notification, provided by the NotificationExtension extension

no setter
hasStarterPack → bool

Available on Notification, provided by the NotificationExtension extension

no setter
indexedAt → DateTime
no setterinherited
isIsRead → bool

Available on Notification, provided by the NotificationExtension extension

no setter
isNotIsRead → bool

Available on Notification, provided by the NotificationExtension extension

no setter
isRead → bool
no setterinherited
labels → List<Label>?
no setterinherited
reason → NotificationReason
The reason why this notification was delivered - e.g. your post was liked, or you received a new follower.
no setterinherited
reasonSubject → AtUri?
no setterinherited
record → Map<String, dynamic>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
starterPack → StarterPackViewBasic?
The starter pack associated with this notification. Present when the notification is for a follow originating from a starter pack.
no setterinherited
uri → AtUri
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Notification value)) → TResult

Available on Notification, provided by the NotificationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Notification value)?) → TResult?

Available on Notification, provided by the NotificationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Notification value)?, {required TResult orElse()}) → TResult

Available on Notification, provided by the NotificationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, AtUri uri, String cid, ProfileView author, NotificationReason reason, AtUri? reasonSubject, Map<String, dynamic> record, StarterPackViewBasic? starterPack, bool isRead, DateTime indexedAt, List<Label>? labels, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on Notification, provided by the NotificationPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Notification to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, AtUri uri, String cid, ProfileView author, NotificationReason reason, AtUri? reasonSubject, Map<String, dynamic> record, StarterPackViewBasic? starterPack, bool isRead, DateTime indexedAt, List<Label>? labels, Map<String, dynamic>? $unknown)) → TResult

Available on Notification, provided by the NotificationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, AtUri uri, String cid, ProfileView author, NotificationReason reason, AtUri? reasonSubject, Map<String, dynamic> record, StarterPackViewBasic? starterPack, bool isRead, DateTime indexedAt, List<Label>? labels, Map<String, dynamic>? $unknown)?) → TResult?

Available on Notification, provided by the NotificationPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>