NotificationListNotificationsOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

NotificationListNotificationsOutput({String? cursor, @NotificationConverter() required List<Notification> notifications, @JsonKey.new(toJson: iso8601) DateTime? seenAt, Map<String, dynamic>? $unknown})
const
factory
NotificationListNotificationsOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $NotificationListNotificationsOutputCopyWith<NotificationListNotificationsOutput>
Create a copy of NotificationListNotificationsOutput with the given fields replaced by the non-null parameter values.
no setterinherited
cursor → String?
no setterinherited
hasCursor → bool

Available on NotificationListNotificationsOutput, provided by the NotificationListNotificationsOutputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotCursor → bool

Available on NotificationListNotificationsOutput, provided by the NotificationListNotificationsOutputExtension extension

no setter
hasNotSeenAt → bool

Available on NotificationListNotificationsOutput, provided by the NotificationListNotificationsOutputExtension extension

no setter
hasSeenAt → bool

Available on NotificationListNotificationsOutput, provided by the NotificationListNotificationsOutputExtension extension

no setter
notifications → List<Notification>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seenAt → DateTime?
no setterinherited

Methods

group({GroupBy? by, NotificationsGrouperConfig? config}) → GroupedNotifications

Available on NotificationListNotificationsOutput, provided by the NotificationsExtension extension

Groups notifications the way the official Bluesky social-app does.
groupByHour(int hour) → GroupedNotifications

Available on NotificationListNotificationsOutput, provided by the NotificationsExtension extension

Groups notifications by reason and reasonSubject, additionally bucketed by hour of wall-clock time.
groupByMinute(int minute) → GroupedNotifications

Available on NotificationListNotificationsOutput, provided by the NotificationsExtension extension

Groups notifications by reason and reasonSubject, additionally bucketed by minute of wall-clock time.
map<TResult extends Object?>(TResult $default(_NotificationListNotificationsOutput value)) → TResult

Available on NotificationListNotificationsOutput, provided by the NotificationListNotificationsOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_NotificationListNotificationsOutput value)?) → TResult?

Available on NotificationListNotificationsOutput, provided by the NotificationListNotificationsOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_NotificationListNotificationsOutput value)?, {required TResult orElse()}) → TResult

Available on NotificationListNotificationsOutput, provided by the NotificationListNotificationsOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? cursor, List<Notification> notifications, DateTime? seenAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on NotificationListNotificationsOutput, provided by the NotificationListNotificationsOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this NotificationListNotificationsOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? cursor, List<Notification> notifications, DateTime? seenAt, Map<String, dynamic>? $unknown)) → TResult

Available on NotificationListNotificationsOutput, provided by the NotificationListNotificationsOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? cursor, List<Notification> notifications, DateTime? seenAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on NotificationListNotificationsOutput, provided by the NotificationListNotificationsOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>