getState method

Future<XRPCResponse<AgeassuranceGetStateOutput>> getState({
  1. required String countryCode,
  2. String? regionCode,
  3. String? $service,
  4. Map<String, String>? $headers,
  5. Map<String, String>? $unknown,
})

Returns server-computed Age Assurance state, if available, and any additional metadata needed to compute Age Assurance state client-side.

Implementation

Future<XRPCResponse<AgeassuranceGetStateOutput>> getState({
  required String countryCode,
  String? regionCode,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await appBskyAgeassuranceGetState(
  countryCode: countryCode,
  regionCode: regionCode,
  $ctx: ctx,
  $service: $service,
  $headers: $headers,
  $unknown: $unknown,
);