DraftService class base

app.bsky.draft.*

Constructors

DraftService(ServiceContext ctx)

Properties

ctx ServiceContext
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDraft({required Draft draft, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<DraftCreateDraftOutput>>
Inserts a draft using private storage (stash). An upper limit of drafts might be enforced. Requires authentication.
deleteDraft({required String id, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<EmptyData>>
Deletes a draft by ID. Requires authentication.
getDrafts({int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<DraftGetDraftsOutput>>
Gets views of user drafts. Requires authentication.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateDraft({required DraftWithId draft, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<EmptyData>>
Updates a draft using private storage (stash). If the draft ID points to a non-existing ID, the update will be silently ignored. This is done because updates don't enforce draft limit, so it accepts all writes, but will ignore invalid ones. Requires authentication.

Operators

operator ==(Object other) bool
The equality operator.
inherited