muteActor method

Future<XRPCResponse<EmptyData>> muteActor({
  1. required String actor,
  2. bool? onlyReposts,
  3. bool? onlyQuoteposts,
  4. String? $service,
  5. Map<String, String>? $headers,
  6. Map<String, String>? $unknown,
})

Creates a mute relationship for the specified account. If a mute already exists for the account, it is updated in place: the stored scope is replaced with the scope in this request. Mutes are private in Bluesky. Requires auth.

Implementation

Future<XRPCResponse<EmptyData>> muteActor({
  required String actor,
  bool? onlyReposts,
  bool? onlyQuoteposts,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await appBskyGraphMuteActor(
  actor: actor,
  onlyReposts: onlyReposts,
  onlyQuoteposts: onlyQuoteposts,
  $ctx: ctx,
  $service: $service,
  $headers: $headers,
  $unknown: $unknown,
);