referencelistoptout property

GraphReferencelistoptoutRecordAccessor get referencelistoptout

Record requesting that its author be omitted from the public presentation of a reference list. This record is only enforced when the subject list's current purpose is app.bsky.graph.defs#referencelist. AppView indexes at most one record per actor and list pair, and ignores duplicate records.

Implementation

GraphReferencelistoptoutRecordAccessor get referencelistoptout =>
    _referencelistoptout;