LabelerService class base

app.bsky.labeler.*

Available extensions

Constructors

LabelerService(ServiceContext ctx)

Properties

ctx → ServiceContext
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → LabelerServiceRecordAccessor
A declaration of the existence of labeler service.
no setter

Methods

getLabelDefinitions(ModerationPrefs prefs) → Future<Map<String, List<InterpretedLabelValueDefinition>>>

Available on LabelerService, provided by the LabelerServiceExtension extension

getServices({required List<String> dids, bool? detailed, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<LabelerGetServicesOutput>>
Get information about a list of labeler services.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited