startUpload method

Future<XRPCResponse<VideoStartUploadOutput>> startUpload({
  1. required int sizeBytes,
  2. required String mimeType,
  3. String? name,
  4. int? durationMs,
  5. int? width,
  6. int? height,
  7. String? $service,
  8. Map<String, String>? $headers,
  9. Map<String, String>? $unknown,
})

Start a multipart video upload. The declared size is exact, while optional media properties are advisory and used only for early failure; the authoritative probe runs asynchronously after upload.

Implementation

Future<XRPCResponse<VideoStartUploadOutput>> startUpload({
  required int sizeBytes,
  required String mimeType,
  String? name,
  int? durationMs,
  int? width,
  int? height,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await appBskyVideoStartUpload(
  sizeBytes: sizeBytes,
  mimeType: mimeType,
  name: name,
  durationMs: durationMs,
  width: width,
  height: height,
  $ctx: ctx,
  $service: $service,
  $headers: $headers,
  $unknown: $unknown,
);