appBskyGraphMuteActor function

Future<XRPCResponse<EmptyData>> appBskyGraphMuteActor({
  1. required String actor,
  2. bool? onlyReposts,
  3. bool? onlyQuoteposts,
  4. required ServiceContext $ctx,
  5. String? $service,
  6. Map<String, String>? $headers,
  7. Map<String, String>? $unknown,
})

Creates a mute relationship for the specified account. If a mute already exists for the account, it is updated in place: the stored scope is replaced with the scope in this request. Mutes are private in Bluesky. Requires auth.

Implementation

Future<XRPCResponse<EmptyData>> appBskyGraphMuteActor({
  required String actor,
  bool? onlyReposts,
  bool? onlyQuoteposts,
  required ServiceContext $ctx,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await $ctx.post(
  ns.appBskyGraphMuteActor,
  service: $service,
  headers: {'Content-type': 'application/json', ...?$headers},
  body: {
    ...?$unknown,
    'actor': actor,
    if (onlyReposts != null) 'onlyReposts': onlyReposts,
    if (onlyQuoteposts != null) 'onlyQuoteposts': onlyQuoteposts,
  },
);