ThreadItemPost constructor

const ThreadItemPost({
  1. @Default.new('app.bsky.unspecced.defs#threadItemPost') String $type,
  2. @PostViewConverter() required PostView post,
  3. required bool moreParents,
  4. required int moreReplies,
  5. required bool opThread,
  6. int? opThreadPostIndex,
  7. int? opThreadPostCount,
  8. required bool hiddenByThreadgate,
  9. required bool mutedByViewer,
  10. Map<String, dynamic>? $unknown,
})

Implementation

@JsonSerializable(includeIfNull: false)
const factory ThreadItemPost({
  @Default('app.bsky.unspecced.defs#threadItemPost') String $type,
  @PostViewConverter() required PostView post,

  /// This post has more parents that were not present in the response. This is just a boolean, without the number of parents.
  required bool moreParents,

  /// This post has more replies that were not present in the response. This is a numeric value, which is best-effort and might not be accurate.
  required int moreReplies,

  /// This post is part of a contiguous thread by the OP from the thread root. Sub-threads by OP deeper in the tree are not considered an OP thread.
  required bool opThread,

  /// The 1-indexed position of this post within the contiguous OP thread. Only present when this post is part of the OP thread (see `opThread`).
  int? opThreadPostIndex,

  /// The total number of posts in the contiguous OP thread that this post belongs to. Only present when this post is part of the OP thread (see `opThread`).
  int? opThreadPostCount,

  /// The threadgate created by the author indicates this post as a reply to be hidden for everyone consuming the thread.
  required bool hiddenByThreadgate,

  /// This is by an account muted by the viewer requesting it.
  required bool mutedByViewer,

  Map<String, dynamic>? $unknown,
}) = _ThreadItemPost;