hiddenByThreadgate property

bool get hiddenByThreadgate
inherited

The threadgate created by the author indicates this post as a reply to be hidden for everyone consuming the thread.

Implementation

int? get opThreadPostCount;/// The threadgate created by the author indicates this post as a reply to be hidden for everyone consuming the thread.
bool get hiddenByThreadgate;