opThreadPostIndex property

int? get opThreadPostIndex
inherited

The 1-indexed position of this post within the contiguous OP thread. Only present when this post is part of the OP thread (see opThread).

Implementation

bool get opThread;/// The 1-indexed position of this post within the contiguous OP thread. Only present when this post is part of the OP thread (see `opThread`).
int? get opThreadPostIndex;