UnspeccedGetPostThreadV2Input constructor
const
UnspeccedGetPostThreadV2Input({
- @AtUriConverter.new() required AtUri anchor,
- @Default.new(true) bool above,
- @Default.new(6) int below,
- @Default.new(10) int branchingFactor,
- @UnspeccedGetPostThreadV2SortConverter() @Default.new(UnspeccedGetPostThreadV2Sort.knownValue(data: KnownUnspeccedGetPostThreadV2Sort.oldest)) UnspeccedGetPostThreadV2Sort sort,
- Map<
String, dynamic> ? $unknown,
Implementation
@JsonSerializable(includeIfNull: false)
const factory UnspeccedGetPostThreadV2Input({
/// Reference (AT-URI) to post record. This is the anchor post, and the thread will be built around it. It can be any post in the tree, not necessarily a root post.
@AtUriConverter() required AtUri anchor,
/// Whether to include parents above the anchor.
@Default(true) bool above,
/// How many levels of replies to include below the anchor.
@Default(6) int below,
/// Maximum of replies to include at each level of the thread, except for the direct replies to the anchor, which are (NOTE: currently, during unspecced phase) all returned (NOTE: later they might be paginated).
@Default(10) int branchingFactor,
/// Sorting for the thread replies.
@UnspeccedGetPostThreadV2SortConverter()
@Default(
UnspeccedGetPostThreadV2Sort.knownValue(
data: KnownUnspeccedGetPostThreadV2Sort.oldest,
),
)
UnspeccedGetPostThreadV2Sort sort,
Map<String, dynamic>? $unknown,
}) = _UnspeccedGetPostThreadV2Input;