UnspeccedGetPostThreadV2Output class abstract

Available extensions
Annotations
  • @freezed

Constructors

UnspeccedGetPostThreadV2Output({@ThreadItemConverter() required List<ThreadItem> thread, @ThreadgateViewConverter() ThreadgateView? threadgate, required bool hasOtherReplies, Map<String, dynamic>? $unknown})
const
factory
UnspeccedGetPostThreadV2Output.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $UnspeccedGetPostThreadV2OutputCopyWith<UnspeccedGetPostThreadV2Output>
Create a copy of UnspeccedGetPostThreadV2Output with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNotThreadgate → bool

Available on UnspeccedGetPostThreadV2Output, provided by the UnspeccedGetPostThreadV2OutputExtension extension

no setter
hasOtherReplies → bool
Whether this thread has additional replies. If true, a call can be made to the getPostThreadOtherV2 endpoint to retrieve them.
no setterinherited
hasThreadgate → bool

Available on UnspeccedGetPostThreadV2Output, provided by the UnspeccedGetPostThreadV2OutputExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thread → List<ThreadItem>
no setterinherited
threadgate → ThreadgateView?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_UnspeccedGetPostThreadV2Output value)) → TResult

Available on UnspeccedGetPostThreadV2Output, provided by the UnspeccedGetPostThreadV2OutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_UnspeccedGetPostThreadV2Output value)?) → TResult?

Available on UnspeccedGetPostThreadV2Output, provided by the UnspeccedGetPostThreadV2OutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_UnspeccedGetPostThreadV2Output value)?, {required TResult orElse()}) → TResult

Available on UnspeccedGetPostThreadV2Output, provided by the UnspeccedGetPostThreadV2OutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<ThreadItem> thread, ThreadgateView? threadgate, bool hasOtherReplies, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on UnspeccedGetPostThreadV2Output, provided by the UnspeccedGetPostThreadV2OutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this UnspeccedGetPostThreadV2Output to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(List<ThreadItem> thread, ThreadgateView? threadgate, bool hasOtherReplies, Map<String, dynamic>? $unknown)) → TResult

Available on UnspeccedGetPostThreadV2Output, provided by the UnspeccedGetPostThreadV2OutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<ThreadItem> thread, ThreadgateView? threadgate, bool hasOtherReplies, Map<String, dynamic>? $unknown)?) → TResult?

Available on UnspeccedGetPostThreadV2Output, provided by the UnspeccedGetPostThreadV2OutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>