KnownJobStatusState enum

Inheritance
Implemented types
Available extensions

Values

jOB_STATE_CREATED → const KnownJobStatusState
const KnownJobStatusState('JOB_STATE_CREATED')
jOB_STATE_ENCODING → const KnownJobStatusState
const KnownJobStatusState('JOB_STATE_ENCODING')
jOB_STATE_ENCODED → const KnownJobStatusState
const KnownJobStatusState('JOB_STATE_ENCODED')
jOB_STATE_SCANNING → const KnownJobStatusState
const KnownJobStatusState('JOB_STATE_SCANNING')
jOB_STATE_SCANNED → const KnownJobStatusState
const KnownJobStatusState('JOB_STATE_SCANNED')
jOB_STATE_UPLOADING → const KnownJobStatusState
const KnownJobStatusState('JOB_STATE_UPLOADING')
jOB_STATE_UPLOADED → const KnownJobStatusState
const KnownJobStatusState('JOB_STATE_UPLOADED')
jOB_STATE_COMPLETED → const KnownJobStatusState
const KnownJobStatusState('JOB_STATE_COMPLETED')
jOB_STATE_FAILED → const KnownJobStatusState
const KnownJobStatusState('JOB_STATE_FAILED')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Returns the value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isKnownValue(String value) bool
valueOf(String? value) KnownJobStatusState?

Constants

values → const List<KnownJobStatusState>
A constant List of the values in this enum, in order of their declaration.