KnownVideoGetUploadStatusState enum
- Inheritance
- Implemented types
- Available extensions
Values
- created → const KnownVideoGetUploadStatusState
-
const KnownVideoGetUploadStatusState('created') - finishing → const KnownVideoGetUploadStatusState
-
const KnownVideoGetUploadStatusState('finishing') - completed → const KnownVideoGetUploadStatusState
-
const KnownVideoGetUploadStatusState('completed') - failed → const KnownVideoGetUploadStatusState
-
const KnownVideoGetUploadStatusState('failed') - aborted → const KnownVideoGetUploadStatusState
-
const KnownVideoGetUploadStatusState('aborted') - expired → const KnownVideoGetUploadStatusState
-
const KnownVideoGetUploadStatusState('expired')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Returns the value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isKnownValue(
String value) → bool -
valueOf(
String? value) → KnownVideoGetUploadStatusState?
Constants
-
values
→ const List<
KnownVideoGetUploadStatusState> - A constant List of the values in this enum, in order of their declaration.