VideoGetUploadStatusState class sealed

Available extensions
Annotations
  • @freezed

Constructors

VideoGetUploadStatusState.knownValue({required KnownVideoGetUploadStatusState data})
const
factory
VideoGetUploadStatusState.unknown({required String data})
const
factory

Properties

data Object
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isKnownValue bool

Available on VideoGetUploadStatusState, provided by the VideoGetUploadStatusStateExtension extension

no setter
isNotKnownValue bool

Available on VideoGetUploadStatusState, provided by the VideoGetUploadStatusStateExtension extension

no setter
isNotUnknown bool

Available on VideoGetUploadStatusState, provided by the VideoGetUploadStatusStateExtension extension

no setter
isUnknown bool

Available on VideoGetUploadStatusState, provided by the VideoGetUploadStatusStateExtension extension

no setter
knownValue KnownVideoGetUploadStatusState?

Available on VideoGetUploadStatusState, provided by the VideoGetUploadStatusStateExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknown String?

Available on VideoGetUploadStatusState, provided by the VideoGetUploadStatusStateExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult knownValue(VideoGetUploadStatusStateKnownValue value), required TResult unknown(VideoGetUploadStatusStateUnknown value)}) → TResult

Available on VideoGetUploadStatusState, provided by the VideoGetUploadStatusStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(VideoGetUploadStatusStateKnownValue value)?, TResult? unknown(VideoGetUploadStatusStateUnknown value)?}) → TResult?

Available on VideoGetUploadStatusState, provided by the VideoGetUploadStatusStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(VideoGetUploadStatusStateKnownValue value)?, TResult unknown(VideoGetUploadStatusStateUnknown value)?, required TResult orElse()}) → TResult

Available on VideoGetUploadStatusState, provided by the VideoGetUploadStatusStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownVideoGetUploadStatusState data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on VideoGetUploadStatusState, provided by the VideoGetUploadStatusStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult knownValue(KnownVideoGetUploadStatusState data), required TResult unknown(String data)}) → TResult

Available on VideoGetUploadStatusState, provided by the VideoGetUploadStatusStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownVideoGetUploadStatusState data)?, TResult? unknown(String data)?}) → TResult?

Available on VideoGetUploadStatusState, provided by the VideoGetUploadStatusStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(String? value) VideoGetUploadStatusState?