VideoStartUploadOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

VideoStartUploadOutput({required String jobId, required int partSizeBytes, required int partCount, @JsonKey.new(toJson: iso8601) required DateTime expiresAt, Map<String, dynamic>? $unknown})
const
factory
VideoStartUploadOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
copyWith → $VideoStartUploadOutputCopyWith<VideoStartUploadOutput>
Create a copy of VideoStartUploadOutput with the given fields replaced by the non-null parameter values.
no setterinherited
expiresAt DateTime
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
jobId String
no setterinherited
partCount int
no setterinherited
partSizeBytes int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_VideoStartUploadOutput value)) → TResult

Available on VideoStartUploadOutput, provided by the VideoStartUploadOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VideoStartUploadOutput value)?) → TResult?

Available on VideoStartUploadOutput, provided by the VideoStartUploadOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VideoStartUploadOutput value)?, {required TResult orElse()}) → TResult

Available on VideoStartUploadOutput, provided by the VideoStartUploadOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String jobId, int partSizeBytes, int partCount, DateTime expiresAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on VideoStartUploadOutput, provided by the VideoStartUploadOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this VideoStartUploadOutput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String jobId, int partSizeBytes, int partCount, DateTime expiresAt, Map<String, dynamic>? $unknown)) → TResult

Available on VideoStartUploadOutput, provided by the VideoStartUploadOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String jobId, int partSizeBytes, int partCount, DateTime expiresAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on VideoStartUploadOutput, provided by the VideoStartUploadOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>