InMemoryOAuthSessionStore class final

Process-memory OAuthSessionStore. Sessions are lost on restart.

Implemented types

Constructors

InMemoryOAuthSessionStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String sub) Future<void>
override
find(String sub) Future<OAuthSession?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String sub, OAuthSession session) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited