OAuthClientMetadata class abstract

Available extensions
Annotations
  • @freezed

Constructors

OAuthClientMetadata({required String clientId, required String applicationType, required String clientName, required String clientUri, @Default.new(true) bool dpopBoundAccessTokens, @Default.new([]) List<String> grantTypes, @Default.new([]) List<String> redirectUris, @Default.new([]) List<String> responseTypes, required String scope, required String tokenEndpointAuthMethod})
const
factory
OAuthClientMetadata.fromJson(Map<String, Object?> json)
factory

Properties

applicationType → String
no setterinherited
clientId → String
no setterinherited
clientName → String
no setterinherited
clientUri → String
no setterinherited
copyWith → $OAuthClientMetadataCopyWith<OAuthClientMetadata>
Create a copy of OAuthClientMetadata with the given fields replaced by the non-null parameter values.
no setterinherited
dpopBoundAccessTokens → bool
no setterinherited
grantTypes → List<String>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
redirectUris → List<String>
no setterinherited
responseTypes → List<String>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
no setterinherited
tokenEndpointAuthMethod → String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_OAuthClientMetadata value)) → TResult

Available on OAuthClientMetadata, provided by the OAuthClientMetadataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_OAuthClientMetadata value)?) → TResult?

Available on OAuthClientMetadata, provided by the OAuthClientMetadataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_OAuthClientMetadata value)?, {required TResult orElse()}) → TResult

Available on OAuthClientMetadata, provided by the OAuthClientMetadataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String clientId, String applicationType, String clientName, String clientUri, bool dpopBoundAccessTokens, List<String> grantTypes, List<String> redirectUris, List<String> responseTypes, String scope, String tokenEndpointAuthMethod)?, {required TResult orElse()}) → TResult

Available on OAuthClientMetadata, provided by the OAuthClientMetadataPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this OAuthClientMetadata to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String clientId, String applicationType, String clientName, String clientUri, bool dpopBoundAccessTokens, List<String> grantTypes, List<String> redirectUris, List<String> responseTypes, String scope, String tokenEndpointAuthMethod)) → TResult

Available on OAuthClientMetadata, provided by the OAuthClientMetadataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String clientId, String applicationType, String clientName, String clientUri, bool dpopBoundAccessTokens, List<String> grantTypes, List<String> redirectUris, List<String> responseTypes, String scope, String tokenEndpointAuthMethod)?) → TResult?

Available on OAuthClientMetadata, provided by the OAuthClientMetadataPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited