sub property
Subject identifier for token binding.
Unique identifier that binds the token to a specific user or entity. For atproto this is the account DID.
Implementation
final String sub;
Subject identifier for token binding.
Unique identifier that binds the token to a specific user or entity. For atproto this is the account DID.
final String sub;