OAuthSessionRevokedException class final
Thrown when a refresh fails with invalid_grant or the session has been
revoked. The session has been removed from the session store; callers
should route the user back through authorize.
- Inheritance
-
- Object
- OAuthException
- OAuthSessionRevokedException
Constructors
- OAuthSessionRevokedException(String message)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited