OAuthStateStore class abstract interface

Persists per-authorization OAuthContext between authorize and callback, keyed by the OAuth state parameter. Inject a durable implementation to support callbacks that arrive after an app restart.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String key) Future<void>
find(String key) Future<OAuthContext?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String key, OAuthContext context) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited