FeedServiceImpl class final

Inheritance

Constructors

FeedServiceImpl(ServiceContext ctx)

Properties

ctx ServiceContext
finalinherited
generator FeedGeneratorRecordAccessor
Record declaring of the existence of a feed generator, and containing metadata about it. The record can exist in any repository.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
like FeedLikeRecordAccessor
Record declaring a 'like' of a piece of subject content.
no setterinherited
post FeedPostRecordAccessor
Record containing a Bluesky post.
no setterinherited
postgate FeedPostgateRecordAccessor
Record defining interaction rules for a post. The record key (rkey) of the postgate record must match the record key of the post, and that record must be in the same repository.
no setterinherited
repost FeedRepostRecordAccessor
Record representing a 'repost' of an existing Bluesky post.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threadgate FeedThreadgateRecordAccessor
Record defining interaction gating rules for a thread (aka, reply controls). The record key (rkey) of the threadgate record must match the record key of the thread's root post, and that record must be in the same repository.
no setterinherited

Methods

buildPostText(String text, {HandleResolver? handleResolver}) Future<PostText>
Formats text and resolves its facets — mentions, links, hashtags — returning both in the types post.create and ThreadPost take.
createThreadAtomic({required List<ThreadPost> posts, ReplyRef? reply, DateTime? createdAt, bool? validate, String? swapCommit, String? $service, Map<String, String>? $headers}) Future<XRPCResponse<CreatedThread>>
Publishes posts as one thread, in a single atomic commit, and returns each created post's strong ref in order.
describeFeedGenerator({String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedDescribeFeedGeneratorOutput>>
Get information about a feed generator, including policies and offered feed URIs. Does not require auth; implemented by Feed Generator services (not App View).
inherited
getActorFeeds({required String actor, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetActorFeedsOutput>>
Get a list of feeds (feed generator records) created by the actor (in the actor's repo).
inherited
getActorLikes({required String actor, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetActorLikesOutput>>
Get a list of posts liked by an actor. Requires auth, actor must be the requesting account.
inherited
getAuthorFeed({required String actor, int? limit, String? cursor, FeedGetAuthorFeedFilter? filter, bool? includePins, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetAuthorFeedOutput>>
Get a view of an actor's 'author feed' (post and reposts by the author). Does not require auth.
inherited
getFeed({required AtUri feed, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetFeedOutput>>
Get a hydrated feed from an actor's selected feed generator. Implemented by App View.
inherited
getFeedGenerator({required AtUri feed, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetFeedGeneratorOutput>>
Get information about a feed generator. Implemented by AppView.
inherited
getFeedGenerators({required List<AtUri> feeds, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetFeedGeneratorsOutput>>
Get information about a list of feed generators.
inherited
getFeedSkeleton({required AtUri feed, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetFeedSkeletonOutput>>
Get a skeleton of a feed provided by a feed generator. Auth is optional, depending on provider requirements, and provides the DID of the requester. Implemented by Feed Generator Service.
inherited
getLikes({required AtUri uri, String? cid, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetLikesOutput>>
Get like records which reference a subject (by AT-URI and CID).
inherited
getListFeed({required AtUri list, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetListFeedOutput>>
Get a feed of recent posts from a list (posts and reposts from any actors on the list). Does not require auth.
inherited
getPosts({required List<AtUri> uris, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetPostsOutput>>
Gets post views for a specified list of posts (by AT-URI). This is sometimes referred to as 'hydrating' a 'feed skeleton'.
inherited
getPostThread({required AtUri uri, int? depth, int? parentHeight, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetPostThreadOutput>>
Get posts in a thread. Does not require auth, but additional metadata and filtering will be applied for authed requests.
inherited
getQuotes({required AtUri uri, String? cid, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetQuotesOutput>>
Get a list of quotes for a given post.
inherited
getRepostedBy({required AtUri uri, String? cid, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetRepostedByOutput>>
Get a list of reposts for a given post.
inherited
getSuggestedFeeds({int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetSuggestedFeedsOutput>>
Get a list of suggested feeds (feed generators) for the requesting account.
inherited
getTimeline({String? algorithm, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedGetTimelineOutput>>
Get a view of the requesting account's home timeline. This is expected to be some form of reverse-chronological feed.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postText(String text, {ReplyRef? reply, UFeedPostEmbed? embed, List<String>? langs, UFeedPostLabels? labels, List<String>? tags, DateTime? createdAt, String? rkey, bool? validate, String? swapCommit, HandleResolver? handleResolver, void onUnresolvedHandles(List<String> handles)?, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<RepoCreateRecordOutput>>
Builds text with buildPostText and publishes it as an app.bsky.feed.post in one call.
searchPosts({required String q, FeedSearchPostsSort? sort, String? since, String? until, String? mentions, String? author, String? lang, String? domain, String? url, List<String>? tag, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedSearchPostsOutput>>
Find posts matching search criteria, returning views of those posts. Note that this API endpoint may require authentication (eg, not public) for some service providers and implementations.
inherited
searchPostsV2({String? cursor, int? limit, String? query, FeedSearchPostsV2Sort? sort, List<String>? authors, List<String>? mentions, List<String>? domains, List<String>? urls, List<AtUri>? embeddedAtUris, List<String>? hashtags, List<String>? excludeAuthors, List<String>? excludeMentions, List<String>? excludeDomains, List<String>? excludeUrls, List<AtUri>? excludeEmbeddedAtUris, List<String>? excludeHashtags, String? since, String? until, bool? allTime, List<String>? languages, List<String>? excludeLanguages, bool? hasMedia, bool? hasVideo, AtUri? replyParentUri, AtUri? threadRootUri, bool? excludeReplies, bool? repliesOnly, bool? following, FeedSearchPostsV2QueryLanguage? queryLanguage, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<FeedSearchPostsV2Output>>
Find posts matching a search query or filters, returning search hits for matching post records.
inherited
sendInteractions({AtUri? feed, required List<Interaction> interactions, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<EmptyData>>
Send information about interactions with feed items back to the feed generator that served them.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited