GroupedNotificationPatterns extension

Adds pattern-matching-related methods to GroupedNotification.

on

Methods

map<TResult extends Object?>(TResult $default(_GroupedNotification value)) → TResult

Available on GroupedNotification, provided by the GroupedNotificationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GroupedNotification value)?) → TResult?

Available on GroupedNotification, provided by the GroupedNotificationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GroupedNotification value)?, {required TResult orElse()}) → TResult

Available on GroupedNotification, provided by the GroupedNotificationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<AtUri> uris, List<ProfileView> authors, GroupedNotificationReason reason, AtUri? reasonSubject, bool isRead, List<Label> labels, Map<String, dynamic>? record, DateTime indexedAt)?, {required TResult orElse()}) → TResult

Available on GroupedNotification, provided by the GroupedNotificationPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(List<AtUri> uris, List<ProfileView> authors, GroupedNotificationReason reason, AtUri? reasonSubject, bool isRead, List<Label> labels, Map<String, dynamic>? record, DateTime indexedAt)) → TResult

Available on GroupedNotification, provided by the GroupedNotificationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<AtUri> uris, List<ProfileView> authors, GroupedNotificationReason reason, AtUri? reasonSubject, bool isRead, List<Label> labels, Map<String, dynamic>? record, DateTime indexedAt)?) → TResult?

Available on GroupedNotification, provided by the GroupedNotificationPatterns extension

A variant of when that fallback to returning null