GroupedNotificationReason enum

A class that encapsulates a reason for grouped notification.

Inheritance
Available extensions

Values

like → const GroupedNotificationReason

Indicates likes.

const GroupedNotificationReason('like')
customFeedLike → const GroupedNotificationReason

Indicates likes for custom feed.

const GroupedNotificationReason('customFeedLike')
repost → const GroupedNotificationReason

Indicates reposts.

const GroupedNotificationReason('repost')
follow → const GroupedNotificationReason

Indicates follows.

const GroupedNotificationReason('follow')
mention → const GroupedNotificationReason

Indicates mentions.

const GroupedNotificationReason('mention')
reply → const GroupedNotificationReason

Indicates replies.

const GroupedNotificationReason('reply')
quote → const GroupedNotificationReason

Indicates quotes.

const GroupedNotificationReason('quote')
starterpackJoined → const GroupedNotificationReason

Indicates a join of a starter pack.

const GroupedNotificationReason('starterpack-joined')
verified → const GroupedNotificationReason

Indicates the account was verified.

const GroupedNotificationReason('verified')
unverified → const GroupedNotificationReason

Indicates the account verification was removed.

const GroupedNotificationReason('unverified')
likeViaRepost → const GroupedNotificationReason

Indicates a like created via a repost.

const GroupedNotificationReason('like-via-repost')
repostViaRepost → const GroupedNotificationReason

Indicates a repost created via a repost.

const GroupedNotificationReason('repost-via-repost')
subscribedPost → const GroupedNotificationReason

Indicates a new post from a subscribed account.

const GroupedNotificationReason('subscribed-post')
contactMatch → const GroupedNotificationReason

Indicates a matched contact.

const GroupedNotificationReason('contact-match')
unknown → const GroupedNotificationReason

Indicates a reason that is not known to this client version.

This is a safe fallback so that new reasons introduced by the AppView do not crash the grouping logic.

const GroupedNotificationReason('unknown')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isContactMatch bool
Returns true if this reason is contactMatch, otherwise false.
no setter
isCustomFeedLike bool
Returns true if this reason is customFeedLike, otherwise false.
no setter
isFollow bool
Returns true if this reason is follow, otherwise false.
no setter
isLike bool
Returns true if this reason is like, otherwise false.
no setter
isLikeViaRepost bool
Returns true if this reason is likeViaRepost, otherwise false.
no setter
isMention bool
Returns true if this reason is mention, otherwise false.
no setter
isNotContactMatch bool
Returns true if this reason is not contactMatch, otherwise false.
no setter
isNotCustomFeedLike bool
Returns true if this reason is not customFeedLike, otherwise false.
no setter
isNotFollow bool
Returns true if this reason is not follow, otherwise false.
no setter
isNotLike bool
Returns true if this reason is not like, otherwise false.
no setter
isNotLikeViaRepost bool
Returns true if this reason is not likeViaRepost, otherwise false.
no setter
isNotMention bool
Returns true if this reason is not mention, otherwise false.
no setter
isNotQuote bool
Returns true if this reason is not quote, otherwise false.
no setter
isNotReply bool
Returns true if this reason is not reply, otherwise false.
no setter
isNotRepost bool
Returns true if this reason is not repost, otherwise false.
no setter
isNotRepostViaRepost bool
Returns true if this reason is not repostViaRepost, otherwise false.
no setter
isNotStarterpackJoined bool
Returns true if this reason is not starterpackJoined, otherwise false.
no setter
isNotSubscribedPost bool
Returns true if this reason is not subscribedPost, otherwise false.
no setter
isNotUnknown bool
Returns true if this reason is not unknown, otherwise false.
no setter
isNotUnverified bool
Returns true if this reason is not unverified, otherwise false.
no setter
isNotVerified bool
Returns true if this reason is not verified, otherwise false.
no setter
isQuote bool
Returns true if this reason is quote, otherwise false.
no setter
isReply bool
Returns true if this reason is reply, otherwise false.
no setter
isRepost bool
Returns true if this reason is repost, otherwise false.
no setter
isRepostViaRepost bool
Returns true if this reason is repostViaRepost, otherwise false.
no setter
isStarterpackJoined bool
Returns true if this reason is starterpackJoined, otherwise false.
no setter
isSubscribedPost bool
Returns true if this reason is subscribedPost, otherwise false.
no setter
isUnknown bool
Returns true if this reason is unknown, otherwise false.
no setter
isUnverified bool
Returns true if this reason is unverified, otherwise false.
no setter
isVerified bool
Returns true if this reason is verified, otherwise false.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Json value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(String? value) GroupedNotificationReason
Returns the GroupedNotificationReason associated with the given value.

Constants

values → const List<GroupedNotificationReason>
A constant List of the values in this enum, in order of their declaration.