ActorDeclarationRecord class abstract

A declaration of a Bluesky chat account.

Available extensions
Annotations
  • @freezed

Constructors

ActorDeclarationRecord({@Default.new('chat.bsky.actor.declaration') String $type, @ActorDeclarationAllowIncomingConverter() required ActorDeclarationAllowIncoming allowIncoming, @ActorDeclarationAllowGroupInvitesConverter() ActorDeclarationAllowGroupInvites? allowGroupInvites, Map<String, dynamic>? $unknown})
const
factory
ActorDeclarationRecord.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
allowGroupInvites ActorDeclarationAllowGroupInvites?
NOTE: This is under active development and should be considered unstable while this note is here. Declaration about group chat invitation preferences for the record owner.
no setterinherited
allowIncoming ActorDeclarationAllowIncoming
no setterinherited
copyWith → $ActorDeclarationRecordCopyWith<ActorDeclarationRecord>
Create a copy of ActorDeclarationRecord with the given fields replaced by the non-null parameter values.
no setterinherited
hasAllowGroupInvites bool

Available on ActorDeclarationRecord, provided by the ActorDeclarationRecordExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotAllowGroupInvites bool

Available on ActorDeclarationRecord, provided by the ActorDeclarationRecordExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ActorDeclarationRecord value)) → TResult

Available on ActorDeclarationRecord, provided by the ActorDeclarationRecordPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ActorDeclarationRecord value)?) → TResult?

Available on ActorDeclarationRecord, provided by the ActorDeclarationRecordPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ActorDeclarationRecord value)?, {required TResult orElse()}) → TResult

Available on ActorDeclarationRecord, provided by the ActorDeclarationRecordPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, ActorDeclarationAllowIncoming allowIncoming, ActorDeclarationAllowGroupInvites? allowGroupInvites, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ActorDeclarationRecord, provided by the ActorDeclarationRecordPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ActorDeclarationRecord to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, ActorDeclarationAllowIncoming allowIncoming, ActorDeclarationAllowGroupInvites? allowGroupInvites, Map<String, dynamic>? $unknown)) → TResult

Available on ActorDeclarationRecord, provided by the ActorDeclarationRecordPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, ActorDeclarationAllowIncoming allowIncoming, ActorDeclarationAllowGroupInvites? allowGroupInvites, Map<String, dynamic>? $unknown)?) → TResult?

Available on ActorDeclarationRecord, provided by the ActorDeclarationRecordPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>