allowGroupInvites property
NOTE: This is under active development and should be considered unstable while this note is here. Declaration about group chat invitation preferences for the record owner.
Implementation
String get $type;@ActorDeclarationAllowIncomingConverter() ActorDeclarationAllowIncoming get allowIncoming;/// [NOTE: This is under active development and should be considered unstable while this note is here]. Declaration about group chat invitation preferences for the record owner.
@ActorDeclarationAllowGroupInvitesConverter() ActorDeclarationAllowGroupInvites? get allowGroupInvites;