ProfileViewBasic class abstract

Available extensions
Annotations
  • @freezed

Constructors

ProfileViewBasic({@Default.new('chat.bsky.actor.defs#profileViewBasic') String $type, required String did, required String handle, String? displayName, String? avatar, @ProfileAssociatedConverter() ProfileAssociated? associated, @ViewerStateConverter() ViewerState? viewer, @LabelConverter() List<Label>? labels, @JsonKey.new(toJson: iso8601) DateTime? createdAt, bool? chatDisabled, @VerificationStateConverter() VerificationState? verification, @UProfileViewBasicKindConverter() UProfileViewBasicKind? kind, Map<String, dynamic>? $unknown})
const
factory
ProfileViewBasic.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
associated → ProfileAssociated?
no setterinherited
avatar → String?
no setterinherited
chatDisabled → bool?
Set to true when the actor cannot actively participate in conversations
no setterinherited
copyWith → $ProfileViewBasicCopyWith<ProfileViewBasic>
Create a copy of ProfileViewBasic with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime?
no setterinherited
did → String
no setterinherited
displayName → String?
no setterinherited
handle → String
no setterinherited
hasAssociated → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
hasAvatar → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
hasCreatedAt → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
hasDisplayName → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasKind → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
hasNotAssociated → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
hasNotAvatar → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
hasNotCreatedAt → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
hasNotDisplayName → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
hasNotKind → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
hasNotVerification → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
hasNotViewer → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
hasVerification → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
hasViewer → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
isChatDisabled → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
isNotChatDisabled → bool

Available on ProfileViewBasic, provided by the ProfileViewBasicExtension extension

no setter
kind → UProfileViewBasicKind?
no setterinherited
labels → List<Label>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verification → VerificationState?
no setterinherited
viewer → ViewerState?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ProfileViewBasic value)) → TResult

Available on ProfileViewBasic, provided by the ProfileViewBasicPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ProfileViewBasic value)?) → TResult?

Available on ProfileViewBasic, provided by the ProfileViewBasicPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ProfileViewBasic value)?, {required TResult orElse()}) → TResult

Available on ProfileViewBasic, provided by the ProfileViewBasicPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String did, String handle, String? displayName, String? avatar, ProfileAssociated? associated, ViewerState? viewer, List<Label>? labels, DateTime? createdAt, bool? chatDisabled, VerificationState? verification, UProfileViewBasicKind? kind, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ProfileViewBasic, provided by the ProfileViewBasicPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ProfileViewBasic to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String did, String handle, String? displayName, String? avatar, ProfileAssociated? associated, ViewerState? viewer, List<Label>? labels, DateTime? createdAt, bool? chatDisabled, VerificationState? verification, UProfileViewBasicKind? kind, Map<String, dynamic>? $unknown)) → TResult

Available on ProfileViewBasic, provided by the ProfileViewBasicPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String did, String handle, String? displayName, String? avatar, ProfileAssociated? associated, ViewerState? viewer, List<Label>? labels, DateTime? createdAt, bool? chatDisabled, VerificationState? verification, UProfileViewBasicKind? kind, Map<String, dynamic>? $unknown)?) → TResult?

Available on ProfileViewBasic, provided by the ProfileViewBasicPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>