ActorGetStatusOutput constructor
const
ActorGetStatusOutput({})
Implementation
@JsonSerializable(includeIfNull: false)
const factory ActorGetStatusOutput({
/// True when the viewer's account is disabled and cannot actively participate in chat.
required bool chatDisabled,
/// Whether the viewer's account is allowed to create group chats. New accounts are restricted from creating groups.
required bool canCreateGroups,
/// The maximum number of members allowed in a group conversation.
required int groupMemberLimit,
Map<String, dynamic>? $unknown,
}) = _ActorGetStatusOutput;