chatDisabled property
True when the viewer's account is disabled and cannot actively participate in chat.
Implementation
bool get chatDisabled;
True when the viewer's account is disabled and cannot actively participate in chat.
bool get chatDisabled;