LogApproveJoinRequest class abstract

Event indicating a join request was approved by the viewer. Only the owner gets this. The approved member gets a logBeginConvo.

Available extensions
Annotations
  • @freezed

Constructors

LogApproveJoinRequest({@Default.new('chat.bsky.convo.defs#logApproveJoinRequest') String $type, required String rev, required String convoId, @ProfileViewBasicConverter() required ProfileViewBasic member, Map<String, dynamic>? $unknown})
const
factory
LogApproveJoinRequest.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
convoId String
no setterinherited
copyWith → $LogApproveJoinRequestCopyWith<LogApproveJoinRequest>
Create a copy of LogApproveJoinRequest with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
member ProfileViewBasic
Prospective member who requested to join.
no setterinherited
rev String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_LogApproveJoinRequest value)) → TResult

Available on LogApproveJoinRequest, provided by the LogApproveJoinRequestPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_LogApproveJoinRequest value)?) → TResult?

Available on LogApproveJoinRequest, provided by the LogApproveJoinRequestPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_LogApproveJoinRequest value)?, {required TResult orElse()}) → TResult

Available on LogApproveJoinRequest, provided by the LogApproveJoinRequestPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String rev, String convoId, ProfileViewBasic member, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on LogApproveJoinRequest, provided by the LogApproveJoinRequestPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this LogApproveJoinRequest to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String rev, String convoId, ProfileViewBasic member, Map<String, dynamic>? $unknown)) → TResult

Available on LogApproveJoinRequest, provided by the LogApproveJoinRequestPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String rev, String convoId, ProfileViewBasic member, Map<String, dynamic>? $unknown)?) → TResult?

Available on LogApproveJoinRequest, provided by the LogApproveJoinRequestPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>