LogWithdrawIncomingJoinRequest class abstract

Event indicating a prospective member withdrew their join request. Only the owner gets this.

Available extensions
Annotations
  • @freezed

Constructors

LogWithdrawIncomingJoinRequest({@Default.new('chat.bsky.convo.defs#logWithdrawIncomingJoinRequest') String $type, required String rev, required String convoId, @ProfileViewBasicConverter() required ProfileViewBasic member, Map<String, dynamic>? $unknown})
const
factory
LogWithdrawIncomingJoinRequest.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
convoId String
no setterinherited
copyWith → $LogWithdrawIncomingJoinRequestCopyWith<LogWithdrawIncomingJoinRequest>
Create a copy of LogWithdrawIncomingJoinRequest with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
member ProfileViewBasic
Prospective member who withdrew their join request.
no setterinherited
rev String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_LogWithdrawIncomingJoinRequest value)) → TResult

Available on LogWithdrawIncomingJoinRequest, provided by the LogWithdrawIncomingJoinRequestPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_LogWithdrawIncomingJoinRequest value)?) → TResult?

Available on LogWithdrawIncomingJoinRequest, provided by the LogWithdrawIncomingJoinRequestPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_LogWithdrawIncomingJoinRequest value)?, {required TResult orElse()}) → TResult

Available on LogWithdrawIncomingJoinRequest, provided by the LogWithdrawIncomingJoinRequestPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String rev, String convoId, ProfileViewBasic member, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on LogWithdrawIncomingJoinRequest, provided by the LogWithdrawIncomingJoinRequestPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this LogWithdrawIncomingJoinRequest to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String rev, String convoId, ProfileViewBasic member, Map<String, dynamic>? $unknown)) → TResult

Available on LogWithdrawIncomingJoinRequest, provided by the LogWithdrawIncomingJoinRequestPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String rev, String convoId, ProfileViewBasic member, Map<String, dynamic>? $unknown)?) → TResult?

Available on LogWithdrawIncomingJoinRequest, provided by the LogWithdrawIncomingJoinRequestPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>