MessageBeforeUserJoinedGroupView class abstract

Placeholder embedded in place of a reply's parent message when that parent was sent before the viewer joined the group convo. The viewer has no access to that history, so no message data is carried.

Available extensions
Annotations
  • @freezed

Constructors

MessageBeforeUserJoinedGroupView({@Default.new('chat.bsky.convo.defs#messageBeforeUserJoinedGroupView') String $type, Map<String, dynamic>? $unknown})
const
factory
MessageBeforeUserJoinedGroupView.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
copyWith → $MessageBeforeUserJoinedGroupViewCopyWith<MessageBeforeUserJoinedGroupView>
Create a copy of MessageBeforeUserJoinedGroupView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_MessageBeforeUserJoinedGroupView value)) → TResult

Available on MessageBeforeUserJoinedGroupView, provided by the MessageBeforeUserJoinedGroupViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_MessageBeforeUserJoinedGroupView value)?) → TResult?

Available on MessageBeforeUserJoinedGroupView, provided by the MessageBeforeUserJoinedGroupViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_MessageBeforeUserJoinedGroupView value)?, {required TResult orElse()}) → TResult

Available on MessageBeforeUserJoinedGroupView, provided by the MessageBeforeUserJoinedGroupViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on MessageBeforeUserJoinedGroupView, provided by the MessageBeforeUserJoinedGroupViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this MessageBeforeUserJoinedGroupView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, Map<String, dynamic>? $unknown)) → TResult

Available on MessageBeforeUserJoinedGroupView, provided by the MessageBeforeUserJoinedGroupViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, Map<String, dynamic>? $unknown)?) → TResult?

Available on MessageBeforeUserJoinedGroupView, provided by the MessageBeforeUserJoinedGroupViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>