MessageInput constructor

const MessageInput({
  1. @Default.new('chat.bsky.convo.defs#messageInput') String $type,
  2. required String text,
  3. @RichtextFacetConverter() List<RichtextFacet>? facets,
  4. @UMessageInputEmbedConverter() UMessageInputEmbed? embed,
  5. @ReplyRefConverter() ReplyRef? replyTo,
  6. Map<String, dynamic>? $unknown,
})

Implementation

@JsonSerializable(includeIfNull: false)
const factory MessageInput({
  @Default('chat.bsky.convo.defs#messageInput') String $type,
  required String text,
  @RichtextFacetConverter() List<RichtextFacet>? facets,
  @UMessageInputEmbedConverter() UMessageInputEmbed? embed,

  /// If set, the message this message is replying to. The referenced message must be in the same convo.
  @ReplyRefConverter() ReplyRef? replyTo,

  Map<String, dynamic>? $unknown,
}) = _MessageInput;