MessageView class abstract

Available extensions
Annotations
  • @freezed

Constructors

MessageView({@Default.new('chat.bsky.convo.defs#messageView') String $type, required String id, required String rev, required String text, @RichtextFacetConverter() List<RichtextFacet>? facets, @UMessageViewEmbedConverter() UMessageViewEmbed? embed, @ReactionViewConverter() List<ReactionView>? reactions, @UMessageViewReplyToConverter() UMessageViewReplyTo? replyTo, @MessageViewSenderConverter() required MessageViewSender sender, @JsonKey.new(toJson: iso8601) required DateTime sentAt, Map<String, dynamic>? $unknown})
const
factory
MessageView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $MessageViewCopyWith<MessageView>
Create a copy of MessageView with the given fields replaced by the non-null parameter values.
no setterinherited
embed → UMessageViewEmbed?
no setterinherited
facets → List<RichtextFacet>?
no setterinherited
hasEmbed → bool

Available on MessageView, provided by the MessageViewExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotEmbed → bool

Available on MessageView, provided by the MessageViewExtension extension

no setter
hasNotReplyTo → bool

Available on MessageView, provided by the MessageViewExtension extension

no setter
hasReplyTo → bool

Available on MessageView, provided by the MessageViewExtension extension

no setter
id → String
no setterinherited
reactions → List<ReactionView>?
no setterinherited
replyTo → UMessageViewReplyTo?
no setterinherited
rev → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → MessageViewSender
no setterinherited
sentAt → DateTime
no setterinherited
text → String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_MessageView value)) → TResult

Available on MessageView, provided by the MessageViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_MessageView value)?) → TResult?

Available on MessageView, provided by the MessageViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_MessageView value)?, {required TResult orElse()}) → TResult

Available on MessageView, provided by the MessageViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String id, String rev, String text, List<RichtextFacet>? facets, UMessageViewEmbed? embed, List<ReactionView>? reactions, UMessageViewReplyTo? replyTo, MessageViewSender sender, DateTime sentAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on MessageView, provided by the MessageViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this MessageView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String id, String rev, String text, List<RichtextFacet>? facets, UMessageViewEmbed? embed, List<ReactionView>? reactions, UMessageViewReplyTo? replyTo, MessageViewSender sender, DateTime sentAt, Map<String, dynamic>? $unknown)) → TResult

Available on MessageView, provided by the MessageViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String id, String rev, String text, List<RichtextFacet>? facets, UMessageViewEmbed? embed, List<ReactionView>? reactions, UMessageViewReplyTo? replyTo, MessageViewSender sender, DateTime sentAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on MessageView, provided by the MessageViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>