SystemMessageDataAddMember class abstract

NOTE: This is under active development and should be considered unstable while this note is here. System message indicating a user was added to the group convo.

Available extensions
Annotations
  • @freezed

Constructors

SystemMessageDataAddMember({@Default.new('chat.bsky.convo.defs#systemMessageDataAddMember') String $type, @SystemMessageReferredUserConverter() required SystemMessageReferredUser member, @MemberRoleConverter() required MemberRole role, @SystemMessageReferredUserConverter() required SystemMessageReferredUser addedBy, Map<String, dynamic>? $unknown})
const
factory
SystemMessageDataAddMember.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
addedBy SystemMessageReferredUser
no setterinherited
copyWith → $SystemMessageDataAddMemberCopyWith<SystemMessageDataAddMember>
Create a copy of SystemMessageDataAddMember with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
member SystemMessageReferredUser
Current view of the member who was added.
no setterinherited
role MemberRole
Role the user was added to the group with. The role from 'member' will reflect the current data, not historical.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SystemMessageDataAddMember value)) → TResult

Available on SystemMessageDataAddMember, provided by the SystemMessageDataAddMemberPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SystemMessageDataAddMember value)?) → TResult?

Available on SystemMessageDataAddMember, provided by the SystemMessageDataAddMemberPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SystemMessageDataAddMember value)?, {required TResult orElse()}) → TResult

Available on SystemMessageDataAddMember, provided by the SystemMessageDataAddMemberPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, SystemMessageReferredUser member, MemberRole role, SystemMessageReferredUser addedBy, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on SystemMessageDataAddMember, provided by the SystemMessageDataAddMemberPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SystemMessageDataAddMember to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, SystemMessageReferredUser member, MemberRole role, SystemMessageReferredUser addedBy, Map<String, dynamic>? $unknown)) → TResult

Available on SystemMessageDataAddMember, provided by the SystemMessageDataAddMemberPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, SystemMessageReferredUser member, MemberRole role, SystemMessageReferredUser addedBy, Map<String, dynamic>? $unknown)?) → TResult?

Available on SystemMessageDataAddMember, provided by the SystemMessageDataAddMemberPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>