role property
Role the user was added to the group with. The role from 'member' will reflect the current data, not historical.
Implementation
@SystemMessageReferredUserConverter() SystemMessageReferredUser get member;/// Role the user was added to the group with. The role from 'member' will reflect the current data, not historical.
@MemberRoleConverter() MemberRole get role;