lockedBy property

Current view of the member who locked the group.

Implementation

String get $type;/// Current view of the member who locked the group.
@SystemMessageReferredUserConverter() SystemMessageReferredUser get lockedBy;