SystemMessageDataLockConvoPermanently class abstract

NOTE: This is under active development and should be considered unstable while this note is here. System message indicating the group convo was locked permanently.

Available extensions
Annotations
  • @freezed

Constructors

SystemMessageDataLockConvoPermanently({@Default.new('chat.bsky.convo.defs#systemMessageDataLockConvoPermanently') String $type, @SystemMessageReferredUserConverter() required SystemMessageReferredUser lockedBy, Map<String, dynamic>? $unknown})
const
factory
SystemMessageDataLockConvoPermanently.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
copyWith → $SystemMessageDataLockConvoPermanentlyCopyWith<SystemMessageDataLockConvoPermanently>
Create a copy of SystemMessageDataLockConvoPermanently with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
lockedBy SystemMessageReferredUser
Current view of the member who locked the group.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SystemMessageDataLockConvoPermanently value)) → TResult

Available on SystemMessageDataLockConvoPermanently, provided by the SystemMessageDataLockConvoPermanentlyPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SystemMessageDataLockConvoPermanently value)?) → TResult?

Available on SystemMessageDataLockConvoPermanently, provided by the SystemMessageDataLockConvoPermanentlyPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SystemMessageDataLockConvoPermanently value)?, {required TResult orElse()}) → TResult

Available on SystemMessageDataLockConvoPermanently, provided by the SystemMessageDataLockConvoPermanentlyPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, SystemMessageReferredUser lockedBy, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on SystemMessageDataLockConvoPermanently, provided by the SystemMessageDataLockConvoPermanentlyPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SystemMessageDataLockConvoPermanently to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, SystemMessageReferredUser lockedBy, Map<String, dynamic>? $unknown)) → TResult

Available on SystemMessageDataLockConvoPermanently, provided by the SystemMessageDataLockConvoPermanentlyPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, SystemMessageReferredUser lockedBy, Map<String, dynamic>? $unknown)?) → TResult?

Available on SystemMessageDataLockConvoPermanently, provided by the SystemMessageDataLockConvoPermanentlyPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>