SystemMessageDataMemberJoin constructor
Implementation
@JsonSerializable(includeIfNull: false)
const factory SystemMessageDataMemberJoin({
@Default('chat.bsky.convo.defs#systemMessageDataMemberJoin') String $type,
/// Current view of the member who joined.
@SystemMessageReferredUserConverter()
required SystemMessageReferredUser member,
/// Role the user was added to the group with. The role from 'member' will reflect the current data, not historical.
@MemberRoleConverter() required MemberRole role,
/// If join link was configured to require approval, this will be set to who approved the request. Undefined if approval was not required.
@SystemMessageReferredUserConverter() SystemMessageReferredUser? approvedBy,
Map<String, dynamic>? $unknown,
}) = _SystemMessageDataMemberJoin;