approvedBy property

If join link was configured to require approval, this will be set to who approved the request. Undefined if approval was not required.

Implementation

@MemberRoleConverter() MemberRole get role;/// If join link was configured to require approval, this will be set to who approved the request. Undefined if approval was not required.
@SystemMessageReferredUserConverter() SystemMessageReferredUser? get approvedBy;