SystemMessageView class abstract

NOTE: This is under active development and should be considered unstable while this note is here.

Available extensions
Annotations
  • @freezed

Constructors

SystemMessageView({@Default.new('chat.bsky.convo.defs#systemMessageView') String $type, required String id, required String rev, required DateTime sentAt, @USystemMessageViewDataConverter() required USystemMessageViewData data, Map<String, dynamic>? $unknown})
const
factory
SystemMessageView.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
copyWith → $SystemMessageViewCopyWith<SystemMessageView>
Create a copy of SystemMessageView with the given fields replaced by the non-null parameter values.
no setterinherited
data USystemMessageViewData
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
rev String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentAt DateTime
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SystemMessageView value)) → TResult

Available on SystemMessageView, provided by the SystemMessageViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SystemMessageView value)?) → TResult?

Available on SystemMessageView, provided by the SystemMessageViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SystemMessageView value)?, {required TResult orElse()}) → TResult

Available on SystemMessageView, provided by the SystemMessageViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String id, String rev, DateTime sentAt, USystemMessageViewData data, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on SystemMessageView, provided by the SystemMessageViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SystemMessageView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String id, String rev, DateTime sentAt, USystemMessageViewData data, Map<String, dynamic>? $unknown)) → TResult

Available on SystemMessageView, provided by the SystemMessageViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String id, String rev, DateTime sentAt, USystemMessageViewData data, Map<String, dynamic>? $unknown)?) → TResult?

Available on SystemMessageView, provided by the SystemMessageViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>