SystemMessageViewPatterns extension

Adds pattern-matching-related methods to SystemMessageView.

on

Methods

map<TResult extends Object?>(TResult $default(_SystemMessageView value)) → TResult

Available on SystemMessageView, provided by the SystemMessageViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SystemMessageView value)?) → TResult?

Available on SystemMessageView, provided by the SystemMessageViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SystemMessageView value)?, {required TResult orElse()}) → TResult

Available on SystemMessageView, provided by the SystemMessageViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String id, String rev, DateTime sentAt, USystemMessageViewData data, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on SystemMessageView, provided by the SystemMessageViewPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String $type, String id, String rev, DateTime sentAt, USystemMessageViewData data, Map<String, dynamic>? $unknown)) → TResult

Available on SystemMessageView, provided by the SystemMessageViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String id, String rev, DateTime sentAt, USystemMessageViewData data, Map<String, dynamic>? $unknown)?) → TResult?

Available on SystemMessageView, provided by the SystemMessageViewPatterns extension

A variant of when that fallback to returning null