UMessageInputEmbed class sealed

Available extensions
Annotations
  • @freezed

Constructors

const
factory
UMessageInputEmbed.embedRecord({required EmbedRecord data})
const
factory
UMessageInputEmbed.unknown({required Map<String, dynamic> data})
const
factory

Properties

data Object
no setterinherited

Available on UMessageInputEmbed, provided by the UMessageInputEmbedExtension extension

no setter
embedRecord EmbedRecord?

Available on UMessageInputEmbed, provided by the UMessageInputEmbedExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited

Available on UMessageInputEmbed, provided by the UMessageInputEmbedExtension extension

no setter
isEmbedRecord bool

Available on UMessageInputEmbed, provided by the UMessageInputEmbedExtension extension

no setter

Available on UMessageInputEmbed, provided by the UMessageInputEmbedExtension extension

no setter
isNotEmbedRecord bool

Available on UMessageInputEmbed, provided by the UMessageInputEmbedExtension extension

no setter
isNotUnknown bool

Available on UMessageInputEmbed, provided by the UMessageInputEmbedExtension extension

no setter
isUnknown bool

Available on UMessageInputEmbed, provided by the UMessageInputEmbedExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknown Map<String, dynamic>?

Available on UMessageInputEmbed, provided by the UMessageInputEmbedExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult embedRecord(UMessageInputEmbedEmbedRecord value), required TResult embedJoinLink(UMessageInputEmbedEmbedJoinLink value), required TResult unknown(UMessageInputEmbedUnknown value)}) → TResult

Available on UMessageInputEmbed, provided by the UMessageInputEmbedPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? embedRecord(UMessageInputEmbedEmbedRecord value)?, TResult? embedJoinLink(UMessageInputEmbedEmbedJoinLink value)?, TResult? unknown(UMessageInputEmbedUnknown value)?}) → TResult?

Available on UMessageInputEmbed, provided by the UMessageInputEmbedPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult embedRecord(UMessageInputEmbedEmbedRecord value)?, TResult embedJoinLink(UMessageInputEmbedEmbedJoinLink value)?, TResult unknown(UMessageInputEmbedUnknown value)?, required TResult orElse()}) → TResult

Available on UMessageInputEmbed, provided by the UMessageInputEmbedPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult embedRecord(EmbedRecord data)?, TResult embedJoinLink(EmbedJoinLink data)?, TResult unknown(Map<String, dynamic> data)?, required TResult orElse()}) → TResult

Available on UMessageInputEmbed, provided by the UMessageInputEmbedPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult embedRecord(EmbedRecord data), required TResult embedJoinLink(EmbedJoinLink data), required TResult unknown(Map<String, dynamic> data)}) → TResult

Available on UMessageInputEmbed, provided by the UMessageInputEmbedPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? embedRecord(EmbedRecord data)?, TResult? embedJoinLink(EmbedJoinLink data)?, TResult? unknown(Map<String, dynamic> data)?}) → TResult?

Available on UMessageInputEmbed, provided by the UMessageInputEmbedPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited