GroupAddMembersOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

GroupAddMembersOutput({@ConvoViewConverter() required ConvoView convo, @ProfileViewBasicConverter() List<ProfileViewBasic>? addedMembers, Map<String, dynamic>? $unknown})
const
factory
GroupAddMembersOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
addedMembers List<ProfileViewBasic>?
no setterinherited
convo ConvoView
no setterinherited
copyWith → $GroupAddMembersOutputCopyWith<GroupAddMembersOutput>
Create a copy of GroupAddMembersOutput with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GroupAddMembersOutput value)) → TResult

Available on GroupAddMembersOutput, provided by the GroupAddMembersOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GroupAddMembersOutput value)?) → TResult?

Available on GroupAddMembersOutput, provided by the GroupAddMembersOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GroupAddMembersOutput value)?, {required TResult orElse()}) → TResult

Available on GroupAddMembersOutput, provided by the GroupAddMembersOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(ConvoView convo, List<ProfileViewBasic>? addedMembers, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on GroupAddMembersOutput, provided by the GroupAddMembersOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GroupAddMembersOutput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(ConvoView convo, List<ProfileViewBasic>? addedMembers, Map<String, dynamic>? $unknown)) → TResult

Available on GroupAddMembersOutput, provided by the GroupAddMembersOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(ConvoView convo, List<ProfileViewBasic>? addedMembers, Map<String, dynamic>? $unknown)?) → TResult?

Available on GroupAddMembersOutput, provided by the GroupAddMembersOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>