chat_bsky_group_defs library

Classes

DisabledJoinLinkPreviewView
Preview for a disabled join link. Carries only the code so clients can correlate with the input and render a disabled state.
DisabledJoinLinkPreviewViewConverter
InvalidJoinLinkPreviewView
Preview for a join link code that does not map to an existing link. Carries only the code so clients can correlate with the input and render an invalid state.
InvalidJoinLinkPreviewViewConverter
JoinLinkPreviewView
Preview that can be shown in feeds, including to unauthenticated viewers.
JoinLinkPreviewViewConverter
JoinLinkView
Join link view to be used within a group view, so the convo is surrounding, not specified inside this view.
JoinLinkViewConverter
JoinLinkViewerState
JoinLinkViewerStateConverter
JoinRequestConvoView
A join request from the perspective of the requester, including enough group context to render the request in a list (e.g. group name, owner, member count).
JoinRequestConvoViewConverter
JoinRequestView
A join request from the perspective of the group owner.
JoinRequestViewConverter
JoinRule
JoinRuleConverter
LinkEnabledStatus
LinkEnabledStatusConverter