InvalidJoinLinkPreviewView class abstract
Preview for a join link code that does not map to an existing link. Carries only the code so clients can correlate with the input and render an invalid state.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
InvalidJoinLinkPreviewView({@Default.new('chat.bsky.group.defs#invalidJoinLinkPreviewView') String $type, required String code, Map<
String, dynamic> ? $unknown}) -
constfactory
-
InvalidJoinLinkPreviewView.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
- code → String
-
no setterinherited
-
copyWith
→ $InvalidJoinLinkPreviewViewCopyWith<
InvalidJoinLinkPreviewView> -
Create a copy of InvalidJoinLinkPreviewView
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_InvalidJoinLinkPreviewView value)) → TResult -
Available on InvalidJoinLinkPreviewView, provided by the InvalidJoinLinkPreviewViewPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_InvalidJoinLinkPreviewView value)?) → TResult? -
Available on InvalidJoinLinkPreviewView, provided by the InvalidJoinLinkPreviewViewPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_InvalidJoinLinkPreviewView value)?, {required TResult orElse()}) → TResult -
Available on InvalidJoinLinkPreviewView, provided by the InvalidJoinLinkPreviewViewPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, String code, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on InvalidJoinLinkPreviewView, provided by the InvalidJoinLinkPreviewViewPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this InvalidJoinLinkPreviewView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, String code, Map< String, dynamic> ? $unknown)) → TResult -
Available on InvalidJoinLinkPreviewView, provided by the InvalidJoinLinkPreviewViewPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, String code, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on InvalidJoinLinkPreviewView, provided by the InvalidJoinLinkPreviewViewPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>