JoinLinkPreviewView class abstract

Available extensions
Annotations
  • @freezed

Constructors

JoinLinkPreviewView({@Default.new('chat.bsky.group.defs#joinLinkPreviewView') String $type, required String name, @ProfileViewBasicConverter() required ProfileViewBasic owner, required int memberCount, required bool requireApproval, @ConvoViewConverter() ConvoView? convo, Map<String, dynamic>? $unknown})
const
factory
JoinLinkPreviewView.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
convo ConvoView?
Present only if the request is authenticated and the user is a member of the group.
no setterinherited
copyWith → $JoinLinkPreviewViewCopyWith<JoinLinkPreviewView>
Create a copy of JoinLinkPreviewView with the given fields replaced by the non-null parameter values.
no setterinherited
hasConvo bool

Available on JoinLinkPreviewView, provided by the JoinLinkPreviewViewExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotConvo bool

Available on JoinLinkPreviewView, provided by the JoinLinkPreviewViewExtension extension

no setter
isNotRequireApproval bool

Available on JoinLinkPreviewView, provided by the JoinLinkPreviewViewExtension extension

no setter
isRequireApproval bool

Available on JoinLinkPreviewView, provided by the JoinLinkPreviewViewExtension extension

no setter
memberCount int
no setterinherited
name String
no setterinherited
owner ProfileViewBasic
no setterinherited
requireApproval bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_JoinLinkPreviewView value)) → TResult

Available on JoinLinkPreviewView, provided by the JoinLinkPreviewViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_JoinLinkPreviewView value)?) → TResult?

Available on JoinLinkPreviewView, provided by the JoinLinkPreviewViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_JoinLinkPreviewView value)?, {required TResult orElse()}) → TResult

Available on JoinLinkPreviewView, provided by the JoinLinkPreviewViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String name, ProfileViewBasic owner, int memberCount, bool requireApproval, ConvoView? convo, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on JoinLinkPreviewView, provided by the JoinLinkPreviewViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this JoinLinkPreviewView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String name, ProfileViewBasic owner, int memberCount, bool requireApproval, ConvoView? convo, Map<String, dynamic>? $unknown)) → TResult

Available on JoinLinkPreviewView, provided by the JoinLinkPreviewViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String name, ProfileViewBasic owner, int memberCount, bool requireApproval, ConvoView? convo, Map<String, dynamic>? $unknown)?) → TResult?

Available on JoinLinkPreviewView, provided by the JoinLinkPreviewViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>