JoinLinkViewerStatePatterns extension

Adds pattern-matching-related methods to JoinLinkViewerState.

on

Methods

map<TResult extends Object?>(TResult $default(_JoinLinkViewerState value)) → TResult

Available on JoinLinkViewerState, provided by the JoinLinkViewerStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_JoinLinkViewerState value)?) → TResult?

Available on JoinLinkViewerState, provided by the JoinLinkViewerStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_JoinLinkViewerState value)?, {required TResult orElse()}) → TResult

Available on JoinLinkViewerState, provided by the JoinLinkViewerStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, DateTime? requestedAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on JoinLinkViewerState, provided by the JoinLinkViewerStatePatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String $type, DateTime? requestedAt, Map<String, dynamic>? $unknown)) → TResult

Available on JoinLinkViewerState, provided by the JoinLinkViewerStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, DateTime? requestedAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on JoinLinkViewerState, provided by the JoinLinkViewerStatePatterns extension

A variant of when that fallback to returning null