GroupEditJoinLinkInput class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
GroupEditJoinLinkInput({required String convoId, bool? requireApproval, @JoinRuleConverter() JoinRule? joinRule, Map<
String, dynamic> ? $unknown}) -
constfactory
-
GroupEditJoinLinkInput.fromJson(Map<
String, Object?> json) -
factory
Properties
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
- convoId → String
-
no setterinherited
-
copyWith
→ $GroupEditJoinLinkInputCopyWith<
GroupEditJoinLinkInput> -
Create a copy of GroupEditJoinLinkInput
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasJoinRule → bool
-
Available on GroupEditJoinLinkInput, provided by the GroupEditJoinLinkInputExtension extension
no setter - hasNotJoinRule → bool
-
Available on GroupEditJoinLinkInput, provided by the GroupEditJoinLinkInputExtension extension
no setter - isNotRequireApproval → bool
-
Available on GroupEditJoinLinkInput, provided by the GroupEditJoinLinkInputExtension extension
no setter - isRequireApproval → bool
-
Available on GroupEditJoinLinkInput, provided by the GroupEditJoinLinkInputExtension extension
no setter - joinRule → JoinRule?
-
no setterinherited
- requireApproval → bool?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_GroupEditJoinLinkInput value)) → TResult -
Available on GroupEditJoinLinkInput, provided by the GroupEditJoinLinkInputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_GroupEditJoinLinkInput value)?) → TResult? -
Available on GroupEditJoinLinkInput, provided by the GroupEditJoinLinkInputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_GroupEditJoinLinkInput value)?, {required TResult orElse()}) → TResult -
Available on GroupEditJoinLinkInput, provided by the GroupEditJoinLinkInputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String convoId, bool? requireApproval, JoinRule? joinRule, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on GroupEditJoinLinkInput, provided by the GroupEditJoinLinkInputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this GroupEditJoinLinkInput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String convoId, bool? requireApproval, JoinRule? joinRule, Map< String, dynamic> ? $unknown)) → TResult -
Available on GroupEditJoinLinkInput, provided by the GroupEditJoinLinkInputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String convoId, bool? requireApproval, JoinRule? joinRule, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on GroupEditJoinLinkInput, provided by the GroupEditJoinLinkInputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>