GroupListMutualGroupsInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

GroupListMutualGroupsInput({required String subject, @Default.new(50) int limit, String? cursor, Map<String, dynamic>? $unknown})
const
factory
GroupListMutualGroupsInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
copyWith → $GroupListMutualGroupsInputCopyWith<GroupListMutualGroupsInput>
Create a copy of GroupListMutualGroupsInput with the given fields replaced by the non-null parameter values.
no setterinherited
cursor String?
no setterinherited
hasCursor bool

Available on GroupListMutualGroupsInput, provided by the GroupListMutualGroupsInputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotCursor bool

Available on GroupListMutualGroupsInput, provided by the GroupListMutualGroupsInputExtension extension

no setter
limit int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GroupListMutualGroupsInput value)) → TResult

Available on GroupListMutualGroupsInput, provided by the GroupListMutualGroupsInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GroupListMutualGroupsInput value)?) → TResult?

Available on GroupListMutualGroupsInput, provided by the GroupListMutualGroupsInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GroupListMutualGroupsInput value)?, {required TResult orElse()}) → TResult

Available on GroupListMutualGroupsInput, provided by the GroupListMutualGroupsInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String subject, int limit, String? cursor, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on GroupListMutualGroupsInput, provided by the GroupListMutualGroupsInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GroupListMutualGroupsInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String subject, int limit, String? cursor, Map<String, dynamic>? $unknown)) → TResult

Available on GroupListMutualGroupsInput, provided by the GroupListMutualGroupsInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String subject, int limit, String? cursor, Map<String, dynamic>? $unknown)?) → TResult?

Available on GroupListMutualGroupsInput, provided by the GroupListMutualGroupsInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>