GroupRequestJoinOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

GroupRequestJoinOutput({@GroupRequestJoinStatusConverter() required GroupRequestJoinStatus status, @ConvoViewConverter() ConvoView? convo, Map<String, dynamic>? $unknown})
const
factory
GroupRequestJoinOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
convo ConvoView?
The group convo joined. This is only present in the case of status=joined
no setterinherited
copyWith → $GroupRequestJoinOutputCopyWith<GroupRequestJoinOutput>
Create a copy of GroupRequestJoinOutput with the given fields replaced by the non-null parameter values.
no setterinherited
hasConvo bool

Available on GroupRequestJoinOutput, provided by the GroupRequestJoinOutputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotConvo bool

Available on GroupRequestJoinOutput, provided by the GroupRequestJoinOutputExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status GroupRequestJoinStatus
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GroupRequestJoinOutput value)) → TResult

Available on GroupRequestJoinOutput, provided by the GroupRequestJoinOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GroupRequestJoinOutput value)?) → TResult?

Available on GroupRequestJoinOutput, provided by the GroupRequestJoinOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GroupRequestJoinOutput value)?, {required TResult orElse()}) → TResult

Available on GroupRequestJoinOutput, provided by the GroupRequestJoinOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(GroupRequestJoinStatus status, ConvoView? convo, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on GroupRequestJoinOutput, provided by the GroupRequestJoinOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GroupRequestJoinOutput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(GroupRequestJoinStatus status, ConvoView? convo, Map<String, dynamic>? $unknown)) → TResult

Available on GroupRequestJoinOutput, provided by the GroupRequestJoinOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(GroupRequestJoinStatus status, ConvoView? convo, Map<String, dynamic>? $unknown)?) → TResult?

Available on GroupRequestJoinOutput, provided by the GroupRequestJoinOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>