convo property

  1. @ConvoViewConverter()
ConvoView? get convo
inherited

The group convo joined. This is only present in the case of status=joined

Implementation

@GroupRequestJoinStatusConverter() GroupRequestJoinStatus get status;/// The group convo joined. This is only present in the case of status=joined
@ConvoViewConverter() ConvoView? get convo;