ModerationGetMessageContextInput constructor

  1. @JsonSerializable.new(includeIfNull: false)
const ModerationGetMessageContextInput({
  1. String? convoId,
  2. required String messageId,
  3. @Default.new(5) int before,
  4. @Default.new(5) int after,
  5. @Default.new(10) int maxInterleavedSystemMessages,
  6. Map<String, dynamic>? $unknown,
})

Implementation

@JsonSerializable(includeIfNull: false)
const factory ModerationGetMessageContextInput({
  /// Conversation that the message is from. NOTE: this field will eventually be required.
  String? convoId,
  required String messageId,

  /// Number of user messages before the target to include. System messages between the earliest returned user message and the target are also included, capped per gap by `maxInterleavedSystemMessages`. If there are no user messages before the target, up to `maxInterleavedSystemMessages` system messages immediately preceding the target are returned instead.
  @Default(5) int before,

  /// Number of user messages after the target to include. System messages between the target and the latest returned user message are also included, capped per gap by `maxInterleavedSystemMessages`. If there are no user messages after the target, up to `maxInterleavedSystemMessages` system messages immediately following the target are returned instead.
  @Default(5) int after,

  /// Maximum number of system messages to include per gap between consecutive returned messages (and per side when there are no user messages on that side). Within a gap, the system messages closest to the earlier message are kept.
  @Default(10) int maxInterleavedSystemMessages,

  Map<String, dynamic>? $unknown,
}) = _ModerationGetMessageContextInput;