before property
Number of user messages before the target to include. System messages between the earliest returned user message and the target are also included, capped per gap by maxInterleavedSystemMessages. If there are no user messages before the target, up to maxInterleavedSystemMessages system messages immediately preceding the target are returned instead.
Implementation
String? get convoId; String get messageId;/// Number of user messages before the target to include. System messages between the earliest returned user message and the target are also included, capped per gap by `maxInterleavedSystemMessages`. If there are no user messages before the target, up to `maxInterleavedSystemMessages` system messages immediately preceding the target are returned instead.
int get before;