maxInterleavedSystemMessages property

int get maxInterleavedSystemMessages
inherited

Maximum number of system messages to include per gap between consecutive returned messages (and per side when there are no user messages on that side). Within a gap, the system messages closest to the earlier message are kept.

Implementation

int get after;/// Maximum number of system messages to include per gap between consecutive returned messages (and per side when there are no user messages on that side). Within a gap, the system messages closest to the earlier message are kept.
int get maxInterleavedSystemMessages;