EventChatAcceptedMethod class abstract

Available extensions
Annotations
  • @freezed

Constructors

EventChatAcceptedMethod.knownValue({required KnownEventChatAcceptedMethod data})
const
factory
EventChatAcceptedMethod.unknown({required String data})
const
factory

Properties

data Object
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isKnownValue bool

Available on EventChatAcceptedMethod, provided by the EventChatAcceptedMethodExtension extension

no setter
isNotKnownValue bool

Available on EventChatAcceptedMethod, provided by the EventChatAcceptedMethodExtension extension

no setter
isNotUnknown bool

Available on EventChatAcceptedMethod, provided by the EventChatAcceptedMethodExtension extension

no setter
isUnknown bool

Available on EventChatAcceptedMethod, provided by the EventChatAcceptedMethodExtension extension

no setter
knownValue KnownEventChatAcceptedMethod?

Available on EventChatAcceptedMethod, provided by the EventChatAcceptedMethodExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknown String?

Available on EventChatAcceptedMethod, provided by the EventChatAcceptedMethodExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult knownValue(EventChatAcceptedMethodKnownValue value), required TResult unknown(EventChatAcceptedMethodUnknown value)}) → TResult

Available on EventChatAcceptedMethod, provided by the EventChatAcceptedMethodPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(EventChatAcceptedMethodKnownValue value)?, TResult? unknown(EventChatAcceptedMethodUnknown value)?}) → TResult?

Available on EventChatAcceptedMethod, provided by the EventChatAcceptedMethodPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(EventChatAcceptedMethodKnownValue value)?, TResult unknown(EventChatAcceptedMethodUnknown value)?, required TResult orElse()}) → TResult

Available on EventChatAcceptedMethod, provided by the EventChatAcceptedMethodPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownEventChatAcceptedMethod data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on EventChatAcceptedMethod, provided by the EventChatAcceptedMethodPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult knownValue(KnownEventChatAcceptedMethod data), required TResult unknown(String data)}) → TResult

Available on EventChatAcceptedMethod, provided by the EventChatAcceptedMethodPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownEventChatAcceptedMethod data)?, TResult? unknown(String data)?}) → TResult?

Available on EventChatAcceptedMethod, provided by the EventChatAcceptedMethodPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(String? value) EventChatAcceptedMethod?