joinLinkCode property
The code of the join link used to request joining.
Implementation
int get groupMemberCount; String get groupName;/// The code of the join link used to request joining.
String get joinLinkCode;
The code of the join link used to request joining.
int get groupMemberCount; String get groupName;/// The code of the join link used to request joining.
String get joinLinkCode;