EventGroupChatJoinRequestApproved class abstract

Fired when a join request is approved by the group owner.

Available extensions
Annotations
  • @freezed

Constructors

EventGroupChatJoinRequestApproved({@Default.new('chat.bsky.moderation.subscribeModEvents#eventGroupChatJoinRequestApproved') String $type, required String actorDid, required DateTime convoCreatedAt, required String convoId, required DateTime createdAt, required int groupMemberCount, required String groupName, required String ownerDid, required String rev, required String subjectDid, Map<String, dynamic>? $unknown})
const
factory
EventGroupChatJoinRequestApproved.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
actorDid String
The DID of the owner approving the request.
no setterinherited
convoCreatedAt DateTime
When the group was originally created.
no setterinherited
convoId String
no setterinherited
copyWith → $EventGroupChatJoinRequestApprovedCopyWith<EventGroupChatJoinRequestApproved>
Create a copy of EventGroupChatJoinRequestApproved with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime
no setterinherited
groupMemberCount int
Current member count at the time of the event.
no setterinherited
groupName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ownerDid String
The DID of the group chat owner.
no setterinherited
rev String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subjectDid String
The DID of the member whose request was approved.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EventGroupChatJoinRequestApproved value)) → TResult

Available on EventGroupChatJoinRequestApproved, provided by the EventGroupChatJoinRequestApprovedPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EventGroupChatJoinRequestApproved value)?) → TResult?

Available on EventGroupChatJoinRequestApproved, provided by the EventGroupChatJoinRequestApprovedPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EventGroupChatJoinRequestApproved value)?, {required TResult orElse()}) → TResult

Available on EventGroupChatJoinRequestApproved, provided by the EventGroupChatJoinRequestApprovedPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String actorDid, DateTime convoCreatedAt, String convoId, DateTime createdAt, int groupMemberCount, String groupName, String ownerDid, String rev, String subjectDid, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EventGroupChatJoinRequestApproved, provided by the EventGroupChatJoinRequestApprovedPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this EventGroupChatJoinRequestApproved to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String actorDid, DateTime convoCreatedAt, String convoId, DateTime createdAt, int groupMemberCount, String groupName, String ownerDid, String rev, String subjectDid, Map<String, dynamic>? $unknown)) → TResult

Available on EventGroupChatJoinRequestApproved, provided by the EventGroupChatJoinRequestApprovedPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String actorDid, DateTime convoCreatedAt, String convoId, DateTime createdAt, int groupMemberCount, String groupName, String ownerDid, String rev, String subjectDid, Map<String, dynamic>? $unknown)?) → TResult?

Available on EventGroupChatJoinRequestApproved, provided by the EventGroupChatJoinRequestApprovedPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>