groupMemberCount property
Current member count at the time of the event.
Implementation
DateTime get convoCreatedAt; String get convoId; DateTime get createdAt;/// Current member count at the time of the event.
int get groupMemberCount;
Current member count at the time of the event.
DateTime get convoCreatedAt; String get convoId; DateTime get createdAt;/// Current member count at the time of the event.
int get groupMemberCount;