groupMemberCount property

int get groupMemberCount
inherited

Current member count at the time of the event.

Implementation

DateTime get convoCreatedAt; String get convoId; DateTime get createdAt;/// Current member count at the time of the event.
int get groupMemberCount;