EventGroupChatUpdated class abstract

Fired when a group chat's metadata or status changes.

Available extensions
Annotations
  • @freezed

Constructors

EventGroupChatUpdated({@Default.new('chat.bsky.moderation.subscribeModEvents#eventGroupChatUpdated') String $type, required String actorDid, required DateTime convoCreatedAt, required String convoId, required DateTime createdAt, required int groupMemberCount, required String groupName, String? joinLinkCode, bool? joinLinkFollowersOnly, bool? joinLinkRequiresApproval, @EventGroupChatUpdatedLockReasonConverter() EventGroupChatUpdatedLockReason? lockReason, String? newName, String? oldName, required String ownerDid, required String rev, @EventGroupChatUpdatedUpdateTypeConverter() required EventGroupChatUpdatedUpdateType updateType, Map<String, dynamic>? $unknown})
const
factory
EventGroupChatUpdated.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
actorDid String
The DID of the actor performing the action (the owner).
no setterinherited
convoCreatedAt DateTime
When the group was originally created.
no setterinherited
convoId String
no setterinherited
copyWith → $EventGroupChatUpdatedCopyWith<EventGroupChatUpdated>
Create a copy of EventGroupChatUpdated with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime
no setterinherited
groupMemberCount int
Current member count at the time of the event.
no setterinherited
groupName String
Current group name.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasJoinLinkCode bool

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedExtension extension

no setter
hasLockReason bool

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedExtension extension

no setter
hasNewName bool

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedExtension extension

no setter
hasNotJoinLinkCode bool

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedExtension extension

no setter
hasNotLockReason bool

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedExtension extension

no setter
hasNotNewName bool

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedExtension extension

no setter
hasNotOldName bool

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedExtension extension

no setter
hasOldName bool

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedExtension extension

no setter
isJoinLinkFollowersOnly bool

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedExtension extension

no setter
isJoinLinkRequiresApproval bool

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedExtension extension

no setter
isNotJoinLinkFollowersOnly bool

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedExtension extension

no setter
isNotJoinLinkRequiresApproval bool

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedExtension extension

no setter
joinLinkCode String?
The code of the join link. Only present when updateType is join-link-related.
no setterinherited
joinLinkFollowersOnly bool?
Whether the join link is restricted to followers of the owner. Only present when updateType is join-link-related.
no setterinherited
joinLinkRequiresApproval bool?
Whether the join link requires owner approval to join. Only present when updateType is join-link-related.
no setterinherited
lockReason EventGroupChatUpdatedLockReason?
Why the group was locked. Only present when updateType is 'locked'.
no setterinherited
newName String?
The new group name. Only present when updateType is 'name_changed'.
no setterinherited
oldName String?
The previous group name. Only present when updateType is 'name_changed'.
no setterinherited
ownerDid String
The DID of the group chat owner.
no setterinherited
rev String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateType EventGroupChatUpdatedUpdateType
What changed.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EventGroupChatUpdated value)) → TResult

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EventGroupChatUpdated value)?) → TResult?

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EventGroupChatUpdated value)?, {required TResult orElse()}) → TResult

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String actorDid, DateTime convoCreatedAt, String convoId, DateTime createdAt, int groupMemberCount, String groupName, String? joinLinkCode, bool? joinLinkFollowersOnly, bool? joinLinkRequiresApproval, EventGroupChatUpdatedLockReason? lockReason, String? newName, String? oldName, String ownerDid, String rev, EventGroupChatUpdatedUpdateType updateType, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this EventGroupChatUpdated to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String actorDid, DateTime convoCreatedAt, String convoId, DateTime createdAt, int groupMemberCount, String groupName, String? joinLinkCode, bool? joinLinkFollowersOnly, bool? joinLinkRequiresApproval, EventGroupChatUpdatedLockReason? lockReason, String? newName, String? oldName, String ownerDid, String rev, EventGroupChatUpdatedUpdateType updateType, Map<String, dynamic>? $unknown)) → TResult

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String actorDid, DateTime convoCreatedAt, String convoId, DateTime createdAt, int groupMemberCount, String groupName, String? joinLinkCode, bool? joinLinkFollowersOnly, bool? joinLinkRequiresApproval, EventGroupChatUpdatedLockReason? lockReason, String? newName, String? oldName, String ownerDid, String rev, EventGroupChatUpdatedUpdateType updateType, Map<String, dynamic>? $unknown)?) → TResult?

Available on EventGroupChatUpdated, provided by the EventGroupChatUpdatedPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>