EventGroupChatUpdated constructor
- @JsonSerializable.new(includeIfNull: false)
const
EventGroupChatUpdated(
{ - @Default.new('chat.bsky.moderation.subscribeModEvents#eventGroupChatUpdated') String $type,
- required String actorDid,
- required DateTime convoCreatedAt,
- required String convoId,
- required DateTime createdAt,
- required int groupMemberCount,
- required String groupName,
- String? joinLinkCode,
- bool? joinLinkFollowersOnly,
- bool? joinLinkRequiresApproval,
- @EventGroupChatUpdatedLockReasonConverter() EventGroupChatUpdatedLockReason? lockReason,
- String? newName,
- String? oldName,
- required String ownerDid,
- required String rev,
- @EventGroupChatUpdatedUpdateTypeConverter() required EventGroupChatUpdatedUpdateType updateType,
- Map<String, dynamic>? $unknown,
})
Implementation
@JsonSerializable(includeIfNull: false)
const factory EventGroupChatUpdated({
@Default('chat.bsky.moderation.subscribeModEvents#eventGroupChatUpdated')
String $type,
/// The DID of the actor performing the action (the owner).
required String actorDid,
/// When the group was originally created.
required DateTime convoCreatedAt,
required String convoId,
required DateTime createdAt,
/// Current member count at the time of the event.
required int groupMemberCount,
/// Current group name.
required String groupName,
/// The code of the join link. Only present when updateType is join-link-related.
String? joinLinkCode,
/// Whether the join link is restricted to followers of the owner. Only present when updateType is join-link-related.
bool? joinLinkFollowersOnly,
/// Whether the join link requires owner approval to join. Only present when updateType is join-link-related.
bool? joinLinkRequiresApproval,
/// Why the group was locked. Only present when updateType is 'locked'.
@EventGroupChatUpdatedLockReasonConverter()
EventGroupChatUpdatedLockReason? lockReason,
/// The new group name. Only present when updateType is 'name_changed'.
String? newName,
/// The previous group name. Only present when updateType is 'name_changed'.
String? oldName,
/// The DID of the group chat owner.
required String ownerDid,
required String rev,
/// What changed.
@EventGroupChatUpdatedUpdateTypeConverter()
required EventGroupChatUpdatedUpdateType updateType,
Map<String, dynamic>? $unknown,
}) = _EventGroupChatUpdated;