EventRateLimitExceeded class abstract

Fired when a user exceeds a rate limit.

Available extensions
Annotations
  • @freezed

Constructors

EventRateLimitExceeded({@Default.new('chat.bsky.moderation.subscribeModEvents#eventRateLimitExceeded') String $type, required String actorDid, @JsonKey.new(toJson: iso8601) required DateTime createdAt, required String endpoint, required String rev, Map<String, dynamic>? $unknown})
const
factory
EventRateLimitExceeded.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
actorDid String
The DID of the user who hit the rate limit.
no setterinherited
copyWith → $EventRateLimitExceededCopyWith<EventRateLimitExceeded>
Create a copy of EventRateLimitExceeded with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime
no setterinherited
endpoint String
The NSID of the endpoint that was rate limited.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
rev String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EventRateLimitExceeded value)) → TResult

Available on EventRateLimitExceeded, provided by the EventRateLimitExceededPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EventRateLimitExceeded value)?) → TResult?

Available on EventRateLimitExceeded, provided by the EventRateLimitExceededPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EventRateLimitExceeded value)?, {required TResult orElse()}) → TResult

Available on EventRateLimitExceeded, provided by the EventRateLimitExceededPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String actorDid, DateTime createdAt, String endpoint, String rev, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EventRateLimitExceeded, provided by the EventRateLimitExceededPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this EventRateLimitExceeded to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String actorDid, DateTime createdAt, String endpoint, String rev, Map<String, dynamic>? $unknown)) → TResult

Available on EventRateLimitExceeded, provided by the EventRateLimitExceededPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String actorDid, DateTime createdAt, String endpoint, String rev, Map<String, dynamic>? $unknown)?) → TResult?

Available on EventRateLimitExceeded, provided by the EventRateLimitExceededPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>