KnownEventGroupChatUpdatedLockReason enum
- Inheritance
- Implemented types
- Available extensions
Values
- owner_action → const KnownEventGroupChatUpdatedLockReason
-
const KnownEventGroupChatUpdatedLockReason('owner_action') - owner_left → const KnownEventGroupChatUpdatedLockReason
-
const KnownEventGroupChatUpdatedLockReason('owner_left') - owner_deactivated → const KnownEventGroupChatUpdatedLockReason
-
const KnownEventGroupChatUpdatedLockReason('owner_deactivated') - owner_deleted → const KnownEventGroupChatUpdatedLockReason
-
const KnownEventGroupChatUpdatedLockReason('owner_deleted') - owner_taken_down → const KnownEventGroupChatUpdatedLockReason
-
const KnownEventGroupChatUpdatedLockReason('owner_taken_down') - label_applied → const KnownEventGroupChatUpdatedLockReason
-
const KnownEventGroupChatUpdatedLockReason('label_applied')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Returns the value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isKnownValue(
String value) → bool -
valueOf(
String? value) → KnownEventGroupChatUpdatedLockReason?
Constants
-
values
→ const List<
KnownEventGroupChatUpdatedLockReason> - A constant List of the values in this enum, in order of their declaration.