ModerationSubscribeModEventsInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ModerationSubscribeModEventsInput({String? cursor, Map<String, dynamic>? $unknown})
const
factory
ModerationSubscribeModEventsInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
copyWith → $ModerationSubscribeModEventsInputCopyWith<ModerationSubscribeModEventsInput>
Create a copy of ModerationSubscribeModEventsInput with the given fields replaced by the non-null parameter values.
no setterinherited
cursor String?
The last known event seq number to backfill from. Use '2222222222222' to backfill from the beginning. Don't specify a cursor to listen only for new events.
no setterinherited
hasCursor bool

Available on ModerationSubscribeModEventsInput, provided by the ModerationSubscribeModEventsInputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotCursor bool

Available on ModerationSubscribeModEventsInput, provided by the ModerationSubscribeModEventsInputExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ModerationSubscribeModEventsInput value)) → TResult

Available on ModerationSubscribeModEventsInput, provided by the ModerationSubscribeModEventsInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ModerationSubscribeModEventsInput value)?) → TResult?

Available on ModerationSubscribeModEventsInput, provided by the ModerationSubscribeModEventsInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ModerationSubscribeModEventsInput value)?, {required TResult orElse()}) → TResult

Available on ModerationSubscribeModEventsInput, provided by the ModerationSubscribeModEventsInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? cursor, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ModerationSubscribeModEventsInput, provided by the ModerationSubscribeModEventsInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModerationSubscribeModEventsInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? cursor, Map<String, dynamic>? $unknown)) → TResult

Available on ModerationSubscribeModEventsInput, provided by the ModerationSubscribeModEventsInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? cursor, Map<String, dynamic>? $unknown)?) → TResult?

Available on ModerationSubscribeModEventsInput, provided by the ModerationSubscribeModEventsInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>