cursor property

String? get cursor
inherited

The last known event seq number to backfill from. Use '2222222222222' to backfill from the beginning. Don't specify a cursor to listen only for new events.

Implementation

String? get cursor;