NotificationPutPreferencesOutputPatterns extension

Adds pattern-matching-related methods to NotificationPutPreferencesOutput.

on

Methods

map<TResult extends Object?>(TResult $default(_NotificationPutPreferencesOutput value)) → TResult

Available on NotificationPutPreferencesOutput, provided by the NotificationPutPreferencesOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_NotificationPutPreferencesOutput value)?) → TResult?

Available on NotificationPutPreferencesOutput, provided by the NotificationPutPreferencesOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_NotificationPutPreferencesOutput value)?, {required TResult orElse()}) → TResult

Available on NotificationPutPreferencesOutput, provided by the NotificationPutPreferencesOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Preferences preferences, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on NotificationPutPreferencesOutput, provided by the NotificationPutPreferencesOutputPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(Preferences preferences, Map<String, dynamic>? $unknown)) → TResult

Available on NotificationPutPreferencesOutput, provided by the NotificationPutPreferencesOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Preferences preferences, Map<String, dynamic>? $unknown)?) → TResult?

Available on NotificationPutPreferencesOutput, provided by the NotificationPutPreferencesOutputPatterns extension

A variant of when that fallback to returning null