ActorService class base
chat.bsky.actor.*
Constructors
Properties
- ctx → ServiceContext
-
final
- declaration → ActorDeclarationRecordAccessor
-
A declaration of a Bluesky chat account.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteAccount(
{String? $service, Map< String, String> ? $headers}) → Future<XRPCResponse< EmptyData> > -
exportAccountData(
{String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< Uint8List> > -
getStatus(
{String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ActorGetStatusOutput> > - Get the authenticated viewer's chat status: whether their account is chat-disabled and whether their group-membership additions are restricted to accounts they follow.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited