acceptConvo method

Future<XRPCResponse<ConvoAcceptConvoOutput>> acceptConvo({
  1. required String convoId,
  2. String? $service,
  3. Map<String, String>? $headers,
  4. Map<String, String>? $unknown,
})

Marks a conversation as accepted, so it is shown in the list of accepted convos instead on the request convos.

Implementation

Future<XRPCResponse<ConvoAcceptConvoOutput>> acceptConvo({
  required String convoId,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await chatBskyConvoAcceptConvo(
  convoId: convoId,
  $ctx: ctx,
  $service: $service,
  $headers: $headers,
  $unknown: $unknown,
);