GroupService class base
chat.bsky.group.*
Constructors
Properties
- ctx → ServiceContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addMembers(
{required String convoId, required List< String> members, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupAddMembersOutput> > - Adds members to a group. The members are added in 'request' status, so they have to accept it. This creates convo memberships.
-
approveJoinRequest(
{required String convoId, required String member, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupApproveJoinRequestOutput> > - Approves a request to join a group (via join link) the user owns. Action taken by the group owner.
-
createGroup(
{required List< String> members, required String name, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupCreateGroupOutput> > - Creates a group convo, specifying the members to be added to it. Unlike getConvoForMembers, this isn't idempotent. It will create new groups even if the membership is identical to pre-existing groups. Will create 'request' membership for all members, except the owner who is 'accepted'.
-
createJoinLink(
{required String convoId, bool? requireApproval, required JoinRule joinRule, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupCreateJoinLinkOutput> > - Creates a join link for the group convo.
-
disableJoinLink(
{required String convoId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupDisableJoinLinkOutput> > - Disables the active join link for the group convo.
-
editGroup(
{required String convoId, required String name, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupEditGroupOutput> > - Edits group settings.
-
editJoinLink(
{required String convoId, bool? requireApproval, JoinRule? joinRule, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupEditJoinLinkOutput> > - Edits the existing join link settings for the group convo.
-
enableJoinLink(
{required String convoId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupEnableJoinLinkOutput> > - Re-enables a previously disabled join link for the group convo.
-
getJoinLinkPreviews(
{required List< String> codes, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupGetJoinLinkPreviewsOutput> > - Get public information about groups from join links. The output array matches the input codes one-to-one by position (and each view also carries its 'code'). Disabled codes return a disabledJoinLinkPreviewView, and codes that do not map to a previewable link return an invalidJoinLinkPreviewView.
-
listJoinRequests(
{required String convoId, int? limit, String? cursor, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupListJoinRequestsOutput> > - Lists a page of request to join a group (via join link) the user owns. Shows the data from the owner's point of view.
-
listMutualGroups(
{required String subject, int? limit, String? cursor, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupListMutualGroupsOutput> > - Returns a page of group conversations that both the requester and the specified actor are members of.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rejectJoinRequest(
{required String convoId, required String member, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< EmptyData> > - Rejects a request to join a group (via join link) the user owns. Action taken by the group owner.
-
removeMembers(
{required String convoId, required List< String> members, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupRemoveMembersOutput> > - Removes members from a group. This deletes convo memberships, doesn't just set a status.
-
requestJoin(
{required String code, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupRequestJoinOutput> > - Sends a request to join a group (via join link) to the group owner. Action taken by the prospective group member.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateJoinRequestsRead(
{required String convoId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< EmptyData> > - Marks all join requests as read for the group owner.
-
withdrawJoinRequest(
{required String convoId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< EmptyData> > - Withdraws a pending request to join a group. Action taken by the prospective member who originally requested to join.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited