disableJoinLink method

Future<XRPCResponse<GroupDisableJoinLinkOutput>> disableJoinLink({
  1. required String convoId,
  2. String? $service,
  3. Map<String, String>? $headers,
  4. Map<String, String>? $unknown,
})

NOTE: This is under active development and should be considered unstable while this note is here. Disables the active join link for the group convo.

Implementation

Future<XRPCResponse<GroupDisableJoinLinkOutput>> disableJoinLink({
  required String convoId,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await chatBskyGroupDisableJoinLink(
  convoId: convoId,
  $ctx: ctx,
  $service: $service,
  $headers: $headers,
  $unknown: $unknown,
);