editJoinLink method

Future<XRPCResponse<GroupEditJoinLinkOutput>> editJoinLink({
  1. required String convoId,
  2. bool? requireApproval,
  3. JoinRule? joinRule,
  4. String? $service,
  5. Map<String, String>? $headers,
  6. Map<String, String>? $unknown,
})

NOTE: This is under active development and should be considered unstable while this note is here. Edits the existing join link settings for the group convo.

Implementation

Future<XRPCResponse<GroupEditJoinLinkOutput>> editJoinLink({
  required String convoId,
  bool? requireApproval,
  JoinRule? joinRule,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await chatBskyGroupEditJoinLink(
  convoId: convoId,
  requireApproval: requireApproval,
  joinRule: joinRule,
  $ctx: ctx,
  $service: $service,
  $headers: $headers,
  $unknown: $unknown,
);