enableJoinLink method
NOTE: This is under active development and should be considered unstable while this note is here. Re-enables a previously disabled join link for the group convo.
Implementation
Future<XRPCResponse<GroupEnableJoinLinkOutput>> enableJoinLink({
required String convoId,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await chatBskyGroupEnableJoinLink(
convoId: convoId,
$ctx: ctx,
$service: $service,
$headers: $headers,
$unknown: $unknown,
);