getJoinLinkPreview method

Future<XRPCResponse<GroupGetJoinLinkPreviewOutput>> getJoinLinkPreview({
  1. required String code,
  2. String? $service,
  3. Map<String, String>? $headers,
  4. Map<String, String>? $unknown,
})

NOTE: This is under active development and should be considered unstable while this note is here. Get public information about a group from an join link.

Implementation

Future<XRPCResponse<GroupGetJoinLinkPreviewOutput>> getJoinLinkPreview({
  required String code,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await chatBskyGroupGetJoinLinkPreview(
  code: code,
  $ctx: ctx,
  $service: $service,
  $headers: $headers,
  $unknown: $unknown,
);