getJoinLinkPreviews method

Future<XRPCResponse<GroupGetJoinLinkPreviewsOutput>> getJoinLinkPreviews({
  1. required List<String> codes,
  2. String? $service,
  3. Map<String, String>? $headers,
  4. Map<String, String>? $unknown,
})

NOTE: This is under active development and should be considered unstable while this note is here. Get public information about groups from join links. Invalid or disabled codes are silently omitted from results.

Implementation

Future<XRPCResponse<GroupGetJoinLinkPreviewsOutput>> getJoinLinkPreviews({
  required List<String> codes,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await chatBskyGroupGetJoinLinkPreviews(
  codes: codes,
  $ctx: ctx,
  $service: $service,
  $headers: $headers,
  $unknown: $unknown,
);