ModerationService class base

chat.bsky.moderation.*

Constructors

ModerationService(ServiceContext ctx)

Properties

ctx ServiceContext
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getActorMetadata({required String actor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<ModerationGetActorMetadataOutput>>
getConvo({required String convoId, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<ModerationGetConvoOutput>>
Gets an existing conversation by its ID, for moderation purposes. Does not require the requester to be a member of the conversation.
getConvoMembers({required String convoId, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<ModerationGetConvoMembersOutput>>
Returns a paginated list of members from a conversation, for moderation purposes. Does not require the requester to be a member of the conversation.
getConvos({required List<String> convoIds, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<ModerationGetConvosOutput>>
Gets existing conversations by their IDs, for moderation purposes. Does not require the requester to be a member of the conversations. Unknown IDs are silently omitted from the response.
getMessageContext({String? convoId, required String messageId, int? before, int? after, int? maxInterleavedSystemMessages, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<ModerationGetMessageContextOutput>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribeModEvents({String? cursor}) Future<XRPCResponse<Subscription<Uint8List>>>
Subscribe to stream of chat events targeted to moderation. Private endpoint.
toString() String
A string representation of this object.
inherited
updateActorAccess({required String actor, required bool allowAccess, String? ref, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<EmptyData>>

Operators

operator ==(Object other) bool
The equality operator.
inherited