getConvoMembers method

Future<XRPCResponse<ModerationGetConvoMembersOutput>> getConvoMembers({
  1. required String convoId,
  2. int? limit,
  3. String? cursor,
  4. String? $service,
  5. Map<String, String>? $headers,
  6. Map<String, String>? $unknown,
})

Returns a paginated list of members from a conversation, for moderation purposes. Does not require the requester to be a member of the conversation.

Implementation

Future<XRPCResponse<ModerationGetConvoMembersOutput>> getConvoMembers({
  required String convoId,
  int? limit,
  String? cursor,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await chatBskyModerationGetConvoMembers(
  convoId: convoId,
  limit: limit,
  cursor: cursor,
  $ctx: ctx,
  $service: $service,
  $headers: $headers,
  $unknown: $unknown,
);