NotificationService class base

chat.bsky.notification.*

Properties

ctx ServiceContext
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPreferences({String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<NotificationGetPreferencesOutput>>
Get the requesting account's chat notification preferences. Defaults are returned for accounts that have not set any preferences. Requires auth.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putPreferences({ChatPreference? chat, ChatPreference? chatRequest, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) Future<XRPCResponse<NotificationPutPreferencesOutput>>
Set the requesting account's chat notification preferences. Only the provided preferences are updated; omitted preferences are left unchanged.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited