chatBskyConvoGetUnreadCounts function
Returns unread conversation counts for conversations that are unlocked, not muted, split by convo status. Direct convos are excluded when a block relationship exists between the actor and the other member, or when the other member's account is deleted or deactivated. Group convos are considered unread if they have unread join request counts.
Implementation
Future<XRPCResponse<ConvoGetUnreadCountsOutput>> chatBskyConvoGetUnreadCounts({
bool? includeGroupChats,
required ServiceContext $ctx,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await $ctx.get(
ns.chatBskyConvoGetUnreadCounts,
service: $service,
headers: $headers,
parameters: {
...?$unknown,
if (includeGroupChats != null) 'includeGroupChats': includeGroupChats,
},
to: const ConvoGetUnreadCountsOutputConverter().fromJson,
);