chatBskyGroupCreateGroup function

Future<XRPCResponse<GroupCreateGroupOutput>> chatBskyGroupCreateGroup({
  1. required List<String> members,
  2. required String name,
  3. required ServiceContext $ctx,
  4. String? $service,
  5. Map<String, String>? $headers,
  6. Map<String, String>? $unknown,
})

NOTE: This is under active development and should be considered unstable while this note is here. Creates a group convo, specifying the members to be added to it. Unlike getConvoForMembers, this isn't idempotent. It will create new groups even if the membership is identical to pre-existing groups. Will create 'pending' membership for all members, except the owner who is 'accepted'.

Implementation

Future<XRPCResponse<GroupCreateGroupOutput>> chatBskyGroupCreateGroup({
  required List<String> members,
  required String name,
  required ServiceContext $ctx,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await $ctx.post(
  ns.chatBskyGroupCreateGroup,
  service: $service,
  headers: {'Content-type': 'application/json', ...?$headers},
  body: {...?$unknown, 'members': members, 'name': name},
  to: const GroupCreateGroupOutputConverter().fromJson,
);