chatBskyGroupDisableJoinLink function
NOTE: This is under active development and should be considered unstable while this note is here. Disables the active join link for the group convo.
Implementation
Future<XRPCResponse<GroupDisableJoinLinkOutput>> chatBskyGroupDisableJoinLink({
required String convoId,
required ServiceContext $ctx,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await $ctx.post(
ns.chatBskyGroupDisableJoinLink,
service: $service,
headers: {'Content-type': 'application/json', ...?$headers},
body: {...?$unknown, 'convoId': convoId},
to: const GroupDisableJoinLinkOutputConverter().fromJson,
);