chatBskyGroupEditJoinLink function
NOTE: This is under active development and should be considered unstable while this note is here. Edits the existing join link settings for the group convo.
Implementation
Future<XRPCResponse<GroupEditJoinLinkOutput>> chatBskyGroupEditJoinLink({
required String convoId,
bool? requireApproval,
JoinRule? joinRule,
required ServiceContext $ctx,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await $ctx.post(
ns.chatBskyGroupEditJoinLink,
service: $service,
headers: {'Content-type': 'application/json', ...?$headers},
body: {
...?$unknown,
'convoId': convoId,
if (requireApproval != null) 'requireApproval': requireApproval,
if (joinRule != null) 'joinRule': joinRule.toJson(),
},
to: const GroupEditJoinLinkOutputConverter().fromJson,
);