chatBskyGroupEnableJoinLink function
NOTE: This is under active development and should be considered unstable while this note is here. Re-enables a previously disabled join link for the group convo.
Implementation
Future<XRPCResponse<GroupEnableJoinLinkOutput>> chatBskyGroupEnableJoinLink({
required String convoId,
required ServiceContext $ctx,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await $ctx.post(
ns.chatBskyGroupEnableJoinLink,
service: $service,
headers: {'Content-type': 'application/json', ...?$headers},
body: {...?$unknown, 'convoId': convoId},
to: const GroupEnableJoinLinkOutputConverter().fromJson,
);