chatBskyGroupGetJoinLinkPreview function

Future<XRPCResponse<GroupGetJoinLinkPreviewOutput>> chatBskyGroupGetJoinLinkPreview({
  1. required String code,
  2. required ServiceContext $ctx,
  3. String? $service,
  4. Map<String, String>? $headers,
  5. Map<String, String>? $unknown,
})

NOTE: This is under active development and should be considered unstable while this note is here. Get public information about a group from an join link.

Implementation

Future<XRPCResponse<GroupGetJoinLinkPreviewOutput>>
chatBskyGroupGetJoinLinkPreview({
  required String code,
  required ServiceContext $ctx,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await $ctx.get(
  ns.chatBskyGroupGetJoinLinkPreview,
  service: $service,
  headers: $headers,
  parameters: {...?$unknown, 'code': code},
  to: const GroupGetJoinLinkPreviewOutputConverter().fromJson,
);