StatusAttr class abstract

Available extensions
Annotations
  • @freezed

Constructors

StatusAttr({@Default.new('com.atproto.admin.defs#statusAttr') String $type, required bool applied, String? ref, Map<String, dynamic>? $unknown})
const
factory
StatusAttr.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
applied → bool
no setterinherited
copyWith → $StatusAttrCopyWith<StatusAttr>
Create a copy of StatusAttr with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNotRef → bool

Available on StatusAttr, provided by the StatusAttrExtension extension

no setter
hasRef → bool

Available on StatusAttr, provided by the StatusAttrExtension extension

no setter
isApplied → bool

Available on StatusAttr, provided by the StatusAttrExtension extension

no setter
isNotApplied → bool

Available on StatusAttr, provided by the StatusAttrExtension extension

no setter
ref → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_StatusAttr value)) → TResult

Available on StatusAttr, provided by the StatusAttrPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_StatusAttr value)?) → TResult?

Available on StatusAttr, provided by the StatusAttrPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_StatusAttr value)?, {required TResult orElse()}) → TResult

Available on StatusAttr, provided by the StatusAttrPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, bool applied, String? ref, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on StatusAttr, provided by the StatusAttrPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this StatusAttr to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, bool applied, String? ref, Map<String, dynamic>? $unknown)) → TResult

Available on StatusAttr, provided by the StatusAttrPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, bool applied, String? ref, Map<String, dynamic>? $unknown)?) → TResult?

Available on StatusAttr, provided by the StatusAttrPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>