AdminGetSubjectStatusInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

AdminGetSubjectStatusInput({String? did, @AtUriConverter.new() AtUri? uri, String? blob, Map<String, dynamic>? $unknown})
const
factory
AdminGetSubjectStatusInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
blob → String?
no setterinherited
copyWith → $AdminGetSubjectStatusInputCopyWith<AdminGetSubjectStatusInput>
Create a copy of AdminGetSubjectStatusInput with the given fields replaced by the non-null parameter values.
no setterinherited
did → String?
no setterinherited
hasBlob → bool

Available on AdminGetSubjectStatusInput, provided by the AdminGetSubjectStatusInputExtension extension

no setter
hasDid → bool

Available on AdminGetSubjectStatusInput, provided by the AdminGetSubjectStatusInputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotBlob → bool

Available on AdminGetSubjectStatusInput, provided by the AdminGetSubjectStatusInputExtension extension

no setter
hasNotDid → bool

Available on AdminGetSubjectStatusInput, provided by the AdminGetSubjectStatusInputExtension extension

no setter
hasNotUri → bool

Available on AdminGetSubjectStatusInput, provided by the AdminGetSubjectStatusInputExtension extension

no setter
hasUri → bool

Available on AdminGetSubjectStatusInput, provided by the AdminGetSubjectStatusInputExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → AtUri?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AdminGetSubjectStatusInput value)) → TResult

Available on AdminGetSubjectStatusInput, provided by the AdminGetSubjectStatusInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AdminGetSubjectStatusInput value)?) → TResult?

Available on AdminGetSubjectStatusInput, provided by the AdminGetSubjectStatusInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AdminGetSubjectStatusInput value)?, {required TResult orElse()}) → TResult

Available on AdminGetSubjectStatusInput, provided by the AdminGetSubjectStatusInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? did, AtUri? uri, String? blob, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on AdminGetSubjectStatusInput, provided by the AdminGetSubjectStatusInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AdminGetSubjectStatusInput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? did, AtUri? uri, String? blob, Map<String, dynamic>? $unknown)) → TResult

Available on AdminGetSubjectStatusInput, provided by the AdminGetSubjectStatusInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? did, AtUri? uri, String? blob, Map<String, dynamic>? $unknown)?) → TResult?

Available on AdminGetSubjectStatusInput, provided by the AdminGetSubjectStatusInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>