ServerCreateAccountInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ServerCreateAccountInput({String? email, required String handle, String? did, String? inviteCode, String? verificationCode, String? verificationPhone, String? password, String? recoveryKey, Map<String, dynamic>? plcOp, Map<String, dynamic>? $unknown})
const
factory
ServerCreateAccountInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $ServerCreateAccountInputCopyWith<ServerCreateAccountInput>
Create a copy of ServerCreateAccountInput with the given fields replaced by the non-null parameter values.
no setterinherited
did → String?
Pre-existing atproto DID, being imported to a new account.
no setterinherited
email → String?
no setterinherited
handle → String
Requested handle for the account.
no setterinherited
hasDid → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasEmail → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasInviteCode → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasNotDid → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasNotEmail → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasNotInviteCode → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasNotPassword → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasNotPlcOp → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasNotRecoveryKey → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasNotVerificationCode → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasNotVerificationPhone → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasPassword → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasPlcOp → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasRecoveryKey → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasVerificationCode → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
hasVerificationPhone → bool

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputExtension extension

no setter
inviteCode → String?
no setterinherited
password → String?
Initial account password. May need to meet instance-specific password strength requirements.
no setterinherited
plcOp → Map<String, dynamic>?
no setterinherited
recoveryKey → String?
DID PLC rotation key (aka, recovery key) to be included in PLC creation operation.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verificationCode → String?
no setterinherited
verificationPhone → String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ServerCreateAccountInput value)) → TResult

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ServerCreateAccountInput value)?) → TResult?

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ServerCreateAccountInput value)?, {required TResult orElse()}) → TResult

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? email, String handle, String? did, String? inviteCode, String? verificationCode, String? verificationPhone, String? password, String? recoveryKey, Map<String, dynamic>? plcOp, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ServerCreateAccountInput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? email, String handle, String? did, String? inviteCode, String? verificationCode, String? verificationPhone, String? password, String? recoveryKey, Map<String, dynamic>? plcOp, Map<String, dynamic>? $unknown)) → TResult

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? email, String handle, String? did, String? inviteCode, String? verificationCode, String? verificationPhone, String? password, String? recoveryKey, Map<String, dynamic>? plcOp, Map<String, dynamic>? $unknown)?) → TResult?

Available on ServerCreateAccountInput, provided by the ServerCreateAccountInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>