ServerCreateSessionInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ServerCreateSessionInput({required String identifier, required String password, String? authFactorToken, bool? allowTakendown, Map<String, dynamic>? $unknown})
const
factory
ServerCreateSessionInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
allowTakendown → bool?
When true, instead of throwing error for takendown accounts, a valid response with a narrow scoped token will be returned
no setterinherited
authFactorToken → String?
no setterinherited
copyWith → $ServerCreateSessionInputCopyWith<ServerCreateSessionInput>
Create a copy of ServerCreateSessionInput with the given fields replaced by the non-null parameter values.
no setterinherited
hasAuthFactorToken → bool

Available on ServerCreateSessionInput, provided by the ServerCreateSessionInputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotAuthFactorToken → bool

Available on ServerCreateSessionInput, provided by the ServerCreateSessionInputExtension extension

no setter
identifier → String
Handle or other identifier supported by the server for the authenticating user.
no setterinherited
isAllowTakendown → bool

Available on ServerCreateSessionInput, provided by the ServerCreateSessionInputExtension extension

no setter
isNotAllowTakendown → bool

Available on ServerCreateSessionInput, provided by the ServerCreateSessionInputExtension extension

no setter
password → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ServerCreateSessionInput value)) → TResult

Available on ServerCreateSessionInput, provided by the ServerCreateSessionInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ServerCreateSessionInput value)?) → TResult?

Available on ServerCreateSessionInput, provided by the ServerCreateSessionInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ServerCreateSessionInput value)?, {required TResult orElse()}) → TResult

Available on ServerCreateSessionInput, provided by the ServerCreateSessionInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String identifier, String password, String? authFactorToken, bool? allowTakendown, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ServerCreateSessionInput, provided by the ServerCreateSessionInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ServerCreateSessionInput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String identifier, String password, String? authFactorToken, bool? allowTakendown, Map<String, dynamic>? $unknown)) → TResult

Available on ServerCreateSessionInput, provided by the ServerCreateSessionInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String identifier, String password, String? authFactorToken, bool? allowTakendown, Map<String, dynamic>? $unknown)?) → TResult?

Available on ServerCreateSessionInput, provided by the ServerCreateSessionInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>