Contact class abstract

Available extensions
Annotations
  • @freezed

Constructors

Contact({@Default.new('com.atproto.server.describeServer#contact') String $type, String? email, Map<String, dynamic>? $unknown})
const
factory
Contact.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $ContactCopyWith<Contact>
Create a copy of Contact with the given fields replaced by the non-null parameter values.
no setterinherited
email → String?
no setterinherited
hasEmail → bool

Available on Contact, provided by the ContactExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotEmail → bool

Available on Contact, provided by the ContactExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Contact value)) → TResult

Available on Contact, provided by the ContactPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Contact value)?) → TResult?

Available on Contact, provided by the ContactPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Contact value)?, {required TResult orElse()}) → TResult

Available on Contact, provided by the ContactPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String? email, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on Contact, provided by the ContactPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Contact to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String? email, Map<String, dynamic>? $unknown)) → TResult

Available on Contact, provided by the ContactPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String? email, Map<String, dynamic>? $unknown)?) → TResult?

Available on Contact, provided by the ContactPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>