ServerDescribeServerOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ServerDescribeServerOutput({bool? inviteCodeRequired, bool? phoneVerificationRequired, int? blobUploadLimit, required List<String> availableUserDomains, @LinksConverter() Links? links, @ContactConverter() Contact? contact, required String did, Map<String, dynamic>? $unknown})
const
factory
ServerDescribeServerOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
availableUserDomains → List<String>
no setterinherited
blobUploadLimit → int?
Maximum size of a blob that can be uploaded via com.atproto.repo.uploadBlob, in bytes.
no setterinherited
contact → Contact?
Contact information
no setterinherited
copyWith → $ServerDescribeServerOutputCopyWith<ServerDescribeServerOutput>
Create a copy of ServerDescribeServerOutput with the given fields replaced by the non-null parameter values.
no setterinherited
did → String
no setterinherited
hasBlobUploadLimit → bool

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputExtension extension

no setter
hasContact → bool

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputExtension extension

no setter
hasNotBlobUploadLimit → bool

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputExtension extension

no setter
hasNotContact → bool

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputExtension extension

no setter

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputExtension extension

no setter
inviteCodeRequired → bool?
If true, an invite code must be supplied to create an account on this instance.
no setterinherited
isInviteCodeRequired → bool

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputExtension extension

no setter
isNotInviteCodeRequired → bool

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputExtension extension

no setter
isNotPhoneVerificationRequired → bool

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputExtension extension

no setter
isPhoneVerificationRequired → bool

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputExtension extension

no setter
URLs of service policy documents.
no setterinherited
phoneVerificationRequired → bool?
If true, a phone verification token must be supplied to create an account on this instance.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ServerDescribeServerOutput value)) → TResult

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ServerDescribeServerOutput value)?) → TResult?

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ServerDescribeServerOutput value)?, {required TResult orElse()}) → TResult

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool? inviteCodeRequired, bool? phoneVerificationRequired, int? blobUploadLimit, List<String> availableUserDomains, Links? links, Contact? contact, String did, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ServerDescribeServerOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool? inviteCodeRequired, bool? phoneVerificationRequired, int? blobUploadLimit, List<String> availableUserDomains, Links? links, Contact? contact, String did, Map<String, dynamic>? $unknown)) → TResult

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool? inviteCodeRequired, bool? phoneVerificationRequired, int? blobUploadLimit, List<String> availableUserDomains, Links? links, Contact? contact, String did, Map<String, dynamic>? $unknown)?) → TResult?

Available on ServerDescribeServerOutput, provided by the ServerDescribeServerOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>