ServerGetAccountInviteCodesInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ServerGetAccountInviteCodesInput({@Default.new(true) bool includeUsed, @Default.new(true) bool createAvailable, Map<String, dynamic>? $unknown})
const
factory
ServerGetAccountInviteCodesInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $ServerGetAccountInviteCodesInputCopyWith<ServerGetAccountInviteCodesInput>
Create a copy of ServerGetAccountInviteCodesInput with the given fields replaced by the non-null parameter values.
no setterinherited
createAvailable → bool
Controls whether any new 'earned' but not 'created' invites should be created.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
includeUsed → bool
no setterinherited
isCreateAvailable → bool

Available on ServerGetAccountInviteCodesInput, provided by the ServerGetAccountInviteCodesInputExtension extension

no setter
isIncludeUsed → bool

Available on ServerGetAccountInviteCodesInput, provided by the ServerGetAccountInviteCodesInputExtension extension

no setter
isNotCreateAvailable → bool

Available on ServerGetAccountInviteCodesInput, provided by the ServerGetAccountInviteCodesInputExtension extension

no setter
isNotIncludeUsed → bool

Available on ServerGetAccountInviteCodesInput, provided by the ServerGetAccountInviteCodesInputExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ServerGetAccountInviteCodesInput value)) → TResult

Available on ServerGetAccountInviteCodesInput, provided by the ServerGetAccountInviteCodesInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ServerGetAccountInviteCodesInput value)?) → TResult?

Available on ServerGetAccountInviteCodesInput, provided by the ServerGetAccountInviteCodesInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ServerGetAccountInviteCodesInput value)?, {required TResult orElse()}) → TResult

Available on ServerGetAccountInviteCodesInput, provided by the ServerGetAccountInviteCodesInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool includeUsed, bool createAvailable, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ServerGetAccountInviteCodesInput, provided by the ServerGetAccountInviteCodesInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ServerGetAccountInviteCodesInput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool includeUsed, bool createAvailable, Map<String, dynamic>? $unknown)) → TResult

Available on ServerGetAccountInviteCodesInput, provided by the ServerGetAccountInviteCodesInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool includeUsed, bool createAvailable, Map<String, dynamic>? $unknown)?) → TResult?

Available on ServerGetAccountInviteCodesInput, provided by the ServerGetAccountInviteCodesInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>