ServerGetServiceAuthInput constructor

  1. @JsonSerializable.new(includeIfNull: false)
const ServerGetServiceAuthInput({
  1. required String aud,
  2. int? exp,
  3. String? lxm,
  4. Map<String, dynamic>? $unknown,
})

Implementation

@JsonSerializable(includeIfNull: false)
const factory ServerGetServiceAuthInput({
  /// The DID or `did#serviceId` reference of the service that the token will be used to authenticate with.
  required String aud,

  /// The time in Unix Epoch seconds that the JWT expires. Defaults to 60 seconds in the future. The service may enforce certain time bounds on tokens depending on the requested scope.
  int? exp,

  /// Lexicon (XRPC) method to bind the requested token to
  String? lxm,

  Map<String, dynamic>? $unknown,
}) = _ServerGetServiceAuthInput;