aud property
The DID or did#serviceId reference of the service that the token will be used to authenticate with.
Implementation
String get aud;
The DID or did#serviceId reference of the service that the token will be used to authenticate with.
String get aud;