SyncGetHostStatusOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

SyncGetHostStatusOutput({required String hostname, int? seq, int? accountCount, @HostStatusConverter() HostStatus? status, Map<String, dynamic>? $unknown})
const
factory
SyncGetHostStatusOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
accountCount → int?
Number of accounts on the server which are associated with the upstream host. Note that the upstream may actually have more accounts.
no setterinherited
copyWith → $SyncGetHostStatusOutputCopyWith<SyncGetHostStatusOutput>
Create a copy of SyncGetHostStatusOutput with the given fields replaced by the non-null parameter values.
no setterinherited
hasAccountCount → bool

Available on SyncGetHostStatusOutput, provided by the SyncGetHostStatusOutputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotAccountCount → bool

Available on SyncGetHostStatusOutput, provided by the SyncGetHostStatusOutputExtension extension

no setter
hasNotSeq → bool

Available on SyncGetHostStatusOutput, provided by the SyncGetHostStatusOutputExtension extension

no setter
hasNotStatus → bool

Available on SyncGetHostStatusOutput, provided by the SyncGetHostStatusOutputExtension extension

no setter
hasSeq → bool

Available on SyncGetHostStatusOutput, provided by the SyncGetHostStatusOutputExtension extension

no setter
hasStatus → bool

Available on SyncGetHostStatusOutput, provided by the SyncGetHostStatusOutputExtension extension

no setter
hostname → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seq → int?
Recent repo stream event sequence number. May be delayed from actual stream processing (eg, persisted cursor not in-memory cursor).
no setterinherited
status → HostStatus?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SyncGetHostStatusOutput value)) → TResult

Available on SyncGetHostStatusOutput, provided by the SyncGetHostStatusOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SyncGetHostStatusOutput value)?) → TResult?

Available on SyncGetHostStatusOutput, provided by the SyncGetHostStatusOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SyncGetHostStatusOutput value)?, {required TResult orElse()}) → TResult

Available on SyncGetHostStatusOutput, provided by the SyncGetHostStatusOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String hostname, int? seq, int? accountCount, HostStatus? status, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on SyncGetHostStatusOutput, provided by the SyncGetHostStatusOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this SyncGetHostStatusOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String hostname, int? seq, int? accountCount, HostStatus? status, Map<String, dynamic>? $unknown)) → TResult

Available on SyncGetHostStatusOutput, provided by the SyncGetHostStatusOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String hostname, int? seq, int? accountCount, HostStatus? status, Map<String, dynamic>? $unknown)?) → TResult?

Available on SyncGetHostStatusOutput, provided by the SyncGetHostStatusOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>