SyncGetRepoStatusOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

SyncGetRepoStatusOutput({required String did, required bool active, @SyncGetRepoStatusStatusConverter() SyncGetRepoStatusStatus? status, String? rev, Map<String, dynamic>? $unknown})
const
factory
SyncGetRepoStatusOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
active → bool
no setterinherited
copyWith → $SyncGetRepoStatusOutputCopyWith<SyncGetRepoStatusOutput>
Create a copy of SyncGetRepoStatusOutput with the given fields replaced by the non-null parameter values.
no setterinherited
did → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNotRev → bool

Available on SyncGetRepoStatusOutput, provided by the SyncGetRepoStatusOutputExtension extension

no setter
hasNotStatus → bool

Available on SyncGetRepoStatusOutput, provided by the SyncGetRepoStatusOutputExtension extension

no setter
hasRev → bool

Available on SyncGetRepoStatusOutput, provided by the SyncGetRepoStatusOutputExtension extension

no setter
hasStatus → bool

Available on SyncGetRepoStatusOutput, provided by the SyncGetRepoStatusOutputExtension extension

no setter
isActive → bool

Available on SyncGetRepoStatusOutput, provided by the SyncGetRepoStatusOutputExtension extension

no setter
isNotActive → bool

Available on SyncGetRepoStatusOutput, provided by the SyncGetRepoStatusOutputExtension extension

no setter
rev → String?
Optional field, the current rev of the repo, if active=true
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → SyncGetRepoStatusStatus?
If active=false, this optional field indicates a possible reason for why the account is not active. If active=false and no status is supplied, then the host makes no claim for why the repository is no longer being hosted.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SyncGetRepoStatusOutput value)) → TResult

Available on SyncGetRepoStatusOutput, provided by the SyncGetRepoStatusOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SyncGetRepoStatusOutput value)?) → TResult?

Available on SyncGetRepoStatusOutput, provided by the SyncGetRepoStatusOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SyncGetRepoStatusOutput value)?, {required TResult orElse()}) → TResult

Available on SyncGetRepoStatusOutput, provided by the SyncGetRepoStatusOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String did, bool active, SyncGetRepoStatusStatus? status, String? rev, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on SyncGetRepoStatusOutput, provided by the SyncGetRepoStatusOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this SyncGetRepoStatusOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String did, bool active, SyncGetRepoStatusStatus? status, String? rev, Map<String, dynamic>? $unknown)) → TResult

Available on SyncGetRepoStatusOutput, provided by the SyncGetRepoStatusOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String did, bool active, SyncGetRepoStatusStatus? status, String? rev, Map<String, dynamic>? $unknown)?) → TResult?

Available on SyncGetRepoStatusOutput, provided by the SyncGetRepoStatusOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>