Host class abstract

Available extensions
Annotations
  • @freezed

Constructors

Host({@Default.new('com.atproto.sync.listHosts#host') String $type, required String hostname, int? seq, int? accountCount, @HostStatusConverter() HostStatus? status, Map<String, dynamic>? $unknown})
const
factory
Host.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
accountCount → int?
no setterinherited
copyWith → $HostCopyWith<Host>
Create a copy of Host with the given fields replaced by the non-null parameter values.
no setterinherited
hasAccountCount → bool

Available on Host, provided by the HostExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotAccountCount → bool

Available on Host, provided by the HostExtension extension

no setter
hasNotSeq → bool

Available on Host, provided by the HostExtension extension

no setter
hasNotStatus → bool

Available on Host, provided by the HostExtension extension

no setter
hasSeq → bool

Available on Host, provided by the HostExtension extension

no setter
hasStatus → bool

Available on Host, provided by the HostExtension extension

no setter
hostname → String
hostname of server; not a URL (no scheme)
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seq → int?
Recent repo stream event sequence number. May be delayed from actual stream processing (eg, persisted cursor not in-memory cursor).
no setterinherited
status → HostStatus?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Host value)) → TResult

Available on Host, provided by the HostPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Host value)?) → TResult?

Available on Host, provided by the HostPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Host value)?, {required TResult orElse()}) → TResult

Available on Host, provided by the HostPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String hostname, int? seq, int? accountCount, HostStatus? status, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on Host, provided by the HostPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Host to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String hostname, int? seq, int? accountCount, HostStatus? status, Map<String, dynamic>? $unknown)) → TResult

Available on Host, provided by the HostPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String hostname, int? seq, int? accountCount, HostStatus? status, Map<String, dynamic>? $unknown)?) → TResult?

Available on Host, provided by the HostPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>