Blob class abstract

Available extensions
Annotations
  • @freezed

Constructors

Blob({@Default.new('blob') String $type, required String mimeType, required int size, required BlobRef ref})
const
factory
Blob.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
copyWith → $BlobCopyWith<Blob>
Create a copy of Blob with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mimeType → String
no setterinherited
ref → BlobRef
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEmbedImage({required String alt, AspectRatio? aspectRatio}) → UFeedPostEmbed

Available on Blob, provided by the BlobExtension extension

Returns the single UFeedPostEmbed image representation of this blob.
toImage({required String alt, AspectRatio? aspectRatio}) → EmbedImagesImage

Available on Blob, provided by the BlobExtension extension

Returns the EmbedImagesImage representation of this blob.
toJson() → Map<String, dynamic>
Serializes this Blob to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited