onExecute property
A callback function to be called when the retry is executed.
Implementation
final FutureOr<void> Function(RetryEvent event)? onExecute;
A callback function to be called when the retry is executed.
final FutureOr<void> Function(RetryEvent event)? onExecute;