attempt property
The number of attempts that have already failed, starting at 1 for the
first failure. The initial request is attempt 1 once it fails, so the
value handed to the strategy is always >= 1.
Implementation
final int attempt;
The number of attempts that have already failed, starting at 1 for the
first failure. The initial request is attempt 1 once it fails, so the
value handed to the strategy is always >= 1.
final int attempt;