stream property

Stream<T> get stream

Returns the stream.

A done event is always delivered to listeners when the connection is closed, either by the server or by calling close.

Implementation

Stream<T> get stream => _controller.stream;