firehose library

Typedefs

RepoCommitOnCreate<T> = FutureOr<void> Function(RepoCommitCreate<T> data)
RepoCommitOnDelete = FutureOr<void> Function(RepoCommitDelete data)
RepoCommitOnUpdate<T> = FutureOr<void> Function(RepoCommitUpdate<T> data)

Exceptions / Errors

FirehoseErrorException
Thrown when the relay sends a firehose error frame (op == -1), such as FutureCursor or ConsumerTooSlow.
FirehoseFrameException
Thrown when a firehose frame is malformed or arrives in an unexpected shape (e.g. a WebSocket text frame instead of the expected binary frame).