close property
Tears down the underlying socket, or null when there is nothing to tear
down (an in-memory stream in a test, say).
Implementation
final Future<void> Function()? close;
Tears down the underlying socket, or null when there is nothing to tear
down (an in-memory stream in a test, say).
final Future<void> Function()? close;