Identity class abstract

Represents a change to an account's identity. Could be an updated handle, signing key, or pds hosting endpoint. Serves as a prod to all downstream services to refresh their identity cache.

Available extensions
Annotations
  • @freezed

Constructors

Identity({@Default.new('com.atproto.sync.subscribeRepos#identity') String $type, required int seq, required String did, @JsonKey.new(toJson: iso8601) required DateTime time, String? handle, Map<String, dynamic>? $unknown})
const
factory
Identity.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $IdentityCopyWith<Identity>
Create a copy of Identity with the given fields replaced by the non-null parameter values.
no setterinherited
did → String
no setterinherited
handle → String?
The current handle for the account, or 'handle.invalid' if validation fails. This field is optional, might have been validated or passed-through from an upstream source. Semantics and behaviors for PDS vs Relay may evolve in the future; see atproto specs for more details.
no setterinherited
hasHandle → bool

Available on Identity, provided by the IdentityExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotHandle → bool

Available on Identity, provided by the IdentityExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seq → int
no setterinherited
time → DateTime
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Identity value)) → TResult

Available on Identity, provided by the IdentityPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Identity value)?) → TResult?

Available on Identity, provided by the IdentityPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Identity value)?, {required TResult orElse()}) → TResult

Available on Identity, provided by the IdentityPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, int seq, String did, DateTime time, String? handle, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on Identity, provided by the IdentityPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Identity to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, int seq, String did, DateTime time, String? handle, Map<String, dynamic>? $unknown)) → TResult

Available on Identity, provided by the IdentityPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, int seq, String did, DateTime time, String? handle, Map<String, dynamic>? $unknown)?) → TResult?

Available on Identity, provided by the IdentityPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>