RepoCommitDelete class final

Constructors

RepoCommitDelete({required AtUri uri, required String author, required int cursor, required DateTime createdAt})
Returns the new instance of RepoCommitDelete.
const

Properties

author → String
The author of this event.
final
createdAt → DateTime
The date and time this event was created.
final
cursor → int
The current cursor.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → AtUri
The AT URI of this event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant RepoCommitDelete other) → bool
The equality operator.
override