RepoCommitUpdate<T> class final

Constructors

RepoCommitUpdate({required T record, required AtUri uri, required String? cid, required String author, required int cursor, required DateTime createdAt})
Returns the new instance of RepoCommitUpdate.
const

Properties

author → String
The author of this event.
final
cid → String?
CID of this record.
final
createdAt → DateTime
The date and time this event was created.
final
cursor → int
The current cursor.
final
hashCode → int
The hash code for this object.
no setteroverride
record → T
The created data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → AtUri
The AT URI of this record.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant RepoCommitUpdate<T> other) → bool
The equality operator.
override