RepoOp class abstract

A repo operation, ie a mutation of a single record.

Available extensions
Annotations
  • @freezed

Constructors

RepoOp({@Default.new('com.atproto.sync.subscribeRepos#repoOp') String $type, @RepoOpActionConverter() required RepoOpAction action, required String path, @JsonKey.new(includeIfNull: true) required String? cid, String? prev, Map<String, dynamic>? $unknown})
const
factory
RepoOp.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
action → RepoOpAction
no setterinherited
cid → String?
For creates and updates, the new record CID. For deletions, null.
no setterinherited
copyWith → $RepoOpCopyWith<RepoOp>
Create a copy of RepoOp with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNotPrev → bool

Available on RepoOp, provided by the RepoOpExtension extension

no setter
hasPrev → bool

Available on RepoOp, provided by the RepoOpExtension extension

no setter
path → String
no setterinherited
prev → String?
For updates and deletes, the previous record CID (required for inductive firehose). For creations, field should not be defined.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_RepoOp value)) → TResult

Available on RepoOp, provided by the RepoOpPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_RepoOp value)?) → TResult?

Available on RepoOp, provided by the RepoOpPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_RepoOp value)?, {required TResult orElse()}) → TResult

Available on RepoOp, provided by the RepoOpPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, RepoOpAction action, String path, String? cid, String? prev, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on RepoOp, provided by the RepoOpPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this RepoOp to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, RepoOpAction action, String path, String? cid, String? prev, Map<String, dynamic>? $unknown)) → TResult

Available on RepoOp, provided by the RepoOpPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, RepoOpAction action, String path, String? cid, String? prev, Map<String, dynamic>? $unknown)?) → TResult?

Available on RepoOp, provided by the RepoOpPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>