ModerationBehaviorContext enum

Inheritance
Available extensions

Values

profileList → const ModerationBehaviorContext
profileView → const ModerationBehaviorContext
avatar → const ModerationBehaviorContext
displayName → const ModerationBehaviorContext
contentList → const ModerationBehaviorContext
contentView → const ModerationBehaviorContext
contentMedia → const ModerationBehaviorContext

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isAvatar → bool
no setter
isBanner → bool
no setter
isContentList → bool
no setter
isContentMedia → bool
no setter
isContentView → bool
no setter
isDisplayName → bool
no setter
isProfileList → bool
no setter
isProfileView → bool
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ModerationBehaviorContext>
A constant List of the values in this enum, in order of their declaration.