hide property
The behaviors applied when the subject was hidden by the user.
Implementation
final Map<ModerationBehaviorContext, ModerationBehavior> hide;
The behaviors applied when the subject was hidden by the user.
final Map<ModerationBehaviorContext, ModerationBehavior> hide;