mute property
The behaviors applied when the subject is muted by the user.
Implementation
final Map<ModerationBehaviorContext, ModerationBehavior> mute;
The behaviors applied when the subject is muted by the user.
final Map<ModerationBehaviorContext, ModerationBehavior> mute;