muteWord property
The behaviors applied when the subject matches one of the user's muted words.
Implementation
final Map<ModerationBehaviorContext, ModerationBehavior> muteWord;
The behaviors applied when the subject matches one of the user's muted words.
final Map<ModerationBehaviorContext, ModerationBehavior> muteWord;