ModerationCauseLabel class abstract

Available extensions
Annotations
  • @Freezed.new(fromJson: false, toJson: false)

Constructors

ModerationCauseLabel({required ModerationCauseSource source, required Label label, required InterpretedLabelValueDefinition labelDef, required LabelTarget target, required LabelPreference setting, required Map<ModerationBehaviorContext, ModerationBehavior> behavior, @Default.new(false) bool noOverride, @Assert.new(_assertEvalPriority) @Default.new(0) int priority, @Default.new(false) bool downgraded})
const
factory

Properties

behavior → Map<ModerationBehaviorContext, ModerationBehavior>
no setterinherited
copyWith → $ModerationCauseLabelCopyWith<ModerationCauseLabel>
Create a copy of ModerationCauseLabel with the given fields replaced by the non-null parameter values.
no setterinherited
downgraded → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
label → Label
no setterinherited
labelDef → InterpretedLabelValueDefinition
no setterinherited
noOverride → bool
no setterinherited
priority → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setting → LabelPreference
no setterinherited
source → ModerationCauseSource
no setterinherited
target → LabelTarget
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ModerationCauseLabel value)) → TResult

Available on ModerationCauseLabel, provided by the ModerationCauseLabelPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ModerationCauseLabel value)?) → TResult?

Available on ModerationCauseLabel, provided by the ModerationCauseLabelPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ModerationCauseLabel value)?, {required TResult orElse()}) → TResult

Available on ModerationCauseLabel, provided by the ModerationCauseLabelPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(ModerationCauseSource source, Label label, InterpretedLabelValueDefinition labelDef, LabelTarget target, LabelPreference setting, Map<ModerationBehaviorContext, ModerationBehavior> behavior, bool noOverride, int priority, bool downgraded)?, {required TResult orElse()}) → TResult

Available on ModerationCauseLabel, provided by the ModerationCauseLabelPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(ModerationCauseSource source, Label label, InterpretedLabelValueDefinition labelDef, LabelTarget target, LabelPreference setting, Map<ModerationBehaviorContext, ModerationBehavior> behavior, bool noOverride, int priority, bool downgraded)) → TResult

Available on ModerationCauseLabel, provided by the ModerationCauseLabelPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(ModerationCauseSource source, Label label, InterpretedLabelValueDefinition labelDef, LabelTarget target, LabelPreference setting, Map<ModerationBehaviorContext, ModerationBehavior> behavior, bool noOverride, int priority, bool downgraded)?) → TResult?

Available on ModerationCauseLabel, provided by the ModerationCauseLabelPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited