ModerationDecision class final
Constructors
- ModerationDecision.init({String did = '', bool me = false, ModerationBehaviors behaviors = const ModerationBehaviors()})
-
factory
-
ModerationDecision.merge(List<
ModerationDecision> decisions) -
factory
Properties
- behaviors → ModerationBehaviors
-
The behaviors used to interpret the causes in getUI.
final
-
causes
→ List<
ModerationCause> -
final
- did → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- me → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addBlockedBy(
) → void -
addBlocking(
) → void -
addBlockingByList(
ListViewBasic blockingByList) → void -
addBlockOther(
) → void -
addHidden(
) → void -
addLabel(
{required LabelTarget target, required Label label, required ModerationOpts opts}) → void -
addMuted(
) → void -
addMutedByList(
ListViewBasic mutedByList) → void -
addMutedWord(
[List< MuteWordMatch> ? matches]) → void -
downgrade(
) → ModerationDecision -
getUI(
ModerationBehaviorContext context) → ModerationUI -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited