MuteWordMatch class final

A match found by matchMuteWords.

Constructors

MuteWordMatch({required MutedWord word, required String predicate})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
predicate String
The string that matched the muted word.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
word MutedWord
The muted word that matched.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited