ActionView class abstract
A single moderation action taken against a subject.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
ActionView({@Default.new('tools.ozone.inbox.defs#actionView') String $type, required int id, required String type, @ActionViewScopeConverter() ActionViewScope? scope, @JsonKey.new(toJson: iso8601) required DateTime createdAt, @JsonKey.new(toJson: iso8601) DateTime? reversedAt, @JsonKey.new(toJson: iso8601) DateTime? expiresAt, List<
String> ? labels, List<String> ? policies, Map<String, dynamic> ? $unknown}) -
constfactory
-
ActionView.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
copyWith
→ $ActionViewCopyWith<
ActionView> -
Create a copy of ActionView
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime
-
no setterinherited
- expiresAt → DateTime?
-
no setterinherited
- hasExpiresAt → bool
-
Available on ActionView, provided by the ActionViewExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotExpiresAt → bool
-
Available on ActionView, provided by the ActionViewExtension extension
no setter - hasNotReversedAt → bool
-
Available on ActionView, provided by the ActionViewExtension extension
no setter - hasNotScope → bool
-
Available on ActionView, provided by the ActionViewExtension extension
no setter - hasReversedAt → bool
-
Available on ActionView, provided by the ActionViewExtension extension
no setter - hasScope → bool
-
Available on ActionView, provided by the ActionViewExtension extension
no setter - id → int
-
Action ID (moderation event ID).
no setterinherited
-
labels
→ List<
String> ? -
no setterinherited
-
policies
→ List<
String> ? -
no setterinherited
- reversedAt → DateTime?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → ActionViewScope?
-
no setterinherited
- type → String
-
Public action type.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ActionView value)) → TResult -
Available on ActionView, provided by the ActionViewPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ActionView value)?) → TResult? -
Available on ActionView, provided by the ActionViewPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ActionView value)?, {required TResult orElse()}) → TResult -
Available on ActionView, provided by the ActionViewPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, int id, String type, ActionViewScope? scope, DateTime createdAt, DateTime? reversedAt, DateTime? expiresAt, List< String> ? labels, List<String> ? policies, Map<String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on ActionView, provided by the ActionViewPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ActionView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, int id, String type, ActionViewScope? scope, DateTime createdAt, DateTime? reversedAt, DateTime? expiresAt, List< String> ? labels, List<String> ? policies, Map<String, dynamic> ? $unknown)) → TResult -
Available on ActionView, provided by the ActionViewPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, int id, String type, ActionViewScope? scope, DateTime createdAt, DateTime? reversedAt, DateTime? expiresAt, List< String> ? labels, List<String> ? policies, Map<String, dynamic> ? $unknown)?) → TResult? -
Available on ActionView, provided by the ActionViewPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>