ActionViewPatterns extension

Adds pattern-matching-related methods to ActionView.

on

Methods

map<TResult extends Object?>(TResult $default(_ActionView value)) → TResult

Available on ActionView, provided by the ActionViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ActionView value)?) → TResult?

Available on ActionView, provided by the ActionViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ActionView value)?, {required TResult orElse()}) → TResult

Available on ActionView, provided by the ActionViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, int id, String type, ActionViewScope? scope, DateTime createdAt, DateTime? reversedAt, DateTime? expiresAt, List<String>? labels, List<String>? policies, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ActionView, provided by the ActionViewPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String $type, int id, String type, ActionViewScope? scope, DateTime createdAt, DateTime? reversedAt, DateTime? expiresAt, List<String>? labels, List<String>? policies, Map<String, dynamic>? $unknown)) → TResult

Available on ActionView, provided by the ActionViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, int id, String type, ActionViewScope? scope, DateTime createdAt, DateTime? reversedAt, DateTime? expiresAt, List<String>? labels, List<String>? policies, Map<String, dynamic>? $unknown)?) → TResult?

Available on ActionView, provided by the ActionViewPatterns extension

A variant of when that fallback to returning null