KnownNotificationReason enum

Inheritance
Implemented types
Available extensions

Values

reportResolved → const KnownNotificationReason
const KnownNotificationReason('reportResolved')
reportReopened → const KnownNotificationReason
const KnownNotificationReason('reportReopened')
actionTaken → const KnownNotificationReason
const KnownNotificationReason('actionTaken')
actionReversed → const KnownNotificationReason
const KnownNotificationReason('actionReversed')
appealResolved → const KnownNotificationReason
const KnownNotificationReason('appealResolved')
standingChanged → const KnownNotificationReason
const KnownNotificationReason('standingChanged')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
Returns the value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isKnownValue(String value) → bool
valueOf(String? value) → KnownNotificationReason?

Constants

values → const List<KnownNotificationReason>
A constant List of the values in this enum, in order of their declaration.