Notification class abstract

Available extensions
Annotations
  • @freezed

Constructors

Notification({@Default.new('tools.ozone.inbox.defs#notification') String $type, required int id, @NotificationReasonConverter() required NotificationReason reason, @UNotificationTargetConverter() required UNotificationTarget target, required bool isRead, @JsonKey.new(toJson: iso8601) required DateTime createdAt, Map<String, dynamic>? $unknown})
const
factory
Notification.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $NotificationCopyWith<Notification>
Create a copy of Notification with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
isIsRead → bool

Available on Notification, provided by the NotificationExtension extension

no setter
isNotIsRead → bool

Available on Notification, provided by the NotificationExtension extension

no setter
isRead → bool
no setterinherited
reason → NotificationReason
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → UNotificationTarget
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Notification value)) → TResult

Available on Notification, provided by the NotificationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Notification value)?) → TResult?

Available on Notification, provided by the NotificationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Notification value)?, {required TResult orElse()}) → TResult

Available on Notification, provided by the NotificationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, int id, NotificationReason reason, UNotificationTarget target, bool isRead, DateTime createdAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on Notification, provided by the NotificationPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Notification to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, int id, NotificationReason reason, UNotificationTarget target, bool isRead, DateTime createdAt, Map<String, dynamic>? $unknown)) → TResult

Available on Notification, provided by the NotificationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, int id, NotificationReason reason, UNotificationTarget target, bool isRead, DateTime createdAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on Notification, provided by the NotificationPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>