ReportRef class abstract
Reference to a report by its report table ID, as used by getReport and Ozone's report detail page.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
ReportRef({@Default.new('tools.ozone.inbox.defs#reportRef') String $type, required int reportId, @UReportRefSubjectConverter() UReportRefSubject? subject, @ReportRefStatusConverter() ReportRefStatus? status, Map<
String, dynamic> ? $unknown}) -
constfactory
-
ReportRef.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
copyWith
→ $ReportRefCopyWith<
ReportRef> -
Create a copy of ReportRef
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotStatus → bool
-
Available on ReportRef, provided by the ReportRefExtension extension
no setter - hasNotSubject → bool
-
Available on ReportRef, provided by the ReportRefExtension extension
no setter - hasStatus → bool
-
Available on ReportRef, provided by the ReportRefExtension extension
no setter - hasSubject → bool
-
Available on ReportRef, provided by the ReportRefExtension extension
no setter - reportId → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ReportRefStatus?
-
no setterinherited
- subject → UReportRefSubject?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ReportRef value)) → TResult -
Available on ReportRef, provided by the ReportRefPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ReportRef value)?) → TResult? -
Available on ReportRef, provided by the ReportRefPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ReportRef value)?, {required TResult orElse()}) → TResult -
Available on ReportRef, provided by the ReportRefPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, int reportId, UReportRefSubject? subject, ReportRefStatus? status, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on ReportRef, provided by the ReportRefPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ReportRef to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, int reportId, UReportRefSubject? subject, ReportRefStatus? status, Map< String, dynamic> ? $unknown)) → TResult -
Available on ReportRef, provided by the ReportRefPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, int reportId, UReportRefSubject? subject, ReportRefStatus? status, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on ReportRef, provided by the ReportRefPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>