SubjectRef class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
SubjectRef({@Default.new('tools.ozone.inbox.defs#subjectRef') String $type, @USubjectRefSubjectConverter() required USubjectRefSubject subject, String? actionType, int? actionId, Map<
String, dynamic> ? $unknown}) -
constfactory
-
SubjectRef.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
- actionId → int?
-
no setterinherited
- actionType → String?
-
no setterinherited
-
copyWith
→ $SubjectRefCopyWith<
SubjectRef> -
Create a copy of SubjectRef
with the given fields replaced by the non-null parameter values.
no setterinherited
- hasActionId → bool
-
Available on SubjectRef, provided by the SubjectRefExtension extension
no setter - hasActionType → bool
-
Available on SubjectRef, provided by the SubjectRefExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotActionId → bool
-
Available on SubjectRef, provided by the SubjectRefExtension extension
no setter - hasNotActionType → bool
-
Available on SubjectRef, provided by the SubjectRefExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → USubjectRefSubject
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_SubjectRef value)) → TResult -
Available on SubjectRef, provided by the SubjectRefPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_SubjectRef value)?) → TResult? -
Available on SubjectRef, provided by the SubjectRefPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_SubjectRef value)?, {required TResult orElse()}) → TResult -
Available on SubjectRef, provided by the SubjectRefPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, USubjectRefSubject subject, String? actionType, int? actionId, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on SubjectRef, provided by the SubjectRefPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this SubjectRef to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, USubjectRefSubject subject, String? actionType, int? actionId, Map< String, dynamic> ? $unknown)) → TResult -
Available on SubjectRef, provided by the SubjectRefPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, USubjectRefSubject subject, String? actionType, int? actionId, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on SubjectRef, provided by the SubjectRefPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>