SubjectView class abstract

A subject belonging to the viewer that has moderation actions against it.

Available extensions
Annotations
  • @freezed

Constructors

SubjectView({@Default.new('tools.ozone.inbox.defs#subjectView') String $type, required String src, @USubjectViewSubjectConverter() required USubjectViewSubject subject, @EnforcementViewConverter() required EnforcementView enforcement, @AppealViewConverter() AppealView? appeal, @SubjectViewAvailableActionsConverter() List<SubjectViewAvailableActions>? availableActions, @ActionViewConverter() ActionView? latestAction, int? actionCount, @JsonKey.new(toJson: iso8601) required DateTime createdAt, @JsonKey.new(toJson: iso8601) required DateTime updatedAt, Map<String, dynamic>? $unknown})
const
factory
SubjectView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
actionCount → int?
no setterinherited
appeal → AppealView?
no setterinherited
availableActions → List<SubjectViewAvailableActions>?
no setterinherited
copyWith → $SubjectViewCopyWith<SubjectView>
Create a copy of SubjectView with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
enforcement → EnforcementView
no setterinherited
hasActionCount → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
hasAppeal → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasLatestAction → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
hasNotActionCount → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
hasNotAppeal → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
hasNotLatestAction → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
latestAction → ActionView?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src → String
DID of the moderation service that took the actions.
no setterinherited
subject → USubjectViewSubject
no setterinherited
updatedAt → DateTime
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SubjectView value)) → TResult

Available on SubjectView, provided by the SubjectViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SubjectView value)?) → TResult?

Available on SubjectView, provided by the SubjectViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SubjectView value)?, {required TResult orElse()}) → TResult

Available on SubjectView, provided by the SubjectViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String src, USubjectViewSubject subject, EnforcementView enforcement, AppealView? appeal, List<SubjectViewAvailableActions>? availableActions, ActionView? latestAction, int? actionCount, DateTime createdAt, DateTime updatedAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on SubjectView, provided by the SubjectViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this SubjectView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String src, USubjectViewSubject subject, EnforcementView enforcement, AppealView? appeal, List<SubjectViewAvailableActions>? availableActions, ActionView? latestAction, int? actionCount, DateTime createdAt, DateTime updatedAt, Map<String, dynamic>? $unknown)) → TResult

Available on SubjectView, provided by the SubjectViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String src, USubjectViewSubject subject, EnforcementView enforcement, AppealView? appeal, List<SubjectViewAvailableActions>? availableActions, ActionView? latestAction, int? actionCount, DateTime createdAt, DateTime updatedAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on SubjectView, provided by the SubjectViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>