src property
DID of the moderation service that took the actions.
Implementation
String get $type;/// DID of the moderation service that took the actions.
String get src;
DID of the moderation service that took the actions.
String get $type;/// DID of the moderation service that took the actions.
String get src;