did property
Reporter to preview. Defaults to the authenticated account; another account requires an active moderator, triage, or admin credential.
Implementation
String? get did;
Reporter to preview. Defaults to the authenticated account; another account requires an active moderator, triage, or admin credential.
String? get did;