InboxGetReportOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

InboxGetReportOutput({@ReportViewConverter() required ReportView report, @ResolutionViewConverter() ResolutionView? resolution, Map<String, dynamic>? $unknown})
const
factory
InboxGetReportOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $InboxGetReportOutputCopyWith<InboxGetReportOutput>
Create a copy of InboxGetReportOutput with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNotResolution → bool

Available on InboxGetReportOutput, provided by the InboxGetReportOutputExtension extension

no setter
hasResolution → bool

Available on InboxGetReportOutput, provided by the InboxGetReportOutputExtension extension

no setter
report → ReportView
no setterinherited
resolution → ResolutionView?
Present only when the report is resolved.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_InboxGetReportOutput value)) → TResult

Available on InboxGetReportOutput, provided by the InboxGetReportOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_InboxGetReportOutput value)?) → TResult?

Available on InboxGetReportOutput, provided by the InboxGetReportOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_InboxGetReportOutput value)?, {required TResult orElse()}) → TResult

Available on InboxGetReportOutput, provided by the InboxGetReportOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(ReportView report, ResolutionView? resolution, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on InboxGetReportOutput, provided by the InboxGetReportOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this InboxGetReportOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(ReportView report, ResolutionView? resolution, Map<String, dynamic>? $unknown)) → TResult

Available on InboxGetReportOutput, provided by the InboxGetReportOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(ReportView report, ResolutionView? resolution, Map<String, dynamic>? $unknown)?) → TResult?

Available on InboxGetReportOutput, provided by the InboxGetReportOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>