ReportView class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
ReportView({@Default.new('tools.ozone.inbox.getReport#reportView') String $type, required String src, required int id, required String reasonType, String? reason, @UReportViewSubjectConverter() required UReportViewSubject subject, Map<
String, dynamic> ? record, @ReportViewStatusConverter() required ReportViewStatus status, @JsonKey.new(toJson: iso8601) required DateTime createdAt, @JsonKey.new(toJson: iso8601) required DateTime updatedAt, Map<String, dynamic> ? $unknown}) -
constfactory
-
ReportView.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
copyWith
→ $ReportViewCopyWith<
ReportView> -
Create a copy of ReportView
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotReason → bool
-
Available on ReportView, provided by the ReportViewExtension extension
no setter - hasNotRecord → bool
-
Available on ReportView, provided by the ReportViewExtension extension
no setter - hasReason → bool
-
Available on ReportView, provided by the ReportViewExtension extension
no setter - hasRecord → bool
-
Available on ReportView, provided by the ReportViewExtension extension
no setter - id → int
-
Report ID (report table ID), used by Ozone's report detail page.
no setterinherited
- reason → String?
-
no setterinherited
- reasonType → String
-
The exact fully-qualified reason NSID submitted with and stored on the report.
no setterinherited
-
record
→ Map<
String, dynamic> ? -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- src → String
-
DID of the moderation service that received the report.
no setterinherited
- status → ReportViewStatus
-
no setterinherited
- subject → UReportViewSubject
-
no setterinherited
- updatedAt → DateTime
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ReportView value)) → TResult -
Available on ReportView, provided by the ReportViewPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ReportView value)?) → TResult? -
Available on ReportView, provided by the ReportViewPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ReportView value)?, {required TResult orElse()}) → TResult -
Available on ReportView, provided by the ReportViewPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, String src, int id, String reasonType, String? reason, UReportViewSubject subject, Map< String, dynamic> ? record, ReportViewStatus status, DateTime createdAt, DateTime updatedAt, Map<String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on ReportView, provided by the ReportViewPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ReportView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, String src, int id, String reasonType, String? reason, UReportViewSubject subject, Map< String, dynamic> ? record, ReportViewStatus status, DateTime createdAt, DateTime updatedAt, Map<String, dynamic> ? $unknown)) → TResult -
Available on ReportView, provided by the ReportViewPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, String src, int id, String reasonType, String? reason, UReportViewSubject subject, Map< String, dynamic> ? record, ReportViewStatus status, DateTime createdAt, DateTime updatedAt, Map<String, dynamic> ? $unknown)?) → TResult? -
Available on ReportView, provided by the ReportViewPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>