src property

String get src
inherited

DID of the moderation service that received the report.

Implementation

String get $type;/// DID of the moderation service that received the report.
String get src;