ResolutionView class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
ResolutionView({@Default.new('tools.ozone.inbox.getReport#resolutionView') String $type, @ResolutionViewOutcomeConverter() required ResolutionViewOutcome outcome, String? actionTaken, @ResolutionViewScopeConverter() ResolutionViewScope? scope, @JsonKey.new(toJson: iso8601) required DateTime resolvedAt, Map<
String, dynamic> ? $unknown}) -
constfactory
-
ResolutionView.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
- actionTaken → String?
-
Public action associated with this report's resolution. See the public action vocabulary table.
no setterinherited
-
copyWith
→ $ResolutionViewCopyWith<
ResolutionView> -
Create a copy of ResolutionView
with the given fields replaced by the non-null parameter values.
no setterinherited
- hasActionTaken → bool
-
Available on ResolutionView, provided by the ResolutionViewExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotActionTaken → bool
-
Available on ResolutionView, provided by the ResolutionViewExtension extension
no setter - hasNotScope → bool
-
Available on ResolutionView, provided by the ResolutionViewExtension extension
no setter - hasScope → bool
-
Available on ResolutionView, provided by the ResolutionViewExtension extension
no setter - outcome → ResolutionViewOutcome
-
no setterinherited
- resolvedAt → DateTime
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → ResolutionViewScope?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ResolutionView value)) → TResult -
Available on ResolutionView, provided by the ResolutionViewPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ResolutionView value)?) → TResult? -
Available on ResolutionView, provided by the ResolutionViewPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ResolutionView value)?, {required TResult orElse()}) → TResult -
Available on ResolutionView, provided by the ResolutionViewPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, ResolutionViewOutcome outcome, String? actionTaken, ResolutionViewScope? scope, DateTime resolvedAt, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on ResolutionView, provided by the ResolutionViewPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ResolutionView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, ResolutionViewOutcome outcome, String? actionTaken, ResolutionViewScope? scope, DateTime resolvedAt, Map< String, dynamic> ? $unknown)) → TResult -
Available on ResolutionView, provided by the ResolutionViewPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, ResolutionViewOutcome outcome, String? actionTaken, ResolutionViewScope? scope, DateTime resolvedAt, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on ResolutionView, provided by the ResolutionViewPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>