InboxGetUnreadCountSectionPatterns extension

Adds pattern-matching-related methods to InboxGetUnreadCountSection.

on

Methods

map<TResult extends Object?>({required TResult knownValue(InboxGetUnreadCountSectionKnownValue value), required TResult unknown(InboxGetUnreadCountSectionUnknown value)}) → TResult

Available on InboxGetUnreadCountSection, provided by the InboxGetUnreadCountSectionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(InboxGetUnreadCountSectionKnownValue value)?, TResult? unknown(InboxGetUnreadCountSectionUnknown value)?}) → TResult?

Available on InboxGetUnreadCountSection, provided by the InboxGetUnreadCountSectionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(InboxGetUnreadCountSectionKnownValue value)?, TResult unknown(InboxGetUnreadCountSectionUnknown value)?, required TResult orElse()}) → TResult

Available on InboxGetUnreadCountSection, provided by the InboxGetUnreadCountSectionPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownInboxGetUnreadCountSection data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on InboxGetUnreadCountSection, provided by the InboxGetUnreadCountSectionPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult knownValue(KnownInboxGetUnreadCountSection data), required TResult unknown(String data)}) → TResult

Available on InboxGetUnreadCountSection, provided by the InboxGetUnreadCountSectionPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownInboxGetUnreadCountSection data)?, TResult? unknown(String data)?}) → TResult?

Available on InboxGetUnreadCountSection, provided by the InboxGetUnreadCountSectionPatterns extension

A variant of when that fallback to returning null