InboxListNotificationsInputPatterns extension

Adds pattern-matching-related methods to InboxListNotificationsInput.

on

Methods

map<TResult extends Object?>(TResult $default(_InboxListNotificationsInput value)) → TResult

Available on InboxListNotificationsInput, provided by the InboxListNotificationsInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_InboxListNotificationsInput value)?) → TResult?

Available on InboxListNotificationsInput, provided by the InboxListNotificationsInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_InboxListNotificationsInput value)?, {required TResult orElse()}) → TResult

Available on InboxListNotificationsInput, provided by the InboxListNotificationsInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(InboxListNotificationsSection? section, List<InboxListNotificationsReasons>? reasons, bool unreadOnly, int limit, String? cursor, String? did, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on InboxListNotificationsInput, provided by the InboxListNotificationsInputPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(InboxListNotificationsSection? section, List<InboxListNotificationsReasons>? reasons, bool unreadOnly, int limit, String? cursor, String? did, Map<String, dynamic>? $unknown)) → TResult

Available on InboxListNotificationsInput, provided by the InboxListNotificationsInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(InboxListNotificationsSection? section, List<InboxListNotificationsReasons>? reasons, bool unreadOnly, int limit, String? cursor, String? did, Map<String, dynamic>? $unknown)?) → TResult?

Available on InboxListNotificationsInput, provided by the InboxListNotificationsInputPatterns extension

A variant of when that fallback to returning null