InboxListNotificationsReasonsPatterns extension

Adds pattern-matching-related methods to InboxListNotificationsReasons.

on

Methods

map<TResult extends Object?>({required TResult knownValue(InboxListNotificationsReasonsKnownValue value), required TResult unknown(InboxListNotificationsReasonsUnknown value)}) → TResult

Available on InboxListNotificationsReasons, provided by the InboxListNotificationsReasonsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(InboxListNotificationsReasonsKnownValue value)?, TResult? unknown(InboxListNotificationsReasonsUnknown value)?}) → TResult?

Available on InboxListNotificationsReasons, provided by the InboxListNotificationsReasonsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(InboxListNotificationsReasonsKnownValue value)?, TResult unknown(InboxListNotificationsReasonsUnknown value)?, required TResult orElse()}) → TResult

Available on InboxListNotificationsReasons, provided by the InboxListNotificationsReasonsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownInboxListNotificationsReasons data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on InboxListNotificationsReasons, provided by the InboxListNotificationsReasonsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult knownValue(KnownInboxListNotificationsReasons data), required TResult unknown(String data)}) → TResult

Available on InboxListNotificationsReasons, provided by the InboxListNotificationsReasonsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownInboxListNotificationsReasons data)?, TResult? unknown(String data)?}) → TResult?

Available on InboxListNotificationsReasons, provided by the InboxListNotificationsReasonsPatterns extension

A variant of when that fallback to returning null