InboxListNotificationsSectionPatterns extension

Adds pattern-matching-related methods to InboxListNotificationsSection.

on

Methods

map<TResult extends Object?>({required TResult knownValue(InboxListNotificationsSectionKnownValue value), required TResult unknown(InboxListNotificationsSectionUnknown value)}) → TResult

Available on InboxListNotificationsSection, provided by the InboxListNotificationsSectionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(InboxListNotificationsSectionKnownValue value)?, TResult? unknown(InboxListNotificationsSectionUnknown value)?}) → TResult?

Available on InboxListNotificationsSection, provided by the InboxListNotificationsSectionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(InboxListNotificationsSectionKnownValue value)?, TResult unknown(InboxListNotificationsSectionUnknown value)?, required TResult orElse()}) → TResult

Available on InboxListNotificationsSection, provided by the InboxListNotificationsSectionPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownInboxListNotificationsSection data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on InboxListNotificationsSection, provided by the InboxListNotificationsSectionPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult knownValue(KnownInboxListNotificationsSection data), required TResult unknown(String data)}) → TResult

Available on InboxListNotificationsSection, provided by the InboxListNotificationsSectionPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownInboxListNotificationsSection data)?, TResult? unknown(String data)?}) → TResult?

Available on InboxListNotificationsSection, provided by the InboxListNotificationsSectionPatterns extension

A variant of when that fallback to returning null