InboxListReportsInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

InboxListReportsInput({String? did, @Default.new('all') String filter, @Default.new('updatedAt') String sortField, @Default.new('desc') String sortDirection, @Default.new(50) int limit, String? cursor, Map<String, dynamic>? $unknown})
const
factory
InboxListReportsInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $InboxListReportsInputCopyWith<InboxListReportsInput>
Create a copy of InboxListReportsInput with the given fields replaced by the non-null parameter values.
no setterinherited
cursor → String?
An opaque cursor for pagination.
no setterinherited
did → String?
Account to preview. Defaults to the authenticated account; another account requires an active moderator, triage, or admin credential.
no setterinherited
filter → String
Filter report activity. unread includes reports whose updatedAt is after the reports section's seenAt watermark.
no setterinherited
hasCursor → bool

Available on InboxListReportsInput, provided by the InboxListReportsInputExtension extension

no setter
hasDid → bool

Available on InboxListReportsInput, provided by the InboxListReportsInputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotCursor → bool

Available on InboxListReportsInput, provided by the InboxListReportsInputExtension extension

no setter
hasNotDid → bool

Available on InboxListReportsInput, provided by the InboxListReportsInputExtension extension

no setter
limit → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortDirection → String
no setterinherited
sortField → String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_InboxListReportsInput value)) → TResult

Available on InboxListReportsInput, provided by the InboxListReportsInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_InboxListReportsInput value)?) → TResult?

Available on InboxListReportsInput, provided by the InboxListReportsInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_InboxListReportsInput value)?, {required TResult orElse()}) → TResult

Available on InboxListReportsInput, provided by the InboxListReportsInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? did, String filter, String sortField, String sortDirection, int limit, String? cursor, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on InboxListReportsInput, provided by the InboxListReportsInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this InboxListReportsInput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? did, String filter, String sortField, String sortDirection, int limit, String? cursor, Map<String, dynamic>? $unknown)) → TResult

Available on InboxListReportsInput, provided by the InboxListReportsInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? did, String filter, String sortField, String sortDirection, int limit, String? cursor, Map<String, dynamic>? $unknown)?) → TResult?

Available on InboxListReportsInput, provided by the InboxListReportsInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>