ReportView class abstract

Available extensions
Annotations
  • @freezed

Constructors

ReportView({@Default.new('tools.ozone.inbox.listReports#reportView') String $type, required String src, required int id, required bool isRead, required String reasonType, String? reason, String? lastActionTaken, @ReportViewScopeConverter() ReportViewScope? scope, @UReportViewSubjectConverter() required UReportViewSubject subject, @ReportViewStatusConverter() required ReportViewStatus status, @JsonKey.new(toJson: iso8601) required DateTime createdAt, @JsonKey.new(toJson: iso8601) required DateTime updatedAt, Map<String, dynamic>? $unknown})
const
factory
ReportView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $ReportViewCopyWith<ReportView>
Create a copy of ReportView with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasLastActionTaken → bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasNotLastActionTaken → bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasNotReason → bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasNotScope → bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasReason → bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasScope → bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
id → int
Report ID (report table ID), used by getReport and Ozone's report detail page.
no setterinherited
isIsRead → bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
isNotIsRead → bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
isRead → bool
no setterinherited
lastActionTaken → String?
Public action associated with this report's transition to resolved. See the public action vocabulary table.
no setterinherited
reason → String?
no setterinherited
reasonType → String
The exact fully-qualified reason NSID submitted with and stored on the report.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → ReportViewScope?
no setterinherited
src → String
DID of the moderation service that received the report.
no setterinherited
status → ReportViewStatus
no setterinherited
subject → UReportViewSubject
no setterinherited
updatedAt → DateTime
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReportView value)) → TResult

Available on ReportView, provided by the ReportViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReportView value)?) → TResult?

Available on ReportView, provided by the ReportViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReportView value)?, {required TResult orElse()}) → TResult

Available on ReportView, provided by the ReportViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String src, int id, bool isRead, String reasonType, String? reason, String? lastActionTaken, ReportViewScope? scope, UReportViewSubject subject, ReportViewStatus status, DateTime createdAt, DateTime updatedAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ReportView, provided by the ReportViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ReportView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String src, int id, bool isRead, String reasonType, String? reason, String? lastActionTaken, ReportViewScope? scope, UReportViewSubject subject, ReportViewStatus status, DateTime createdAt, DateTime updatedAt, Map<String, dynamic>? $unknown)) → TResult

Available on ReportView, provided by the ReportViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String src, int id, bool isRead, String reasonType, String? reason, String? lastActionTaken, ReportViewScope? scope, UReportViewSubject subject, ReportViewStatus status, DateTime createdAt, DateTime updatedAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on ReportView, provided by the ReportViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>