src property
DID of the moderation service that received the report.
Implementation
String get $type;/// DID of the moderation service that received the report.
String get src;
DID of the moderation service that received the report.
String get $type;/// DID of the moderation service that received the report.
String get src;