AccountStats class abstract

Statistics about a particular account subject

Available extensions
Annotations
  • @freezed

Constructors

AccountStats({@Default.new('tools.ozone.moderation.defs#accountStats') String $type, int? reportCount, int? appealCount, int? suspendCount, int? escalateCount, int? takedownCount, Map<String, dynamic>? $unknown})
const
factory
AccountStats.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
appealCount → int?
Total number of appeals against a moderation action on the account
no setterinherited
copyWith → $AccountStatsCopyWith<AccountStats>
Create a copy of AccountStats with the given fields replaced by the non-null parameter values.
no setterinherited
escalateCount → int?
Number of times the account was escalated
no setterinherited
hasAppealCount → bool

Available on AccountStats, provided by the AccountStatsExtension extension

no setter
hasEscalateCount → bool

Available on AccountStats, provided by the AccountStatsExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotAppealCount → bool

Available on AccountStats, provided by the AccountStatsExtension extension

no setter
hasNotEscalateCount → bool

Available on AccountStats, provided by the AccountStatsExtension extension

no setter
hasNotReportCount → bool

Available on AccountStats, provided by the AccountStatsExtension extension

no setter
hasNotSuspendCount → bool

Available on AccountStats, provided by the AccountStatsExtension extension

no setter
hasNotTakedownCount → bool

Available on AccountStats, provided by the AccountStatsExtension extension

no setter
hasReportCount → bool

Available on AccountStats, provided by the AccountStatsExtension extension

no setter
hasSuspendCount → bool

Available on AccountStats, provided by the AccountStatsExtension extension

no setter
hasTakedownCount → bool

Available on AccountStats, provided by the AccountStatsExtension extension

no setter
reportCount → int?
Total number of reports on the account
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suspendCount → int?
Number of times the account was suspended
no setterinherited
takedownCount → int?
Number of times the account was taken down
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AccountStats value)) → TResult

Available on AccountStats, provided by the AccountStatsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AccountStats value)?) → TResult?

Available on AccountStats, provided by the AccountStatsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AccountStats value)?, {required TResult orElse()}) → TResult

Available on AccountStats, provided by the AccountStatsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, int? reportCount, int? appealCount, int? suspendCount, int? escalateCount, int? takedownCount, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on AccountStats, provided by the AccountStatsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AccountStats to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, int? reportCount, int? appealCount, int? suspendCount, int? escalateCount, int? takedownCount, Map<String, dynamic>? $unknown)) → TResult

Available on AccountStats, provided by the AccountStatsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, int? reportCount, int? appealCount, int? suspendCount, int? escalateCount, int? takedownCount, Map<String, dynamic>? $unknown)?) → TResult?

Available on AccountStats, provided by the AccountStatsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>