IdentityEvent class abstract

Logs identity related events on a repo subject. Normally captured by automod from the firehose and emitted to ozone for historical tracking.

Available extensions
Annotations
  • @freezed

Constructors

IdentityEvent({@Default.new('tools.ozone.moderation.defs#identityEvent') String $type, String? comment, String? handle, String? pdsHost, bool? tombstone, @JsonKey.new(toJson: iso8601) required DateTime timestamp, Map<String, dynamic>? $unknown})
const
factory
IdentityEvent.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
comment → String?
no setterinherited
copyWith → $IdentityEventCopyWith<IdentityEvent>
Create a copy of IdentityEvent with the given fields replaced by the non-null parameter values.
no setterinherited
handle → String?
no setterinherited
hasComment → bool

Available on IdentityEvent, provided by the IdentityEventExtension extension

no setter
hasHandle → bool

Available on IdentityEvent, provided by the IdentityEventExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotComment → bool

Available on IdentityEvent, provided by the IdentityEventExtension extension

no setter
hasNotHandle → bool

Available on IdentityEvent, provided by the IdentityEventExtension extension

no setter
hasNotPdsHost → bool

Available on IdentityEvent, provided by the IdentityEventExtension extension

no setter
hasPdsHost → bool

Available on IdentityEvent, provided by the IdentityEventExtension extension

no setter
isNotTombstone → bool

Available on IdentityEvent, provided by the IdentityEventExtension extension

no setter
isTombstone → bool

Available on IdentityEvent, provided by the IdentityEventExtension extension

no setter
pdsHost → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
no setterinherited
tombstone → bool?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_IdentityEvent value)) → TResult

Available on IdentityEvent, provided by the IdentityEventPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_IdentityEvent value)?) → TResult?

Available on IdentityEvent, provided by the IdentityEventPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_IdentityEvent value)?, {required TResult orElse()}) → TResult

Available on IdentityEvent, provided by the IdentityEventPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String? comment, String? handle, String? pdsHost, bool? tombstone, DateTime timestamp, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on IdentityEvent, provided by the IdentityEventPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this IdentityEvent to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String? comment, String? handle, String? pdsHost, bool? tombstone, DateTime timestamp, Map<String, dynamic>? $unknown)) → TResult

Available on IdentityEvent, provided by the IdentityEventPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String? comment, String? handle, String? pdsHost, bool? tombstone, DateTime timestamp, Map<String, dynamic>? $unknown)?) → TResult?

Available on IdentityEvent, provided by the IdentityEventPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>