ModEventAcknowledge class abstract

Available extensions
Annotations
  • @freezed

Constructors

ModEventAcknowledge({@Default.new('tools.ozone.moderation.defs#modEventAcknowledge') String $type, String? comment, bool? acknowledgeAccountSubjects, Map<String, dynamic>? $unknown})
const
factory
ModEventAcknowledge.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
acknowledgeAccountSubjects → bool?
If true, all other reports on content authored by this account will be resolved (acknowledged).
no setterinherited
comment → String?
no setterinherited
copyWith → $ModEventAcknowledgeCopyWith<ModEventAcknowledge>
Create a copy of ModEventAcknowledge with the given fields replaced by the non-null parameter values.
no setterinherited
hasComment → bool

Available on ModEventAcknowledge, provided by the ModEventAcknowledgeExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotComment → bool

Available on ModEventAcknowledge, provided by the ModEventAcknowledgeExtension extension

no setter
isAcknowledgeAccountSubjects → bool

Available on ModEventAcknowledge, provided by the ModEventAcknowledgeExtension extension

no setter
isNotAcknowledgeAccountSubjects → bool

Available on ModEventAcknowledge, provided by the ModEventAcknowledgeExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ModEventAcknowledge value)) → TResult

Available on ModEventAcknowledge, provided by the ModEventAcknowledgePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ModEventAcknowledge value)?) → TResult?

Available on ModEventAcknowledge, provided by the ModEventAcknowledgePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ModEventAcknowledge value)?, {required TResult orElse()}) → TResult

Available on ModEventAcknowledge, provided by the ModEventAcknowledgePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String? comment, bool? acknowledgeAccountSubjects, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ModEventAcknowledge, provided by the ModEventAcknowledgePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ModEventAcknowledge to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String? comment, bool? acknowledgeAccountSubjects, Map<String, dynamic>? $unknown)) → TResult

Available on ModEventAcknowledge, provided by the ModEventAcknowledgePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String? comment, bool? acknowledgeAccountSubjects, Map<String, dynamic>? $unknown)?) → TResult?

Available on ModEventAcknowledge, provided by the ModEventAcknowledgePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>