ModEventComment class abstract

Add a comment to a subject. An empty comment will clear any previously set sticky comment.

Available extensions
Annotations
  • @freezed

Constructors

ModEventComment({@Default.new('tools.ozone.moderation.defs#modEventComment') String $type, String? comment, bool? sticky, Map<String, dynamic>? $unknown})
const
factory
ModEventComment.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
comment → String?
no setterinherited
copyWith → $ModEventCommentCopyWith<ModEventComment>
Create a copy of ModEventComment with the given fields replaced by the non-null parameter values.
no setterinherited
hasComment → bool

Available on ModEventComment, provided by the ModEventCommentExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotComment → bool

Available on ModEventComment, provided by the ModEventCommentExtension extension

no setter
isNotSticky → bool

Available on ModEventComment, provided by the ModEventCommentExtension extension

no setter
isSticky → bool

Available on ModEventComment, provided by the ModEventCommentExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sticky → bool?
Make the comment persistent on the subject
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ModEventComment value)) → TResult

Available on ModEventComment, provided by the ModEventCommentPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ModEventComment value)?) → TResult?

Available on ModEventComment, provided by the ModEventCommentPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ModEventComment value)?, {required TResult orElse()}) → TResult

Available on ModEventComment, provided by the ModEventCommentPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String? comment, bool? sticky, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ModEventComment, provided by the ModEventCommentPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ModEventComment to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String? comment, bool? sticky, Map<String, dynamic>? $unknown)) → TResult

Available on ModEventComment, provided by the ModEventCommentPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String? comment, bool? sticky, Map<String, dynamic>? $unknown)?) → TResult?

Available on ModEventComment, provided by the ModEventCommentPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>