ModEventEmail class abstract

Keep a log of outgoing email to a user

Available extensions
Annotations
  • @freezed

Constructors

ModEventEmail({@Default.new('tools.ozone.moderation.defs#modEventEmail') String $type, required String subjectLine, String? content, String? comment, List<String>? policies, String? severityLevel, int? strikeCount, @JsonKey.new(toJson: iso8601) DateTime? strikeExpiresAt, bool? isDelivered, Map<String, dynamic>? $unknown})
const
factory
ModEventEmail.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
comment → String?
Additional comment about the outgoing comm.
no setterinherited
content → String?
The content of the email sent to the user.
no setterinherited
copyWith → $ModEventEmailCopyWith<ModEventEmail>
Create a copy of ModEventEmail with the given fields replaced by the non-null parameter values.
no setterinherited
hasComment → bool

Available on ModEventEmail, provided by the ModEventEmailExtension extension

no setter
hasContent → bool

Available on ModEventEmail, provided by the ModEventEmailExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotComment → bool

Available on ModEventEmail, provided by the ModEventEmailExtension extension

no setter
hasNotContent → bool

Available on ModEventEmail, provided by the ModEventEmailExtension extension

no setter
hasNotSeverityLevel → bool

Available on ModEventEmail, provided by the ModEventEmailExtension extension

no setter
hasNotStrikeCount → bool

Available on ModEventEmail, provided by the ModEventEmailExtension extension

no setter
hasNotStrikeExpiresAt → bool

Available on ModEventEmail, provided by the ModEventEmailExtension extension

no setter
hasSeverityLevel → bool

Available on ModEventEmail, provided by the ModEventEmailExtension extension

no setter
hasStrikeCount → bool

Available on ModEventEmail, provided by the ModEventEmailExtension extension

no setter
hasStrikeExpiresAt → bool

Available on ModEventEmail, provided by the ModEventEmailExtension extension

no setter
isDelivered → bool?
Indicates whether the email was successfully delivered to the user's inbox.
no setterinherited
isIsDelivered → bool

Available on ModEventEmail, provided by the ModEventEmailExtension extension

no setter
isNotIsDelivered → bool

Available on ModEventEmail, provided by the ModEventEmailExtension extension

no setter
policies → List<String>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severityLevel → String?
Severity level of the violation. Normally 'sev-1' that adds strike on repeat offense
no setterinherited
strikeCount → int?
Number of strikes to assign to the user for this violation. Normally 0 as an indicator of a warning and only added as a strike on a repeat offense.
no setterinherited
strikeExpiresAt → DateTime?
When the strike should expire. If not provided, the strike never expires.
no setterinherited
subjectLine → String
The subject line of the email sent to the user.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ModEventEmail value)) → TResult

Available on ModEventEmail, provided by the ModEventEmailPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ModEventEmail value)?) → TResult?

Available on ModEventEmail, provided by the ModEventEmailPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ModEventEmail value)?, {required TResult orElse()}) → TResult

Available on ModEventEmail, provided by the ModEventEmailPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String subjectLine, String? content, String? comment, List<String>? policies, String? severityLevel, int? strikeCount, DateTime? strikeExpiresAt, bool? isDelivered, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ModEventEmail, provided by the ModEventEmailPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ModEventEmail to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String subjectLine, String? content, String? comment, List<String>? policies, String? severityLevel, int? strikeCount, DateTime? strikeExpiresAt, bool? isDelivered, Map<String, dynamic>? $unknown)) → TResult

Available on ModEventEmail, provided by the ModEventEmailPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String subjectLine, String? content, String? comment, List<String>? policies, String? severityLevel, int? strikeCount, DateTime? strikeExpiresAt, bool? isDelivered, Map<String, dynamic>? $unknown)?) → TResult?

Available on ModEventEmail, provided by the ModEventEmailPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>