ModEventMute class abstract

Mute incoming reports on a subject

Available extensions
Annotations
  • @freezed

Constructors

ModEventMute({@Default.new('tools.ozone.moderation.defs#modEventMute') String $type, String? comment, required int durationInHours, Map<String, dynamic>? $unknown})
const
factory
ModEventMute.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
comment → String?
no setterinherited
copyWith → $ModEventMuteCopyWith<ModEventMute>
Create a copy of ModEventMute with the given fields replaced by the non-null parameter values.
no setterinherited
durationInHours → int
Indicates how long the subject should remain muted.
no setterinherited
hasComment → bool

Available on ModEventMute, provided by the ModEventMuteExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotComment → bool

Available on ModEventMute, provided by the ModEventMuteExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ModEventMute value)) → TResult

Available on ModEventMute, provided by the ModEventMutePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ModEventMute value)?) → TResult?

Available on ModEventMute, provided by the ModEventMutePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ModEventMute value)?, {required TResult orElse()}) → TResult

Available on ModEventMute, provided by the ModEventMutePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String? comment, int durationInHours, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ModEventMute, provided by the ModEventMutePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ModEventMute to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String? comment, int durationInHours, Map<String, dynamic>? $unknown)) → TResult

Available on ModEventMute, provided by the ModEventMutePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String? comment, int durationInHours, Map<String, dynamic>? $unknown)?) → TResult?

Available on ModEventMute, provided by the ModEventMutePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>