ModEventPriorityScore class abstract

Set priority score of the subject. Higher score means higher priority.

Available extensions
Annotations
  • @freezed

Constructors

ModEventPriorityScore({@Default.new('tools.ozone.moderation.defs#modEventPriorityScore') String $type, String? comment, required int score, Map<String, dynamic>? $unknown})
const
factory
ModEventPriorityScore.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
comment → String?
no setterinherited
copyWith → $ModEventPriorityScoreCopyWith<ModEventPriorityScore>
Create a copy of ModEventPriorityScore with the given fields replaced by the non-null parameter values.
no setterinherited
hasComment → bool

Available on ModEventPriorityScore, provided by the ModEventPriorityScoreExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotComment → bool

Available on ModEventPriorityScore, provided by the ModEventPriorityScoreExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → int
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ModEventPriorityScore value)) → TResult

Available on ModEventPriorityScore, provided by the ModEventPriorityScorePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ModEventPriorityScore value)?) → TResult?

Available on ModEventPriorityScore, provided by the ModEventPriorityScorePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ModEventPriorityScore value)?, {required TResult orElse()}) → TResult

Available on ModEventPriorityScore, provided by the ModEventPriorityScorePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String? comment, int score, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ModEventPriorityScore, provided by the ModEventPriorityScorePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ModEventPriorityScore to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String? comment, int score, Map<String, dynamic>? $unknown)) → TResult

Available on ModEventPriorityScore, provided by the ModEventPriorityScorePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String? comment, int score, Map<String, dynamic>? $unknown)?) → TResult?

Available on ModEventPriorityScore, provided by the ModEventPriorityScorePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>