ModEventReport constructor

const ModEventReport({
  1. @Default.new('tools.ozone.moderation.defs#modEventReport') String $type,
  2. String? appealSubmittedBy,
  3. String? appealActionType,
  4. int? appealActionId,
  5. String? appealLabel,
  6. String? comment,
  7. bool? isReporterMuted,
  8. @ReasonTypeConverter() required ReasonType reportType,
  9. Map<String, dynamic>? $unknown,
})

Implementation

@JsonSerializable(includeIfNull: false)
const factory ModEventReport({
  @Default('tools.ozone.moderation.defs#modEventReport') String $type,

  /// Moderator who submitted this appeal on behalf of the affected account. Returned by moderator event APIs.
  String? appealSubmittedBy,

  /// Action reference type recorded when this appeal was submitted.
  String? appealActionType,
  int? appealActionId,
  String? appealLabel,
  String? comment,

  /// Set to true if the reporter was muted from reporting at the time of the event. These reports won't impact the reviewState of the subject.
  bool? isReporterMuted,
  @ReasonTypeConverter() required ReasonType reportType,

  Map<String, dynamic>? $unknown,
}) = _ModEventReport;