isReporterMuted property
Set to true if the reporter was muted from reporting at the time of the event. These reports won't impact the reviewState of the subject.
Implementation
String? get appealActionType; int? get appealActionId; String? get appealLabel; String? get comment;/// Set to true if the reporter was muted from reporting at the time of the event. These reports won't impact the reviewState of the subject.
bool? get isReporterMuted;