ModEventTakedown class abstract

Take down a subject permanently or temporarily

Available extensions
Annotations
  • @freezed

Constructors

ModEventTakedown({@Default.new('tools.ozone.moderation.defs#modEventTakedown') String $type, String? comment, int? durationInHours, bool? acknowledgeAccountSubjects, List<String>? policies, String? severityLevel, @ModEventTakedownTargetServicesConverter() List<ModEventTakedownTargetServices>? targetServices, int? strikeCount, @JsonKey.new(toJson: iso8601) DateTime? strikeExpiresAt, Map<String, dynamic>? $unknown})
const
factory
ModEventTakedown.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
acknowledgeAccountSubjects → bool?
If true, all other reports on content authored by this account will be resolved (acknowledged).
no setterinherited
comment → String?
no setterinherited
copyWith → $ModEventTakedownCopyWith<ModEventTakedown>
Create a copy of ModEventTakedown with the given fields replaced by the non-null parameter values.
no setterinherited
durationInHours → int?
Indicates how long the takedown should be in effect before automatically expiring.
no setterinherited
hasComment → bool

Available on ModEventTakedown, provided by the ModEventTakedownExtension extension

no setter
hasDurationInHours → bool

Available on ModEventTakedown, provided by the ModEventTakedownExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotComment → bool

Available on ModEventTakedown, provided by the ModEventTakedownExtension extension

no setter
hasNotDurationInHours → bool

Available on ModEventTakedown, provided by the ModEventTakedownExtension extension

no setter
hasNotSeverityLevel → bool

Available on ModEventTakedown, provided by the ModEventTakedownExtension extension

no setter
hasNotStrikeCount → bool

Available on ModEventTakedown, provided by the ModEventTakedownExtension extension

no setter
hasNotStrikeExpiresAt → bool

Available on ModEventTakedown, provided by the ModEventTakedownExtension extension

no setter
hasSeverityLevel → bool

Available on ModEventTakedown, provided by the ModEventTakedownExtension extension

no setter
hasStrikeCount → bool

Available on ModEventTakedown, provided by the ModEventTakedownExtension extension

no setter
hasStrikeExpiresAt → bool

Available on ModEventTakedown, provided by the ModEventTakedownExtension extension

no setter
isAcknowledgeAccountSubjects → bool

Available on ModEventTakedown, provided by the ModEventTakedownExtension extension

no setter
isNotAcknowledgeAccountSubjects → bool

Available on ModEventTakedown, provided by the ModEventTakedownExtension extension

no setter
policies → List<String>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severityLevel → String?
Severity level of the violation (e.g., 'sev-0', 'sev-1', 'sev-2', etc.).
no setterinherited
strikeCount → int?
Number of strikes to assign to the user for this violation.
no setterinherited
strikeExpiresAt → DateTime?
When the strike should expire. If not provided, the strike never expires.
no setterinherited
targetServices → List<ModEventTakedownTargetServices>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ModEventTakedown value)) → TResult

Available on ModEventTakedown, provided by the ModEventTakedownPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ModEventTakedown value)?) → TResult?

Available on ModEventTakedown, provided by the ModEventTakedownPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ModEventTakedown value)?, {required TResult orElse()}) → TResult

Available on ModEventTakedown, provided by the ModEventTakedownPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String? comment, int? durationInHours, bool? acknowledgeAccountSubjects, List<String>? policies, String? severityLevel, List<ModEventTakedownTargetServices>? targetServices, int? strikeCount, DateTime? strikeExpiresAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ModEventTakedown, provided by the ModEventTakedownPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ModEventTakedown to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String? comment, int? durationInHours, bool? acknowledgeAccountSubjects, List<String>? policies, String? severityLevel, List<ModEventTakedownTargetServices>? targetServices, int? strikeCount, DateTime? strikeExpiresAt, Map<String, dynamic>? $unknown)) → TResult

Available on ModEventTakedown, provided by the ModEventTakedownPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String? comment, int? durationInHours, bool? acknowledgeAccountSubjects, List<String>? policies, String? severityLevel, List<ModEventTakedownTargetServices>? targetServices, int? strikeCount, DateTime? strikeExpiresAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on ModEventTakedown, provided by the ModEventTakedownPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>