ModEventTakedown constructor
const
ModEventTakedown({
- @Default.new('tools.ozone.moderation.defs#modEventTakedown') String $type,
- String? comment,
- int? durationInHours,
- bool? acknowledgeAccountSubjects,
- List<
String> ? policies, - String? severityLevel,
- @ModEventTakedownTargetServicesConverter() List<
ModEventTakedownTargetServices> ? targetServices, - int? strikeCount,
- @JsonKey.new(toJson: iso8601) DateTime? strikeExpiresAt,
- Map<
String, dynamic> ? $unknown,
Implementation
@JsonSerializable(includeIfNull: false)
const factory ModEventTakedown({
@Default('tools.ozone.moderation.defs#modEventTakedown') String $type,
String? comment,
/// Indicates how long the takedown should be in effect before automatically expiring.
int? durationInHours,
/// If true, all other reports on content authored by this account will be resolved (acknowledged).
bool? acknowledgeAccountSubjects,
List<String>? policies,
/// Severity level of the violation (e.g., 'sev-0', 'sev-1', 'sev-2', etc.).
String? severityLevel,
@ModEventTakedownTargetServicesConverter()
List<ModEventTakedownTargetServices>? targetServices,
/// Number of strikes to assign to the user for this violation.
int? strikeCount,
/// When the strike should expire. If not provided, the strike never expires.
@JsonKey(toJson: iso8601) DateTime? strikeExpiresAt,
Map<String, dynamic>? $unknown,
}) = _ModEventTakedown;