ModEventView class abstract

Available extensions
Annotations
  • @freezed

Constructors

ModEventView({@Default.new('tools.ozone.moderation.defs#modEventView') String $type, required int id, @UModEventViewEventConverter() required UModEventViewEvent event, @UModEventViewSubjectConverter() required UModEventViewSubject subject, required List<String> subjectBlobCids, required String createdBy, @JsonKey.new(toJson: iso8601) required DateTime createdAt, String? creatorHandle, String? subjectHandle, @ModToolConverter() ModTool? modTool, Map<String, dynamic>? $unknown})
const
factory
ModEventView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $ModEventViewCopyWith<ModEventView>
Create a copy of ModEventView with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
createdBy → String
no setterinherited
creatorHandle → String?
no setterinherited
event → UModEventViewEvent
no setterinherited
hasCreatorHandle → bool

Available on ModEventView, provided by the ModEventViewExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasModTool → bool

Available on ModEventView, provided by the ModEventViewExtension extension

no setter
hasNotCreatorHandle → bool

Available on ModEventView, provided by the ModEventViewExtension extension

no setter
hasNotModTool → bool

Available on ModEventView, provided by the ModEventViewExtension extension

no setter
hasNotSubjectHandle → bool

Available on ModEventView, provided by the ModEventViewExtension extension

no setter
hasSubjectHandle → bool

Available on ModEventView, provided by the ModEventViewExtension extension

no setter
id → int
no setterinherited
modTool → ModTool?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → UModEventViewSubject
no setterinherited
subjectBlobCids → List<String>
no setterinherited
subjectHandle → String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ModEventView value)) → TResult

Available on ModEventView, provided by the ModEventViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ModEventView value)?) → TResult?

Available on ModEventView, provided by the ModEventViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ModEventView value)?, {required TResult orElse()}) → TResult

Available on ModEventView, provided by the ModEventViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, int id, UModEventViewEvent event, UModEventViewSubject subject, List<String> subjectBlobCids, String createdBy, DateTime createdAt, String? creatorHandle, String? subjectHandle, ModTool? modTool, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ModEventView, provided by the ModEventViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ModEventView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, int id, UModEventViewEvent event, UModEventViewSubject subject, List<String> subjectBlobCids, String createdBy, DateTime createdAt, String? creatorHandle, String? subjectHandle, ModTool? modTool, Map<String, dynamic>? $unknown)) → TResult

Available on ModEventView, provided by the ModEventViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, int id, UModEventViewEvent event, UModEventViewSubject subject, List<String> subjectBlobCids, String createdBy, DateTime createdAt, String? creatorHandle, String? subjectHandle, ModTool? modTool, Map<String, dynamic>? $unknown)?) → TResult?

Available on ModEventView, provided by the ModEventViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>