ModEventViewDetail class abstract

Available extensions
Annotations
  • @freezed

Constructors

ModEventViewDetail({@Default.new('tools.ozone.moderation.defs#modEventViewDetail') String $type, required int id, @UModEventViewDetailEventConverter() required UModEventViewDetailEvent event, @UModEventViewDetailSubjectConverter() required UModEventViewDetailSubject subject, @BlobViewConverter() required List<BlobView> subjectBlobs, required String createdBy, @JsonKey.new(toJson: iso8601) required DateTime createdAt, @ModToolConverter() ModTool? modTool, Map<String, dynamic>? $unknown})
const
factory
ModEventViewDetail.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $ModEventViewDetailCopyWith<ModEventViewDetail>
Create a copy of ModEventViewDetail with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
createdBy → String
no setterinherited
event → UModEventViewDetailEvent
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasModTool → bool

Available on ModEventViewDetail, provided by the ModEventViewDetailExtension extension

no setter
hasNotModTool → bool

Available on ModEventViewDetail, provided by the ModEventViewDetailExtension extension

no setter
id → int
no setterinherited
modTool → ModTool?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → UModEventViewDetailSubject
no setterinherited
subjectBlobs → List<BlobView>
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ModEventViewDetail value)) → TResult

Available on ModEventViewDetail, provided by the ModEventViewDetailPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ModEventViewDetail value)?) → TResult?

Available on ModEventViewDetail, provided by the ModEventViewDetailPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ModEventViewDetail value)?, {required TResult orElse()}) → TResult

Available on ModEventViewDetail, provided by the ModEventViewDetailPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, int id, UModEventViewDetailEvent event, UModEventViewDetailSubject subject, List<BlobView> subjectBlobs, String createdBy, DateTime createdAt, ModTool? modTool, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ModEventViewDetail, provided by the ModEventViewDetailPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ModEventViewDetail to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, int id, UModEventViewDetailEvent event, UModEventViewDetailSubject subject, List<BlobView> subjectBlobs, String createdBy, DateTime createdAt, ModTool? modTool, Map<String, dynamic>? $unknown)) → TResult

Available on ModEventViewDetail, provided by the ModEventViewDetailPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, int id, UModEventViewDetailEvent event, UModEventViewDetailSubject subject, List<BlobView> subjectBlobs, String createdBy, DateTime createdAt, ModTool? modTool, Map<String, dynamic>? $unknown)?) → TResult?

Available on ModEventViewDetail, provided by the ModEventViewDetailPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>