Moderation class abstract

Available extensions
Annotations
  • @freezed

Constructors

Moderation({@Default.new('tools.ozone.moderation.defs#moderation') String $type, @SubjectStatusViewConverter() SubjectStatusView? subjectStatus, Map<String, dynamic>? $unknown})
const
factory
Moderation.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $ModerationCopyWith<Moderation>
Create a copy of Moderation with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNotSubjectStatus → bool

Available on Moderation, provided by the ModerationExtension extension

no setter
hasSubjectStatus → bool

Available on Moderation, provided by the ModerationExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subjectStatus → SubjectStatusView?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Moderation value)) → TResult

Available on Moderation, provided by the ModerationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Moderation value)?) → TResult?

Available on Moderation, provided by the ModerationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Moderation value)?, {required TResult orElse()}) → TResult

Available on Moderation, provided by the ModerationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, SubjectStatusView? subjectStatus, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on Moderation, provided by the ModerationPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Moderation to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, SubjectStatusView? subjectStatus, Map<String, dynamic>? $unknown)) → TResult

Available on Moderation, provided by the ModerationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, SubjectStatusView? subjectStatus, Map<String, dynamic>? $unknown)?) → TResult?

Available on Moderation, provided by the ModerationPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>