RecordEvent class abstract

Logs lifecycle event on a record subject. Normally captured by automod from the firehose and emitted to ozone for historical tracking.

Available extensions
Annotations
  • @freezed

Constructors

RecordEvent({@Default.new('tools.ozone.moderation.defs#recordEvent') String $type, String? comment, @RecordEventOpConverter() required RecordEventOp op, String? cid, @JsonKey.new(toJson: iso8601) required DateTime timestamp, Map<String, dynamic>? $unknown})
const
factory
RecordEvent.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
cid → String?
no setterinherited
comment → String?
no setterinherited
copyWith → $RecordEventCopyWith<RecordEvent>
Create a copy of RecordEvent with the given fields replaced by the non-null parameter values.
no setterinherited
hasCid → bool

Available on RecordEvent, provided by the RecordEventExtension extension

no setter
hasComment → bool

Available on RecordEvent, provided by the RecordEventExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotCid → bool

Available on RecordEvent, provided by the RecordEventExtension extension

no setter
hasNotComment → bool

Available on RecordEvent, provided by the RecordEventExtension extension

no setter
op → RecordEventOp
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_RecordEvent value)) → TResult

Available on RecordEvent, provided by the RecordEventPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_RecordEvent value)?) → TResult?

Available on RecordEvent, provided by the RecordEventPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_RecordEvent value)?, {required TResult orElse()}) → TResult

Available on RecordEvent, provided by the RecordEventPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String? comment, RecordEventOp op, String? cid, DateTime timestamp, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on RecordEvent, provided by the RecordEventPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this RecordEvent to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String? comment, RecordEventOp op, String? cid, DateTime timestamp, Map<String, dynamic>? $unknown)) → TResult

Available on RecordEvent, provided by the RecordEventPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String? comment, RecordEventOp op, String? cid, DateTime timestamp, Map<String, dynamic>? $unknown)?) → TResult?

Available on RecordEvent, provided by the RecordEventPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>