RecordsStats class abstract

Statistics about a set of record subject items

Available extensions
Annotations
  • @freezed

Constructors

RecordsStats({@Default.new('tools.ozone.moderation.defs#recordsStats') String $type, int? totalReports, int? reportedCount, int? escalatedCount, int? appealedCount, int? subjectCount, int? pendingCount, int? processedCount, int? takendownCount, Map<String, dynamic>? $unknown})
const
factory
RecordsStats.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
appealedCount → int?
Number of items that were appealed at least once
no setterinherited
copyWith → $RecordsStatsCopyWith<RecordsStats>
Create a copy of RecordsStats with the given fields replaced by the non-null parameter values.
no setterinherited
escalatedCount → int?
Number of items that were escalated at least once
no setterinherited
hasAppealedCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasEscalatedCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotAppealedCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasNotEscalatedCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasNotPendingCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasNotProcessedCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasNotReportedCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasNotSubjectCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasNotTakendownCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasNotTotalReports → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasPendingCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasProcessedCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasReportedCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasSubjectCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasTakendownCount → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
hasTotalReports → bool

Available on RecordsStats, provided by the RecordsStatsExtension extension

no setter
pendingCount → int?
Number of item currently in "reviewOpen" or "reviewEscalated" state
no setterinherited
processedCount → int?
Number of item currently in "reviewNone" or "reviewClosed" state
no setterinherited
reportedCount → int?
Number of items that were reported at least once
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subjectCount → int?
Total number of item in the set
no setterinherited
takendownCount → int?
Number of item currently taken down
no setterinherited
totalReports → int?
Cumulative sum of the number of reports on the items in the set
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_RecordsStats value)) → TResult

Available on RecordsStats, provided by the RecordsStatsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_RecordsStats value)?) → TResult?

Available on RecordsStats, provided by the RecordsStatsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_RecordsStats value)?, {required TResult orElse()}) → TResult

Available on RecordsStats, provided by the RecordsStatsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, int? totalReports, int? reportedCount, int? escalatedCount, int? appealedCount, int? subjectCount, int? pendingCount, int? processedCount, int? takendownCount, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on RecordsStats, provided by the RecordsStatsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this RecordsStats to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, int? totalReports, int? reportedCount, int? escalatedCount, int? appealedCount, int? subjectCount, int? pendingCount, int? processedCount, int? takendownCount, Map<String, dynamic>? $unknown)) → TResult

Available on RecordsStats, provided by the RecordsStatsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, int? totalReports, int? reportedCount, int? escalatedCount, int? appealedCount, int? subjectCount, int? pendingCount, int? processedCount, int? takendownCount, Map<String, dynamic>? $unknown)?) → TResult?

Available on RecordsStats, provided by the RecordsStatsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>