RepoView class abstract

Available extensions
Annotations
  • @freezed

Constructors

RepoView({@Default.new('tools.ozone.moderation.defs#repoView') String $type, required String did, required String handle, String? email, required List<Map<String, dynamic>> relatedRecords, @JsonKey.new(toJson: iso8601) required DateTime indexedAt, @ModerationConverter() required Moderation moderation, @InviteCodeConverter() InviteCode? invitedBy, bool? invitesDisabled, String? inviteNote, @JsonKey.new(toJson: iso8601) DateTime? deactivatedAt, @ThreatSignatureConverter() List<ThreatSignature>? threatSignatures, Map<String, dynamic>? $unknown})
const
factory
RepoView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $RepoViewCopyWith<RepoView>
Create a copy of RepoView with the given fields replaced by the non-null parameter values.
no setterinherited
deactivatedAt → DateTime?
no setterinherited
did → String
no setterinherited
email → String?
no setterinherited
handle → String
no setterinherited
hasDeactivatedAt → bool

Available on RepoView, provided by the RepoViewExtension extension

no setter
hasEmail → bool

Available on RepoView, provided by the RepoViewExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasInvitedBy → bool

Available on RepoView, provided by the RepoViewExtension extension

no setter
hasInviteNote → bool

Available on RepoView, provided by the RepoViewExtension extension

no setter
hasNotDeactivatedAt → bool

Available on RepoView, provided by the RepoViewExtension extension

no setter
hasNotEmail → bool

Available on RepoView, provided by the RepoViewExtension extension

no setter
hasNotInvitedBy → bool

Available on RepoView, provided by the RepoViewExtension extension

no setter
hasNotInviteNote → bool

Available on RepoView, provided by the RepoViewExtension extension

no setter
indexedAt → DateTime
no setterinherited
invitedBy → InviteCode?
no setterinherited
inviteNote → String?
no setterinherited
invitesDisabled → bool?
no setterinherited
isInvitesDisabled → bool

Available on RepoView, provided by the RepoViewExtension extension

no setter
isNotInvitesDisabled → bool

Available on RepoView, provided by the RepoViewExtension extension

no setter
moderation → Moderation
no setterinherited
relatedRecords → List<Map<String, dynamic>>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threatSignatures → List<ThreatSignature>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_RepoView value)) → TResult

Available on RepoView, provided by the RepoViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_RepoView value)?) → TResult?

Available on RepoView, provided by the RepoViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_RepoView value)?, {required TResult orElse()}) → TResult

Available on RepoView, provided by the RepoViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String did, String handle, String? email, List<Map<String, dynamic>> relatedRecords, DateTime indexedAt, Moderation moderation, InviteCode? invitedBy, bool? invitesDisabled, String? inviteNote, DateTime? deactivatedAt, List<ThreatSignature>? threatSignatures, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on RepoView, provided by the RepoViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this RepoView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String did, String handle, String? email, List<Map<String, dynamic>> relatedRecords, DateTime indexedAt, Moderation moderation, InviteCode? invitedBy, bool? invitesDisabled, String? inviteNote, DateTime? deactivatedAt, List<ThreatSignature>? threatSignatures, Map<String, dynamic>? $unknown)) → TResult

Available on RepoView, provided by the RepoViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String did, String handle, String? email, List<Map<String, dynamic>> relatedRecords, DateTime indexedAt, Moderation moderation, InviteCode? invitedBy, bool? invitesDisabled, String? inviteNote, DateTime? deactivatedAt, List<ThreatSignature>? threatSignatures, Map<String, dynamic>? $unknown)?) → TResult?

Available on RepoView, provided by the RepoViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>