SubjectStatusView class abstract

Available extensions
Annotations
  • @freezed

Constructors

SubjectStatusView({@Default.new('tools.ozone.moderation.defs#subjectStatusView') String $type, required int id, @USubjectStatusViewSubjectConverter() required USubjectStatusViewSubject subject, @USubjectStatusViewHostingConverter() USubjectStatusViewHosting? hosting, List<String>? subjectBlobCids, String? subjectRepoHandle, @JsonKey.new(toJson: iso8601) required DateTime updatedAt, @JsonKey.new(toJson: iso8601) required DateTime createdAt, @SubjectReviewStateConverter() required SubjectReviewState reviewState, String? comment, int? priorityScore, @JsonKey.new(toJson: iso8601) DateTime? muteUntil, @JsonKey.new(toJson: iso8601) DateTime? muteReportingUntil, String? lastReviewedBy, @JsonKey.new(toJson: iso8601) DateTime? lastReviewedAt, @JsonKey.new(toJson: iso8601) DateTime? lastReportedAt, @JsonKey.new(toJson: iso8601) DateTime? lastAppealedAt, bool? takendown, bool? appealed, @JsonKey.new(toJson: iso8601) DateTime? suspendUntil, List<String>? tags, @AccountStatsConverter() AccountStats? accountStats, @RecordsStatsConverter() RecordsStats? recordsStats, @AccountStrikeConverter() AccountStrike? accountStrike, @SubjectStatusViewAgeAssuranceStateConverter() SubjectStatusViewAgeAssuranceState? ageAssuranceState, @SubjectStatusViewAgeAssuranceUpdatedByConverter() SubjectStatusViewAgeAssuranceUpdatedBy? ageAssuranceUpdatedBy, Map<String, dynamic>? $unknown})
const
factory
SubjectStatusView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
accountStats → AccountStats?
Statistics related to the account subject
no setterinherited
accountStrike → AccountStrike?
Strike information for the account (account-level only)
no setterinherited
ageAssuranceState → SubjectStatusViewAgeAssuranceState?
Current age assurance state of the subject.
no setterinherited
ageAssuranceUpdatedBy → SubjectStatusViewAgeAssuranceUpdatedBy?
Whether or not the last successful update to age assurance was made by the user or admin.
no setterinherited
appealed → bool?
True indicates that the a previously taken moderator action was appealed against, by the author of the content. False indicates last appeal was resolved by moderators.
no setterinherited
comment → String?
Sticky comment on the subject.
no setterinherited
copyWith → $SubjectStatusViewCopyWith<SubjectStatusView>
Create a copy of SubjectStatusView with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
Timestamp referencing the first moderation status impacting event was emitted on the subject
no setterinherited
hasAccountStats → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasAccountStrike → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasAgeAssuranceState → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasAgeAssuranceUpdatedBy → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasComment → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasHosting → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasLastAppealedAt → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasLastReportedAt → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasLastReviewedAt → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasLastReviewedBy → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasMuteReportingUntil → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasMuteUntil → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotAccountStats → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotAccountStrike → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotAgeAssuranceState → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotAgeAssuranceUpdatedBy → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotComment → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotHosting → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotLastAppealedAt → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotLastReportedAt → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotLastReviewedAt → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotLastReviewedBy → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotMuteReportingUntil → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotMuteUntil → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotPriorityScore → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotRecordsStats → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotSubjectRepoHandle → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasNotSuspendUntil → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasPriorityScore → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasRecordsStats → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasSubjectRepoHandle → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hasSuspendUntil → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
hosting → USubjectStatusViewHosting?
no setterinherited
id → int
no setterinherited
isAppealed → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
isNotAppealed → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
isNotTakendown → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
isTakendown → bool

Available on SubjectStatusView, provided by the SubjectStatusViewExtension extension

no setter
lastAppealedAt → DateTime?
Timestamp referencing when the author of the subject appealed a moderation action
no setterinherited
lastReportedAt → DateTime?
no setterinherited
lastReviewedAt → DateTime?
no setterinherited
lastReviewedBy → String?
no setterinherited
muteReportingUntil → DateTime?
no setterinherited
muteUntil → DateTime?
no setterinherited
priorityScore → int?
Numeric value representing the level of priority. Higher score means higher priority.
no setterinherited
recordsStats → RecordsStats?
Statistics related to the record subjects authored by the subject's account
no setterinherited
reviewState → SubjectReviewState
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → USubjectStatusViewSubject
no setterinherited
subjectBlobCids → List<String>?
no setterinherited
subjectRepoHandle → String?
no setterinherited
suspendUntil → DateTime?
no setterinherited
tags → List<String>?
no setterinherited
takendown → bool?
no setterinherited
updatedAt → DateTime
Timestamp referencing when the last update was made to the moderation status of the subject
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SubjectStatusView value)) → TResult

Available on SubjectStatusView, provided by the SubjectStatusViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SubjectStatusView value)?) → TResult?

Available on SubjectStatusView, provided by the SubjectStatusViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SubjectStatusView value)?, {required TResult orElse()}) → TResult

Available on SubjectStatusView, provided by the SubjectStatusViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, int id, USubjectStatusViewSubject subject, USubjectStatusViewHosting? hosting, List<String>? subjectBlobCids, String? subjectRepoHandle, DateTime updatedAt, DateTime createdAt, SubjectReviewState reviewState, String? comment, int? priorityScore, DateTime? muteUntil, DateTime? muteReportingUntil, String? lastReviewedBy, DateTime? lastReviewedAt, DateTime? lastReportedAt, DateTime? lastAppealedAt, bool? takendown, bool? appealed, DateTime? suspendUntil, List<String>? tags, AccountStats? accountStats, RecordsStats? recordsStats, AccountStrike? accountStrike, SubjectStatusViewAgeAssuranceState? ageAssuranceState, SubjectStatusViewAgeAssuranceUpdatedBy? ageAssuranceUpdatedBy, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on SubjectStatusView, provided by the SubjectStatusViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this SubjectStatusView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, int id, USubjectStatusViewSubject subject, USubjectStatusViewHosting? hosting, List<String>? subjectBlobCids, String? subjectRepoHandle, DateTime updatedAt, DateTime createdAt, SubjectReviewState reviewState, String? comment, int? priorityScore, DateTime? muteUntil, DateTime? muteReportingUntil, String? lastReviewedBy, DateTime? lastReviewedAt, DateTime? lastReportedAt, DateTime? lastAppealedAt, bool? takendown, bool? appealed, DateTime? suspendUntil, List<String>? tags, AccountStats? accountStats, RecordsStats? recordsStats, AccountStrike? accountStrike, SubjectStatusViewAgeAssuranceState? ageAssuranceState, SubjectStatusViewAgeAssuranceUpdatedBy? ageAssuranceUpdatedBy, Map<String, dynamic>? $unknown)) → TResult

Available on SubjectStatusView, provided by the SubjectStatusViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, int id, USubjectStatusViewSubject subject, USubjectStatusViewHosting? hosting, List<String>? subjectBlobCids, String? subjectRepoHandle, DateTime updatedAt, DateTime createdAt, SubjectReviewState reviewState, String? comment, int? priorityScore, DateTime? muteUntil, DateTime? muteReportingUntil, String? lastReviewedBy, DateTime? lastReviewedAt, DateTime? lastReportedAt, DateTime? lastAppealedAt, bool? takendown, bool? appealed, DateTime? suspendUntil, List<String>? tags, AccountStats? accountStats, RecordsStats? recordsStats, AccountStrike? accountStrike, SubjectStatusViewAgeAssuranceState? ageAssuranceState, SubjectStatusViewAgeAssuranceUpdatedBy? ageAssuranceUpdatedBy, Map<String, dynamic>? $unknown)?) → TResult?

Available on SubjectStatusView, provided by the SubjectStatusViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>