createdAt property

  1. @JsonKey.new(toJson: iso8601)
DateTime get createdAt
inherited

Timestamp referencing the first moderation status impacting event was emitted on the subject

Implementation

@JsonKey(toJson: iso8601) DateTime get updatedAt;/// Timestamp referencing the first moderation status impacting event was emitted on the subject
@JsonKey(toJson: iso8601) DateTime get createdAt;