updatedAt property
Timestamp referencing when the last update was made to the moderation status of the subject
Implementation
String get $type; int get id;@USubjectStatusViewSubjectConverter() USubjectStatusViewSubject get subject;@USubjectStatusViewHostingConverter() USubjectStatusViewHosting? get hosting; List<String>? get subjectBlobCids; String? get subjectRepoHandle;/// Timestamp referencing when the last update was made to the moderation status of the subject
@JsonKey(toJson: iso8601) DateTime get updatedAt;