SubjectView class abstract

Detailed view of a subject. For record subjects, the author's repo and profile will be returned.

Available extensions
Annotations
  • @freezed

Constructors

SubjectView({@Default.new('tools.ozone.moderation.defs#subjectView') String $type, @SubjectTypeConverter() required SubjectType type, required String subject, @SubjectStatusViewConverter() SubjectStatusView? status, @RepoViewDetailConverter() RepoViewDetail? repo, @USubjectViewProfileConverter() USubjectViewProfile? profile, @RecordViewDetailConverter() RecordViewDetail? record, Map<String, dynamic>? $unknown})
const
factory
SubjectView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $SubjectViewCopyWith<SubjectView>
Create a copy of SubjectView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNotProfile → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
hasNotRecord → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
hasNotRepo → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
hasNotStatus → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
hasProfile → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
hasRecord → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
hasRepo → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
hasStatus → bool

Available on SubjectView, provided by the SubjectViewExtension extension

no setter
profile → USubjectViewProfile?
no setterinherited
record → RecordViewDetail?
no setterinherited
repo → RepoViewDetail?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → SubjectStatusView?
no setterinherited
subject → String
no setterinherited
type → SubjectType
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SubjectView value)) → TResult

Available on SubjectView, provided by the SubjectViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SubjectView value)?) → TResult?

Available on SubjectView, provided by the SubjectViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SubjectView value)?, {required TResult orElse()}) → TResult

Available on SubjectView, provided by the SubjectViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, SubjectType type, String subject, SubjectStatusView? status, RepoViewDetail? repo, USubjectViewProfile? profile, RecordViewDetail? record, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on SubjectView, provided by the SubjectViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this SubjectView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, SubjectType type, String subject, SubjectStatusView? status, RepoViewDetail? repo, USubjectViewProfile? profile, RecordViewDetail? record, Map<String, dynamic>? $unknown)) → TResult

Available on SubjectView, provided by the SubjectViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, SubjectType type, String subject, SubjectStatusView? status, RepoViewDetail? repo, USubjectViewProfile? profile, RecordViewDetail? record, Map<String, dynamic>? $unknown)?) → TResult?

Available on SubjectView, provided by the SubjectViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>