reportAction property
Optional report-level targeting. If provided, this event will be linked to specific reports and reporters may be notified.
Implementation
String? get externalId;/// Optional report-level targeting. If provided, this event will be linked to specific reports and reporters may be notified.
@ReportActionConverter() ReportAction? get reportAction;