ReportAction class abstract

Target specific reports when emitting a moderation event

Available extensions
Annotations
  • @freezed

Constructors

ReportAction({@Default.new('tools.ozone.moderation.emitEvent#reportAction') String $type, List<int>? ids, List<String>? types, bool? all, String? note, Map<String, dynamic>? $unknown})
const
factory
ReportAction.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
all → bool?
Target ALL reports on the subject
no setterinherited
copyWith → $ReportActionCopyWith<ReportAction>
Create a copy of ReportAction with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNote → bool

Available on ReportAction, provided by the ReportActionExtension extension

no setter
hasNotNote → bool

Available on ReportAction, provided by the ReportActionExtension extension

no setter
ids → List<int>?
no setterinherited
isAll → bool

Available on ReportAction, provided by the ReportActionExtension extension

no setter
isNotAll → bool

Available on ReportAction, provided by the ReportActionExtension extension

no setter
note → String?
Note to send to reporter(s) when actioning their report
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types → List<String>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReportAction value)) → TResult

Available on ReportAction, provided by the ReportActionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReportAction value)?) → TResult?

Available on ReportAction, provided by the ReportActionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReportAction value)?, {required TResult orElse()}) → TResult

Available on ReportAction, provided by the ReportActionPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, List<int>? ids, List<String>? types, bool? all, String? note, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ReportAction, provided by the ReportActionPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ReportAction to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, List<int>? ids, List<String>? types, bool? all, String? note, Map<String, dynamic>? $unknown)) → TResult

Available on ReportAction, provided by the ReportActionPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, List<int>? ids, List<String>? types, bool? all, String? note, Map<String, dynamic>? $unknown)?) → TResult?

Available on ReportAction, provided by the ReportActionPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>