ModerationScheduleActionInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ModerationScheduleActionInput({@UModerationScheduleActionActionConverter() required UModerationScheduleActionAction action, required List<String> subjects, required String createdBy, @SchedulingConfigConverter() required SchedulingConfig scheduling, @ModToolConverter() ModTool? modTool, Map<String, dynamic>? $unknown})
const
factory
ModerationScheduleActionInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
action → UModerationScheduleActionAction
no setterinherited
copyWith → $ModerationScheduleActionInputCopyWith<ModerationScheduleActionInput>
Create a copy of ModerationScheduleActionInput with the given fields replaced by the non-null parameter values.
no setterinherited
createdBy → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasModTool → bool

Available on ModerationScheduleActionInput, provided by the ModerationScheduleActionInputExtension extension

no setter
hasNotModTool → bool

Available on ModerationScheduleActionInput, provided by the ModerationScheduleActionInputExtension extension

no setter
modTool → ModTool?
This will be propagated to the moderation event when it is applied
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduling → SchedulingConfig
no setterinherited
subjects → List<String>
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ModerationScheduleActionInput value)) → TResult

Available on ModerationScheduleActionInput, provided by the ModerationScheduleActionInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ModerationScheduleActionInput value)?) → TResult?

Available on ModerationScheduleActionInput, provided by the ModerationScheduleActionInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ModerationScheduleActionInput value)?, {required TResult orElse()}) → TResult

Available on ModerationScheduleActionInput, provided by the ModerationScheduleActionInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(UModerationScheduleActionAction action, List<String> subjects, String createdBy, SchedulingConfig scheduling, ModTool? modTool, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ModerationScheduleActionInput, provided by the ModerationScheduleActionInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ModerationScheduleActionInput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(UModerationScheduleActionAction action, List<String> subjects, String createdBy, SchedulingConfig scheduling, ModTool? modTool, Map<String, dynamic>? $unknown)) → TResult

Available on ModerationScheduleActionInput, provided by the ModerationScheduleActionInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(UModerationScheduleActionAction action, List<String> subjects, String createdBy, SchedulingConfig scheduling, ModTool? modTool, Map<String, dynamic>? $unknown)?) → TResult?

Available on ModerationScheduleActionInput, provided by the ModerationScheduleActionInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>