SchedulingConfig class abstract

Configuration for when the action should be executed

Available extensions
Annotations
  • @freezed

Constructors

SchedulingConfig({@Default.new('tools.ozone.moderation.scheduleAction#schedulingConfig') String $type, @JsonKey.new(toJson: iso8601) DateTime? executeAt, @JsonKey.new(toJson: iso8601) DateTime? executeAfter, @JsonKey.new(toJson: iso8601) DateTime? executeUntil, Map<String, dynamic>? $unknown})
const
factory
SchedulingConfig.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $SchedulingConfigCopyWith<SchedulingConfig>
Create a copy of SchedulingConfig with the given fields replaced by the non-null parameter values.
no setterinherited
executeAfter → DateTime?
Earliest time to execute the action (for randomized scheduling)
no setterinherited
executeAt → DateTime?
Exact time to execute the action
no setterinherited
executeUntil → DateTime?
Latest time to execute the action (for randomized scheduling)
no setterinherited
hasExecuteAfter → bool

Available on SchedulingConfig, provided by the SchedulingConfigExtension extension

no setter
hasExecuteAt → bool

Available on SchedulingConfig, provided by the SchedulingConfigExtension extension

no setter
hasExecuteUntil → bool

Available on SchedulingConfig, provided by the SchedulingConfigExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotExecuteAfter → bool

Available on SchedulingConfig, provided by the SchedulingConfigExtension extension

no setter
hasNotExecuteAt → bool

Available on SchedulingConfig, provided by the SchedulingConfigExtension extension

no setter
hasNotExecuteUntil → bool

Available on SchedulingConfig, provided by the SchedulingConfigExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SchedulingConfig value)) → TResult

Available on SchedulingConfig, provided by the SchedulingConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SchedulingConfig value)?) → TResult?

Available on SchedulingConfig, provided by the SchedulingConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SchedulingConfig value)?, {required TResult orElse()}) → TResult

Available on SchedulingConfig, provided by the SchedulingConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, DateTime? executeAt, DateTime? executeAfter, DateTime? executeUntil, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on SchedulingConfig, provided by the SchedulingConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this SchedulingConfig to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, DateTime? executeAt, DateTime? executeAfter, DateTime? executeUntil, Map<String, dynamic>? $unknown)) → TResult

Available on SchedulingConfig, provided by the SchedulingConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, DateTime? executeAt, DateTime? executeAfter, DateTime? executeUntil, Map<String, dynamic>? $unknown)?) → TResult?

Available on SchedulingConfig, provided by the SchedulingConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>