QueueAssignModeratorInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

QueueAssignModeratorInput({required int queueId, required String did, Map<String, dynamic>? $unknown})
const
factory
QueueAssignModeratorInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
copyWith → $QueueAssignModeratorInputCopyWith<QueueAssignModeratorInput>
Create a copy of QueueAssignModeratorInput with the given fields replaced by the non-null parameter values.
no setterinherited
did String
DID to be assigned.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
queueId int
The ID of the queue to assign the user to.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_QueueAssignModeratorInput value)) → TResult

Available on QueueAssignModeratorInput, provided by the QueueAssignModeratorInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_QueueAssignModeratorInput value)?) → TResult?

Available on QueueAssignModeratorInput, provided by the QueueAssignModeratorInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_QueueAssignModeratorInput value)?, {required TResult orElse()}) → TResult

Available on QueueAssignModeratorInput, provided by the QueueAssignModeratorInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int queueId, String did, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on QueueAssignModeratorInput, provided by the QueueAssignModeratorInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this QueueAssignModeratorInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int queueId, String did, Map<String, dynamic>? $unknown)) → TResult

Available on QueueAssignModeratorInput, provided by the QueueAssignModeratorInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int queueId, String did, Map<String, dynamic>? $unknown)?) → TResult?

Available on QueueAssignModeratorInput, provided by the QueueAssignModeratorInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>