QueueCreateQueueInputPatterns extension

Adds pattern-matching-related methods to QueueCreateQueueInput.

on

Methods

map<TResult extends Object?>(TResult $default(_QueueCreateQueueInput value)) → TResult

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_QueueCreateQueueInput value)?) → TResult?

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_QueueCreateQueueInput value)?, {required TResult orElse()}) → TResult

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String name, List<QueueCreateQueueSubjectTypes> subjectTypes, String? collection, List<String> reportTypes, String? description, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String name, List<QueueCreateQueueSubjectTypes> subjectTypes, String? collection, List<String> reportTypes, String? description, Map<String, dynamic>? $unknown)) → TResult

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String name, List<QueueCreateQueueSubjectTypes> subjectTypes, String? collection, List<String> reportTypes, String? description, Map<String, dynamic>? $unknown)?) → TResult?

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputPatterns extension

A variant of when that fallback to returning null