QueueStats class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
QueueStats({@Default.new('tools.ozone.queue.defs#queueStats') String $type, int? pendingCount, int? actionedCount, int? escalatedCount, int? inboundCount, int? actionRate, int? avgHandlingTimeSec, DateTime? lastUpdated, Map<
String, dynamic> ? $unknown}) -
constfactory
-
QueueStats.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
- actionedCount → int?
-
Number of reports in 'closed' status
no setterinherited
- actionRate → int?
-
Percentage of reports actioned (actionedCount / inboundCount * 100), rounded to nearest integer. Absent when inboundCount is 0.
no setterinherited
- avgHandlingTimeSec → int?
-
Average time in seconds from report creation to close, for reports closed in this period.
no setterinherited
-
copyWith
→ $QueueStatsCopyWith<
QueueStats> -
Create a copy of QueueStats
with the given fields replaced by the non-null parameter values.
no setterinherited
- escalatedCount → int?
-
Number of reports in 'escalated' status
no setterinherited
- hasActionedCount → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - hasActionRate → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - hasAvgHandlingTimeSec → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - hasEscalatedCount → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasInboundCount → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - hasLastUpdated → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - hasNotActionedCount → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - hasNotActionRate → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - hasNotAvgHandlingTimeSec → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - hasNotEscalatedCount → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - hasNotInboundCount → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - hasNotLastUpdated → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - hasNotPendingCount → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - hasPendingCount → bool
-
Available on QueueStats, provided by the QueueStatsExtension extension
no setter - inboundCount → int?
-
Reports received in this queue in the last 24 hours.
no setterinherited
- lastUpdated → DateTime?
-
When these statistics were last computed
no setterinherited
- pendingCount → int?
-
Number of reports in 'open' status
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_QueueStats value)) → TResult -
Available on QueueStats, provided by the QueueStatsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_QueueStats value)?) → TResult? -
Available on QueueStats, provided by the QueueStatsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_QueueStats value)?, {required TResult orElse()}) → TResult -
Available on QueueStats, provided by the QueueStatsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, int? pendingCount, int? actionedCount, int? escalatedCount, int? inboundCount, int? actionRate, int? avgHandlingTimeSec, DateTime? lastUpdated, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on QueueStats, provided by the QueueStatsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this QueueStats to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, int? pendingCount, int? actionedCount, int? escalatedCount, int? inboundCount, int? actionRate, int? avgHandlingTimeSec, DateTime? lastUpdated, Map< String, dynamic> ? $unknown)) → TResult -
Available on QueueStats, provided by the QueueStatsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, int? pendingCount, int? actionedCount, int? escalatedCount, int? inboundCount, int? actionRate, int? avgHandlingTimeSec, DateTime? lastUpdated, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on QueueStats, provided by the QueueStatsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>