QueueStats constructor
const
QueueStats({})
Implementation
@JsonSerializable(includeIfNull: false)
const factory QueueStats({
@Default('tools.ozone.queue.defs#queueStats') String $type,
/// Number of reports in 'open' status
int? pendingCount,
/// Number of reports in 'closed' status
int? actionedCount,
/// Number of reports in 'escalated' status
int? escalatedCount,
/// Reports received in this queue in the last 24 hours.
int? inboundCount,
/// Percentage of reports actioned (actionedCount / inboundCount * 100), rounded to nearest integer. Absent when inboundCount is 0.
int? actionRate,
/// Average time in seconds from report creation to close, for reports closed in this period.
int? avgHandlingTimeSec,
/// When these statistics were last computed
DateTime? lastUpdated,
Map<String, dynamic>? $unknown,
}) = _QueueStats;