inboundCount property
Reports received in this queue in the last 24 hours.
Implementation
int? get escalatedCount;/// Reports received in this queue in the last 24 hours.
int? get inboundCount;
Reports received in this queue in the last 24 hours.
int? get escalatedCount;/// Reports received in this queue in the last 24 hours.
int? get inboundCount;