QueueDeleteQueueInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

QueueDeleteQueueInput({required int queueId, int? migrateToQueueId, Map<String, dynamic>? $unknown})
const
factory
QueueDeleteQueueInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
copyWith → $QueueDeleteQueueInputCopyWith<QueueDeleteQueueInput>
Create a copy of QueueDeleteQueueInput with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasMigrateToQueueId bool

Available on QueueDeleteQueueInput, provided by the QueueDeleteQueueInputExtension extension

no setter
hasNotMigrateToQueueId bool

Available on QueueDeleteQueueInput, provided by the QueueDeleteQueueInputExtension extension

no setter
migrateToQueueId int?
Optional: migrate all reports to this queue. If not specified, reports will be set to unassigned (-1).
no setterinherited
queueId int
ID of the queue to delete
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_QueueDeleteQueueInput value)) → TResult

Available on QueueDeleteQueueInput, provided by the QueueDeleteQueueInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_QueueDeleteQueueInput value)?) → TResult?

Available on QueueDeleteQueueInput, provided by the QueueDeleteQueueInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_QueueDeleteQueueInput value)?, {required TResult orElse()}) → TResult

Available on QueueDeleteQueueInput, provided by the QueueDeleteQueueInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int queueId, int? migrateToQueueId, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on QueueDeleteQueueInput, provided by the QueueDeleteQueueInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this QueueDeleteQueueInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int queueId, int? migrateToQueueId, Map<String, dynamic>? $unknown)) → TResult

Available on QueueDeleteQueueInput, provided by the QueueDeleteQueueInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int queueId, int? migrateToQueueId, Map<String, dynamic>? $unknown)?) → TResult?

Available on QueueDeleteQueueInput, provided by the QueueDeleteQueueInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>