QueueDeleteQueueOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

QueueDeleteQueueOutput({required bool deleted, int? reportsMigrated, Map<String, dynamic>? $unknown})
const
factory
QueueDeleteQueueOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
copyWith → $QueueDeleteQueueOutputCopyWith<QueueDeleteQueueOutput>
Create a copy of QueueDeleteQueueOutput with the given fields replaced by the non-null parameter values.
no setterinherited
deleted bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasNotReportsMigrated bool

Available on QueueDeleteQueueOutput, provided by the QueueDeleteQueueOutputExtension extension

no setter
hasReportsMigrated bool

Available on QueueDeleteQueueOutput, provided by the QueueDeleteQueueOutputExtension extension

no setter
isDeleted bool

Available on QueueDeleteQueueOutput, provided by the QueueDeleteQueueOutputExtension extension

no setter
isNotDeleted bool

Available on QueueDeleteQueueOutput, provided by the QueueDeleteQueueOutputExtension extension

no setter
reportsMigrated int?
Number of reports that were migrated (if migration occurred)
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_QueueDeleteQueueOutput value)) → TResult

Available on QueueDeleteQueueOutput, provided by the QueueDeleteQueueOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_QueueDeleteQueueOutput value)?) → TResult?

Available on QueueDeleteQueueOutput, provided by the QueueDeleteQueueOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_QueueDeleteQueueOutput value)?, {required TResult orElse()}) → TResult

Available on QueueDeleteQueueOutput, provided by the QueueDeleteQueueOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool deleted, int? reportsMigrated, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on QueueDeleteQueueOutput, provided by the QueueDeleteQueueOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this QueueDeleteQueueOutput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool deleted, int? reportsMigrated, Map<String, dynamic>? $unknown)) → TResult

Available on QueueDeleteQueueOutput, provided by the QueueDeleteQueueOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool deleted, int? reportsMigrated, Map<String, dynamic>? $unknown)?) → TResult?

Available on QueueDeleteQueueOutput, provided by the QueueDeleteQueueOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>