QueueListQueuesInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

QueueListQueuesInput({bool? enabled, String? subjectType, String? collection, List<String>? reportTypes, @Default.new(50) int limit, String? cursor, Map<String, dynamic>? $unknown})
const
factory
QueueListQueuesInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
collection String?
Filter queues by collection name (e.g. 'app.bsky.feed.post').
no setterinherited
copyWith → $QueueListQueuesInputCopyWith<QueueListQueuesInput>
Create a copy of QueueListQueuesInput with the given fields replaced by the non-null parameter values.
no setterinherited
cursor String?
no setterinherited
enabled bool?
Filter by enabled status. If not specified, returns all queues.
no setterinherited
hasCollection bool

Available on QueueListQueuesInput, provided by the QueueListQueuesInputExtension extension

no setter
hasCursor bool

Available on QueueListQueuesInput, provided by the QueueListQueuesInputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotCollection bool

Available on QueueListQueuesInput, provided by the QueueListQueuesInputExtension extension

no setter
hasNotCursor bool

Available on QueueListQueuesInput, provided by the QueueListQueuesInputExtension extension

no setter
hasNotSubjectType bool

Available on QueueListQueuesInput, provided by the QueueListQueuesInputExtension extension

no setter
hasSubjectType bool

Available on QueueListQueuesInput, provided by the QueueListQueuesInputExtension extension

no setter
isEnabled bool

Available on QueueListQueuesInput, provided by the QueueListQueuesInputExtension extension

no setter
isNotEnabled bool

Available on QueueListQueuesInput, provided by the QueueListQueuesInputExtension extension

no setter
limit int
no setterinherited
reportTypes List<String>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subjectType String?
Filter queues that handle this subject type ('account' or 'record').
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_QueueListQueuesInput value)) → TResult

Available on QueueListQueuesInput, provided by the QueueListQueuesInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_QueueListQueuesInput value)?) → TResult?

Available on QueueListQueuesInput, provided by the QueueListQueuesInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_QueueListQueuesInput value)?, {required TResult orElse()}) → TResult

Available on QueueListQueuesInput, provided by the QueueListQueuesInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool? enabled, String? subjectType, String? collection, List<String>? reportTypes, int limit, String? cursor, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on QueueListQueuesInput, provided by the QueueListQueuesInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this QueueListQueuesInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool? enabled, String? subjectType, String? collection, List<String>? reportTypes, int limit, String? cursor, Map<String, dynamic>? $unknown)) → TResult

Available on QueueListQueuesInput, provided by the QueueListQueuesInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool? enabled, String? subjectType, String? collection, List<String>? reportTypes, int limit, String? cursor, Map<String, dynamic>? $unknown)?) → TResult?

Available on QueueListQueuesInput, provided by the QueueListQueuesInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>