QueueListQueuesOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

QueueListQueuesOutput({String? cursor, @QueueViewConverter() required List<QueueView> queues, Map<String, dynamic>? $unknown})
const
factory
QueueListQueuesOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
copyWith → $QueueListQueuesOutputCopyWith<QueueListQueuesOutput>
Create a copy of QueueListQueuesOutput with the given fields replaced by the non-null parameter values.
no setterinherited
cursor String?
no setterinherited
hasCursor bool

Available on QueueListQueuesOutput, provided by the QueueListQueuesOutputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotCursor bool

Available on QueueListQueuesOutput, provided by the QueueListQueuesOutputExtension extension

no setter
queues List<QueueView>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_QueueListQueuesOutput value)) → TResult

Available on QueueListQueuesOutput, provided by the QueueListQueuesOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_QueueListQueuesOutput value)?) → TResult?

Available on QueueListQueuesOutput, provided by the QueueListQueuesOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_QueueListQueuesOutput value)?, {required TResult orElse()}) → TResult

Available on QueueListQueuesOutput, provided by the QueueListQueuesOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? cursor, List<QueueView> queues, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on QueueListQueuesOutput, provided by the QueueListQueuesOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this QueueListQueuesOutput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? cursor, List<QueueView> queues, Map<String, dynamic>? $unknown)) → TResult

Available on QueueListQueuesOutput, provided by the QueueListQueuesOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? cursor, List<QueueView> queues, Map<String, dynamic>? $unknown)?) → TResult?

Available on QueueListQueuesOutput, provided by the QueueListQueuesOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>