QueueUpdateQueueInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

QueueUpdateQueueInput({required int queueId, String? name, bool? enabled, String? description, Map<String, dynamic>? $unknown})
const
factory
QueueUpdateQueueInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
copyWith → $QueueUpdateQueueInputCopyWith<QueueUpdateQueueInput>
Create a copy of QueueUpdateQueueInput with the given fields replaced by the non-null parameter values.
no setterinherited
description String?
Optional description of the queue
no setterinherited
enabled bool?
Enable or disable the queue
no setterinherited
hasDescription bool

Available on QueueUpdateQueueInput, provided by the QueueUpdateQueueInputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasName bool

Available on QueueUpdateQueueInput, provided by the QueueUpdateQueueInputExtension extension

no setter
hasNotDescription bool

Available on QueueUpdateQueueInput, provided by the QueueUpdateQueueInputExtension extension

no setter
hasNotName bool

Available on QueueUpdateQueueInput, provided by the QueueUpdateQueueInputExtension extension

no setter
isEnabled bool

Available on QueueUpdateQueueInput, provided by the QueueUpdateQueueInputExtension extension

no setter
isNotEnabled bool

Available on QueueUpdateQueueInput, provided by the QueueUpdateQueueInputExtension extension

no setter
name String?
New display name for the queue
no setterinherited
queueId int
ID of the queue to update
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_QueueUpdateQueueInput value)) → TResult

Available on QueueUpdateQueueInput, provided by the QueueUpdateQueueInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_QueueUpdateQueueInput value)?) → TResult?

Available on QueueUpdateQueueInput, provided by the QueueUpdateQueueInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_QueueUpdateQueueInput value)?, {required TResult orElse()}) → TResult

Available on QueueUpdateQueueInput, provided by the QueueUpdateQueueInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int queueId, String? name, bool? enabled, String? description, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on QueueUpdateQueueInput, provided by the QueueUpdateQueueInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this QueueUpdateQueueInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int queueId, String? name, bool? enabled, String? description, Map<String, dynamic>? $unknown)) → TResult

Available on QueueUpdateQueueInput, provided by the QueueUpdateQueueInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int queueId, String? name, bool? enabled, String? description, Map<String, dynamic>? $unknown)?) → TResult?

Available on QueueUpdateQueueInput, provided by the QueueUpdateQueueInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>