isPermanent property

bool? get isPermanent
inherited

When true, the assignment has no expiry (endAt is null). Throws AlreadyAssigned if another user already has a permanent assignment on this report.

Implementation

String? get did;/// When true, the assignment has no expiry (endAt is null). Throws AlreadyAssigned if another user already has a permanent assignment on this report.
bool? get isPermanent;