queueId property

int? get queueId
inherited

Optional queue ID to associate the assignment with. If not provided and the report has been assigned on a queue before, it will stay on that queue.

Implementation

int get reportId;/// Optional queue ID to associate the assignment with. If not provided and the report has been assigned on a queue before, it will stay on that queue.
int? get queueId;