isAutomated property
Set true when this action is triggered by an automated process. Defaults to false.
Implementation
String? get internalNote;/// Set true when this action is triggered by an automated process. Defaults to false.
bool get isAutomated;