ReportCreateActivityInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ReportCreateActivityInput({int? reportId, int? eventId, @UReportCreateActivityActivityConverter() required UReportCreateActivityActivity activity, String? internalNote, String? publicNote, @Default.new(false) bool isAutomated, Map<String, dynamic>? $unknown})
const
factory
ReportCreateActivityInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
activity UReportCreateActivityActivity
no setterinherited
copyWith → $ReportCreateActivityInputCopyWith<ReportCreateActivityInput>
Create a copy of ReportCreateActivityInput with the given fields replaced by the non-null parameter values.
no setterinherited
eventId int?
ID of the report moderation event. Resolves to the report created from that event. Exactly one of reportId or eventId must be provided.
no setterinherited
hasEventId bool

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasInternalNote bool

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputExtension extension

no setter
hasNotEventId bool

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputExtension extension

no setter
hasNotInternalNote bool

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputExtension extension

no setter
hasNotPublicNote bool

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputExtension extension

no setter
hasNotReportId bool

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputExtension extension

no setter
hasPublicNote bool

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputExtension extension

no setter
hasReportId bool

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputExtension extension

no setter
internalNote String?
Optional moderator-only note. Not visible to reporters.
no setterinherited
isAutomated bool
Set true when this activity is triggered by an automated process. Defaults to false.
no setterinherited
isIsAutomated bool

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputExtension extension

no setter
isNotIsAutomated bool

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputExtension extension

no setter
publicNote String?
Optional public-facing note, potentially visible to the reporter.
no setterinherited
reportId int?
ID of the report to record activity on. Exactly one of reportId or eventId must be provided.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReportCreateActivityInput value)) → TResult

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReportCreateActivityInput value)?) → TResult?

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReportCreateActivityInput value)?, {required TResult orElse()}) → TResult

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int? reportId, int? eventId, UReportCreateActivityActivity activity, String? internalNote, String? publicNote, bool isAutomated, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ReportCreateActivityInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int? reportId, int? eventId, UReportCreateActivityActivity activity, String? internalNote, String? publicNote, bool isAutomated, Map<String, dynamic>? $unknown)) → TResult

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int? reportId, int? eventId, UReportCreateActivityActivity activity, String? internalNote, String? publicNote, bool isAutomated, Map<String, dynamic>? $unknown)?) → TResult?

Available on ReportCreateActivityInput, provided by the ReportCreateActivityInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>