CloseActivity class abstract

Activity recording a report being closed.

Available extensions
Annotations
  • @freezed

Constructors

CloseActivity({@Default.new('tools.ozone.report.defs#closeActivity') String $type, @CloseActivityPreviousStatusConverter() CloseActivityPreviousStatus? previousStatus, Map<String, dynamic>? $unknown})
const
factory
CloseActivity.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
copyWith → $CloseActivityCopyWith<CloseActivity>
Create a copy of CloseActivity with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasNotPreviousStatus bool

Available on CloseActivity, provided by the CloseActivityExtension extension

no setter
hasPreviousStatus bool

Available on CloseActivity, provided by the CloseActivityExtension extension

no setter
previousStatus CloseActivityPreviousStatus?
The report's status before this activity. Populated automatically from the report row; not required in input.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CloseActivity value)) → TResult

Available on CloseActivity, provided by the CloseActivityPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CloseActivity value)?) → TResult?

Available on CloseActivity, provided by the CloseActivityPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CloseActivity value)?, {required TResult orElse()}) → TResult

Available on CloseActivity, provided by the CloseActivityPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, CloseActivityPreviousStatus? previousStatus, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on CloseActivity, provided by the CloseActivityPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CloseActivity to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, CloseActivityPreviousStatus? previousStatus, Map<String, dynamic>? $unknown)) → TResult

Available on CloseActivity, provided by the CloseActivityPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, CloseActivityPreviousStatus? previousStatus, Map<String, dynamic>? $unknown)?) → TResult?

Available on CloseActivity, provided by the CloseActivityPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>