HistoricalStatsPatterns extension

Adds pattern-matching-related methods to HistoricalStats.

on

Methods

map<TResult extends Object?>(TResult $default(_HistoricalStats value)) → TResult

Available on HistoricalStats, provided by the HistoricalStatsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_HistoricalStats value)?) → TResult?

Available on HistoricalStats, provided by the HistoricalStatsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_HistoricalStats value)?, {required TResult orElse()}) → TResult

Available on HistoricalStats, provided by the HistoricalStatsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String date, DateTime? computedAt, int? pendingCount, int? closedCount, int? actionedCount, int? acknowledgedCount, int? escalatedCount, int? inboundCount, int? labelActionCount, int? tagActionCount, int? takedownActionCount, int? ahtDurationSec, int? ahtSampleCount, int? resolutionDurationSec, int? resolutionSampleCount, int? actionRate, int? avgHandlingTimeSec, int? avgResolutionTimeSec, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on HistoricalStats, provided by the HistoricalStatsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String $type, String date, DateTime? computedAt, int? pendingCount, int? closedCount, int? actionedCount, int? acknowledgedCount, int? escalatedCount, int? inboundCount, int? labelActionCount, int? tagActionCount, int? takedownActionCount, int? ahtDurationSec, int? ahtSampleCount, int? resolutionDurationSec, int? resolutionSampleCount, int? actionRate, int? avgHandlingTimeSec, int? avgResolutionTimeSec, Map<String, dynamic>? $unknown)) → TResult

Available on HistoricalStats, provided by the HistoricalStatsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String date, DateTime? computedAt, int? pendingCount, int? closedCount, int? actionedCount, int? acknowledgedCount, int? escalatedCount, int? inboundCount, int? labelActionCount, int? tagActionCount, int? takedownActionCount, int? ahtDurationSec, int? ahtSampleCount, int? resolutionDurationSec, int? resolutionSampleCount, int? actionRate, int? avgHandlingTimeSec, int? avgResolutionTimeSec, Map<String, dynamic>? $unknown)?) → TResult?

Available on HistoricalStats, provided by the HistoricalStatsPatterns extension

A variant of when that fallback to returning null