LiveStats class abstract
Live statistics for reports for the current calendar day, filterable by queue, moderator, or report type.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
LiveStats({@Default.new('tools.ozone.report.defs#liveStats') String $type, int? pendingCount, int? closedCount, int? actionedCount, int? acknowledgedCount, int? escalatedCount, int? inboundCount, int? labelActionCount, int? tagActionCount, int? takedownActionCount, int? ahtDurationSec, int? ahtSampleCount, int? resolutionDurationSec, int? resolutionSampleCount, int? actionRate, int? avgHandlingTimeSec, int? avgResolutionTimeSec, @JsonKey.new(toJson: iso8601) DateTime? lastUpdated, Map<
String, dynamic> ? $unknown}) -
constfactory
-
LiveStats.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
- acknowledgedCount → int?
-
Number of closures whose last report action is not label, tag, or takedown.
no setterinherited
- actionedCount → int?
-
Number of closures whose last report action is label, tag, or takedown.
no setterinherited
- actionRate → int?
-
Percentage of closures actioned (actionedCount / closedCount * 100), rounded to nearest integer.
no setterinherited
- ahtDurationSec → int?
-
Sum of report assignment-to-close seconds.
no setterinherited
- ahtSampleCount → int?
-
Number of assigned closed-report samples in ahtDurationSec.
no setterinherited
- avgHandlingTimeSec → int?
-
Average handling time in seconds from report assignment to close.
no setterinherited
- avgResolutionTimeSec → int?
-
Average resolution time in seconds from report creation to close.
no setterinherited
- closedCount → int?
-
Number of close transitions.
no setterinherited
-
copyWith
→ $LiveStatsCopyWith<
LiveStats> -
Create a copy of LiveStats
with the given fields replaced by the non-null parameter values.
no setterinherited
- escalatedCount → int?
-
Number of reports escalated.
no setterinherited
- hasAcknowledgedCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasActionedCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasActionRate → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasAhtDurationSec → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasAhtSampleCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasAvgHandlingTimeSec → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasAvgResolutionTimeSec → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasClosedCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasEscalatedCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasInboundCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasLabelActionCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasLastUpdated → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotAcknowledgedCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotActionedCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotActionRate → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotAhtDurationSec → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotAhtSampleCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotAvgHandlingTimeSec → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotAvgResolutionTimeSec → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotClosedCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotEscalatedCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotInboundCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotLabelActionCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotLastUpdated → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotPendingCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotResolutionDurationSec → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotResolutionSampleCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotTagActionCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasNotTakedownActionCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasPendingCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasResolutionDurationSec → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasResolutionSampleCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasTagActionCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - hasTakedownActionCount → bool
-
Available on LiveStats, provided by the LiveStatsExtension extension
no setter - inboundCount → int?
-
Reports received.
no setterinherited
- labelActionCount → int?
-
Closures whose last report action is a label event.
no setterinherited
- lastUpdated → DateTime?
-
When these statistics were last computed.
no setterinherited
- pendingCount → int?
-
Number of reports currently not closed.
no setterinherited
- resolutionDurationSec → int?
-
Sum of report creation-to-close seconds.
no setterinherited
- resolutionSampleCount → int?
-
Number of closed-report samples in resolutionDurationSec.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tagActionCount → int?
-
Closures whose last report action is a tag event.
no setterinherited
- takedownActionCount → int?
-
Closures whose last report action is a takedown event.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_LiveStats value)) → TResult -
Available on LiveStats, provided by the LiveStatsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_LiveStats value)?) → TResult? -
Available on LiveStats, provided by the LiveStatsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_LiveStats value)?, {required TResult orElse()}) → TResult -
Available on LiveStats, provided by the LiveStatsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, int? pendingCount, int? closedCount, int? actionedCount, int? acknowledgedCount, int? escalatedCount, int? inboundCount, int? labelActionCount, int? tagActionCount, int? takedownActionCount, int? ahtDurationSec, int? ahtSampleCount, int? resolutionDurationSec, int? resolutionSampleCount, int? actionRate, int? avgHandlingTimeSec, int? avgResolutionTimeSec, DateTime? lastUpdated, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on LiveStats, provided by the LiveStatsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this LiveStats to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, int? pendingCount, int? closedCount, int? actionedCount, int? acknowledgedCount, int? escalatedCount, int? inboundCount, int? labelActionCount, int? tagActionCount, int? takedownActionCount, int? ahtDurationSec, int? ahtSampleCount, int? resolutionDurationSec, int? resolutionSampleCount, int? actionRate, int? avgHandlingTimeSec, int? avgResolutionTimeSec, DateTime? lastUpdated, Map< String, dynamic> ? $unknown)) → TResult -
Available on LiveStats, provided by the LiveStatsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, int? pendingCount, int? closedCount, int? actionedCount, int? acknowledgedCount, int? escalatedCount, int? inboundCount, int? labelActionCount, int? tagActionCount, int? takedownActionCount, int? ahtDurationSec, int? ahtSampleCount, int? resolutionDurationSec, int? resolutionSampleCount, int? actionRate, int? avgHandlingTimeSec, int? avgResolutionTimeSec, DateTime? lastUpdated, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on LiveStats, provided by the LiveStatsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>