LiveStats constructor

const LiveStats({
  1. @Default.new('tools.ozone.report.defs#liveStats') String $type,
  2. int? pendingCount,
  3. int? closedCount,
  4. int? actionedCount,
  5. int? acknowledgedCount,
  6. int? escalatedCount,
  7. int? inboundCount,
  8. int? labelActionCount,
  9. int? tagActionCount,
  10. int? takedownActionCount,
  11. int? ahtDurationSec,
  12. int? ahtSampleCount,
  13. int? resolutionDurationSec,
  14. int? resolutionSampleCount,
  15. int? actionRate,
  16. int? avgHandlingTimeSec,
  17. int? avgResolutionTimeSec,
  18. @JsonKey.new(toJson: iso8601) DateTime? lastUpdated,
  19. Map<String, dynamic>? $unknown,
})

Implementation

@JsonSerializable(includeIfNull: false)
const factory LiveStats({
  @Default('tools.ozone.report.defs#liveStats') String $type,

  /// Number of reports currently not closed.
  int? pendingCount,

  /// Number of close transitions.
  int? closedCount,

  /// Number of closures whose last report action is label, tag, or takedown.
  int? actionedCount,

  /// Number of closures whose last report action is not label, tag, or takedown.
  int? acknowledgedCount,

  /// Number of reports escalated.
  int? escalatedCount,

  /// Reports received.
  int? inboundCount,

  /// Closures whose last report action is a label event.
  int? labelActionCount,

  /// Closures whose last report action is a tag event.
  int? tagActionCount,

  /// Closures whose last report action is a takedown event.
  int? takedownActionCount,

  /// Sum of report assignment-to-close seconds.
  int? ahtDurationSec,

  /// Number of assigned closed-report samples in ahtDurationSec.
  int? ahtSampleCount,

  /// Sum of report creation-to-close seconds.
  int? resolutionDurationSec,

  /// Number of closed-report samples in resolutionDurationSec.
  int? resolutionSampleCount,

  /// Percentage of closures actioned (actionedCount / closedCount * 100), rounded to nearest integer.
  int? actionRate,

  /// Average handling time in seconds from report assignment to close.
  int? avgHandlingTimeSec,

  /// Average resolution time in seconds from report creation to close.
  int? avgResolutionTimeSec,

  /// When these statistics were last computed.
  @JsonKey(toJson: iso8601) DateTime? lastUpdated,

  Map<String, dynamic>? $unknown,
}) = _LiveStats;