actionedCount property

int? get actionedCount
inherited

Number of closures whose last report action is label, tag, or takedown.

Implementation

int? get closedCount;/// Number of closures whose last report action is label, tag, or takedown.
int? get actionedCount;