QueueActivity class abstract

Activity recording a report being routed to a queue.

Available extensions
Annotations
  • @freezed

Constructors

QueueActivity({@Default.new('tools.ozone.report.defs#queueActivity') String $type, @QueueActivityPreviousStatusConverter() QueueActivityPreviousStatus? previousStatus, Map<String, dynamic>? $unknown})
const
factory
QueueActivity.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
copyWith → $QueueActivityCopyWith<QueueActivity>
Create a copy of QueueActivity with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasNotPreviousStatus bool

Available on QueueActivity, provided by the QueueActivityExtension extension

no setter
hasPreviousStatus bool

Available on QueueActivity, provided by the QueueActivityExtension extension

no setter
previousStatus QueueActivityPreviousStatus?
The report's status before this activity. Populated automatically from the report row; not required in input.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_QueueActivity value)) → TResult

Available on QueueActivity, provided by the QueueActivityPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_QueueActivity value)?) → TResult?

Available on QueueActivity, provided by the QueueActivityPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_QueueActivity value)?, {required TResult orElse()}) → TResult

Available on QueueActivity, provided by the QueueActivityPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, QueueActivityPreviousStatus? previousStatus, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on QueueActivity, provided by the QueueActivityPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this QueueActivity to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, QueueActivityPreviousStatus? previousStatus, Map<String, dynamic>? $unknown)) → TResult

Available on QueueActivity, provided by the QueueActivityPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, QueueActivityPreviousStatus? previousStatus, Map<String, dynamic>? $unknown)?) → TResult?

Available on QueueActivity, provided by the QueueActivityPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>