ReopenActivity class abstract

Activity recording a closed report being reopened. Only valid when the report is in 'closed' status.

Available extensions
Annotations
  • @freezed

Constructors

ReopenActivity({@Default.new('tools.ozone.report.defs#reopenActivity') String $type, @ReopenActivityPreviousStatusConverter() ReopenActivityPreviousStatus? previousStatus, Map<String, dynamic>? $unknown})
const
factory
ReopenActivity.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
copyWith → $ReopenActivityCopyWith<ReopenActivity>
Create a copy of ReopenActivity with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasNotPreviousStatus bool

Available on ReopenActivity, provided by the ReopenActivityExtension extension

no setter
hasPreviousStatus bool

Available on ReopenActivity, provided by the ReopenActivityExtension extension

no setter
previousStatus ReopenActivityPreviousStatus?
The report's status before this activity. Populated automatically from the report row; not required in input.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReopenActivity value)) → TResult

Available on ReopenActivity, provided by the ReopenActivityPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReopenActivity value)?) → TResult?

Available on ReopenActivity, provided by the ReopenActivityPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReopenActivity value)?, {required TResult orElse()}) → TResult

Available on ReopenActivity, provided by the ReopenActivityPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, ReopenActivityPreviousStatus? previousStatus, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ReopenActivity, provided by the ReopenActivityPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ReopenActivity to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, ReopenActivityPreviousStatus? previousStatus, Map<String, dynamic>? $unknown)) → TResult

Available on ReopenActivity, provided by the ReopenActivityPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, ReopenActivityPreviousStatus? previousStatus, Map<String, dynamic>? $unknown)?) → TResult?

Available on ReopenActivity, provided by the ReopenActivityPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>