ReportActivityView class abstract

A single activity entry on a report.

Available extensions
Annotations
  • @freezed

Constructors

ReportActivityView({@Default.new('tools.ozone.report.defs#reportActivityView') String $type, required int id, required int reportId, @UReportActivityViewActivityConverter() required UReportActivityViewActivity activity, String? internalNote, String? publicNote, Map<String, dynamic>? meta, required bool isAutomated, required String createdBy, @MemberConverter() Member? moderator, required DateTime createdAt, Map<String, dynamic>? $unknown})
const
factory
ReportActivityView.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
activity UReportActivityViewActivity
no setterinherited
copyWith → $ReportActivityViewCopyWith<ReportActivityView>
Create a copy of ReportActivityView with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime
When this activity was created
no setterinherited
createdBy String
DID of the actor who created this activity, or the service DID for automated activities.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasInternalNote bool

Available on ReportActivityView, provided by the ReportActivityViewExtension extension

no setter
hasMeta bool

Available on ReportActivityView, provided by the ReportActivityViewExtension extension

no setter
hasModerator bool

Available on ReportActivityView, provided by the ReportActivityViewExtension extension

no setter
hasNotInternalNote bool

Available on ReportActivityView, provided by the ReportActivityViewExtension extension

no setter
hasNotMeta bool

Available on ReportActivityView, provided by the ReportActivityViewExtension extension

no setter
hasNotModerator bool

Available on ReportActivityView, provided by the ReportActivityViewExtension extension

no setter
hasNotPublicNote bool

Available on ReportActivityView, provided by the ReportActivityViewExtension extension

no setter
hasPublicNote bool

Available on ReportActivityView, provided by the ReportActivityViewExtension extension

no setter
id int
Activity ID
no setterinherited
internalNote String?
Optional moderator-only note. Not visible to reporters.
no setterinherited
isAutomated bool
True if this activity was created by an automated process (e.g. queue router) rather than a direct human action.
no setterinherited
isIsAutomated bool

Available on ReportActivityView, provided by the ReportActivityViewExtension extension

no setter
isNotIsAutomated bool

Available on ReportActivityView, provided by the ReportActivityViewExtension extension

no setter
meta Map<String, dynamic>?
no setterinherited
moderator Member?
Full member record of the moderator who created this activity
no setterinherited
publicNote String?
Optional public note, potentially visible to the reporter.
no setterinherited
reportId int
ID of the report this activity belongs to
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReportActivityView value)) → TResult

Available on ReportActivityView, provided by the ReportActivityViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReportActivityView value)?) → TResult?

Available on ReportActivityView, provided by the ReportActivityViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReportActivityView value)?, {required TResult orElse()}) → TResult

Available on ReportActivityView, provided by the ReportActivityViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, int id, int reportId, UReportActivityViewActivity activity, String? internalNote, String? publicNote, Map<String, dynamic>? meta, bool isAutomated, String createdBy, Member? moderator, DateTime createdAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ReportActivityView, provided by the ReportActivityViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ReportActivityView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, int id, int reportId, UReportActivityViewActivity activity, String? internalNote, String? publicNote, Map<String, dynamic>? meta, bool isAutomated, String createdBy, Member? moderator, DateTime createdAt, Map<String, dynamic>? $unknown)) → TResult

Available on ReportActivityView, provided by the ReportActivityViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, int id, int reportId, UReportActivityViewActivity activity, String? internalNote, String? publicNote, Map<String, dynamic>? meta, bool isAutomated, String createdBy, Member? moderator, DateTime createdAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on ReportActivityView, provided by the ReportActivityViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>