createdBy property

String get createdBy
inherited

DID of the actor who created this activity, or the service DID for automated activities.

Implementation

bool get isAutomated;/// DID of the actor who created this activity, or the service DID for automated activities.
String get createdBy;