isAutomated property

bool get isAutomated
inherited

True if this activity was created by an automated process (e.g. queue router) rather than a direct human action.

Implementation

String? get publicNote; Map<String, dynamic>? get meta;/// True if this activity was created by an automated process (e.g. queue router) rather than a direct human action.
bool get isAutomated;