ReportAssignment class abstract

Information about the moderator currently assigned to a report.

Available extensions
Annotations
  • @freezed

Constructors

ReportAssignment({@Default.new('tools.ozone.report.defs#reportAssignment') String $type, required String did, @MemberConverter() Member? moderator, required DateTime assignedAt, Map<String, dynamic>? $unknown})
const
factory
ReportAssignment.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
assignedAt DateTime
When the report was assigned
no setterinherited
copyWith → $ReportAssignmentCopyWith<ReportAssignment>
Create a copy of ReportAssignment with the given fields replaced by the non-null parameter values.
no setterinherited
did String
DID of the assigned moderator
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasModerator bool

Available on ReportAssignment, provided by the ReportAssignmentExtension extension

no setter
hasNotModerator bool

Available on ReportAssignment, provided by the ReportAssignmentExtension extension

no setter
moderator Member?
Full member record of the assigned moderator
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReportAssignment value)) → TResult

Available on ReportAssignment, provided by the ReportAssignmentPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReportAssignment value)?) → TResult?

Available on ReportAssignment, provided by the ReportAssignmentPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReportAssignment value)?, {required TResult orElse()}) → TResult

Available on ReportAssignment, provided by the ReportAssignmentPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String did, Member? moderator, DateTime assignedAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ReportAssignment, provided by the ReportAssignmentPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ReportAssignment to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String did, Member? moderator, DateTime assignedAt, Map<String, dynamic>? $unknown)) → TResult

Available on ReportAssignment, provided by the ReportAssignmentPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String did, Member? moderator, DateTime assignedAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on ReportAssignment, provided by the ReportAssignmentPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>