assignment property

  1. @ReportAssignmentConverter()
ReportAssignment? get assignment
inherited

Information about moderator currently assigned to this report (if any)

Implementation

int? get relatedReportCount;/// Information about moderator currently assigned to this report (if any)
@ReportAssignmentConverter() ReportAssignment? get assignment;