eventId property
ID of the moderation event that created this report
Implementation
int get id;/// ID of the moderation event that created this report
int get eventId;
ID of the moderation event that created this report
int get id;/// ID of the moderation event that created this report
int get eventId;