ReportGetAssignmentsInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ReportGetAssignmentsInput({@Default.new(true) bool onlyActive, List<int>? reportIds, List<String>? dids, @Default.new(50) int limit, String? cursor, Map<String, dynamic>? $unknown})
const
factory
ReportGetAssignmentsInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
copyWith → $ReportGetAssignmentsInputCopyWith<ReportGetAssignmentsInput>
Create a copy of ReportGetAssignmentsInput with the given fields replaced by the non-null parameter values.
no setterinherited
cursor String?
no setterinherited
dids List<String>?
no setterinherited
hasCursor bool

Available on ReportGetAssignmentsInput, provided by the ReportGetAssignmentsInputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotCursor bool

Available on ReportGetAssignmentsInput, provided by the ReportGetAssignmentsInputExtension extension

no setter
isNotOnlyActive bool

Available on ReportGetAssignmentsInput, provided by the ReportGetAssignmentsInputExtension extension

no setter
isOnlyActive bool

Available on ReportGetAssignmentsInput, provided by the ReportGetAssignmentsInputExtension extension

no setter
limit int
no setterinherited
onlyActive bool
When true, only returns active assignments.
no setterinherited
reportIds List<int>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReportGetAssignmentsInput value)) → TResult

Available on ReportGetAssignmentsInput, provided by the ReportGetAssignmentsInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReportGetAssignmentsInput value)?) → TResult?

Available on ReportGetAssignmentsInput, provided by the ReportGetAssignmentsInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReportGetAssignmentsInput value)?, {required TResult orElse()}) → TResult

Available on ReportGetAssignmentsInput, provided by the ReportGetAssignmentsInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool onlyActive, List<int>? reportIds, List<String>? dids, int limit, String? cursor, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ReportGetAssignmentsInput, provided by the ReportGetAssignmentsInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ReportGetAssignmentsInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool onlyActive, List<int>? reportIds, List<String>? dids, int limit, String? cursor, Map<String, dynamic>? $unknown)) → TResult

Available on ReportGetAssignmentsInput, provided by the ReportGetAssignmentsInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool onlyActive, List<int>? reportIds, List<String>? dids, int limit, String? cursor, Map<String, dynamic>? $unknown)?) → TResult?

Available on ReportGetAssignmentsInput, provided by the ReportGetAssignmentsInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>