ReportQueryActivitiesInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ReportQueryActivitiesInput({List<String>? activityTypes, DateTime? createdAfter, DateTime? createdBefore, @Default.new('desc') String sortDirection, @Default.new(50) int limit, String? cursor, Map<String, dynamic>? $unknown})
const
factory
ReportQueryActivitiesInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
activityTypes List<String>?
no setterinherited
copyWith → $ReportQueryActivitiesInputCopyWith<ReportQueryActivitiesInput>
Create a copy of ReportQueryActivitiesInput with the given fields replaced by the non-null parameter values.
no setterinherited
createdAfter DateTime?
Retrieve activities created at or after a given timestamp
no setterinherited
createdBefore DateTime?
Retrieve activities created at or before a given timestamp
no setterinherited
cursor String?
Cursor of the form <createdAtMs>::<activityId>.
no setterinherited
hasCreatedAfter bool

Available on ReportQueryActivitiesInput, provided by the ReportQueryActivitiesInputExtension extension

no setter
hasCreatedBefore bool

Available on ReportQueryActivitiesInput, provided by the ReportQueryActivitiesInputExtension extension

no setter
hasCursor bool

Available on ReportQueryActivitiesInput, provided by the ReportQueryActivitiesInputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotCreatedAfter bool

Available on ReportQueryActivitiesInput, provided by the ReportQueryActivitiesInputExtension extension

no setter
hasNotCreatedBefore bool

Available on ReportQueryActivitiesInput, provided by the ReportQueryActivitiesInputExtension extension

no setter
hasNotCursor bool

Available on ReportQueryActivitiesInput, provided by the ReportQueryActivitiesInputExtension extension

no setter
limit int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortDirection String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReportQueryActivitiesInput value)) → TResult

Available on ReportQueryActivitiesInput, provided by the ReportQueryActivitiesInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReportQueryActivitiesInput value)?) → TResult?

Available on ReportQueryActivitiesInput, provided by the ReportQueryActivitiesInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReportQueryActivitiesInput value)?, {required TResult orElse()}) → TResult

Available on ReportQueryActivitiesInput, provided by the ReportQueryActivitiesInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<String>? activityTypes, DateTime? createdAfter, DateTime? createdBefore, String sortDirection, int limit, String? cursor, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ReportQueryActivitiesInput, provided by the ReportQueryActivitiesInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ReportQueryActivitiesInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(List<String>? activityTypes, DateTime? createdAfter, DateTime? createdBefore, String sortDirection, int limit, String? cursor, Map<String, dynamic>? $unknown)) → TResult

Available on ReportQueryActivitiesInput, provided by the ReportQueryActivitiesInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<String>? activityTypes, DateTime? createdAfter, DateTime? createdBefore, String sortDirection, int limit, String? cursor, Map<String, dynamic>? $unknown)?) → TResult?

Available on ReportQueryActivitiesInput, provided by the ReportQueryActivitiesInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>