assignedTo property

String? get assignedTo
inherited

Filter by the DID of the moderator permanently assigned to the report.

Implementation

bool get isMuted;/// Filter by the DID of the moderator permanently assigned to the report.
String? get assignedTo;