did property

String? get did
inherited

Filter to reports where the subject is this DID or any record owned by this DID. Unlike subject (which scopes to a specific account or record), this returns all reports tied to the DID across both account-level and record-level subjects.

Implementation

String? get subject;/// Filter to reports where the subject is this DID or any record owned by this DID. Unlike `subject` (which scopes to a specific account or record), this returns all reports tied to the DID across both account-level and record-level subjects.
String? get did;