ReportReassignQueueInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ReportReassignQueueInput({required int reportId, required int queueId, String? comment, Map<String, dynamic>? $unknown})
const
factory
ReportReassignQueueInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
comment String?
Optional moderator-only note recorded on the resulting queueActivity as internalNote.
no setterinherited
copyWith → $ReportReassignQueueInputCopyWith<ReportReassignQueueInput>
Create a copy of ReportReassignQueueInput with the given fields replaced by the non-null parameter values.
no setterinherited
hasComment bool

Available on ReportReassignQueueInput, provided by the ReportReassignQueueInputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotComment bool

Available on ReportReassignQueueInput, provided by the ReportReassignQueueInputExtension extension

no setter
queueId int
Target queue ID. Use -1 to unassign from any queue.
no setterinherited
reportId int
ID of the report to reassign
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReportReassignQueueInput value)) → TResult

Available on ReportReassignQueueInput, provided by the ReportReassignQueueInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReportReassignQueueInput value)?) → TResult?

Available on ReportReassignQueueInput, provided by the ReportReassignQueueInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReportReassignQueueInput value)?, {required TResult orElse()}) → TResult

Available on ReportReassignQueueInput, provided by the ReportReassignQueueInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int reportId, int queueId, String? comment, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ReportReassignQueueInput, provided by the ReportReassignQueueInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ReportReassignQueueInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int reportId, int queueId, String? comment, Map<String, dynamic>? $unknown)) → TResult

Available on ReportReassignQueueInput, provided by the ReportReassignQueueInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int reportId, int queueId, String? comment, Map<String, dynamic>? $unknown)?) → TResult?

Available on ReportReassignQueueInput, provided by the ReportReassignQueueInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>