NotificationConfigChannelsPatterns extension

Adds pattern-matching-related methods to NotificationConfigChannels.

on

Methods

map<TResult extends Object?>({required TResult knownValue(NotificationConfigChannelsKnownValue value), required TResult unknown(NotificationConfigChannelsUnknown value)}) → TResult

Available on NotificationConfigChannels, provided by the NotificationConfigChannelsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(NotificationConfigChannelsKnownValue value)?, TResult? unknown(NotificationConfigChannelsUnknown value)?}) → TResult?

Available on NotificationConfigChannels, provided by the NotificationConfigChannelsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(NotificationConfigChannelsKnownValue value)?, TResult unknown(NotificationConfigChannelsUnknown value)?, required TResult orElse()}) → TResult

Available on NotificationConfigChannels, provided by the NotificationConfigChannelsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownNotificationConfigChannels data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on NotificationConfigChannels, provided by the NotificationConfigChannelsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult knownValue(KnownNotificationConfigChannels data), required TResult unknown(String data)}) → TResult

Available on NotificationConfigChannels, provided by the NotificationConfigChannelsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownNotificationConfigChannels data)?, TResult? unknown(String data)?}) → TResult?

Available on NotificationConfigChannels, provided by the NotificationConfigChannelsPatterns extension

A variant of when that fallback to returning null