InboxService class base

tools.ozone.inbox.*

Constructors

InboxService(ServiceContext ctx)

Properties

ctx → ServiceContext
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

appealActionedSubject({UInboxAppealActionedSubjectAction? action, required UInboxAppealActionedSubjectSubject subject, String? reason, ModTool? modTool, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<SubjectView>>
Appeal a moderation action affecting the user's account or content.
getAccountStatus({String? did, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<InboxGetAccountStatusOutput>>
Get the authenticated account's current standing with this moderation service.
getActionedSubject({String? did, required String subject, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<SubjectViewDetail>>
Get a subject belonging to the authenticated account, including its moderation action history from this moderation service.
getNotificationPreferences({String? did, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<InboxGetNotificationPreferencesOutput>>
getReport({String? did, required int id, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<InboxGetReportOutput>>
Get a moderation report submitted by the authenticated account to this moderation service.
getUnreadCount({InboxGetUnreadCountSection? section, String? did, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<InboxGetUnreadCountOutput>>
listActionedSubjects({String? did, String? filter, String? sortField, String? sortDirection, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<InboxListActionedSubjectsOutput>>
List subjects belonging to the authenticated account that have moderation actions from this moderation service.
listNotifications({InboxListNotificationsSection? section, List<InboxListNotificationsReasons>? reasons, bool? unreadOnly, int? limit, String? cursor, String? did, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<InboxListNotificationsOutput>>
listReports({String? did, String? filter, String? sortField, String? sortDirection, int? limit, String? cursor, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<InboxListReportsOutput>>
List moderation reports submitted by the authenticated account to this moderation service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putNotificationPreferences({required bool push, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<InboxPutNotificationPreferencesOutput>>
toString() → String
A string representation of this object.
inherited
updateSeen({required List<InboxUpdateSeenSections> sections, DateTime? seenAt, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<InboxUpdateSeenOutput>>

Operators

operator ==(Object other) → bool
The equality operator.
inherited