getActionedSubject method

Future<XRPCResponse<SubjectViewDetail>> getActionedSubject({
  1. String? did,
  2. required String subject,
  3. int? limit,
  4. String? cursor,
  5. String? $service,
  6. Map<String, String>? $headers,
  7. Map<String, String>? $unknown,
})

Get a subject belonging to the authenticated account, including its moderation action history from this moderation service.

Implementation

Future<XRPCResponse<SubjectViewDetail>> getActionedSubject({
  String? did,
  required String subject,
  int? limit,
  String? cursor,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await toolsOzoneInboxGetActionedSubject(
  did: did,
  subject: subject,
  limit: limit,
  cursor: cursor,
  $ctx: ctx,
  $service: $service,
  $headers: $headers,
  $unknown: $unknown,
);