createQueue method
Create a new moderation queue. A queue can have optional matching criteria that ozone's queue router will use to match reports. A queue with no criteria must have reports assigned to it manually via (1) modTool.meta.queueId in tools.ozone.moderation.emitEvent or (2) tools.ozone.report.reassignQueue.
Implementation
Future<XRPCResponse<QueueCreateQueueOutput>> createQueue({
required String name,
List<QueueCreateQueueSubjectTypes>? subjectTypes,
String? collection,
List<String>? reportTypes,
String? description,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await toolsOzoneQueueCreateQueue(
name: name,
subjectTypes: subjectTypes,
collection: collection,
reportTypes: reportTypes,
description: description,
$ctx: ctx,
$service: $service,
$headers: $headers,
$unknown: $unknown,
);