closeReports method

Future<XRPCResponse<ReportCloseReportsOutput>> closeReports({
  1. required String subject,
  2. List<String>? reportTypes,
  3. String? internalNote,
  4. bool? isAutomated,
  5. String? $service,
  6. Map<String, String>? $headers,
  7. Map<String, String>? $unknown,
})

Close all reports on a subject matching the given criteria. Reports whose current status does not permit a transition to closed are skipped silently. Intended for automated flows that resolve reports without taking action on the subject.

Implementation

Future<XRPCResponse<ReportCloseReportsOutput>> closeReports({
  required String subject,
  List<String>? reportTypes,
  String? internalNote,
  bool? isAutomated,
  String? $service,
  Map<String, String>? $headers,
  Map<String, String>? $unknown,
}) async => await toolsOzoneReportCloseReports(
  subject: subject,
  reportTypes: reportTypes,
  internalNote: internalNote,
  isAutomated: isAutomated,
  $ctx: ctx,
  $service: $service,
  $headers: $headers,
  $unknown: $unknown,
);