toolsOzoneInboxGetActionedSubject function
Get a subject belonging to the authenticated account, including its moderation action history from this moderation service.
Implementation
Future<XRPCResponse<SubjectViewDetail>> toolsOzoneInboxGetActionedSubject({
String? did,
required String subject,
int? limit,
String? cursor,
required ServiceContext $ctx,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await $ctx.get(
ns.toolsOzoneInboxGetActionedSubject,
service: $service,
headers: $headers,
parameters: {
...?$unknown,
if (did != null) 'did': did,
'subject': subject,
if (limit != null) 'limit': limit,
if (cursor != null) 'cursor': cursor,
},
to: const SubjectViewDetailConverter().fromJson,
);