SetView class abstract

Available extensions
Annotations
  • @freezed

Constructors

SetView({@Default.new('tools.ozone.set.defs#setView') String $type, required String name, String? description, required int setSize, @JsonKey.new(toJson: iso8601) required DateTime createdAt, @JsonKey.new(toJson: iso8601) required DateTime updatedAt, Map<String, dynamic>? $unknown})
const
factory
SetView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $SetViewCopyWith<SetView>
Create a copy of SetView with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
description → String?
no setterinherited
hasDescription → bool

Available on SetView, provided by the SetViewExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotDescription → bool

Available on SetView, provided by the SetViewExtension extension

no setter
name → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setSize → int
no setterinherited
updatedAt → DateTime
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SetView value)) → TResult

Available on SetView, provided by the SetViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SetView value)?) → TResult?

Available on SetView, provided by the SetViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SetView value)?, {required TResult orElse()}) → TResult

Available on SetView, provided by the SetViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String name, String? description, int setSize, DateTime createdAt, DateTime updatedAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on SetView, provided by the SetViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this SetView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String name, String? description, int setSize, DateTime createdAt, DateTime updatedAt, Map<String, dynamic>? $unknown)) → TResult

Available on SetView, provided by the SetViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String name, String? description, int setSize, DateTime createdAt, DateTime updatedAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on SetView, provided by the SetViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>