UVerificationViewSubjectProfile class sealed

Available extensions
Annotations
  • @freezed

Constructors

UVerificationViewSubjectProfile.unknown({required Map<String, dynamic> data})
const
factory

Properties

copyWith → $UVerificationViewSubjectProfileCopyWith<UVerificationViewSubjectProfile>
Create a copy of UVerificationViewSubjectProfile with the given fields replaced by the non-null parameter values.
no setterinherited
data → Map<String, dynamic>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isNotUnknown → bool

Available on UVerificationViewSubjectProfile, provided by the UVerificationViewSubjectProfileExtension extension

no setter
isUnknown → bool

Available on UVerificationViewSubjectProfile, provided by the UVerificationViewSubjectProfileExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknown → Map<String, dynamic>?

Available on UVerificationViewSubjectProfile, provided by the UVerificationViewSubjectProfileExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult unknown(UVerificationViewSubjectProfileUnknown value)}) → TResult

Available on UVerificationViewSubjectProfile, provided by the UVerificationViewSubjectProfilePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? unknown(UVerificationViewSubjectProfileUnknown value)?}) → TResult?

Available on UVerificationViewSubjectProfile, provided by the UVerificationViewSubjectProfilePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult unknown(UVerificationViewSubjectProfileUnknown value)?, required TResult orElse()}) → TResult

Available on UVerificationViewSubjectProfile, provided by the UVerificationViewSubjectProfilePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult unknown(Map<String, dynamic> data)?, required TResult orElse()}) → TResult

Available on UVerificationViewSubjectProfile, provided by the UVerificationViewSubjectProfilePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult unknown(Map<String, dynamic> data)}) → TResult

Available on UVerificationViewSubjectProfile, provided by the UVerificationViewSubjectProfilePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? unknown(Map<String, dynamic> data)?}) → TResult?

Available on UVerificationViewSubjectProfile, provided by the UVerificationViewSubjectProfilePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited