VerificationInput constructor
const
VerificationInput({})
Implementation
@JsonSerializable(includeIfNull: false)
const factory VerificationInput({
@Default('tools.ozone.verification.grantVerifications#verificationInput')
String $type,
/// The did of the subject being verified
required String subject,
/// Handle of the subject the verification applies to at the moment of verifying.
required String handle,
/// Display name of the subject the verification applies to at the moment of verifying.
required String displayName,
/// Timestamp for verification record. Defaults to current time when not specified.
@JsonKey(toJson: iso8601) DateTime? createdAt,
Map<String, dynamic>? $unknown,
}) = _VerificationInput;