VerificationListVerificationsInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

VerificationListVerificationsInput({String? cursor, @Default.new(50) int limit, @JsonKey.new(toJson: iso8601) DateTime? createdAfter, @JsonKey.new(toJson: iso8601) DateTime? createdBefore, List<String>? issuers, List<String>? subjects, @Default.new('desc') String sortDirection, bool? isRevoked, Map<String, dynamic>? $unknown})
const
factory
VerificationListVerificationsInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $VerificationListVerificationsInputCopyWith<VerificationListVerificationsInput>
Create a copy of VerificationListVerificationsInput with the given fields replaced by the non-null parameter values.
no setterinherited
createdAfter → DateTime?
Filter to verifications created after this timestamp
no setterinherited
createdBefore → DateTime?
Filter to verifications created before this timestamp
no setterinherited
cursor → String?
Pagination cursor
no setterinherited
hasCreatedAfter → bool

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputExtension extension

no setter
hasCreatedBefore → bool

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputExtension extension

no setter
hasCursor → bool

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotCreatedAfter → bool

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputExtension extension

no setter
hasNotCreatedBefore → bool

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputExtension extension

no setter
hasNotCursor → bool

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputExtension extension

no setter
isIsRevoked → bool

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputExtension extension

no setter
isNotIsRevoked → bool

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputExtension extension

no setter
isRevoked → bool?
Filter to verifications that are revoked or not. By default, includes both.
no setterinherited
issuers → List<String>?
no setterinherited
limit → int
Maximum number of results to return
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortDirection → String
Sort direction for creation date
no setterinherited
subjects → List<String>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_VerificationListVerificationsInput value)) → TResult

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VerificationListVerificationsInput value)?) → TResult?

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VerificationListVerificationsInput value)?, {required TResult orElse()}) → TResult

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? cursor, int limit, DateTime? createdAfter, DateTime? createdBefore, List<String>? issuers, List<String>? subjects, String sortDirection, bool? isRevoked, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this VerificationListVerificationsInput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? cursor, int limit, DateTime? createdAfter, DateTime? createdBefore, List<String>? issuers, List<String>? subjects, String sortDirection, bool? isRevoked, Map<String, dynamic>? $unknown)) → TResult

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? cursor, int limit, DateTime? createdAfter, DateTime? createdBefore, List<String>? issuers, List<String>? subjects, String sortDirection, bool? isRevoked, Map<String, dynamic>? $unknown)?) → TResult?

Available on VerificationListVerificationsInput, provided by the VerificationListVerificationsInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>