ProfileAssociatedChatAllowGroupInvites class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- ProfileAssociatedChatAllowGroupInvites.knownValue({required KnownProfileAssociatedChatAllowGroupInvites data})
-
constfactory
- ProfileAssociatedChatAllowGroupInvites.unknown({required String data})
-
constfactory
Properties
- data → Object
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isKnownValue → bool
-
Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesExtension extension
no setter - isNotKnownValue → bool
-
Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesExtension extension
no setter - isNotUnknown → bool
-
Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesExtension extension
no setter - isUnknown → bool
-
Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesExtension extension
no setter - knownValue → KnownProfileAssociatedChatAllowGroupInvites?
-
Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unknown → String?
-
Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesExtension extension
no setter
Methods
-
map<
TResult extends Object?> ({required TResult knownValue(ProfileAssociatedChatAllowGroupInvitesKnownValue value), required TResult unknown(ProfileAssociatedChatAllowGroupInvitesUnknown value)}) → TResult -
Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> ({TResult? knownValue(ProfileAssociatedChatAllowGroupInvitesKnownValue value)?, TResult? unknown(ProfileAssociatedChatAllowGroupInvitesUnknown value)?}) → TResult? -
Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({TResult knownValue(ProfileAssociatedChatAllowGroupInvitesKnownValue value)?, TResult unknown(ProfileAssociatedChatAllowGroupInvitesUnknown value)?, required TResult orElse()}) → TResult -
Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({TResult knownValue(KnownProfileAssociatedChatAllowGroupInvites data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult -
Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> ({required TResult knownValue(KnownProfileAssociatedChatAllowGroupInvites data), required TResult unknown(String data)}) → TResult -
Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> ({TResult? knownValue(KnownProfileAssociatedChatAllowGroupInvites data)?, TResult? unknown(String data)?}) → TResult? -
Available on ProfileAssociatedChatAllowGroupInvites, provided by the ProfileAssociatedChatAllowGroupInvitesPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
String? value) → ProfileAssociatedChatAllowGroupInvites?