ActorLinkRecord class abstract

A link shown on the account's profile. The profile record's links field sets which links are shown, and in what order.

Available extensions
Annotations
  • @freezed

Constructors

ActorLinkRecord({@Default.new('app.bsky.actor.link') String $type, required String url, String? title, @BlobConverter() Blob? icon, @JsonKey.new(toJson: iso8601) required DateTime createdAt, Map<String, dynamic>? $unknown})
const
factory
ActorLinkRecord.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $ActorLinkRecordCopyWith<ActorLinkRecord>
Create a copy of ActorLinkRecord with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasIcon → bool

Available on ActorLinkRecord, provided by the ActorLinkRecordExtension extension

no setter
hasNotIcon → bool

Available on ActorLinkRecord, provided by the ActorLinkRecordExtension extension

no setter
hasNotTitle → bool

Available on ActorLinkRecord, provided by the ActorLinkRecordExtension extension

no setter
hasTitle → bool

Available on ActorLinkRecord, provided by the ActorLinkRecordExtension extension

no setter
icon → Blob?
The destination site's icon, uploaded when the link is saved.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
Optional label for the link. Clients can fall back to the destination's domain.
no setterinherited
url → String
The link destination, an https URL.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ActorLinkRecord value)) → TResult

Available on ActorLinkRecord, provided by the ActorLinkRecordPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ActorLinkRecord value)?) → TResult?

Available on ActorLinkRecord, provided by the ActorLinkRecordPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ActorLinkRecord value)?, {required TResult orElse()}) → TResult

Available on ActorLinkRecord, provided by the ActorLinkRecordPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String url, String? title, Blob? icon, DateTime createdAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ActorLinkRecord, provided by the ActorLinkRecordPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ActorLinkRecord to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String url, String? title, Blob? icon, DateTime createdAt, Map<String, dynamic>? $unknown)) → TResult

Available on ActorLinkRecord, provided by the ActorLinkRecordPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String url, String? title, Blob? icon, DateTime createdAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on ActorLinkRecord, provided by the ActorLinkRecordPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>