app_bsky_embed_external library
Classes
- EmbedExternal
- A representation of some externally linked content (eg, a URL and 'card'), embedded in a Bluesky record (eg, a post).
- EmbedExternalColorRGB
- RGB color definition, inspired by site.standard.theme.color#rgb
- EmbedExternalColorRGBConverter
- EmbedExternalConverter
- EmbedExternalExternal
- EmbedExternalExternalConverter
- EmbedExternalView
- EmbedExternalViewConverter
- EmbedExternalViewExternal
- EmbedExternalViewExternalConverter
- EmbedExternalViewExternalSource
- The source of an external embed, such as a standard.site publication.
- EmbedExternalViewExternalSourceConverter
- EmbedExternalViewExternalSourceTheme
- The theme colors of an external source, such as a site.standard.publication. These colors may be used when rendering an embed from that source.
- EmbedExternalViewExternalSourceThemeConverter
Extensions
- EmbedExternalColorRGBPatterns on EmbedExternalColorRGB
- Adds pattern-matching-related methods to EmbedExternalColorRGB.
- EmbedExternalExternalExtension on EmbedExternalExternal
- EmbedExternalExternalPatterns on EmbedExternalExternal
- Adds pattern-matching-related methods to EmbedExternalExternal.
- EmbedExternalPatterns on EmbedExternal
- Adds pattern-matching-related methods to EmbedExternal.
- EmbedExternalViewExternalExtension on EmbedExternalViewExternal
- EmbedExternalViewExternalPatterns on EmbedExternalViewExternal
- Adds pattern-matching-related methods to EmbedExternalViewExternal.
- EmbedExternalViewExternalSourceExtension on EmbedExternalViewExternalSource
- EmbedExternalViewExternalSourcePatterns on EmbedExternalViewExternalSource
- Adds pattern-matching-related methods to EmbedExternalViewExternalSource.
- EmbedExternalViewExternalSourceThemeExtension on EmbedExternalViewExternalSourceTheme
- EmbedExternalViewExternalSourceThemePatterns on EmbedExternalViewExternalSourceTheme
- Adds pattern-matching-related methods to EmbedExternalViewExternalSourceTheme.
- EmbedExternalViewPatterns on EmbedExternalView
- Adds pattern-matching-related methods to EmbedExternalView.