EmbedExternalViewArticlePublicationTheme class abstract

Available extensions
Annotations
  • @freezed

Constructors

EmbedExternalViewArticlePublicationTheme({@Default.new('app.bsky.embed.external#viewArticlePublicationTheme') String $type, String? background, String? foreground, String? accent, String? accentForeground, Map<String, dynamic>? $unknown})
const
factory
EmbedExternalViewArticlePublicationTheme.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
accent → String?
Hex color string, if available. Example: '#ffffff'.
no setterinherited
accentForeground → String?
Hex color string, if available. Example: '#ffffff'.
no setterinherited
background → String?
Hex color string, if available. Example: '#ffffff'.
no setterinherited
copyWith → $EmbedExternalViewArticlePublicationThemeCopyWith<EmbedExternalViewArticlePublicationTheme>
Create a copy of EmbedExternalViewArticlePublicationTheme with the given fields replaced by the non-null parameter values.
no setterinherited
foreground → String?
Hex color string, if available. Example: '#ffffff'.
no setterinherited
hasAccent → bool

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemeExtension extension

no setter
hasAccentForeground → bool

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemeExtension extension

no setter
hasBackground → bool

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemeExtension extension

no setter
hasForeground → bool

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemeExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotAccent → bool

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemeExtension extension

no setter
hasNotAccentForeground → bool

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemeExtension extension

no setter
hasNotBackground → bool

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemeExtension extension

no setter
hasNotForeground → bool

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemeExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_EmbedExternalViewArticlePublicationTheme value)) → TResult

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_EmbedExternalViewArticlePublicationTheme value)?) → TResult?

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_EmbedExternalViewArticlePublicationTheme value)?, {required TResult orElse()}) → TResult

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String? background, String? foreground, String? accent, String? accentForeground, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this EmbedExternalViewArticlePublicationTheme to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String? background, String? foreground, String? accent, String? accentForeground, Map<String, dynamic>? $unknown)) → TResult

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String? background, String? foreground, String? accent, String? accentForeground, Map<String, dynamic>? $unknown)?) → TResult?

Available on EmbedExternalViewArticlePublicationTheme, provided by the EmbedExternalViewArticlePublicationThemePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>