EmbedExternalViewExternal class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
EmbedExternalViewExternal({@Default.new('app.bsky.embed.external#viewExternal') String $type, required String uri, required String title, required String description, String? thumb, DateTime? createdAt, DateTime? updatedAt, int? readingTime, @LabelConverter() List<
Label> ? labels, @EmbedExternalViewExternalSourceConverter() EmbedExternalViewExternalSource? source, @RepoStrongRefConverter() List<RepoStrongRef> ? associatedRefs, Map<String, dynamic> ? $unknown}) -
constfactory
-
EmbedExternalViewExternal.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
associatedRefs
→ List<
RepoStrongRef> ? -
no setterinherited
-
copyWith
→ $EmbedExternalViewExternalCopyWith<
EmbedExternalViewExternal> -
Create a copy of EmbedExternalViewExternal
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime?
-
When the external content was created, if available. Example: a publication date, for an article.
no setterinherited
- description → String
-
no setterinherited
- hasCreatedAt → bool
-
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotCreatedAt → bool
-
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalExtension extension
no setter - hasNotReadingTime → bool
-
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalExtension extension
no setter - hasNotSource → bool
-
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalExtension extension
no setter - hasNotThumb → bool
-
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalExtension extension
no setter - hasNotUpdatedAt → bool
-
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalExtension extension
no setter - hasReadingTime → bool
-
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalExtension extension
no setter - hasSource → bool
-
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalExtension extension
no setter - hasThumb → bool
-
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalExtension extension
no setter - hasUpdatedAt → bool
-
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalExtension extension
no setter -
labels
→ List<
Label> ? -
no setterinherited
- readingTime → int?
-
Estimated reading time in minutes, if applicable and available.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → EmbedExternalViewExternalSource?
-
no setterinherited
- thumb → String?
-
no setterinherited
- title → String
-
no setterinherited
- updatedAt → DateTime?
-
When the external content was updated, if available.
no setterinherited
- uri → String
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_EmbedExternalViewExternal value)) → TResult -
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_EmbedExternalViewExternal value)?) → TResult? -
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_EmbedExternalViewExternal value)?, {required TResult orElse()}) → TResult -
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, String uri, String title, String description, String? thumb, DateTime? createdAt, DateTime? updatedAt, int? readingTime, List< Label> ? labels, EmbedExternalViewExternalSource? source, List<RepoStrongRef> ? associatedRefs, Map<String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this EmbedExternalViewExternal to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, String uri, String title, String description, String? thumb, DateTime? createdAt, DateTime? updatedAt, int? readingTime, List< Label> ? labels, EmbedExternalViewExternalSource? source, List<RepoStrongRef> ? associatedRefs, Map<String, dynamic> ? $unknown)) → TResult -
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, String uri, String title, String description, String? thumb, DateTime? createdAt, DateTime? updatedAt, int? readingTime, List< Label> ? labels, EmbedExternalViewExternalSource? source, List<RepoStrongRef> ? associatedRefs, Map<String, dynamic> ? $unknown)?) → TResult? -
Available on EmbedExternalViewExternal, provided by the EmbedExternalViewExternalPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>