readingTime property
Estimated reading time in minutes, if applicable and available.
Implementation
DateTime? get updatedAt;/// Estimated reading time in minutes, if applicable and available.
int? get readingTime;
Estimated reading time in minutes, if applicable and available.
DateTime? get updatedAt;/// Estimated reading time in minutes, if applicable and available.
int? get readingTime;