EmbedGalleryViewImage constructor
const
EmbedGalleryViewImage({
- @Default.new('app.bsky.embed.gallery#viewImage') String $type,
- required String thumbnail,
- required String fullsize,
- required String alt,
- @AspectRatioConverter() required AspectRatio aspectRatio,
- Map<
String, dynamic> ? $unknown,
Implementation
@JsonSerializable(includeIfNull: false)
const factory EmbedGalleryViewImage({
@Default('app.bsky.embed.gallery#viewImage') String $type,
/// Fully-qualified URL where a thumbnail of the image can be fetched. For example, CDN location provided by the App View.
required String thumbnail,
/// Fully-qualified URL where a large version of the image can be fetched. May or may not be the exact original blob. For example, CDN location provided by the App View.
required String fullsize,
/// Alt text description of the image, for accessibility.
required String alt,
@AspectRatioConverter() required AspectRatio aspectRatio,
Map<String, dynamic>? $unknown,
}) = _EmbedGalleryViewImage;