EmbedGetEmbedExternalViewInput class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
EmbedGetEmbedExternalViewInput({required String url, @AtUriConverter.new() required List<
AtUri> uris, Map<String, dynamic> ? $unknown}) -
constfactory
-
EmbedGetEmbedExternalViewInput.fromJson(Map<
String, Object?> json) -
factory
Properties
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
copyWith
→ $EmbedGetEmbedExternalViewInputCopyWith<
EmbedGetEmbedExternalViewInput> -
Create a copy of EmbedGetEmbedExternalViewInput
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
uris
→ List<
AtUri> -
no setterinherited
- url → String
-
The canonical web URL the embed represents (typically the URL the user pasted into the composer). Used as the returned view's
uri. May be used for validation in the future.no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_EmbedGetEmbedExternalViewInput value)) → TResult -
Available on EmbedGetEmbedExternalViewInput, provided by the EmbedGetEmbedExternalViewInputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_EmbedGetEmbedExternalViewInput value)?) → TResult? -
Available on EmbedGetEmbedExternalViewInput, provided by the EmbedGetEmbedExternalViewInputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_EmbedGetEmbedExternalViewInput value)?, {required TResult orElse()}) → TResult -
Available on EmbedGetEmbedExternalViewInput, provided by the EmbedGetEmbedExternalViewInputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String url, List< AtUri> uris, Map<String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on EmbedGetEmbedExternalViewInput, provided by the EmbedGetEmbedExternalViewInputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this EmbedGetEmbedExternalViewInput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String url, List< AtUri> uris, Map<String, dynamic> ? $unknown)) → TResult -
Available on EmbedGetEmbedExternalViewInput, provided by the EmbedGetEmbedExternalViewInputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String url, List< AtUri> uris, Map<String, dynamic> ? $unknown)?) → TResult? -
Available on EmbedGetEmbedExternalViewInput, provided by the EmbedGetEmbedExternalViewInputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>