presentation property

A hint to the client about how to present the video.

Implementation

String? get alt;@AspectRatioConverter() AspectRatio? get aspectRatio;/// A hint to the client about how to present the video.
@EmbedVideoPresentationConverter() EmbedVideoPresentation? get presentation;