presentation property
A hint to the client about how to present the video.
Implementation
String get $type; String get cid; String get playlist; String? get thumbnail; String? get alt;@AspectRatioConverter() AspectRatio? get aspectRatio;/// A hint to the client about how to present the video.
@EmbedVideoViewPresentationConverter() EmbedVideoViewPresentation? get presentation;