FeedViewPost constructor
const
FeedViewPost({
- @Default.new('app.bsky.feed.defs#feedViewPost') String $type,
- @PostViewConverter() required PostView post,
- @ReplyRefConverter() ReplyRef? reply,
- int? opThreadPostIndex,
- int? opThreadPostCount,
- @UFeedViewPostReasonConverter() UFeedViewPostReason? reason,
- String? feedContext,
- String? reqId,
- Map<
String, dynamic> ? $unknown,
Implementation
@JsonSerializable(includeIfNull: false)
const factory FeedViewPost({
@Default('app.bsky.feed.defs#feedViewPost') String $type,
@PostViewConverter() required PostView post,
@ReplyRefConverter() ReplyRef? reply,
/// The 1-indexed position of this post within the contiguous OP thread. Only present when this post is part of the OP thread.
int? opThreadPostIndex,
/// The total number of posts in the contiguous OP thread that this post belongs to. Only present when this post is part of the OP thread.
int? opThreadPostCount,
@UFeedViewPostReasonConverter() UFeedViewPostReason? reason,
/// Context provided by feed generator that may be passed back alongside interactions.
String? feedContext,
/// Unique identifier per request that may be passed back alongside interactions.
String? reqId,
Map<String, dynamic>? $unknown,
}) = _FeedViewPost;