opThreadPostIndex property
The 1-indexed position of this post within the contiguous OP thread. Only present when this post is part of the OP thread.
Implementation
String get $type;@PostViewConverter() PostView get post;@ReplyRefConverter() ReplyRef? get reply;/// The 1-indexed position of this post within the contiguous OP thread. Only present when this post is part of the OP thread.
int? get opThreadPostIndex;