GraphMuteActorInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

GraphMuteActorInput({required String actor, bool? onlyReposts, bool? onlyQuoteposts, Map<String, dynamic>? $unknown})
const
factory
GraphMuteActorInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
actor String
no setterinherited
copyWith → $GraphMuteActorInputCopyWith<GraphMuteActorInput>
Create a copy of GraphMuteActorInput with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isNotOnlyQuoteposts bool

Available on GraphMuteActorInput, provided by the GraphMuteActorInputExtension extension

no setter
isNotOnlyReposts bool

Available on GraphMuteActorInput, provided by the GraphMuteActorInputExtension extension

no setter
isOnlyQuoteposts bool

Available on GraphMuteActorInput, provided by the GraphMuteActorInputExtension extension

no setter
isOnlyReposts bool

Available on GraphMuteActorInput, provided by the GraphMuteActorInputExtension extension

no setter
onlyQuoteposts bool?
Restrict the mute to the account's quote posts. See onlyReposts.
no setterinherited
onlyReposts bool?
Restrict the mute to the account's reposts. When any 'only' scope is set, just the scoped content is muted; when none are set, the account is fully muted. Repeat calls replace the stored scope rather than adding to it.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GraphMuteActorInput value)) → TResult

Available on GraphMuteActorInput, provided by the GraphMuteActorInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GraphMuteActorInput value)?) → TResult?

Available on GraphMuteActorInput, provided by the GraphMuteActorInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GraphMuteActorInput value)?, {required TResult orElse()}) → TResult

Available on GraphMuteActorInput, provided by the GraphMuteActorInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String actor, bool? onlyReposts, bool? onlyQuoteposts, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on GraphMuteActorInput, provided by the GraphMuteActorInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GraphMuteActorInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String actor, bool? onlyReposts, bool? onlyQuoteposts, Map<String, dynamic>? $unknown)) → TResult

Available on GraphMuteActorInput, provided by the GraphMuteActorInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String actor, bool? onlyReposts, bool? onlyQuoteposts, Map<String, dynamic>? $unknown)?) → TResult?

Available on GraphMuteActorInput, provided by the GraphMuteActorInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>