starterPack property
The starter pack associated with this notification. Present when the notification is for a follow originating from a starter pack.
Implementation
@NotificationReasonConverter() NotificationReason get reason;@AtUriConverter() AtUri? get reasonSubject; Map<String, dynamic> get record;/// The starter pack associated with this notification. Present when the notification is for a follow originating from a starter pack.
@StarterPackViewBasicConverter() StarterPackViewBasic? get starterPack;