AgeassuranceService class base
app.bsky.ageassurance.*
Constructors
Properties
- ctx → ServiceContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
begin(
{required String email, required String language, required String countryCode, String? regionCode, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< State> > - Initiate Age Assurance for an account.
-
getConfig(
{String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< Config> > - Returns Age Assurance configuration for use on the client.
-
getState(
{required String countryCode, String? regionCode, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< AgeassuranceGetStateOutput> > - Returns server-computed Age Assurance state, if available, and any additional metadata needed to compute Age Assurance state client-side.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited