getState method
Returns server-computed Age Assurance state, if available, and any additional metadata needed to compute Age Assurance state client-side.
Implementation
Future<XRPCResponse<AgeassuranceGetStateOutput>> getState({
required String countryCode,
String? regionCode,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await appBskyAgeassuranceGetState(
countryCode: countryCode,
regionCode: regionCode,
$ctx: ctx,
$service: $service,
$headers: $headers,
$unknown: $unknown,
);