startUpload method
Start a multipart video upload. The declared size is exact, while optional media properties are advisory and used only for early failure; the authoritative probe runs asynchronously after upload.
Implementation
Future<XRPCResponse<VideoStartUploadOutput>> startUpload({
required int sizeBytes,
required String mimeType,
String? name,
int? durationMs,
int? width,
int? height,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await appBskyVideoStartUpload(
sizeBytes: sizeBytes,
mimeType: mimeType,
name: name,
durationMs: durationMs,
width: width,
height: height,
$ctx: ctx,
$service: $service,
$headers: $headers,
$unknown: $unknown,
);