uploadPart method
Upload one part. Parts are idempotent and may be retried or re-sent while the session is created. Each expected length is derived from the upload size and part size, and Content-Length must match exactly. ETags are never exposed to clients.
Implementation
Future<XRPCResponse<VideoUploadPartOutput>> uploadPart({
required Uint8List bytes,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $parameters,
}) async => await appBskyVideoUploadPart(
bytes: bytes,
$parameters: $parameters,
$ctx: ctx,
$service: $service,
$headers: $headers,
);