appBskyVideoUploadPart function
Upload one part. Parts are idempotent and may be retried or re-sent while the session is created. Each expected length is derived from the upload size and part size, and Content-Length must match exactly. ETags are never exposed to clients.
Implementation
Future<XRPCResponse<VideoUploadPartOutput>> appBskyVideoUploadPart({
required Uint8List bytes,
required ServiceContext $ctx,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $parameters,
}) async => await $ctx.post(
ns.appBskyVideoUploadPart,
service: $service,
headers: {'Content-type': 'application/octet-stream', ...?$headers},
parameters: $parameters,
body: bytes,
to: const VideoUploadPartOutputConverter().fromJson,
);