hiddenByThreadgate property
The threadgate created by the author indicates this post as a reply to be hidden for everyone consuming the thread.
Implementation
bool get opThread;/// The threadgate created by the author indicates this post as a reply to be hidden for everyone consuming the thread.
bool get hiddenByThreadgate;