opThreadPostCount property
The total number of posts in the contiguous OP thread that this post belongs to. Only present when this post is part of the OP thread (see opThread).
Implementation
int? get opThreadPostIndex;/// The total number of posts in the contiguous OP thread that this post belongs to. Only present when this post is part of the OP thread (see `opThread`).
int? get opThreadPostCount;