VideoGetUploadStatusOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

VideoGetUploadStatusOutput({required String jobId, required int partSizeBytes, required int partCount, required List<int> receivedParts, @JsonKey.new(toJson: iso8601) required DateTime expiresAt, @VideoGetUploadStatusStateConverter() required VideoGetUploadStatusState state, String? completedJobId, @JobStatusConverter() JobStatus? jobStatus, String? failureReason, Map<String, dynamic>? $unknown})
const
factory
VideoGetUploadStatusOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
completedJobId String?
Present only when state is completed; may differ from jobId on deduplication.
no setterinherited
copyWith → $VideoGetUploadStatusOutputCopyWith<VideoGetUploadStatusOutput>
Create a copy of VideoGetUploadStatusOutput with the given fields replaced by the non-null parameter values.
no setterinherited
expiresAt DateTime
no setterinherited
failureReason String?
Present only when state is failed.
no setterinherited
hasCompletedJobId bool

Available on VideoGetUploadStatusOutput, provided by the VideoGetUploadStatusOutputExtension extension

no setter
hasFailureReason bool

Available on VideoGetUploadStatusOutput, provided by the VideoGetUploadStatusOutputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasJobStatus bool

Available on VideoGetUploadStatusOutput, provided by the VideoGetUploadStatusOutputExtension extension

no setter
hasNotCompletedJobId bool

Available on VideoGetUploadStatusOutput, provided by the VideoGetUploadStatusOutputExtension extension

no setter
hasNotFailureReason bool

Available on VideoGetUploadStatusOutput, provided by the VideoGetUploadStatusOutputExtension extension

no setter
hasNotJobStatus bool

Available on VideoGetUploadStatusOutput, provided by the VideoGetUploadStatusOutputExtension extension

no setter
jobId String
no setterinherited
jobStatus JobStatus?
Present only when state is completed.
no setterinherited
partCount int
no setterinherited
partSizeBytes int
no setterinherited
receivedParts List<int>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state VideoGetUploadStatusState
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_VideoGetUploadStatusOutput value)) → TResult

Available on VideoGetUploadStatusOutput, provided by the VideoGetUploadStatusOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VideoGetUploadStatusOutput value)?) → TResult?

Available on VideoGetUploadStatusOutput, provided by the VideoGetUploadStatusOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VideoGetUploadStatusOutput value)?, {required TResult orElse()}) → TResult

Available on VideoGetUploadStatusOutput, provided by the VideoGetUploadStatusOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String jobId, int partSizeBytes, int partCount, List<int> receivedParts, DateTime expiresAt, VideoGetUploadStatusState state, String? completedJobId, JobStatus? jobStatus, String? failureReason, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on VideoGetUploadStatusOutput, provided by the VideoGetUploadStatusOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this VideoGetUploadStatusOutput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String jobId, int partSizeBytes, int partCount, List<int> receivedParts, DateTime expiresAt, VideoGetUploadStatusState state, String? completedJobId, JobStatus? jobStatus, String? failureReason, Map<String, dynamic>? $unknown)) → TResult

Available on VideoGetUploadStatusOutput, provided by the VideoGetUploadStatusOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String jobId, int partSizeBytes, int partCount, List<int> receivedParts, DateTime expiresAt, VideoGetUploadStatusState state, String? completedJobId, JobStatus? jobStatus, String? failureReason, Map<String, dynamic>? $unknown)?) → TResult?

Available on VideoGetUploadStatusOutput, provided by the VideoGetUploadStatusOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>