IdentityResolver class abstract interface

Resolves a handle or DID to its atproto identity.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(String identity) Future<ResolvedIdentity>
Resolves a handle (alice.example, optionally @/at:// prefixed) or a DID (did:plc: / did:web:) to its atproto identity.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited