ResolvedIdentity class final

The outcome of resolving a handle or DID to its atproto identity.

Constructors

ResolvedIdentity({required String did, required String pds, required String handle, String? signingKey})
const

Properties

did String
The account DID.
final
handle String
The account's bidirectionally verified handle, or handleInvalid when it has none that verifies.
final
hashCode int
The hash code for this object.
no setterinherited
pds String
The PDS origin (https://host[:port], no trailing slash).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signingKey String?
The #atproto verification method's publicKeyMultibase, when present in the DID document; otherwise null.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited