ResolvedIdentity class final
The outcome of resolving a handle or DID to its atproto identity.
Constructors
- ResolvedIdentity({required String did, required String pds, String? handle, String? signingKey})
-
const
Properties
- did → String
-
The account DID.
final
- handle → String?
-
The handle, when resolution started from one; otherwise
null.final - hashCode → int
-
The hash code for this object.
no setterinherited
- pds → String
-
The PDS origin (
https://host[:port], no trailing slash).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signingKey → String?
-
The
#atprotoverification method'spublicKeyMultibase, when present in the DID document; otherwisenull.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited