GroupedNotification class abstract
The class that encapsulates a grouped notification.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
GroupedNotification({@AtUriConverter.new() required List<
AtUri> uris, required List<ProfileView> authors, required GroupedNotificationReason reason, @AtUriConverter.new() AtUri? reasonSubject, required bool isRead, required List<Label> labels, Map<String, dynamic> ? record, required DateTime indexedAt}) -
Creates a new instance of GroupedNotification.
constfactory
-
GroupedNotification.fromJson(Map<
String, Object?> json) -
factory
Properties
-
The collection of authors causing the notification.
no setterinherited
-
copyWith
→ $GroupedNotificationCopyWith<
GroupedNotification> -
Create a copy of GroupedNotification
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexedAt → DateTime
-
Indicates the timestamp at which the notification was indexed.
no setterinherited
- isRead → bool
-
Indicates whether the notification has been read or not.
no setterinherited
-
labels
→ List<
Label> -
May include any labels attached to the notification.
no setterinherited
- reason → GroupedNotificationReason
-
Specifies the reason for the notification.
no setterinherited
- reasonSubject → AtUri?
-
Optionally, represents the subject of the reason for the notification.
no setterinherited
-
record
→ Map<
String, dynamic> ? -
Might include additional data related to the notification.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → AtUri?
-
Available on GroupedNotification, provided by the GroupedNotificationExtension extension
Returns the post url related to this notification.no setter -
uris
→ List<
AtUri> -
The unique URI for the notification content.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_GroupedNotification value)) → TResult -
Available on GroupedNotification, provided by the GroupedNotificationPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_GroupedNotification value)?) → TResult? -
Available on GroupedNotification, provided by the GroupedNotificationPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_GroupedNotification value)?, {required TResult orElse()}) → TResult -
Available on GroupedNotification, provided by the GroupedNotificationPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(List< AtUri> uris, List<ProfileView> authors, GroupedNotificationReason reason, AtUri? reasonSubject, bool isRead, List<Label> labels, Map<String, dynamic> ? record, DateTime indexedAt)?, {required TResult orElse()}) → TResult -
Available on GroupedNotification, provided by the GroupedNotificationPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this GroupedNotification to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(List< AtUri> uris, List<ProfileView> authors, GroupedNotificationReason reason, AtUri? reasonSubject, bool isRead, List<Label> labels, Map<String, dynamic> ? record, DateTime indexedAt)) → TResult -
Available on GroupedNotification, provided by the GroupedNotificationPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(List< AtUri> uris, List<ProfileView> authors, GroupedNotificationReason reason, AtUri? reasonSubject, bool isRead, List<Label> labels, Map<String, dynamic> ? record, DateTime indexedAt)?) → TResult? -
Available on GroupedNotification, provided by the GroupedNotificationPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited