likelyType property
The likely type of the resource cardyb attempted to extract
(e.g. html), mapped from the likely_type field.
Implementation
String? get error;/// The likely type of the resource cardyb attempted to extract
/// (e.g. `html`), mapped from the `likely_type` field.
@JsonKey(name: 'likely_type') String? get likelyType;