ActorGetStatusOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ActorGetStatusOutput({required bool chatDisabled, required bool canCreateGroups, Map<String, dynamic>? $unknown})
const
factory
ActorGetStatusOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
canCreateGroups bool
Whether the viewer's account is allowed to create group chats. New accounts are restricted from creating groups.
no setterinherited
chatDisabled bool
True when the viewer's account is disabled and cannot actively participate in chat.
no setterinherited
copyWith → $ActorGetStatusOutputCopyWith<ActorGetStatusOutput>
Create a copy of ActorGetStatusOutput with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isCanCreateGroups bool

Available on ActorGetStatusOutput, provided by the ActorGetStatusOutputExtension extension

no setter
isChatDisabled bool

Available on ActorGetStatusOutput, provided by the ActorGetStatusOutputExtension extension

no setter
isNotCanCreateGroups bool

Available on ActorGetStatusOutput, provided by the ActorGetStatusOutputExtension extension

no setter
isNotChatDisabled bool

Available on ActorGetStatusOutput, provided by the ActorGetStatusOutputExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ActorGetStatusOutput value)) → TResult

Available on ActorGetStatusOutput, provided by the ActorGetStatusOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ActorGetStatusOutput value)?) → TResult?

Available on ActorGetStatusOutput, provided by the ActorGetStatusOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ActorGetStatusOutput value)?, {required TResult orElse()}) → TResult

Available on ActorGetStatusOutput, provided by the ActorGetStatusOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool chatDisabled, bool canCreateGroups, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ActorGetStatusOutput, provided by the ActorGetStatusOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ActorGetStatusOutput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool chatDisabled, bool canCreateGroups, Map<String, dynamic>? $unknown)) → TResult

Available on ActorGetStatusOutput, provided by the ActorGetStatusOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool chatDisabled, bool canCreateGroups, Map<String, dynamic>? $unknown)?) → TResult?

Available on ActorGetStatusOutput, provided by the ActorGetStatusOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>