MessageInput constructor
const
MessageInput({
- @Default.new('chat.bsky.convo.defs#messageInput') String $type,
- required String text,
- @RichtextFacetConverter() List<
RichtextFacet> ? facets, - @UMessageInputEmbedConverter() UMessageInputEmbed? embed,
- @ReplyRefConverter() ReplyRef? replyTo,
- Map<
String, dynamic> ? $unknown,
Implementation
@JsonSerializable(includeIfNull: false)
const factory MessageInput({
@Default('chat.bsky.convo.defs#messageInput') String $type,
required String text,
@RichtextFacetConverter() List<RichtextFacet>? facets,
@UMessageInputEmbedConverter() UMessageInputEmbed? embed,
/// If set, the message this message is replying to. The referenced message must be in the same convo.
@ReplyRefConverter() ReplyRef? replyTo,
Map<String, dynamic>? $unknown,
}) = _MessageInput;