replyTo property
If set, the message this message is replying to. The referenced message must be in the same convo.
Implementation
String get $type; String get text;@RichtextFacetConverter() List<RichtextFacet>? get facets;@UMessageInputEmbedConverter() UMessageInputEmbed? get embed;/// If set, the message this message is replying to. The referenced message must be in the same convo.
@ReplyRefConverter() ReplyRef? get replyTo;