SystemMessageDataEditGroup class abstract

NOTE: This is under active development and should be considered unstable while this note is here. System message indicating the group info was edited.

Available extensions
Annotations
  • @freezed

Constructors

SystemMessageDataEditGroup({@Default.new('chat.bsky.convo.defs#systemMessageDataEditGroup') String $type, String? oldName, String? newName, Map<String, dynamic>? $unknown})
const
factory
SystemMessageDataEditGroup.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
copyWith → $SystemMessageDataEditGroupCopyWith<SystemMessageDataEditGroup>
Create a copy of SystemMessageDataEditGroup with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasNewName bool

Available on SystemMessageDataEditGroup, provided by the SystemMessageDataEditGroupExtension extension

no setter
hasNotNewName bool

Available on SystemMessageDataEditGroup, provided by the SystemMessageDataEditGroupExtension extension

no setter
hasNotOldName bool

Available on SystemMessageDataEditGroup, provided by the SystemMessageDataEditGroupExtension extension

no setter
hasOldName bool

Available on SystemMessageDataEditGroup, provided by the SystemMessageDataEditGroupExtension extension

no setter
newName String?
Group name that replaced the old.
no setterinherited
oldName String?
Group name that was replaced.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SystemMessageDataEditGroup value)) → TResult

Available on SystemMessageDataEditGroup, provided by the SystemMessageDataEditGroupPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SystemMessageDataEditGroup value)?) → TResult?

Available on SystemMessageDataEditGroup, provided by the SystemMessageDataEditGroupPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SystemMessageDataEditGroup value)?, {required TResult orElse()}) → TResult

Available on SystemMessageDataEditGroup, provided by the SystemMessageDataEditGroupPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String? oldName, String? newName, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on SystemMessageDataEditGroup, provided by the SystemMessageDataEditGroupPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SystemMessageDataEditGroup to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String? oldName, String? newName, Map<String, dynamic>? $unknown)) → TResult

Available on SystemMessageDataEditGroup, provided by the SystemMessageDataEditGroupPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String? oldName, String? newName, Map<String, dynamic>? $unknown)?) → TResult?

Available on SystemMessageDataEditGroup, provided by the SystemMessageDataEditGroupPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>