SystemMessageDataMemberJoin class abstract

NOTE: This is under active development and should be considered unstable while this note is here. System message indicating a user joined the group convo via join link.

Available extensions
Annotations
  • @freezed

Constructors

SystemMessageDataMemberJoin({@Default.new('chat.bsky.convo.defs#systemMessageDataMemberJoin') String $type, @SystemMessageReferredUserConverter() required SystemMessageReferredUser member, @MemberRoleConverter() required MemberRole role, @SystemMessageReferredUserConverter() SystemMessageReferredUser? approvedBy, Map<String, dynamic>? $unknown})
const
factory
SystemMessageDataMemberJoin.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
approvedBy SystemMessageReferredUser?
If join link was configured to require approval, this will be set to who approved the request. Undefined if approval was not required.
no setterinherited
copyWith → $SystemMessageDataMemberJoinCopyWith<SystemMessageDataMemberJoin>
Create a copy of SystemMessageDataMemberJoin with the given fields replaced by the non-null parameter values.
no setterinherited
hasApprovedBy bool

Available on SystemMessageDataMemberJoin, provided by the SystemMessageDataMemberJoinExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotApprovedBy bool

Available on SystemMessageDataMemberJoin, provided by the SystemMessageDataMemberJoinExtension extension

no setter
member SystemMessageReferredUser
Current view of the member who joined.
no setterinherited
role MemberRole
Role the user was added to the group with. The role from 'member' will reflect the current data, not historical.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SystemMessageDataMemberJoin value)) → TResult

Available on SystemMessageDataMemberJoin, provided by the SystemMessageDataMemberJoinPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SystemMessageDataMemberJoin value)?) → TResult?

Available on SystemMessageDataMemberJoin, provided by the SystemMessageDataMemberJoinPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SystemMessageDataMemberJoin value)?, {required TResult orElse()}) → TResult

Available on SystemMessageDataMemberJoin, provided by the SystemMessageDataMemberJoinPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, SystemMessageReferredUser member, MemberRole role, SystemMessageReferredUser? approvedBy, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on SystemMessageDataMemberJoin, provided by the SystemMessageDataMemberJoinPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SystemMessageDataMemberJoin to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, SystemMessageReferredUser member, MemberRole role, SystemMessageReferredUser? approvedBy, Map<String, dynamic>? $unknown)) → TResult

Available on SystemMessageDataMemberJoin, provided by the SystemMessageDataMemberJoinPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, SystemMessageReferredUser member, MemberRole role, SystemMessageReferredUser? approvedBy, Map<String, dynamic>? $unknown)?) → TResult?

Available on SystemMessageDataMemberJoin, provided by the SystemMessageDataMemberJoinPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>