member property
Current view of the member who left the group.
Implementation
String get $type;/// Current view of the member who left the group.
@SystemMessageReferredUserConverter() SystemMessageReferredUser get member;
Current view of the member who left the group.
String get $type;/// Current view of the member who left the group.
@SystemMessageReferredUserConverter() SystemMessageReferredUser get member;