GroupCreateJoinLinkInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

GroupCreateJoinLinkInput({required String convoId, @Default.new(false) bool requireApproval, @JoinRuleConverter() required JoinRule joinRule, Map<String, dynamic>? $unknown})
const
factory
GroupCreateJoinLinkInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
convoId String
no setterinherited
copyWith → $GroupCreateJoinLinkInputCopyWith<GroupCreateJoinLinkInput>
Create a copy of GroupCreateJoinLinkInput with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isNotRequireApproval bool

Available on GroupCreateJoinLinkInput, provided by the GroupCreateJoinLinkInputExtension extension

no setter
isRequireApproval bool

Available on GroupCreateJoinLinkInput, provided by the GroupCreateJoinLinkInputExtension extension

no setter
joinRule JoinRule
no setterinherited
requireApproval bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GroupCreateJoinLinkInput value)) → TResult

Available on GroupCreateJoinLinkInput, provided by the GroupCreateJoinLinkInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GroupCreateJoinLinkInput value)?) → TResult?

Available on GroupCreateJoinLinkInput, provided by the GroupCreateJoinLinkInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GroupCreateJoinLinkInput value)?, {required TResult orElse()}) → TResult

Available on GroupCreateJoinLinkInput, provided by the GroupCreateJoinLinkInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String convoId, bool requireApproval, JoinRule joinRule, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on GroupCreateJoinLinkInput, provided by the GroupCreateJoinLinkInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GroupCreateJoinLinkInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String convoId, bool requireApproval, JoinRule joinRule, Map<String, dynamic>? $unknown)) → TResult

Available on GroupCreateJoinLinkInput, provided by the GroupCreateJoinLinkInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String convoId, bool requireApproval, JoinRule joinRule, Map<String, dynamic>? $unknown)?) → TResult?

Available on GroupCreateJoinLinkInput, provided by the GroupCreateJoinLinkInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>