JoinLinkView class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
JoinLinkView({@Default.new('chat.bsky.group.defs#joinLinkView') String $type, required String code, @LinkEnabledStatusConverter() required LinkEnabledStatus enabledStatus, required bool requireApproval, @JoinRuleConverter() required JoinRule joinRule, required DateTime createdAt, Map<
String, dynamic> ? $unknown}) -
constfactory
-
JoinLinkView.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
- code → String
-
no setterinherited
-
copyWith
→ $JoinLinkViewCopyWith<
JoinLinkView> -
Create a copy of JoinLinkView
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime
-
no setterinherited
- enabledStatus → LinkEnabledStatus
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotRequireApproval → bool
-
Available on JoinLinkView, provided by the JoinLinkViewExtension extension
no setter - isRequireApproval → bool
-
Available on JoinLinkView, provided by the JoinLinkViewExtension extension
no setter - joinRule → JoinRule
-
no setterinherited
- requireApproval → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_JoinLinkView value)) → TResult -
Available on JoinLinkView, provided by the JoinLinkViewPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_JoinLinkView value)?) → TResult? -
Available on JoinLinkView, provided by the JoinLinkViewPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_JoinLinkView value)?, {required TResult orElse()}) → TResult -
Available on JoinLinkView, provided by the JoinLinkViewPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, String code, LinkEnabledStatus enabledStatus, bool requireApproval, JoinRule joinRule, DateTime createdAt, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on JoinLinkView, provided by the JoinLinkViewPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this JoinLinkView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, String code, LinkEnabledStatus enabledStatus, bool requireApproval, JoinRule joinRule, DateTime createdAt, Map< String, dynamic> ? $unknown)) → TResult -
Available on JoinLinkView, provided by the JoinLinkViewPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, String code, LinkEnabledStatus enabledStatus, bool requireApproval, JoinRule joinRule, DateTime createdAt, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on JoinLinkView, provided by the JoinLinkViewPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>