ModerationGetMessageContextInput class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
ModerationGetMessageContextInput({String? convoId, required String messageId, @Default.new(5) int before, @Default.new(5) int after, @Default.new(10) int maxInterleavedSystemMessages, Map<
String, dynamic> ? $unknown}) -
constfactory
-
ModerationGetMessageContextInput.fromJson(Map<
String, Object?> json) -
factory
Properties
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
- after → int
-
Number of user messages after the target to include. System messages between the target and the latest returned user message are also included, capped per gap by
maxInterleavedSystemMessages. If there are no user messages after the target, up tomaxInterleavedSystemMessagessystem messages immediately following the target are returned instead.no setterinherited - before → int
-
Number of user messages before the target to include. System messages between the earliest returned user message and the target are also included, capped per gap by
maxInterleavedSystemMessages. If there are no user messages before the target, up tomaxInterleavedSystemMessagessystem messages immediately preceding the target are returned instead.no setterinherited - convoId → String?
-
Conversation that the message is from. NOTE: this field will eventually be required.
no setterinherited
-
copyWith
→ $ModerationGetMessageContextInputCopyWith<
ModerationGetMessageContextInput> -
Create a copy of ModerationGetMessageContextInput
with the given fields replaced by the non-null parameter values.
no setterinherited
- hasConvoId → bool
-
Available on ModerationGetMessageContextInput, provided by the ModerationGetMessageContextInputExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotConvoId → bool
-
Available on ModerationGetMessageContextInput, provided by the ModerationGetMessageContextInputExtension extension
no setter - maxInterleavedSystemMessages → int
-
Maximum number of system messages to include per gap between consecutive returned messages (and per side when there are no user messages on that side). Within a gap, the system messages closest to the earlier message are kept.
no setterinherited
- messageId → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ModerationGetMessageContextInput value)) → TResult -
Available on ModerationGetMessageContextInput, provided by the ModerationGetMessageContextInputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ModerationGetMessageContextInput value)?) → TResult? -
Available on ModerationGetMessageContextInput, provided by the ModerationGetMessageContextInputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ModerationGetMessageContextInput value)?, {required TResult orElse()}) → TResult -
Available on ModerationGetMessageContextInput, provided by the ModerationGetMessageContextInputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? convoId, String messageId, int before, int after, int maxInterleavedSystemMessages, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on ModerationGetMessageContextInput, provided by the ModerationGetMessageContextInputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ModerationGetMessageContextInput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? convoId, String messageId, int before, int after, int maxInterleavedSystemMessages, Map< String, dynamic> ? $unknown)) → TResult -
Available on ModerationGetMessageContextInput, provided by the ModerationGetMessageContextInputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? convoId, String messageId, int before, int after, int maxInterleavedSystemMessages, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on ModerationGetMessageContextInput, provided by the ModerationGetMessageContextInputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>