after property
Number of user messages after the target to include. System messages between the target and the latest returned user message are also included, capped per gap by maxInterleavedSystemMessages. If there are no user messages after the target, up to maxInterleavedSystemMessages system messages immediately following the target are returned instead.
Implementation
int get before;/// Number of user messages after the target to include. System messages between the target and the latest returned user message are also included, capped per gap by `maxInterleavedSystemMessages`. If there are no user messages after the target, up to `maxInterleavedSystemMessages` system messages immediately following the target are returned instead.
int get after;