EventConvoFirstMessage class abstract
Fired when the first message was sent on a convo.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
EventConvoFirstMessage({@Default.new('chat.bsky.moderation.subscribeModEvents#eventConvoFirstMessage') String $type, required String convoId, required DateTime createdAt, String? messageId, required List<
String> recipients, required String rev, required String user, Map<String, dynamic> ? $unknown}) -
constfactory
-
EventConvoFirstMessage.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
- convoId → String
-
no setterinherited
-
copyWith
→ $EventConvoFirstMessageCopyWith<
EventConvoFirstMessage> -
Create a copy of EventConvoFirstMessage
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMessageId → bool
-
Available on EventConvoFirstMessage, provided by the EventConvoFirstMessageExtension extension
no setter - hasNotMessageId → bool
-
Available on EventConvoFirstMessage, provided by the EventConvoFirstMessageExtension extension
no setter - messageId → String?
-
no setterinherited
-
recipients
→ List<
String> -
no setterinherited
- rev → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → String
-
The DID of the message author.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_EventConvoFirstMessage value)) → TResult -
Available on EventConvoFirstMessage, provided by the EventConvoFirstMessagePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_EventConvoFirstMessage value)?) → TResult? -
Available on EventConvoFirstMessage, provided by the EventConvoFirstMessagePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_EventConvoFirstMessage value)?, {required TResult orElse()}) → TResult -
Available on EventConvoFirstMessage, provided by the EventConvoFirstMessagePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, String convoId, DateTime createdAt, String? messageId, List< String> recipients, String rev, String user, Map<String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on EventConvoFirstMessage, provided by the EventConvoFirstMessagePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this EventConvoFirstMessage to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, String convoId, DateTime createdAt, String? messageId, List< String> recipients, String rev, String user, Map<String, dynamic> ? $unknown)) → TResult -
Available on EventConvoFirstMessage, provided by the EventConvoFirstMessagePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, String convoId, DateTime createdAt, String? messageId, List< String> recipients, String rev, String user, Map<String, dynamic> ? $unknown)?) → TResult? -
Available on EventConvoFirstMessage, provided by the EventConvoFirstMessagePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>