EventGroupChatJoinRequest class abstract
Fired when a user requests to join a group chat via an join link that requires approval.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
EventGroupChatJoinRequest({@Default.new('chat.bsky.moderation.subscribeModEvents#eventGroupChatJoinRequest') String $type, required String actorDid, required DateTime convoCreatedAt, required String convoId, required DateTime createdAt, required int groupMemberCount, required String groupName, required String joinLinkCode, required String ownerDid, required String rev, required bool subjectFollowsOwner, Map<
String, dynamic> ? $unknown}) -
constfactory
-
EventGroupChatJoinRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
- actorDid → String
-
The DID of the person requesting to join.
no setterinherited
- convoCreatedAt → DateTime
-
When the group was originally created.
no setterinherited
- convoId → String
-
no setterinherited
-
copyWith
→ $EventGroupChatJoinRequestCopyWith<
EventGroupChatJoinRequest> -
Create a copy of EventGroupChatJoinRequest
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime
-
no setterinherited
- groupMemberCount → int
-
Current member count at the time of the event.
no setterinherited
- groupName → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotSubjectFollowsOwner → bool
-
Available on EventGroupChatJoinRequest, provided by the EventGroupChatJoinRequestExtension extension
no setter - isSubjectFollowsOwner → bool
-
Available on EventGroupChatJoinRequest, provided by the EventGroupChatJoinRequestExtension extension
no setter - joinLinkCode → String
-
The code of the join link used to request joining.
no setterinherited
- ownerDid → String
-
The DID of the group chat owner.
no setterinherited
- rev → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subjectFollowsOwner → bool
-
Whether the requesting member follows the group owner.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_EventGroupChatJoinRequest value)) → TResult -
Available on EventGroupChatJoinRequest, provided by the EventGroupChatJoinRequestPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_EventGroupChatJoinRequest value)?) → TResult? -
Available on EventGroupChatJoinRequest, provided by the EventGroupChatJoinRequestPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_EventGroupChatJoinRequest value)?, {required TResult orElse()}) → TResult -
Available on EventGroupChatJoinRequest, provided by the EventGroupChatJoinRequestPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, String actorDid, DateTime convoCreatedAt, String convoId, DateTime createdAt, int groupMemberCount, String groupName, String joinLinkCode, String ownerDid, String rev, bool subjectFollowsOwner, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on EventGroupChatJoinRequest, provided by the EventGroupChatJoinRequestPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this EventGroupChatJoinRequest to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, String actorDid, DateTime convoCreatedAt, String convoId, DateTime createdAt, int groupMemberCount, String groupName, String joinLinkCode, String ownerDid, String rev, bool subjectFollowsOwner, Map< String, dynamic> ? $unknown)) → TResult -
Available on EventGroupChatJoinRequest, provided by the EventGroupChatJoinRequestPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, String actorDid, DateTime convoCreatedAt, String convoId, DateTime createdAt, int groupMemberCount, String groupName, String joinLinkCode, String ownerDid, String rev, bool subjectFollowsOwner, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on EventGroupChatJoinRequest, provided by the EventGroupChatJoinRequestPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>