groupMemberCount property

int get groupMemberCount
inherited

Current member count at the time of the event.

Implementation

@JsonKey(toJson: iso8601) DateTime get convoCreatedAt; String get convoId;@JsonKey(toJson: iso8601) DateTime get createdAt;/// Current member count at the time of the event.
 int get groupMemberCount;