joinLinkCode property
The code of the join link used to join.
Implementation
int get groupMemberCount; String get groupName;/// The code of the join link used to join.
String get joinLinkCode;
The code of the join link used to join.
int get groupMemberCount; String get groupName;/// The code of the join link used to join.
String get joinLinkCode;