joinLinkRequiresApproval property
Whether the join link requires owner approval to join. Only present when updateType is join-link-related.
Implementation
bool? get joinLinkFollowersOnly;/// Whether the join link requires owner approval to join. Only present when updateType is join-link-related.
bool? get joinLinkRequiresApproval;