KnownEventGroupChatUpdatedUpdateType enum
- Inheritance
- Implemented types
- Available extensions
Values
- name_changed → const KnownEventGroupChatUpdatedUpdateType
-
const KnownEventGroupChatUpdatedUpdateType('name_changed') - locked → const KnownEventGroupChatUpdatedUpdateType
-
const KnownEventGroupChatUpdatedUpdateType('locked') - locked_permanently → const KnownEventGroupChatUpdatedUpdateType
-
const KnownEventGroupChatUpdatedUpdateType('locked_permanently') - unlocked → const KnownEventGroupChatUpdatedUpdateType
-
const KnownEventGroupChatUpdatedUpdateType('unlocked') - join_link_created → const KnownEventGroupChatUpdatedUpdateType
-
const KnownEventGroupChatUpdatedUpdateType('join_link_created') - join_link_disabled → const KnownEventGroupChatUpdatedUpdateType
-
const KnownEventGroupChatUpdatedUpdateType('join_link_disabled') - join_link_settings_changed → const KnownEventGroupChatUpdatedUpdateType
-
const KnownEventGroupChatUpdatedUpdateType('join_link_settings_changed')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Returns the value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isKnownValue(
String value) → bool -
valueOf(
String? value) → KnownEventGroupChatUpdatedUpdateType?
Constants
-
values
→ const List<
KnownEventGroupChatUpdatedUpdateType> - A constant List of the values in this enum, in order of their declaration.