ModerationSubscribeModEventsInput constructor
- @JsonSerializable.new(includeIfNull: false)
const
ModerationSubscribeModEventsInput(
{ - String? cursor,
- Map<String, dynamic>? $unknown,
})
Implementation
@JsonSerializable(includeIfNull: false)
const factory ModerationSubscribeModEventsInput({
/// The last known event seq number to backfill from. Use '2222222222222' to backfill from the beginning. Don't specify a cursor to listen only for new events.
String? cursor,
Map<String, dynamic>? $unknown,
}) = _ModerationSubscribeModEventsInput;