ConvoService class base
chat.bsky.convo.*
Constructors
Properties
- ctx → ServiceContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acceptConvo(
{required String convoId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoAcceptConvoOutput> > - Marks a conversation as accepted, so it is shown in the list of accepted convos instead on the request convos.
-
addReaction(
{required String convoId, required String messageId, required String value, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoAddReactionOutput> > - Adds an emoji reaction to a message. Requires authentication. It is idempotent, so multiple calls from the same user with the same emoji result in a single reaction.
-
deleteMessageForSelf(
{required String convoId, required String messageId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< DeletedMessageView> > - Marks a message as deleted for the viewer, so they won't see that message in future enumerations.
-
getConvo(
{required String convoId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoGetConvoOutput> > - Gets an existing conversation by its ID.
-
getConvoAvailability(
{required List< String> members, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoGetConvoAvailabilityOutput> > - Check whether the requester and the other members can start a 1-1 chat. Only applicable to direct (non-group) conversations. If an existing convo is found for these members, it is returned. Does not create a new convo if it doesn't exist.
-
getConvoForMembers(
{required List< String> members, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoGetConvoForMembersOutput> > - Get or create a 1-1 conversation for the given members. Always returns the same direct (non-group) conversation. To create a group conversation, use createGroup.
-
getConvoMembers(
{required String convoId, int? limit, String? cursor, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoGetConvoMembersOutput> > - Returns a paginated list of members from a conversation.
-
getLog(
{String? cursor, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoGetLogOutput> > -
getMessages(
{required String convoId, int? limit, String? cursor, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoGetMessagesOutput> > - Returns a page of messages from a conversation.
-
leaveConvo(
{required String convoId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoLeaveConvoOutput> > - Leaves a conversation (direct or group). For group, this effectively removes membership. For direct, membership is never removed, only changed to remove from enumerations by the user who left.
-
listConvoRequests(
{int? limit, String? cursor, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoListConvoRequestsOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Returns a page of incoming conversation requests for the user. Direct convo requests are returned as convoView; group join requests are returned as joinRequestView. -
listConvos(
{int? limit, String? cursor, ConvoListConvosReadState? readState, ConvoListConvosStatus? status, ConvoListConvosKind? kind, ConvoListConvosLockStatus? lockStatus, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoListConvosOutput> > - Returns a page of conversations (direct or group) for the user.
-
lockConvo(
{required String convoId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoLockConvoOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Locks a group convo so no more content (messages, reactions) can be added to it. -
muteConvo(
{required String convoId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoMuteConvoOutput> > - Mutes a conversation, preventing notifications related to it.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeReaction(
{required String convoId, required String messageId, required String value, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoRemoveReactionOutput> > - Removes an emoji reaction from a message. Requires authentication. It is idempotent, so multiple calls from the same user with the same emoji result in that reaction not being present, even if it already wasn't.
-
sendMessage(
{required String convoId, required MessageInput message, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< MessageView> > - Sends a message to a conversation.
-
sendMessageBatch(
{required List< BatchItem> items, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoSendMessageBatchOutput> > - Sends a batch of messages to a conversation.
-
toString(
) → String -
A string representation of this object.
inherited
-
unlockConvo(
{required String convoId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoUnlockConvoOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Unlocks a group convo so it is able to receive new content. -
unmuteConvo(
{required String convoId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoUnmuteConvoOutput> > - Unmutes a conversation, allowing notifications related to it.
-
updateAllRead(
{ConvoUpdateAllReadStatus? status, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoUpdateAllReadOutput> > - Sets conversations from a user as read to the latest message, with filters.
-
updateRead(
{required String convoId, String? messageId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ConvoUpdateReadOutput> > - Updates the read state of a conversation from, optionally specifying the last read message.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited