GroupService class base
chat.bsky.group.*
Constructors
Properties
- ctx → ServiceContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addMembers(
{required String convoId, required List< String> members, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupAddMembersOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Adds members to a group. The members are added in 'request' status, so they have to accept it. This creates convo memberships. -
approveJoinRequest(
{required String convoId, required String member, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupApproveJoinRequestOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Approves a request to join a group (via join link) the user owns. Action taken by the group owner. -
createGroup(
{required List< String> members, required String name, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupCreateGroupOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Creates a group convo, specifying the members to be added to it. Unlike getConvoForMembers, this isn't idempotent. It will create new groups even if the membership is identical to pre-existing groups. Will create 'pending' membership for all members, except the owner who is 'accepted'. -
createJoinLink(
{required String convoId, bool? requireApproval, required JoinRule joinRule, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupCreateJoinLinkOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Creates a join link for the group convo. -
disableJoinLink(
{required String convoId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupDisableJoinLinkOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Disables the active join link for the group convo. -
editGroup(
{required String convoId, required String name, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupEditGroupOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Edits group settings. -
editJoinLink(
{required String convoId, bool? requireApproval, JoinRule? joinRule, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupEditJoinLinkOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Edits the existing join link settings for the group convo. -
enableJoinLink(
{required String convoId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupEnableJoinLinkOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Re-enables a previously disabled join link for the group convo. -
getJoinLinkPreview(
{required String code, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupGetJoinLinkPreviewOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Get public information about a group from an join link. -
listJoinRequests(
{required String convoId, int? limit, String? cursor, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupListJoinRequestsOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Lists a page of request to join a group (via join link) the user owns. Shows the data from the owner's point of view. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rejectJoinRequest(
{required String convoId, required String member, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< EmptyData> > -
NOTE: This is under active development and should be considered unstable while this note is here. Rejects a request to join a group (via join link) the user owns. Action taken by the group owner. -
removeMembers(
{required String convoId, required List< String> members, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupRemoveMembersOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Removes members from a group. This deletes convo memberships, doesn't just set a status. -
requestJoin(
{required String code, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< GroupRequestJoinOutput> > -
NOTE: This is under active development and should be considered unstable while this note is here. Sends a request to join a group (via join link) to the group owner. Action taken by the prospective group member. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited