listJoinRequests method
NOTE: This is under active development and should be considered unstable while this note is here. Lists a page of request to join a group (via join link) the user owns. Shows the data from the owner's point of view.
Implementation
Future<XRPCResponse<GroupListJoinRequestsOutput>> listJoinRequests({
required String convoId,
int? limit,
String? cursor,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await chatBskyGroupListJoinRequests(
convoId: convoId,
limit: limit,
cursor: cursor,
$ctx: ctx,
$service: $service,
$headers: $headers,
$unknown: $unknown,
);