chatBskyGroupGetJoinLinkPreview function
NOTE: This is under active development and should be considered unstable while this note is here. Get public information about a group from an join link.
Implementation
Future<XRPCResponse<GroupGetJoinLinkPreviewOutput>>
chatBskyGroupGetJoinLinkPreview({
required String code,
required ServiceContext $ctx,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await $ctx.get(
ns.chatBskyGroupGetJoinLinkPreview,
service: $service,
headers: $headers,
parameters: {...?$unknown, 'code': code},
to: const GroupGetJoinLinkPreviewOutputConverter().fromJson,
);