chatBskyGroupGetJoinLinkPreviews function
NOTE: This is under active development and should be considered unstable while this note is here. Get public information about groups from join links. Invalid or disabled codes are silently omitted from results.
Implementation
Future<XRPCResponse<GroupGetJoinLinkPreviewsOutput>>
chatBskyGroupGetJoinLinkPreviews({
required List<String> codes,
required ServiceContext $ctx,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await $ctx.get(
ns.chatBskyGroupGetJoinLinkPreviews,
service: $service,
headers: $headers,
parameters: {...?$unknown, 'codes': codes},
to: const GroupGetJoinLinkPreviewsOutputConverter().fromJson,
);