chatBskyGroupListJoinRequests function
NOTE: This is under active development and should be considered unstable while this note is here. Lists a page of request to join a group (via join link) the user owns. Shows the data from the owner's point of view.
Implementation
Future<XRPCResponse<GroupListJoinRequestsOutput>>
chatBskyGroupListJoinRequests({
required String convoId,
int? limit,
String? cursor,
required ServiceContext $ctx,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await $ctx.get(
ns.chatBskyGroupListJoinRequests,
service: $service,
headers: $headers,
parameters: {
...?$unknown,
'convoId': convoId,
if (limit != null) 'limit': limit,
if (cursor != null) 'cursor': cursor,
},
to: const GroupListJoinRequestsOutputConverter().fromJson,
);