blobUploadLimit property
Maximum size of a blob that can be uploaded via com.atproto.repo.uploadBlob, in bytes.
Implementation
bool? get phoneVerificationRequired;/// Maximum size of a blob that can be uploaded via com.atproto.repo.uploadBlob, in bytes.
int? get blobUploadLimit;