core library
Classes
- AtUri
- This is the Dart implementation of AT Uri in AT Protocol.
- Blob
- https://atproto.com/specs/data-model#blob-type
- BlobConverter
- BlobRef
- https://atproto.com/specs/data-model#blob-type
- CID
- This is a simple implementation of V1 CID, or a content identifier. CID is a label used to point to material in IPFS.
- EmptyData
- An object representing a state that is empty instead of null.
- Jitter
- Jwt
- NSID
- This is the Dart implementation of NSID in AT Protocol.
- RateLimit
- Represents the rate limit applied to an API or a service.
- RateLimitPolicy
- Represents a policy for rate limiting.
- RetryConfig
- The default RetryStrategy: capped exponential backoff with jitter and an idempotency-safe retry decision.
- RetryContext
- The information a RetryStrategy uses to decide whether—and how long after—a failed request should be retried.
- RetryEvent
- This class represents the event during the retry process.
- RetryStrategy
- A pluggable policy that decides whether a failed request is retried and how long to wait before the next attempt.
- Serializable
- ServiceContext
- Session
- Represents a user session.
-
Subscription<
T> - XRPCError
- XRPCRequest
- A class that represents a Request sent during XRPC communication.
-
XRPCResponse<
D> - The class represents the response from ATP server.
Enums
- HttpMethod
- HttpStatus
- Multicodec
- Represents multicodecs types.
- Protocol
- RetryReason
- The normalized category of a transient failure that a RetryStrategy may choose to retry.
Extensions
Functions
Typedefs
-
GetClient
= Future<
Response> Function(Uri url, {Map<String, String> ? headers}) -
A function type abstracted from
http.get, mainly for mocking at test time. -
PostClient
= Future<
Response> Function(Uri url, {Object? body, Encoding? encoding, Map<String, String> ? headers}) -
A function type abstracted from
http.post, mainly for mocking at test time. -
ResponseDataAdaptor
= Map<
String, dynamic> Function(dynamic data) - Function to convert response data to an specific structure.
-
ResponseDataBuilder<
T> = T Function(Map< String, Object?> json) - A function type that expresses the function of converting response body to model objects.
- WebSocketChannelFactory = WebSocketChannel Function(Uri uri)
-
A function type abstracted from
WebSocketChannel.connect, mainly for mocking at test time.
Exceptions / Errors
- InternalServerErrorException
- InvalidCidError
- Indicates that the passed CID could not be parsed.
- InvalidRequestException
- RateLimitExceededException
- XRPCException
- This exception indicates that an unexpected error occurred when communicating with the ATP server.
- XRPCNotSupportedException