bytes property
Uint8List
get
bytes
Returns an unmodifiable view of the byte representation of this CID.
The bytes are the CBOR tag-42 payload form: they include the leading
0x00 identity-multibase prefix. This is correct as a DAG-CBOR tag-42
CID payload, but is NOT a raw CID -- for CAR block indexing / raw CID
bytes you must drop the leading 0x00.
The returned view is unmodifiable so that external mutation cannot corrupt the CID or desync the lazily-cached hashCode.
Implementation
Uint8List get bytes => _unmodifiableBytes;