block property
The behaviors applied when the subject is blocking, blocked by, or has another block relationship with the user.
Implementation
final Map<ModerationBehaviorContext, ModerationBehavior> block;
The behaviors applied when the subject is blocking, blocked by, or has another block relationship with the user.
final Map<ModerationBehaviorContext, ModerationBehavior> block;