hasMutedWord function
bool
hasMutedWord({
- required List<
MutedWord> mutedWords, - required String text,
- List<
RichtextFacet> ? facets, - List<
String> ? outlineTags, - List<
String> ? languages, - ProfileViewBasic? actor,
Checks if the given text matches any of the muted words, returning a boolean if any matches are found.
Implementation
bool hasMutedWord({
required List<MutedWord> mutedWords,
required String text,
List<RichtextFacet>? facets,
List<String>? outlineTags,
List<String>? languages,
ProfileViewBasic? actor,
}) => matchMuteWords(
mutedWords: mutedWords,
text: text,
facets: facets,
outlineTags: outlineTags,
languages: languages,
actor: actor,
).isNotEmpty;