EnforcementView class abstract
The current enforcement state of a subject.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
EnforcementView({@Default.new('tools.ozone.inbox.defs#enforcementView') String $type, @EnforcementViewStateConverter() required EnforcementViewState state, @EnforcementViewScopeConverter() EnforcementViewScope? scope, @JsonKey.new(toJson: iso8601) DateTime? expiresAt, List<
String> ? labels, Map<String, dynamic> ? $unknown}) -
constfactory
-
EnforcementView.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
copyWith
→ $EnforcementViewCopyWith<
EnforcementView> -
Create a copy of EnforcementView
with the given fields replaced by the non-null parameter values.
no setterinherited
- expiresAt → DateTime?
-
no setterinherited
- hasExpiresAt → bool
-
Available on EnforcementView, provided by the EnforcementViewExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotExpiresAt → bool
-
Available on EnforcementView, provided by the EnforcementViewExtension extension
no setter - hasNotScope → bool
-
Available on EnforcementView, provided by the EnforcementViewExtension extension
no setter - hasScope → bool
-
Available on EnforcementView, provided by the EnforcementViewExtension extension
no setter -
labels
→ List<
String> ? -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → EnforcementViewScope?
-
no setterinherited
- state → EnforcementViewState
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_EnforcementView value)) → TResult -
Available on EnforcementView, provided by the EnforcementViewPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_EnforcementView value)?) → TResult? -
Available on EnforcementView, provided by the EnforcementViewPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_EnforcementView value)?, {required TResult orElse()}) → TResult -
Available on EnforcementView, provided by the EnforcementViewPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, EnforcementViewState state, EnforcementViewScope? scope, DateTime? expiresAt, List< String> ? labels, Map<String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on EnforcementView, provided by the EnforcementViewPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this EnforcementView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, EnforcementViewState state, EnforcementViewScope? scope, DateTime? expiresAt, List< String> ? labels, Map<String, dynamic> ? $unknown)) → TResult -
Available on EnforcementView, provided by the EnforcementViewPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, EnforcementViewState state, EnforcementViewScope? scope, DateTime? expiresAt, List< String> ? labels, Map<String, dynamic> ? $unknown)?) → TResult? -
Available on EnforcementView, provided by the EnforcementViewPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>