UNotificationTarget class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
- UNotificationTarget.reportRef({required ReportRef data})
-
constfactory
- UNotificationTarget.standingRef({required StandingRef data})
-
constfactory
- UNotificationTarget.subjectRef({required SubjectRef data})
-
constfactory
-
UNotificationTarget.unknown({required Map<
String, dynamic> data}) -
constfactory
Properties
- data → Object
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotReportRef → bool
-
Available on UNotificationTarget, provided by the UNotificationTargetExtension extension
no setter - isNotStandingRef → bool
-
Available on UNotificationTarget, provided by the UNotificationTargetExtension extension
no setter - isNotSubjectRef → bool
-
Available on UNotificationTarget, provided by the UNotificationTargetExtension extension
no setter - isNotUnknown → bool
-
Available on UNotificationTarget, provided by the UNotificationTargetExtension extension
no setter - isReportRef → bool
-
Available on UNotificationTarget, provided by the UNotificationTargetExtension extension
no setter - isStandingRef → bool
-
Available on UNotificationTarget, provided by the UNotificationTargetExtension extension
no setter - isSubjectRef → bool
-
Available on UNotificationTarget, provided by the UNotificationTargetExtension extension
no setter - isUnknown → bool
-
Available on UNotificationTarget, provided by the UNotificationTargetExtension extension
no setter - reportRef → ReportRef?
-
Available on UNotificationTarget, provided by the UNotificationTargetExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- standingRef → StandingRef?
-
Available on UNotificationTarget, provided by the UNotificationTargetExtension extension
no setter - subjectRef → SubjectRef?
-
Available on UNotificationTarget, provided by the UNotificationTargetExtension extension
no setter -
unknown
→ Map<
String, dynamic> ? -
Available on UNotificationTarget, provided by the UNotificationTargetExtension extension
no setter
Methods
-
map<
TResult extends Object?> ({required TResult reportRef(UNotificationTargetReportRef value), required TResult subjectRef(UNotificationTargetSubjectRef value), required TResult standingRef(UNotificationTargetStandingRef value), required TResult unknown(UNotificationTargetUnknown value)}) → TResult -
Available on UNotificationTarget, provided by the UNotificationTargetPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> ({TResult? reportRef(UNotificationTargetReportRef value)?, TResult? subjectRef(UNotificationTargetSubjectRef value)?, TResult? standingRef(UNotificationTargetStandingRef value)?, TResult? unknown(UNotificationTargetUnknown value)?}) → TResult? -
Available on UNotificationTarget, provided by the UNotificationTargetPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({TResult reportRef(UNotificationTargetReportRef value)?, TResult subjectRef(UNotificationTargetSubjectRef value)?, TResult standingRef(UNotificationTargetStandingRef value)?, TResult unknown(UNotificationTargetUnknown value)?, required TResult orElse()}) → TResult -
Available on UNotificationTarget, provided by the UNotificationTargetPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({TResult reportRef(ReportRef data)?, TResult subjectRef(SubjectRef data)?, TResult standingRef(StandingRef data)?, TResult unknown(Map< String, dynamic> data)?, required TResult orElse()}) → TResult -
Available on UNotificationTarget, provided by the UNotificationTargetPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> ({required TResult reportRef(ReportRef data), required TResult subjectRef(SubjectRef data), required TResult standingRef(StandingRef data), required TResult unknown(Map< String, dynamic> data)}) → TResult -
Available on UNotificationTarget, provided by the UNotificationTargetPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> ({TResult? reportRef(ReportRef data)?, TResult? subjectRef(SubjectRef data)?, TResult? standingRef(StandingRef data)?, TResult? unknown(Map< String, dynamic> data)?}) → TResult? -
Available on UNotificationTarget, provided by the UNotificationTargetPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited