isDelivered property

bool? get isDelivered
inherited

Indicates whether the email was successfully delivered to the user's inbox.

Implementation

@JsonKey(toJson: iso8601) DateTime? get strikeExpiresAt;/// Indicates whether the email was successfully delivered to the user's inbox.
 bool? get isDelivered;