UModEventViewSubject class sealed

Available extensions
Annotations
  • @freezed

Constructors

UModEventViewSubject.convoRef({required ConvoRef data})
const
factory
UModEventViewSubject.messageRef({required MessageRef data})
const
factory
UModEventViewSubject.repoRef({required RepoRef data})
const
factory
UModEventViewSubject.repoStrongRef({required RepoStrongRef data})
const
factory
UModEventViewSubject.unknown({required Map<String, dynamic> data})
const
factory

Properties

convoRef ConvoRef?

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
data Object
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isConvoRef bool

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
isMessageRef bool

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
isNotConvoRef bool

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
isNotMessageRef bool

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
isNotRepoRef bool

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
isNotRepoStrongRef bool

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
isNotUnknown bool

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
isRepoRef bool

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
isRepoStrongRef bool

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
isUnknown bool

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
messageRef MessageRef?

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
repoRef RepoRef?

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
repoStrongRef RepoStrongRef?

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknown Map<String, dynamic>?

Available on UModEventViewSubject, provided by the UModEventViewSubjectExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult repoRef(UModEventViewSubjectRepoRef value), required TResult repoStrongRef(UModEventViewSubjectRepoStrongRef value), required TResult messageRef(UModEventViewSubjectMessageRef value), required TResult convoRef(UModEventViewSubjectConvoRef value), required TResult unknown(UModEventViewSubjectUnknown value)}) → TResult

Available on UModEventViewSubject, provided by the UModEventViewSubjectPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? repoRef(UModEventViewSubjectRepoRef value)?, TResult? repoStrongRef(UModEventViewSubjectRepoStrongRef value)?, TResult? messageRef(UModEventViewSubjectMessageRef value)?, TResult? convoRef(UModEventViewSubjectConvoRef value)?, TResult? unknown(UModEventViewSubjectUnknown value)?}) → TResult?

Available on UModEventViewSubject, provided by the UModEventViewSubjectPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult repoRef(UModEventViewSubjectRepoRef value)?, TResult repoStrongRef(UModEventViewSubjectRepoStrongRef value)?, TResult messageRef(UModEventViewSubjectMessageRef value)?, TResult convoRef(UModEventViewSubjectConvoRef value)?, TResult unknown(UModEventViewSubjectUnknown value)?, required TResult orElse()}) → TResult

Available on UModEventViewSubject, provided by the UModEventViewSubjectPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult repoRef(RepoRef data)?, TResult repoStrongRef(RepoStrongRef data)?, TResult messageRef(MessageRef data)?, TResult convoRef(ConvoRef data)?, TResult unknown(Map<String, dynamic> data)?, required TResult orElse()}) → TResult

Available on UModEventViewSubject, provided by the UModEventViewSubjectPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult repoRef(RepoRef data), required TResult repoStrongRef(RepoStrongRef data), required TResult messageRef(MessageRef data), required TResult convoRef(ConvoRef data), required TResult unknown(Map<String, dynamic> data)}) → TResult

Available on UModEventViewSubject, provided by the UModEventViewSubjectPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? repoRef(RepoRef data)?, TResult? repoStrongRef(RepoStrongRef data)?, TResult? messageRef(MessageRef data)?, TResult? convoRef(ConvoRef data)?, TResult? unknown(Map<String, dynamic> data)?}) → TResult?

Available on UModEventViewSubject, provided by the UModEventViewSubjectPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited