QueueAssignModeratorInput class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
QueueAssignModeratorInput({required int queueId, required String did, Map<
String, dynamic> ? $unknown}) -
constfactory
-
QueueAssignModeratorInput.fromJson(Map<
String, Object?> json) -
factory
Properties
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
copyWith
→ $QueueAssignModeratorInputCopyWith<
QueueAssignModeratorInput> -
Create a copy of QueueAssignModeratorInput
with the given fields replaced by the non-null parameter values.
no setterinherited
- did → String
-
DID to be assigned.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- queueId → int
-
The ID of the queue to assign the user to.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_QueueAssignModeratorInput value)) → TResult -
Available on QueueAssignModeratorInput, provided by the QueueAssignModeratorInputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_QueueAssignModeratorInput value)?) → TResult? -
Available on QueueAssignModeratorInput, provided by the QueueAssignModeratorInputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_QueueAssignModeratorInput value)?, {required TResult orElse()}) → TResult -
Available on QueueAssignModeratorInput, provided by the QueueAssignModeratorInputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int queueId, String did, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on QueueAssignModeratorInput, provided by the QueueAssignModeratorInputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this QueueAssignModeratorInput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int queueId, String did, Map< String, dynamic> ? $unknown)) → TResult -
Available on QueueAssignModeratorInput, provided by the QueueAssignModeratorInputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int queueId, String did, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on QueueAssignModeratorInput, provided by the QueueAssignModeratorInputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>