QueueCreateQueueInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

QueueCreateQueueInput({required String name, @QueueCreateQueueSubjectTypesConverter() required List<QueueCreateQueueSubjectTypes> subjectTypes, String? collection, required List<String> reportTypes, String? description, Map<String, dynamic>? $unknown})
const
factory
QueueCreateQueueInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
collection String?
Collection name for record subjects. Required if subjectTypes includes 'record'.
no setterinherited
copyWith → $QueueCreateQueueInputCopyWith<QueueCreateQueueInput>
Create a copy of QueueCreateQueueInput with the given fields replaced by the non-null parameter values.
no setterinherited
description String?
Optional description of the queue
no setterinherited
hasCollection bool

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputExtension extension

no setter
hasDescription bool

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotCollection bool

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputExtension extension

no setter
hasNotDescription bool

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputExtension extension

no setter
name String
Display name for the queue (must be unique)
no setterinherited
reportTypes List<String>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subjectTypes List<QueueCreateQueueSubjectTypes>
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_QueueCreateQueueInput value)) → TResult

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_QueueCreateQueueInput value)?) → TResult?

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_QueueCreateQueueInput value)?, {required TResult orElse()}) → TResult

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String name, List<QueueCreateQueueSubjectTypes> subjectTypes, String? collection, List<String> reportTypes, String? description, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this QueueCreateQueueInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String name, List<QueueCreateQueueSubjectTypes> subjectTypes, String? collection, List<String> reportTypes, String? description, Map<String, dynamic>? $unknown)) → TResult

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String name, List<QueueCreateQueueSubjectTypes> subjectTypes, String? collection, List<String> reportTypes, String? description, Map<String, dynamic>? $unknown)?) → TResult?

Available on QueueCreateQueueInput, provided by the QueueCreateQueueInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>