AssignmentView class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
AssignmentView({@Default.new('tools.ozone.queue.defs#assignmentView') String $type, required int id, required String did, @MemberConverter() Member? moderator, @QueueViewConverter() required QueueView queue, required DateTime startAt, DateTime? endAt, Map<
String, dynamic> ? $unknown}) -
constfactory
-
AssignmentView.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
copyWith
→ $AssignmentViewCopyWith<
AssignmentView> -
Create a copy of AssignmentView
with the given fields replaced by the non-null parameter values.
no setterinherited
- did → String
-
no setterinherited
- endAt → DateTime?
-
no setterinherited
- hasEndAt → bool
-
Available on AssignmentView, provided by the AssignmentViewExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasModerator → bool
-
Available on AssignmentView, provided by the AssignmentViewExtension extension
no setter - hasNotEndAt → bool
-
Available on AssignmentView, provided by the AssignmentViewExtension extension
no setter - hasNotModerator → bool
-
Available on AssignmentView, provided by the AssignmentViewExtension extension
no setter - id → int
-
no setterinherited
- moderator → Member?
-
The moderator assigned to this queue
no setterinherited
- queue → QueueView
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startAt → DateTime
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_AssignmentView value)) → TResult -
Available on AssignmentView, provided by the AssignmentViewPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_AssignmentView value)?) → TResult? -
Available on AssignmentView, provided by the AssignmentViewPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_AssignmentView value)?, {required TResult orElse()}) → TResult -
Available on AssignmentView, provided by the AssignmentViewPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, int id, String did, Member? moderator, QueueView queue, DateTime startAt, DateTime? endAt, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on AssignmentView, provided by the AssignmentViewPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this AssignmentView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, int id, String did, Member? moderator, QueueView queue, DateTime startAt, DateTime? endAt, Map< String, dynamic> ? $unknown)) → TResult -
Available on AssignmentView, provided by the AssignmentViewPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, int id, String did, Member? moderator, QueueView queue, DateTime startAt, DateTime? endAt, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on AssignmentView, provided by the AssignmentViewPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>