QueueView class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
QueueView({@Default.new('tools.ozone.queue.defs#queueView') String $type, required int id, required String name, @QueueViewSubjectTypesConverter() required List<
QueueViewSubjectTypes> subjectTypes, String? collection, required List<String> reportTypes, String? description, required String createdBy, required DateTime createdAt, required DateTime updatedAt, required bool enabled, DateTime? deletedAt, @QueueStatsConverter() required QueueStats stats, Map<String, dynamic> ? $unknown}) -
constfactory
-
QueueView.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
- collection → String?
-
Collection name for record subjects (e.g., 'app.bsky.feed.post')
no setterinherited
-
copyWith
→ $QueueViewCopyWith<
QueueView> -
Create a copy of QueueView
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime
-
no setterinherited
- createdBy → String
-
DID of moderator who created this queue
no setterinherited
- deletedAt → DateTime?
-
When the queue was deleted, if applicable
no setterinherited
- description → String?
-
Optional description of the queue
no setterinherited
- enabled → bool
-
Whether this queue is currently active
no setterinherited
- hasCollection → bool
-
Available on QueueView, provided by the QueueViewExtension extension
no setter - hasDeletedAt → bool
-
Available on QueueView, provided by the QueueViewExtension extension
no setter - hasDescription → bool
-
Available on QueueView, provided by the QueueViewExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotCollection → bool
-
Available on QueueView, provided by the QueueViewExtension extension
no setter - hasNotDeletedAt → bool
-
Available on QueueView, provided by the QueueViewExtension extension
no setter - hasNotDescription → bool
-
Available on QueueView, provided by the QueueViewExtension extension
no setter - id → int
-
Queue ID
no setterinherited
- isEnabled → bool
-
Available on QueueView, provided by the QueueViewExtension extension
no setter - isNotEnabled → bool
-
Available on QueueView, provided by the QueueViewExtension extension
no setter - name → String
-
Display name of the queue
no setterinherited
-
reportTypes
→ List<
String> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stats → QueueStats
-
Statistics about this queue
no setterinherited
-
subjectTypes
→ List<
QueueViewSubjectTypes> -
no setterinherited
- updatedAt → DateTime
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_QueueView value)) → TResult -
Available on QueueView, provided by the QueueViewPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_QueueView value)?) → TResult? -
Available on QueueView, provided by the QueueViewPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_QueueView value)?, {required TResult orElse()}) → TResult -
Available on QueueView, provided by the QueueViewPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, int id, String name, List< QueueViewSubjectTypes> subjectTypes, String? collection, List<String> reportTypes, String? description, String createdBy, DateTime createdAt, DateTime updatedAt, bool enabled, DateTime? deletedAt, QueueStats stats, Map<String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on QueueView, provided by the QueueViewPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this QueueView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, int id, String name, List< QueueViewSubjectTypes> subjectTypes, String? collection, List<String> reportTypes, String? description, String createdBy, DateTime createdAt, DateTime updatedAt, bool enabled, DateTime? deletedAt, QueueStats stats, Map<String, dynamic> ? $unknown)) → TResult -
Available on QueueView, provided by the QueueViewPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, int id, String name, List< QueueViewSubjectTypes> subjectTypes, String? collection, List<String> reportTypes, String? description, String createdBy, DateTime createdAt, DateTime updatedAt, bool enabled, DateTime? deletedAt, QueueStats stats, Map<String, dynamic> ? $unknown)?) → TResult? -
Available on QueueView, provided by the QueueViewPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>