migrateToQueueId property
Optional: migrate all reports to this queue. If not specified, reports will be set to unassigned (-1).
Implementation
int get queueId;/// Optional: migrate all reports to this queue. If not specified, reports will be set to unassigned (-1).
int? get migrateToQueueId;