ReportAssignModeratorInput class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
copyWith
→ $ReportAssignModeratorInputCopyWith<
ReportAssignModeratorInput> -
Create a copy of ReportAssignModeratorInput
with the given fields replaced by the non-null parameter values.
no setterinherited
- did → String?
-
DID to be assigned. Defaults to the caller's DID. Admins may assign to any moderator.
no setterinherited
- hasDid → bool
-
Available on ReportAssignModeratorInput, provided by the ReportAssignModeratorInputExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hasNotDid → bool
-
Available on ReportAssignModeratorInput, provided by the ReportAssignModeratorInputExtension extension
no setter - hasNotQueueId → bool
-
Available on ReportAssignModeratorInput, provided by the ReportAssignModeratorInputExtension extension
no setter - hasQueueId → bool
-
Available on ReportAssignModeratorInput, provided by the ReportAssignModeratorInputExtension extension
no setter - isIsPermanent → bool
-
Available on ReportAssignModeratorInput, provided by the ReportAssignModeratorInputExtension extension
no setter - isNotIsPermanent → bool
-
Available on ReportAssignModeratorInput, provided by the ReportAssignModeratorInputExtension extension
no setter - isPermanent → bool?
-
When true, the assignment has no expiry (endAt is null). Throws AlreadyAssigned if another user already has a permanent assignment on this report.
no setterinherited
- queueId → int?
-
Optional queue ID to associate the assignment with. If not provided and the report has been assigned on a queue before, it will stay on that queue.
no setterinherited
- reportId → int
-
The ID of the report to assign.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ReportAssignModeratorInput value)) → TResult -
Available on ReportAssignModeratorInput, provided by the ReportAssignModeratorInputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ReportAssignModeratorInput value)?) → TResult? -
Available on ReportAssignModeratorInput, provided by the ReportAssignModeratorInputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ReportAssignModeratorInput value)?, {required TResult orElse()}) → TResult -
Available on ReportAssignModeratorInput, provided by the ReportAssignModeratorInputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int reportId, int? queueId, String? did, bool? isPermanent, Map< String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on ReportAssignModeratorInput, provided by the ReportAssignModeratorInputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ReportAssignModeratorInput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int reportId, int? queueId, String? did, bool? isPermanent, Map< String, dynamic> ? $unknown)) → TResult -
Available on ReportAssignModeratorInput, provided by the ReportAssignModeratorInputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int reportId, int? queueId, String? did, bool? isPermanent, Map< String, dynamic> ? $unknown)?) → TResult? -
Available on ReportAssignModeratorInput, provided by the ReportAssignModeratorInputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>