isAutomated property
Set true when this activity is triggered by an automated process. Defaults to false.
Implementation
String? get publicNote;/// Set true when this activity is triggered by an automated process. Defaults to false.
bool get isAutomated;