LiveStats class abstract

Live statistics for reports for the current calendar day, filterable by queue, moderator, or report type.

Available extensions
Annotations
  • @freezed

Constructors

LiveStats({@Default.new('tools.ozone.report.defs#liveStats') String $type, int? pendingCount, int? actionedCount, int? escalatedCount, int? inboundCount, int? actionRate, int? avgHandlingTimeSec, DateTime? lastUpdated, Map<String, dynamic>? $unknown})
const
factory
LiveStats.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
actionedCount int?
Number of reports closed today.
no setterinherited
actionRate int?
Percentage of reports actioned (actionedCount / inboundCount * 100), rounded to nearest integer.
no setterinherited
avgHandlingTimeSec int?
Average time in seconds from report creation (or moderator assignment) to close.
no setterinherited
copyWith → $LiveStatsCopyWith<LiveStats>
Create a copy of LiveStats with the given fields replaced by the non-null parameter values.
no setterinherited
escalatedCount int?
Number of reports escalated today.
no setterinherited
hasActionedCount bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
hasActionRate bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
hasAvgHandlingTimeSec bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
hasEscalatedCount bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasInboundCount bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
hasLastUpdated bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
hasNotActionedCount bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
hasNotActionRate bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
hasNotAvgHandlingTimeSec bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
hasNotEscalatedCount bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
hasNotInboundCount bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
hasNotLastUpdated bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
hasNotPendingCount bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
hasPendingCount bool

Available on LiveStats, provided by the LiveStatsExtension extension

no setter
inboundCount int?
Reports received today.
no setterinherited
lastUpdated DateTime?
When these statistics were last computed.
no setterinherited
pendingCount int?
Number of reports currently not closed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_LiveStats value)) → TResult

Available on LiveStats, provided by the LiveStatsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_LiveStats value)?) → TResult?

Available on LiveStats, provided by the LiveStatsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_LiveStats value)?, {required TResult orElse()}) → TResult

Available on LiveStats, provided by the LiveStatsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, int? pendingCount, int? actionedCount, int? escalatedCount, int? inboundCount, int? actionRate, int? avgHandlingTimeSec, DateTime? lastUpdated, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on LiveStats, provided by the LiveStatsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this LiveStats to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, int? pendingCount, int? actionedCount, int? escalatedCount, int? inboundCount, int? actionRate, int? avgHandlingTimeSec, DateTime? lastUpdated, Map<String, dynamic>? $unknown)) → TResult

Available on LiveStats, provided by the LiveStatsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, int? pendingCount, int? actionedCount, int? escalatedCount, int? inboundCount, int? actionRate, int? avgHandlingTimeSec, DateTime? lastUpdated, Map<String, dynamic>? $unknown)?) → TResult?

Available on LiveStats, provided by the LiveStatsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>