LiveStats constructor
const
LiveStats({
- @Default.new('tools.ozone.report.defs#liveStats') String $type,
- int? pendingCount,
- int? closedCount,
- int? actionedCount,
- int? acknowledgedCount,
- int? escalatedCount,
- int? inboundCount,
- int? labelActionCount,
- int? tagActionCount,
- int? takedownActionCount,
- int? ahtDurationSec,
- int? ahtSampleCount,
- int? resolutionDurationSec,
- int? resolutionSampleCount,
- int? actionRate,
- int? avgHandlingTimeSec,
- int? avgResolutionTimeSec,
- @JsonKey.new(toJson: iso8601) DateTime? lastUpdated,
- Map<
String, dynamic> ? $unknown,
Implementation
@JsonSerializable(includeIfNull: false)
const factory LiveStats({
@Default('tools.ozone.report.defs#liveStats') String $type,
/// Number of reports currently not closed.
int? pendingCount,
/// Number of close transitions.
int? closedCount,
/// Number of closures whose last report action is label, tag, or takedown.
int? actionedCount,
/// Number of closures whose last report action is not label, tag, or takedown.
int? acknowledgedCount,
/// Number of reports escalated.
int? escalatedCount,
/// Reports received.
int? inboundCount,
/// Closures whose last report action is a label event.
int? labelActionCount,
/// Closures whose last report action is a tag event.
int? tagActionCount,
/// Closures whose last report action is a takedown event.
int? takedownActionCount,
/// Sum of report assignment-to-close seconds.
int? ahtDurationSec,
/// Number of assigned closed-report samples in ahtDurationSec.
int? ahtSampleCount,
/// Sum of report creation-to-close seconds.
int? resolutionDurationSec,
/// Number of closed-report samples in resolutionDurationSec.
int? resolutionSampleCount,
/// Percentage of closures actioned (actionedCount / closedCount * 100), rounded to nearest integer.
int? actionRate,
/// Average handling time in seconds from report assignment to close.
int? avgHandlingTimeSec,
/// Average resolution time in seconds from report creation to close.
int? avgResolutionTimeSec,
/// When these statistics were last computed.
@JsonKey(toJson: iso8601) DateTime? lastUpdated,
Map<String, dynamic>? $unknown,
}) = _LiveStats;