actionedCount property
Number of closures whose last report action is label, tag, or takedown.
Implementation
int? get closedCount;/// Number of closures whose last report action is label, tag, or takedown.
int? get actionedCount;
Number of closures whose last report action is label, tag, or takedown.
int? get closedCount;/// Number of closures whose last report action is label, tag, or takedown.
int? get actionedCount;