ReportView class abstract

Available extensions
Annotations
  • @freezed

Constructors

ReportView({@Default.new('tools.ozone.report.defs#reportView') String $type, required int id, required int eventId, @ReportViewStatusConverter() required ReportViewStatus status, @SubjectViewConverter() required SubjectView subject, @ReasonTypeConverter() required ReasonType reportType, required String reportedBy, @SubjectViewConverter() required SubjectView reporter, String? comment, required DateTime createdAt, DateTime? updatedAt, DateTime? queuedAt, List<int>? actionEventIds, @ModEventViewConverter() List<ModEventView>? actions, String? actionNote, @SubjectStatusViewConverter() SubjectStatusView? subjectStatus, int? relatedReportCount, @ReportAssignmentConverter() ReportAssignment? assignment, @QueueViewConverter() QueueView? queue, bool? isMuted, Map<String, dynamic>? $unknown})
const
factory
ReportView.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
actionEventIds List<int>?
no setterinherited
actionNote String?
Note sent to reporter when report was actioned
no setterinherited
actions List<ModEventView>?
no setterinherited
assignment ReportAssignment?
Information about moderator currently assigned to this report (if any)
no setterinherited
comment String?
Comment provided by the reporter
no setterinherited
copyWith → $ReportViewCopyWith<ReportView>
Create a copy of ReportView with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime
When the report was created
no setterinherited
eventId int
ID of the moderation event that created this report
no setterinherited
hasActionNote bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasAssignment bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasComment bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotActionNote bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasNotAssignment bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasNotComment bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasNotQueue bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasNotQueuedAt bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasNotRelatedReportCount bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasNotSubjectStatus bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasNotUpdatedAt bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasQueue bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasQueuedAt bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasRelatedReportCount bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasSubjectStatus bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
hasUpdatedAt bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
id int
Report ID
no setterinherited
isIsMuted bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
isMuted bool?
Whether this report is muted. A report is muted if the reporter was muted or the subject was muted at the time the report was created.
no setterinherited
isNotIsMuted bool

Available on ReportView, provided by the ReportViewExtension extension

no setter
queue QueueView?
The queue this report is assigned to (if any)
no setterinherited
queuedAt DateTime?
When the report was assigned to its current queue
no setterinherited
relatedReportCount int?
Number of other pending reports on the same subject
no setterinherited
reportedBy String
DID of the user who made the report
no setterinherited
reporter SubjectView
Full subject view of the reporter account
no setterinherited
reportType ReasonType
Type of report
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ReportViewStatus
Current status of the report
no setterinherited
subject SubjectView
The subject that was reported with full details
no setterinherited
subjectStatus SubjectStatusView?
Current status of the reported subject
no setterinherited
updatedAt DateTime?
When the report was last updated
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReportView value)) → TResult

Available on ReportView, provided by the ReportViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReportView value)?) → TResult?

Available on ReportView, provided by the ReportViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReportView value)?, {required TResult orElse()}) → TResult

Available on ReportView, provided by the ReportViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, int id, int eventId, ReportViewStatus status, SubjectView subject, ReasonType reportType, String reportedBy, SubjectView reporter, String? comment, DateTime createdAt, DateTime? updatedAt, DateTime? queuedAt, List<int>? actionEventIds, List<ModEventView>? actions, String? actionNote, SubjectStatusView? subjectStatus, int? relatedReportCount, ReportAssignment? assignment, QueueView? queue, bool? isMuted, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ReportView, provided by the ReportViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ReportView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, int id, int eventId, ReportViewStatus status, SubjectView subject, ReasonType reportType, String reportedBy, SubjectView reporter, String? comment, DateTime createdAt, DateTime? updatedAt, DateTime? queuedAt, List<int>? actionEventIds, List<ModEventView>? actions, String? actionNote, SubjectStatusView? subjectStatus, int? relatedReportCount, ReportAssignment? assignment, QueueView? queue, bool? isMuted, Map<String, dynamic>? $unknown)) → TResult

Available on ReportView, provided by the ReportViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, int id, int eventId, ReportViewStatus status, SubjectView subject, ReasonType reportType, String reportedBy, SubjectView reporter, String? comment, DateTime createdAt, DateTime? updatedAt, DateTime? queuedAt, List<int>? actionEventIds, List<ModEventView>? actions, String? actionNote, SubjectStatusView? subjectStatus, int? relatedReportCount, ReportAssignment? assignment, QueueView? queue, bool? isMuted, Map<String, dynamic>? $unknown)?) → TResult?

Available on ReportView, provided by the ReportViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>