ReportView constructor
- @JsonSerializable.new(includeIfNull: false)
const
ReportView(
{ - @Default.new('tools.ozone.report.defs#reportView') String $type,
- required int id,
- required int eventId,
- @ReportViewStatusConverter() required ReportViewStatus status,
- @SubjectViewConverter() required SubjectView subject,
- @ReasonTypeConverter() required ReasonType reportType,
- required String reportedBy,
- @SubjectViewConverter() required SubjectView reporter,
- required DateTime createdAt,
- DateTime? updatedAt,
- DateTime? queuedAt,
- List<int>? actionEventIds,
- @ModEventViewConverter() List<ModEventView>? actions,
- String? actionNote,
- @SubjectStatusViewConverter() SubjectStatusView? subjectStatus,
- int? relatedReportCount,
- @ReportAssignmentConverter() ReportAssignment? assignment,
- @QueueViewConverter() QueueView? queue,
- bool? isMuted,
- Map<String, dynamic>? $unknown,
})
Implementation
@JsonSerializable(includeIfNull: false)
const factory ReportView({
@Default('tools.ozone.report.defs#reportView') String $type,
/// Report ID
required int id,
/// ID of the moderation event that created this report
required int eventId,
/// Current status of the report
@ReportViewStatusConverter() required ReportViewStatus status,
/// The subject that was reported with full details
@SubjectViewConverter() required SubjectView subject,
/// Type of report
@ReasonTypeConverter() required ReasonType reportType,
/// DID of the user who made the report
required String reportedBy,
/// Full subject view of the reporter account
@SubjectViewConverter() required SubjectView reporter,
/// Comment provided by the reporter
String? comment,
/// When the report was created
required DateTime createdAt,
/// When the report was last updated
DateTime? updatedAt,
/// When the report was assigned to its current queue
DateTime? queuedAt,
List<int>? actionEventIds,
@ModEventViewConverter() List<ModEventView>? actions,
/// Note sent to reporter when report was actioned
String? actionNote,
/// Current status of the reported subject
@SubjectStatusViewConverter() SubjectStatusView? subjectStatus,
/// Number of other pending reports on the same subject
int? relatedReportCount,
/// Information about moderator currently assigned to this report (if any)
@ReportAssignmentConverter() ReportAssignment? assignment,
/// The queue this report is assigned to (if any)
@QueueViewConverter() QueueView? queue,
/// Whether this report is muted. A report is muted if the reporter was muted or the subject was muted at the time the report was created.
bool? isMuted,
Map<String, dynamic>? $unknown,
}) = _ReportView;