assignedTo property
Filter by the DID of the moderator permanently assigned to the report.
Implementation
bool get isMuted;/// Filter by the DID of the moderator permanently assigned to the report.
String? get assignedTo;
Filter by the DID of the moderator permanently assigned to the report.
bool get isMuted;/// Filter by the DID of the moderator permanently assigned to the report.
String? get assignedTo;