InboxService class base

tools.ozone.inbox.*

Constructors

InboxService(ServiceContext ctx)

Properties

ctx → ServiceContext
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

appealActionedSubject({UInboxAppealActionedSubjectAction? action, required UInboxAppealActionedSubjectSubject subject, String? reason, ModTool? modTool, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<SubjectView>>
Appeal a moderation action affecting the user's account or content.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited