getActionedSubject method
Get a subject belonging to the authenticated account, including its moderation action history from this moderation service.
Implementation
Future<XRPCResponse<SubjectViewDetail>> getActionedSubject({
String? did,
required String subject,
int? limit,
String? cursor,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await toolsOzoneInboxGetActionedSubject(
did: did,
subject: subject,
limit: limit,
cursor: cursor,
$ctx: ctx,
$service: $service,
$headers: $headers,
$unknown: $unknown,
);