QueueService class base
tools.ozone.queue.*
Constructors
Properties
- ctx → ServiceContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
assignModerator(
{required int queueId, required String did, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< AssignmentView> > - Assign a user to a queue.
-
createQueue(
{required String name, required List< QueueCreateQueueSubjectTypes> subjectTypes, String? collection, required List<String> reportTypes, String? description, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< QueueCreateQueueOutput> > - Create a new moderation queue. Will fail if the queue configuration conflicts with an existing queue.
-
deleteQueue(
{required int queueId, int? migrateToQueueId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< QueueDeleteQueueOutput> > - Delete a moderation queue. Optionally migrate reports to another queue.
-
getAssignments(
{bool? onlyActive, List< int> ? queueIds, List<String> ? dids, int? limit, String? cursor, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< QueueGetAssignmentsOutput> > - Get moderator assignments, optionally filtered by active status, queue, or moderator.
-
listQueues(
{bool? enabled, String? subjectType, String? collection, List< String> ? reportTypes, int? limit, String? cursor, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< QueueListQueuesOutput> > - List all configured moderation queues with statistics.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
routeReports(
{required int startReportId, required int endReportId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< QueueRouteReportsOutput> > - Route reports within an ID range to matching queues based.
-
toString(
) → String -
A string representation of this object.
inherited
-
unassignModerator(
{required int queueId, required String did, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< EmptyData> > - Remove a user's assignment from a queue.
-
updateQueue(
{required int queueId, String? name, bool? enabled, String? description, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< QueueUpdateQueueOutput> > - Update queue properties. Currently only supports updating the name and enabled status to prevent configuration conflicts.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited