ReportService class base
tools.ozone.report.*
Constructors
Properties
- ctx → ServiceContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
assignModerator(
{required int reportId, int? queueId, String? did, bool? isPermanent, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< AssignmentView> > - Assign a report to a user. Defaults to the caller. Admins may assign to any moderator.
-
createActivity(
{required int reportId, required UReportCreateActivityActivity activity, String? internalNote, String? publicNote, bool? isAutomated, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ReportCreateActivityOutput> > - Register an activity on a report. For state-change activity types, validates the transition and updates report.status atomically.
-
getAssignments(
{bool? onlyActive, List< int> ? reportIds, List<String> ? dids, int? limit, String? cursor, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ReportGetAssignmentsOutput> > - Get assignments for reports.
-
getHistoricalStats(
{int? queueId, String? moderatorDid, List< String> ? reportTypes, DateTime? startDate, DateTime? endDate, int? limit, String? cursor, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ReportGetHistoricalStatsOutput> > - Get historical daily report statistics. Returns a paginated list of daily stat snapshots, newest first. Filter by queue, moderator, or report type.
-
getLatestReport(
{String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ReportGetLatestReportOutput> > - Get the most recent report.
-
getLiveStats(
{int? queueId, String? moderatorDid, List< String> ? reportTypes, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ReportGetLiveStatsOutput> > - Get live report statistics from the past 24 hours. Filter by queue, moderator, or report type. Omit all parameters for aggregate stats.
-
getReport(
{required int id, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ReportView> > - Get details about a single moderation report by ID.
-
listActivities(
{required int reportId, int? limit, String? cursor, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ReportListActivitiesOutput> > - List all activities for a report, sorted most-recent-first.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryReports(
{int? queueId, List< String> ? reportTypes, required ReportQueryReportsStatus status, String? subject, String? did, ReportQueryReportsSubjectType? subjectType, List<String> ? collections, DateTime? reportedAfter, DateTime? reportedBefore, bool? isMuted, String? assignedTo, String? sortField, String? sortDirection, int? limit, String? cursor, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ReportQueryReportsOutput> > - View moderation reports. Reports are individual instances of content being reported, as opposed to subject statuses which aggregate reports at the subject level.
-
reassignQueue(
{required int reportId, required int queueId, String? comment, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< ReportReassignQueueOutput> > - Manually reassign a report to a different queue (or unassign it). Records a queueActivity entry on the report.
-
refreshStats(
{required String startDate, required String endDate, List< int> ? queueIds, String? $service, Map<String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< EmptyData> > - Recompute report statistics for a date range. Useful for backfilling after failures or data corrections.
-
toString(
) → String -
A string representation of this object.
inherited
-
unassignModerator(
{required int reportId, String? $service, Map< String, String> ? $headers, Map<String, String> ? $unknown}) → Future<XRPCResponse< AssignmentView> > - Remove report assignment.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited