queryReports method
Future<XRPCResponse<ReportQueryReportsOutput> >
queryReports({
- int? queueId,
- List<
String> ? reportTypes, - required ReportQueryReportsStatus status,
- String? subject,
- String? did,
- ReportQueryReportsSubjectType? subjectType,
- List<
String> ? collections, - DateTime? reportedAfter,
- DateTime? reportedBefore,
- bool? isMuted,
- String? assignedTo,
- String? sortField,
- String? sortDirection,
- int? limit,
- String? cursor,
- String? $service,
- Map<
String, String> ? $headers, - Map<
String, String> ? $unknown,
View moderation reports. Reports are individual instances of content being reported, as opposed to subject statuses which aggregate reports at the subject level.
Implementation
Future<XRPCResponse<ReportQueryReportsOutput>> queryReports({
int? queueId,
List<String>? reportTypes,
required ReportQueryReportsStatus status,
String? subject,
String? did,
ReportQueryReportsSubjectType? subjectType,
List<String>? collections,
DateTime? reportedAfter,
DateTime? reportedBefore,
bool? isMuted,
String? assignedTo,
String? sortField,
String? sortDirection,
int? limit,
String? cursor,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await toolsOzoneReportQueryReports(
queueId: queueId,
reportTypes: reportTypes,
status: status,
subject: subject,
did: did,
subjectType: subjectType,
collections: collections,
reportedAfter: reportedAfter,
reportedBefore: reportedBefore,
isMuted: isMuted,
assignedTo: assignedTo,
sortField: sortField,
sortDirection: sortDirection,
limit: limit,
cursor: cursor,
$ctx: ctx,
$service: $service,
$headers: $headers,
$unknown: $unknown,
);