toolsOzoneReportQueryReports function
Future<XRPCResponse<ReportQueryReportsOutput> >
toolsOzoneReportQueryReports({
- int? queueId,
- List<
String> ? reportTypes, - required ReportQueryReportsStatus status,
- String? subject,
- String? did,
- ReportQueryReportsSubjectType? subjectType,
- List<
String> ? collections, - DateTime? reportedAfter,
- DateTime? reportedBefore,
- bool? isMuted,
- String? assignedTo,
- String? sortField,
- String? sortDirection,
- int? limit,
- String? cursor,
- required ServiceContext $ctx,
- String? $service,
- Map<
String, String> ? $headers, - Map<
String, String> ? $unknown,
View moderation reports. Reports are individual instances of content being reported, as opposed to subject statuses which aggregate reports at the subject level.
Implementation
Future<XRPCResponse<ReportQueryReportsOutput>> toolsOzoneReportQueryReports({
int? queueId,
List<String>? reportTypes,
required ReportQueryReportsStatus status,
String? subject,
String? did,
ReportQueryReportsSubjectType? subjectType,
List<String>? collections,
DateTime? reportedAfter,
DateTime? reportedBefore,
bool? isMuted,
String? assignedTo,
String? sortField,
String? sortDirection,
int? limit,
String? cursor,
required ServiceContext $ctx,
String? $service,
Map<String, String>? $headers,
Map<String, String>? $unknown,
}) async => await $ctx.get(
ns.toolsOzoneReportQueryReports,
service: $service,
headers: $headers,
parameters: {
...?$unknown,
if (queueId != null) 'queueId': queueId,
if (reportTypes != null) 'reportTypes': reportTypes,
'status': status.toJson(),
if (subject != null) 'subject': subject,
if (did != null) 'did': did,
if (subjectType != null) 'subjectType': subjectType.toJson(),
if (collections != null) 'collections': collections,
if (reportedAfter != null) 'reportedAfter': iso8601(reportedAfter),
if (reportedBefore != null) 'reportedBefore': iso8601(reportedBefore),
if (isMuted != null) 'isMuted': isMuted,
if (assignedTo != null) 'assignedTo': assignedTo,
if (sortField != null) 'sortField': sortField,
if (sortDirection != null) 'sortDirection': sortDirection,
if (limit != null) 'limit': limit,
if (cursor != null) 'cursor': cursor,
},
to: const ReportQueryReportsOutputConverter().fromJson,
);