revokeReason property
Describes the reason for revocation, also indicating that the verification is no longer valid.
Implementation
@JsonKey(toJson: iso8601) DateTime get createdAt;/// Describes the reason for revocation, also indicating that the verification is no longer valid.
String? get revokeReason;